module Emojis exposing (Category, Emoji, emojiDict)

import Dict exposing (Dict)



-- typedef for a category of emojis. in the
-- main file, we render emojis by category.


type alias Category =
    { id : String -- short name for category
    , name : String -- display name for category
    , emojis : List String -- list of emoji names in category
    }



-- final data structure for an emoji


type alias Emoji =
    { name : String -- name of emoji
    , native : String -- actual emoji (not codepoint)
    , sortOrder : Int -- Global sorting index for all emoji, based on Unicode CLDR ordering
    , skinVariations : Dict String String -- emojis of skin variations
    , keywords : List String -- keywords taken from the CLDR annotations
    }


emojiDict : Dict String Emoji
emojiDict =
    Dict.fromList
        [ ( "hash", { name = "HASH KEY", native = "#️⃣", sortOrder = 1521, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "keycap_star", { name = "KEYCAP: *", native = "*️⃣", sortOrder = 1522, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "zero", { name = "KEYCAP 0", native = "0️⃣", sortOrder = 1523, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "one", { name = "KEYCAP 1", native = "1️⃣", sortOrder = 1524, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "two", { name = "KEYCAP 2", native = "2️⃣", sortOrder = 1525, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "three", { name = "KEYCAP 3", native = "3️⃣", sortOrder = 1526, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "four", { name = "KEYCAP 4", native = "4️⃣", sortOrder = 1527, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "five", { name = "KEYCAP 5", native = "5️⃣", sortOrder = 1528, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "six", { name = "KEYCAP 6", native = "6️⃣", sortOrder = 1529, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "seven", { name = "KEYCAP 7", native = "7️⃣", sortOrder = 1530, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "eight", { name = "KEYCAP 8", native = "8️⃣", sortOrder = 1531, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "nine", { name = "KEYCAP 9", native = "9️⃣", sortOrder = 1532, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "copyright", { name = "COPYRIGHT SIGN", native = "©️", sortOrder = 1518, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "registered", { name = "REGISTERED SIGN", native = "®️", sortOrder = 1519, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "mahjong", { name = "MAHJONG TILE RED DRAGON", native = "🀄", sortOrder = 1114, skinVariations = Dict.fromList [], keywords = [ "game", "mahjong", "mahjong red dragon", "red" ] } )
        , ( "black_joker", { name = "PLAYING CARD BLACK JOKER", native = "🃏", sortOrder = 1113, skinVariations = Dict.fromList [], keywords = [ "card", "game", "joker", "wildcard" ] } )
        , ( "a", { name = "NEGATIVE SQUARED LATIN CAPITAL LETTER A", native = "🅰️", sortOrder = 1539, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "b", { name = "NEGATIVE SQUARED LATIN CAPITAL LETTER B", native = "🅱️", sortOrder = 1541, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "o2", { name = "NEGATIVE SQUARED LATIN CAPITAL LETTER O", native = "🅾️", sortOrder = 1550, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "parking", { name = "NEGATIVE SQUARED LATIN CAPITAL LETTER P", native = "🅿️", sortOrder = 1552, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ab", { name = "NEGATIVE SQUARED AB", native = "🆎", sortOrder = 1540, skinVariations = Dict.fromList [], keywords = [ "AB", "AB button (blood type)", "blood type" ] } )
        , ( "cl", { name = "SQUARED CL", native = "🆑", sortOrder = 1542, skinVariations = Dict.fromList [], keywords = [ "CL", "CL button" ] } )
        , ( "cool", { name = "SQUARED COOL", native = "🆒", sortOrder = 1543, skinVariations = Dict.fromList [], keywords = [ "COOL", "COOL button" ] } )
        , ( "free", { name = "SQUARED FREE", native = "🆓", sortOrder = 1544, skinVariations = Dict.fromList [], keywords = [ "FREE", "FREE button" ] } )
        , ( "id", { name = "SQUARED ID", native = "🆔", sortOrder = 1546, skinVariations = Dict.fromList [], keywords = [ "ID", "ID button", "identity" ] } )
        , ( "new", { name = "SQUARED NEW", native = "🆕", sortOrder = 1548, skinVariations = Dict.fromList [], keywords = [ "NEW", "NEW button" ] } )
        , ( "ng", { name = "SQUARED NG", native = "🆖", sortOrder = 1549, skinVariations = Dict.fromList [], keywords = [ "NG", "NG button" ] } )
        , ( "ok", { name = "SQUARED OK", native = "🆗", sortOrder = 1551, skinVariations = Dict.fromList [], keywords = [ "OK", "OK button" ] } )
        , ( "sos", { name = "SQUARED SOS", native = "🆘", sortOrder = 1553, skinVariations = Dict.fromList [], keywords = [ "help", "SOS", "SOS button" ] } )
        , ( "up", { name = "SQUARED UP WITH EXCLAMATION MARK", native = "🆙", sortOrder = 1554, skinVariations = Dict.fromList [], keywords = [ "mark", "UP", "UP!", "UP! button" ] } )
        , ( "vs", { name = "SQUARED VS", native = "🆚", sortOrder = 1555, skinVariations = Dict.fromList [], keywords = [ "versus", "VS", "VS button" ] } )
        , ( "flag-ac", { name = "Ascension Island Flag", native = "🇦🇨", sortOrder = 1615, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ad", { name = "Andorra Flag", native = "🇦🇩", sortOrder = 1616, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ae", { name = "United Arab Emirates Flag", native = "🇦🇪", sortOrder = 1617, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-af", { name = "Afghanistan Flag", native = "🇦🇫", sortOrder = 1618, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ag", { name = "Antigua & Barbuda Flag", native = "🇦🇬", sortOrder = 1619, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ai", { name = "Anguilla Flag", native = "🇦🇮", sortOrder = 1620, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-al", { name = "Albania Flag", native = "🇦🇱", sortOrder = 1621, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-am", { name = "Armenia Flag", native = "🇦🇲", sortOrder = 1622, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ao", { name = "Angola Flag", native = "🇦🇴", sortOrder = 1623, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-aq", { name = "Antarctica Flag", native = "🇦🇶", sortOrder = 1624, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ar", { name = "Argentina Flag", native = "🇦🇷", sortOrder = 1625, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-as", { name = "American Samoa Flag", native = "🇦🇸", sortOrder = 1626, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-at", { name = "Austria Flag", native = "🇦🇹", sortOrder = 1627, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-au", { name = "Australia Flag", native = "🇦🇺", sortOrder = 1628, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-aw", { name = "Aruba Flag", native = "🇦🇼", sortOrder = 1629, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ax", { name = "Åland Islands Flag", native = "🇦🇽", sortOrder = 1630, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-az", { name = "Azerbaijan Flag", native = "🇦🇿", sortOrder = 1631, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ba", { name = "Bosnia & Herzegovina Flag", native = "🇧🇦", sortOrder = 1632, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bb", { name = "Barbados Flag", native = "🇧🇧", sortOrder = 1633, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bd", { name = "Bangladesh Flag", native = "🇧🇩", sortOrder = 1634, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-be", { name = "Belgium Flag", native = "🇧🇪", sortOrder = 1635, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bf", { name = "Burkina Faso Flag", native = "🇧🇫", sortOrder = 1636, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bg", { name = "Bulgaria Flag", native = "🇧🇬", sortOrder = 1637, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bh", { name = "Bahrain Flag", native = "🇧🇭", sortOrder = 1638, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bi", { name = "Burundi Flag", native = "🇧🇮", sortOrder = 1639, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bj", { name = "Benin Flag", native = "🇧🇯", sortOrder = 1640, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bl", { name = "St. Barthélemy Flag", native = "🇧🇱", sortOrder = 1641, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bm", { name = "Bermuda Flag", native = "🇧🇲", sortOrder = 1642, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bn", { name = "Brunei Flag", native = "🇧🇳", sortOrder = 1643, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bo", { name = "Bolivia Flag", native = "🇧🇴", sortOrder = 1644, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bq", { name = "Caribbean Netherlands Flag", native = "🇧🇶", sortOrder = 1645, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-br", { name = "Brazil Flag", native = "🇧🇷", sortOrder = 1646, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bs", { name = "Bahamas Flag", native = "🇧🇸", sortOrder = 1647, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bt", { name = "Bhutan Flag", native = "🇧🇹", sortOrder = 1648, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bv", { name = "Bouvet Island Flag", native = "🇧🇻", sortOrder = 1649, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bw", { name = "Botswana Flag", native = "🇧🇼", sortOrder = 1650, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-by", { name = "Belarus Flag", native = "🇧🇾", sortOrder = 1651, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-bz", { name = "Belize Flag", native = "🇧🇿", sortOrder = 1652, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ca", { name = "Canada Flag", native = "🇨🇦", sortOrder = 1653, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cc", { name = "Cocos (Keeling) Islands Flag", native = "🇨🇨", sortOrder = 1654, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cd", { name = "Congo - Kinshasa Flag", native = "🇨🇩", sortOrder = 1655, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cf", { name = "Central African Republic Flag", native = "🇨🇫", sortOrder = 1656, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cg", { name = "Congo - Brazzaville Flag", native = "🇨🇬", sortOrder = 1657, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ch", { name = "Switzerland Flag", native = "🇨🇭", sortOrder = 1658, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ci", { name = "Côte d’Ivoire Flag", native = "🇨🇮", sortOrder = 1659, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ck", { name = "Cook Islands Flag", native = "🇨🇰", sortOrder = 1660, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cl", { name = "Chile Flag", native = "🇨🇱", sortOrder = 1661, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cm", { name = "Cameroon Flag", native = "🇨🇲", sortOrder = 1662, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "cn", { name = "China Flag", native = "🇨🇳", sortOrder = 1663, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-co", { name = "Colombia Flag", native = "🇨🇴", sortOrder = 1664, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cp", { name = "Clipperton Island Flag", native = "🇨🇵", sortOrder = 1665, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cr", { name = "Costa Rica Flag", native = "🇨🇷", sortOrder = 1666, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cu", { name = "Cuba Flag", native = "🇨🇺", sortOrder = 1667, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cv", { name = "Cape Verde Flag", native = "🇨🇻", sortOrder = 1668, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cw", { name = "Curaçao Flag", native = "🇨🇼", sortOrder = 1669, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cx", { name = "Christmas Island Flag", native = "🇨🇽", sortOrder = 1670, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cy", { name = "Cyprus Flag", native = "🇨🇾", sortOrder = 1671, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-cz", { name = "Czechia Flag", native = "🇨🇿", sortOrder = 1672, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "de", { name = "Germany Flag", native = "🇩🇪", sortOrder = 1673, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-dg", { name = "Diego Garcia Flag", native = "🇩🇬", sortOrder = 1674, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-dj", { name = "Djibouti Flag", native = "🇩🇯", sortOrder = 1675, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-dk", { name = "Denmark Flag", native = "🇩🇰", sortOrder = 1676, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-dm", { name = "Dominica Flag", native = "🇩🇲", sortOrder = 1677, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-do", { name = "Dominican Republic Flag", native = "🇩🇴", sortOrder = 1678, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-dz", { name = "Algeria Flag", native = "🇩🇿", sortOrder = 1679, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ea", { name = "Ceuta & Melilla Flag", native = "🇪🇦", sortOrder = 1680, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ec", { name = "Ecuador Flag", native = "🇪🇨", sortOrder = 1681, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ee", { name = "Estonia Flag", native = "🇪🇪", sortOrder = 1682, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-eg", { name = "Egypt Flag", native = "🇪🇬", sortOrder = 1683, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-eh", { name = "Western Sahara Flag", native = "🇪🇭", sortOrder = 1684, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-er", { name = "Eritrea Flag", native = "🇪🇷", sortOrder = 1685, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "es", { name = "Spain Flag", native = "🇪🇸", sortOrder = 1686, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-et", { name = "Ethiopia Flag", native = "🇪🇹", sortOrder = 1687, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-eu", { name = "European Union Flag", native = "🇪🇺", sortOrder = 1688, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-fi", { name = "Finland Flag", native = "🇫🇮", sortOrder = 1689, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-fj", { name = "Fiji Flag", native = "🇫🇯", sortOrder = 1690, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-fk", { name = "Falkland Islands Flag", native = "🇫🇰", sortOrder = 1691, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-fm", { name = "Micronesia Flag", native = "🇫🇲", sortOrder = 1692, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-fo", { name = "Faroe Islands Flag", native = "🇫🇴", sortOrder = 1693, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "fr", { name = "France Flag", native = "🇫🇷", sortOrder = 1694, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ga", { name = "Gabon Flag", native = "🇬🇦", sortOrder = 1695, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "gb", { name = "United Kingdom Flag", native = "🇬🇧", sortOrder = 1696, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gd", { name = "Grenada Flag", native = "🇬🇩", sortOrder = 1697, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ge", { name = "Georgia Flag", native = "🇬🇪", sortOrder = 1698, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gf", { name = "French Guiana Flag", native = "🇬🇫", sortOrder = 1699, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gg", { name = "Guernsey Flag", native = "🇬🇬", sortOrder = 1700, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gh", { name = "Ghana Flag", native = "🇬🇭", sortOrder = 1701, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gi", { name = "Gibraltar Flag", native = "🇬🇮", sortOrder = 1702, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gl", { name = "Greenland Flag", native = "🇬🇱", sortOrder = 1703, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gm", { name = "Gambia Flag", native = "🇬🇲", sortOrder = 1704, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gn", { name = "Guinea Flag", native = "🇬🇳", sortOrder = 1705, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gp", { name = "Guadeloupe Flag", native = "🇬🇵", sortOrder = 1706, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gq", { name = "Equatorial Guinea Flag", native = "🇬🇶", sortOrder = 1707, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gr", { name = "Greece Flag", native = "🇬🇷", sortOrder = 1708, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gs", { name = "South Georgia & South Sandwich Islands Flag", native = "🇬🇸", sortOrder = 1709, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gt", { name = "Guatemala Flag", native = "🇬🇹", sortOrder = 1710, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gu", { name = "Guam Flag", native = "🇬🇺", sortOrder = 1711, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gw", { name = "Guinea-Bissau Flag", native = "🇬🇼", sortOrder = 1712, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-gy", { name = "Guyana Flag", native = "🇬🇾", sortOrder = 1713, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-hk", { name = "Hong Kong SAR China Flag", native = "🇭🇰", sortOrder = 1714, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-hm", { name = "Heard & McDonald Islands Flag", native = "🇭🇲", sortOrder = 1715, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-hn", { name = "Honduras Flag", native = "🇭🇳", sortOrder = 1716, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-hr", { name = "Croatia Flag", native = "🇭🇷", sortOrder = 1717, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ht", { name = "Haiti Flag", native = "🇭🇹", sortOrder = 1718, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-hu", { name = "Hungary Flag", native = "🇭🇺", sortOrder = 1719, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ic", { name = "Canary Islands Flag", native = "🇮🇨", sortOrder = 1720, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-id", { name = "Indonesia Flag", native = "🇮🇩", sortOrder = 1721, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ie", { name = "Ireland Flag", native = "🇮🇪", sortOrder = 1722, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-il", { name = "Israel Flag", native = "🇮🇱", sortOrder = 1723, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-im", { name = "Isle of Man Flag", native = "🇮🇲", sortOrder = 1724, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-in", { name = "India Flag", native = "🇮🇳", sortOrder = 1725, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-io", { name = "British Indian Ocean Territory Flag", native = "🇮🇴", sortOrder = 1726, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-iq", { name = "Iraq Flag", native = "🇮🇶", sortOrder = 1727, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ir", { name = "Iran Flag", native = "🇮🇷", sortOrder = 1728, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-is", { name = "Iceland Flag", native = "🇮🇸", sortOrder = 1729, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "it", { name = "Italy Flag", native = "🇮🇹", sortOrder = 1730, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-je", { name = "Jersey Flag", native = "🇯🇪", sortOrder = 1731, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-jm", { name = "Jamaica Flag", native = "🇯🇲", sortOrder = 1732, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-jo", { name = "Jordan Flag", native = "🇯🇴", sortOrder = 1733, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "jp", { name = "Japan Flag", native = "🇯🇵", sortOrder = 1734, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ke", { name = "Kenya Flag", native = "🇰🇪", sortOrder = 1735, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-kg", { name = "Kyrgyzstan Flag", native = "🇰🇬", sortOrder = 1736, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-kh", { name = "Cambodia Flag", native = "🇰🇭", sortOrder = 1737, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ki", { name = "Kiribati Flag", native = "🇰🇮", sortOrder = 1738, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-km", { name = "Comoros Flag", native = "🇰🇲", sortOrder = 1739, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-kn", { name = "St. Kitts & Nevis Flag", native = "🇰🇳", sortOrder = 1740, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-kp", { name = "North Korea Flag", native = "🇰🇵", sortOrder = 1741, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "kr", { name = "South Korea Flag", native = "🇰🇷", sortOrder = 1742, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-kw", { name = "Kuwait Flag", native = "🇰🇼", sortOrder = 1743, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ky", { name = "Cayman Islands Flag", native = "🇰🇾", sortOrder = 1744, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-kz", { name = "Kazakhstan Flag", native = "🇰🇿", sortOrder = 1745, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-la", { name = "Laos Flag", native = "🇱🇦", sortOrder = 1746, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lb", { name = "Lebanon Flag", native = "🇱🇧", sortOrder = 1747, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lc", { name = "St. Lucia Flag", native = "🇱🇨", sortOrder = 1748, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-li", { name = "Liechtenstein Flag", native = "🇱🇮", sortOrder = 1749, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lk", { name = "Sri Lanka Flag", native = "🇱🇰", sortOrder = 1750, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lr", { name = "Liberia Flag", native = "🇱🇷", sortOrder = 1751, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ls", { name = "Lesotho Flag", native = "🇱🇸", sortOrder = 1752, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lt", { name = "Lithuania Flag", native = "🇱🇹", sortOrder = 1753, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lu", { name = "Luxembourg Flag", native = "🇱🇺", sortOrder = 1754, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-lv", { name = "Latvia Flag", native = "🇱🇻", sortOrder = 1755, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ly", { name = "Libya Flag", native = "🇱🇾", sortOrder = 1756, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ma", { name = "Morocco Flag", native = "🇲🇦", sortOrder = 1757, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mc", { name = "Monaco Flag", native = "🇲🇨", sortOrder = 1758, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-md", { name = "Moldova Flag", native = "🇲🇩", sortOrder = 1759, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-me", { name = "Montenegro Flag", native = "🇲🇪", sortOrder = 1760, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mf", { name = "St. Martin Flag", native = "🇲🇫", sortOrder = 1761, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mg", { name = "Madagascar Flag", native = "🇲🇬", sortOrder = 1762, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mh", { name = "Marshall Islands Flag", native = "🇲🇭", sortOrder = 1763, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mk", { name = "North Macedonia Flag", native = "🇲🇰", sortOrder = 1764, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ml", { name = "Mali Flag", native = "🇲🇱", sortOrder = 1765, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mm", { name = "Myanmar (Burma) Flag", native = "🇲🇲", sortOrder = 1766, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mn", { name = "Mongolia Flag", native = "🇲🇳", sortOrder = 1767, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mo", { name = "Macao SAR China Flag", native = "🇲🇴", sortOrder = 1768, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mp", { name = "Northern Mariana Islands Flag", native = "🇲🇵", sortOrder = 1769, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mq", { name = "Martinique Flag", native = "🇲🇶", sortOrder = 1770, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mr", { name = "Mauritania Flag", native = "🇲🇷", sortOrder = 1771, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ms", { name = "Montserrat Flag", native = "🇲🇸", sortOrder = 1772, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mt", { name = "Malta Flag", native = "🇲🇹", sortOrder = 1773, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mu", { name = "Mauritius Flag", native = "🇲🇺", sortOrder = 1774, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mv", { name = "Maldives Flag", native = "🇲🇻", sortOrder = 1775, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mw", { name = "Malawi Flag", native = "🇲🇼", sortOrder = 1776, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mx", { name = "Mexico Flag", native = "🇲🇽", sortOrder = 1777, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-my", { name = "Malaysia Flag", native = "🇲🇾", sortOrder = 1778, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-mz", { name = "Mozambique Flag", native = "🇲🇿", sortOrder = 1779, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-na", { name = "Namibia Flag", native = "🇳🇦", sortOrder = 1780, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-nc", { name = "New Caledonia Flag", native = "🇳🇨", sortOrder = 1781, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ne", { name = "Niger Flag", native = "🇳🇪", sortOrder = 1782, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-nf", { name = "Norfolk Island Flag", native = "🇳🇫", sortOrder = 1783, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ng", { name = "Nigeria Flag", native = "🇳🇬", sortOrder = 1784, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ni", { name = "Nicaragua Flag", native = "🇳🇮", sortOrder = 1785, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-nl", { name = "Netherlands Flag", native = "🇳🇱", sortOrder = 1786, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-no", { name = "Norway Flag", native = "🇳🇴", sortOrder = 1787, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-np", { name = "Nepal Flag", native = "🇳🇵", sortOrder = 1788, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-nr", { name = "Nauru Flag", native = "🇳🇷", sortOrder = 1789, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-nu", { name = "Niue Flag", native = "🇳🇺", sortOrder = 1790, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-nz", { name = "New Zealand Flag", native = "🇳🇿", sortOrder = 1791, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-om", { name = "Oman Flag", native = "🇴🇲", sortOrder = 1792, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pa", { name = "Panama Flag", native = "🇵🇦", sortOrder = 1793, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pe", { name = "Peru Flag", native = "🇵🇪", sortOrder = 1794, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pf", { name = "French Polynesia Flag", native = "🇵🇫", sortOrder = 1795, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pg", { name = "Papua New Guinea Flag", native = "🇵🇬", sortOrder = 1796, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ph", { name = "Philippines Flag", native = "🇵🇭", sortOrder = 1797, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pk", { name = "Pakistan Flag", native = "🇵🇰", sortOrder = 1798, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pl", { name = "Poland Flag", native = "🇵🇱", sortOrder = 1799, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pm", { name = "St. Pierre & Miquelon Flag", native = "🇵🇲", sortOrder = 1800, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pn", { name = "Pitcairn Islands Flag", native = "🇵🇳", sortOrder = 1801, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pr", { name = "Puerto Rico Flag", native = "🇵🇷", sortOrder = 1802, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ps", { name = "Palestinian Territories Flag", native = "🇵🇸", sortOrder = 1803, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pt", { name = "Portugal Flag", native = "🇵🇹", sortOrder = 1804, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-pw", { name = "Palau Flag", native = "🇵🇼", sortOrder = 1805, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-py", { name = "Paraguay Flag", native = "🇵🇾", sortOrder = 1806, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-qa", { name = "Qatar Flag", native = "🇶🇦", sortOrder = 1807, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-re", { name = "Réunion Flag", native = "🇷🇪", sortOrder = 1808, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ro", { name = "Romania Flag", native = "🇷🇴", sortOrder = 1809, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-rs", { name = "Serbia Flag", native = "🇷🇸", sortOrder = 1810, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ru", { name = "Russia Flag", native = "🇷🇺", sortOrder = 1811, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-rw", { name = "Rwanda Flag", native = "🇷🇼", sortOrder = 1812, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sa", { name = "Saudi Arabia Flag", native = "🇸🇦", sortOrder = 1813, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sb", { name = "Solomon Islands Flag", native = "🇸🇧", sortOrder = 1814, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sc", { name = "Seychelles Flag", native = "🇸🇨", sortOrder = 1815, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sd", { name = "Sudan Flag", native = "🇸🇩", sortOrder = 1816, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-se", { name = "Sweden Flag", native = "🇸🇪", sortOrder = 1817, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sg", { name = "Singapore Flag", native = "🇸🇬", sortOrder = 1818, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sh", { name = "St. Helena Flag", native = "🇸🇭", sortOrder = 1819, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-si", { name = "Slovenia Flag", native = "🇸🇮", sortOrder = 1820, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sj", { name = "Svalbard & Jan Mayen Flag", native = "🇸🇯", sortOrder = 1821, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sk", { name = "Slovakia Flag", native = "🇸🇰", sortOrder = 1822, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sl", { name = "Sierra Leone Flag", native = "🇸🇱", sortOrder = 1823, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sm", { name = "San Marino Flag", native = "🇸🇲", sortOrder = 1824, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sn", { name = "Senegal Flag", native = "🇸🇳", sortOrder = 1825, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-so", { name = "Somalia Flag", native = "🇸🇴", sortOrder = 1826, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sr", { name = "Suriname Flag", native = "🇸🇷", sortOrder = 1827, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ss", { name = "South Sudan Flag", native = "🇸🇸", sortOrder = 1828, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-st", { name = "São Tomé & Príncipe Flag", native = "🇸🇹", sortOrder = 1829, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sv", { name = "El Salvador Flag", native = "🇸🇻", sortOrder = 1830, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sx", { name = "Sint Maarten Flag", native = "🇸🇽", sortOrder = 1831, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sy", { name = "Syria Flag", native = "🇸🇾", sortOrder = 1832, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-sz", { name = "Eswatini Flag", native = "🇸🇿", sortOrder = 1833, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ta", { name = "Tristan da Cunha Flag", native = "🇹🇦", sortOrder = 1834, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tc", { name = "Turks & Caicos Islands Flag", native = "🇹🇨", sortOrder = 1835, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-td", { name = "Chad Flag", native = "🇹🇩", sortOrder = 1836, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tf", { name = "French Southern Territories Flag", native = "🇹🇫", sortOrder = 1837, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tg", { name = "Togo Flag", native = "🇹🇬", sortOrder = 1838, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-th", { name = "Thailand Flag", native = "🇹🇭", sortOrder = 1839, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tj", { name = "Tajikistan Flag", native = "🇹🇯", sortOrder = 1840, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tk", { name = "Tokelau Flag", native = "🇹🇰", sortOrder = 1841, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tl", { name = "Timor-Leste Flag", native = "🇹🇱", sortOrder = 1842, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tm", { name = "Turkmenistan Flag", native = "🇹🇲", sortOrder = 1843, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tn", { name = "Tunisia Flag", native = "🇹🇳", sortOrder = 1844, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-to", { name = "Tonga Flag", native = "🇹🇴", sortOrder = 1845, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tr", { name = "Turkey Flag", native = "🇹🇷", sortOrder = 1846, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tt", { name = "Trinidad & Tobago Flag", native = "🇹🇹", sortOrder = 1847, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tv", { name = "Tuvalu Flag", native = "🇹🇻", sortOrder = 1848, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tw", { name = "Taiwan Flag", native = "🇹🇼", sortOrder = 1849, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-tz", { name = "Tanzania Flag", native = "🇹🇿", sortOrder = 1850, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ua", { name = "Ukraine Flag", native = "🇺🇦", sortOrder = 1851, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ug", { name = "Uganda Flag", native = "🇺🇬", sortOrder = 1852, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-um", { name = "U.S. Outlying Islands Flag", native = "🇺🇲", sortOrder = 1853, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-un", { name = "United Nations Flag", native = "🇺🇳", sortOrder = 1854, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "us", { name = "United States Flag", native = "🇺🇸", sortOrder = 1855, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-uy", { name = "Uruguay Flag", native = "🇺🇾", sortOrder = 1856, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-uz", { name = "Uzbekistan Flag", native = "🇺🇿", sortOrder = 1857, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-va", { name = "Vatican City Flag", native = "🇻🇦", sortOrder = 1858, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-vc", { name = "St. Vincent & Grenadines Flag", native = "🇻🇨", sortOrder = 1859, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ve", { name = "Venezuela Flag", native = "🇻🇪", sortOrder = 1860, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-vg", { name = "British Virgin Islands Flag", native = "🇻🇬", sortOrder = 1861, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-vi", { name = "U.S. Virgin Islands Flag", native = "🇻🇮", sortOrder = 1862, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-vn", { name = "Vietnam Flag", native = "🇻🇳", sortOrder = 1863, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-vu", { name = "Vanuatu Flag", native = "🇻🇺", sortOrder = 1864, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-wf", { name = "Wallis & Futuna Flag", native = "🇼🇫", sortOrder = 1865, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ws", { name = "Samoa Flag", native = "🇼🇸", sortOrder = 1866, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-xk", { name = "Kosovo Flag", native = "🇽🇰", sortOrder = 1867, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-ye", { name = "Yemen Flag", native = "🇾🇪", sortOrder = 1868, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-yt", { name = "Mayotte Flag", native = "🇾🇹", sortOrder = 1869, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-za", { name = "South Africa Flag", native = "🇿🇦", sortOrder = 1870, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-zm", { name = "Zambia Flag", native = "🇿🇲", sortOrder = 1871, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-zw", { name = "Zimbabwe Flag", native = "🇿🇼", sortOrder = 1872, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "koko", { name = "SQUARED KATAKANA KOKO", native = "🈁", sortOrder = 1556, skinVariations = Dict.fromList [], keywords = [ "“here”", "Japanese", "Japanese “here” button", "katakana", "ココ" ] } )
        , ( "sa", { name = "SQUARED KATAKANA SA", native = "🈂️", sortOrder = 1557, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "u7121", { name = "SQUARED CJK UNIFIED IDEOGRAPH-7121", native = "🈚", sortOrder = 1563, skinVariations = Dict.fromList [], keywords = [ "“free of charge”", "ideograph", "Japanese", "Japanese “free of charge” button", "無" ] } )
        , ( "u6307", { name = "SQUARED CJK UNIFIED IDEOGRAPH-6307", native = "🈯", sortOrder = 1560, skinVariations = Dict.fromList [], keywords = [ "“reserved”", "ideograph", "Japanese", "Japanese “reserved” button", "指" ] } )
        , ( "u7981", { name = "SQUARED CJK UNIFIED IDEOGRAPH-7981", native = "🈲", sortOrder = 1564, skinVariations = Dict.fromList [], keywords = [ "“prohibited”", "ideograph", "Japanese", "Japanese “prohibited” button", "禁" ] } )
        , ( "u7a7a", { name = "SQUARED CJK UNIFIED IDEOGRAPH-7A7A", native = "🈳", sortOrder = 1568, skinVariations = Dict.fromList [], keywords = [ "“vacancy”", "ideograph", "Japanese", "Japanese “vacancy” button", "空" ] } )
        , ( "u5408", { name = "SQUARED CJK UNIFIED IDEOGRAPH-5408", native = "🈴", sortOrder = 1567, skinVariations = Dict.fromList [], keywords = [ "“passing grade”", "ideograph", "Japanese", "Japanese “passing grade” button", "合" ] } )
        , ( "u6e80", { name = "SQUARED CJK UNIFIED IDEOGRAPH-6E80", native = "🈵", sortOrder = 1572, skinVariations = Dict.fromList [], keywords = [ "“no vacancy”", "ideograph", "Japanese", "Japanese “no vacancy” button", "満" ] } )
        , ( "u6709", { name = "SQUARED CJK UNIFIED IDEOGRAPH-6709", native = "🈶", sortOrder = 1559, skinVariations = Dict.fromList [], keywords = [ "“not free of charge”", "ideograph", "Japanese", "Japanese “not free of charge” button", "有" ] } )
        , ( "u6708", { name = "SQUARED CJK UNIFIED IDEOGRAPH-6708", native = "🈷️", sortOrder = 1558, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "u7533", { name = "SQUARED CJK UNIFIED IDEOGRAPH-7533", native = "🈸", sortOrder = 1566, skinVariations = Dict.fromList [], keywords = [ "“application”", "ideograph", "Japanese", "Japanese “application” button", "申" ] } )
        , ( "u5272", { name = "SQUARED CJK UNIFIED IDEOGRAPH-5272", native = "🈹", sortOrder = 1562, skinVariations = Dict.fromList [], keywords = [ "“discount”", "ideograph", "Japanese", "Japanese “discount” button", "割" ] } )
        , ( "u55b6", { name = "SQUARED CJK UNIFIED IDEOGRAPH-55B6", native = "🈺", sortOrder = 1571, skinVariations = Dict.fromList [], keywords = [ "“open for business”", "ideograph", "Japanese", "Japanese “open for business” button", "営" ] } )
        , ( "ideograph_advantage", { name = "CIRCLED IDEOGRAPH ADVANTAGE", native = "🉐", sortOrder = 1561, skinVariations = Dict.fromList [], keywords = [ "“bargain”", "ideograph", "Japanese", "Japanese “bargain” button", "得" ] } )
        , ( "accept", { name = "CIRCLED IDEOGRAPH ACCEPT", native = "🉑", sortOrder = 1565, skinVariations = Dict.fromList [], keywords = [ "“acceptable”", "ideograph", "Japanese", "Japanese “acceptable” button", "可" ] } )
        , ( "cyclone", { name = "CYCLONE", native = "🌀", sortOrder = 1024, skinVariations = Dict.fromList [], keywords = [ "cyclone", "dizzy", "hurricane", "twister", "typhoon" ] } )
        , ( "foggy", { name = "FOGGY", native = "🌁", sortOrder = 871, skinVariations = Dict.fromList [], keywords = [ "fog", "foggy" ] } )
        , ( "closed_umbrella", { name = "CLOSED UMBRELLA", native = "🌂", sortOrder = 1026, skinVariations = Dict.fromList [], keywords = [ "closed umbrella", "clothing", "rain", "umbrella" ] } )
        , ( "night_with_stars", { name = "NIGHT WITH STARS", native = "🌃", sortOrder = 872, skinVariations = Dict.fromList [], keywords = [ "night", "night with stars", "star" ] } )
        , ( "sunrise_over_mountains", { name = "SUNRISE OVER MOUNTAINS", native = "🌄", sortOrder = 874, skinVariations = Dict.fromList [], keywords = [ "morning", "mountain", "sun", "sunrise", "sunrise over mountains" ] } )
        , ( "sunrise", { name = "SUNRISE", native = "🌅", sortOrder = 875, skinVariations = Dict.fromList [], keywords = [ "morning", "sun", "sunrise" ] } )
        , ( "city_sunset", { name = "CITYSCAPE AT DUSK", native = "🌆", sortOrder = 876, skinVariations = Dict.fromList [], keywords = [ "city", "cityscape at dusk", "dusk", "evening", "landscape", "sunset" ] } )
        , ( "city_sunrise", { name = "SUNSET OVER BUILDINGS", native = "🌇", sortOrder = 877, skinVariations = Dict.fromList [], keywords = [ "dusk", "sun", "sunset" ] } )
        , ( "rainbow", { name = "RAINBOW", native = "🌈", sortOrder = 1025, skinVariations = Dict.fromList [], keywords = [ "rain", "rainbow" ] } )
        , ( "bridge_at_night", { name = "BRIDGE AT NIGHT", native = "🌉", sortOrder = 878, skinVariations = Dict.fromList [], keywords = [ "bridge", "bridge at night", "night" ] } )
        , ( "ocean", { name = "WATER WAVE", native = "🌊", sortOrder = 1037, skinVariations = Dict.fromList [], keywords = [ "ocean", "water", "wave" ] } )
        , ( "volcano", { name = "VOLCANO", native = "🌋", sortOrder = 829, skinVariations = Dict.fromList [], keywords = [ "eruption", "mountain", "volcano" ] } )
        , ( "milky_way", { name = "MILKY WAY", native = "🌌", sortOrder = 1011, skinVariations = Dict.fromList [], keywords = [ "milky way", "space" ] } )
        , ( "earth_africa", { name = "EARTH GLOBE EUROPE-AFRICA", native = "🌍", sortOrder = 820, skinVariations = Dict.fromList [], keywords = [ "Africa", "earth", "Europe", "globe", "globe showing Europe-Africa", "world" ] } )
        , ( "earth_americas", { name = "EARTH GLOBE AMERICAS", native = "🌎", sortOrder = 821, skinVariations = Dict.fromList [], keywords = [ "Americas", "earth", "globe", "globe showing Americas", "world" ] } )
        , ( "earth_asia", { name = "EARTH GLOBE ASIA-AUSTRALIA", native = "🌏", sortOrder = 822, skinVariations = Dict.fromList [], keywords = [ "Asia", "Australia", "earth", "globe", "globe showing Asia-Australia", "world" ] } )
        , ( "globe_with_meridians", { name = "GLOBE WITH MERIDIANS", native = "🌐", sortOrder = 823, skinVariations = Dict.fromList [], keywords = [ "earth", "globe", "globe with meridians", "meridians", "world" ] } )
        , ( "new_moon", { name = "NEW MOON SYMBOL", native = "🌑", sortOrder = 991, skinVariations = Dict.fromList [], keywords = [ "dark", "moon", "new moon" ] } )
        , ( "waxing_crescent_moon", { name = "WAXING CRESCENT MOON SYMBOL", native = "🌒", sortOrder = 992, skinVariations = Dict.fromList [], keywords = [ "crescent", "moon", "waxing" ] } )
        , ( "first_quarter_moon", { name = "FIRST QUARTER MOON SYMBOL", native = "🌓", sortOrder = 993, skinVariations = Dict.fromList [], keywords = [ "first quarter moon", "moon", "quarter" ] } )
        , ( "moon", { name = "WAXING GIBBOUS MOON SYMBOL", native = "🌔", sortOrder = 994, skinVariations = Dict.fromList [], keywords = [ "gibbous", "moon", "waxing" ] } )
        , ( "full_moon", { name = "FULL MOON SYMBOL", native = "🌕", sortOrder = 995, skinVariations = Dict.fromList [], keywords = [ "full", "moon" ] } )
        , ( "waning_gibbous_moon", { name = "WANING GIBBOUS MOON SYMBOL", native = "🌖", sortOrder = 996, skinVariations = Dict.fromList [], keywords = [ "gibbous", "moon", "waning" ] } )
        , ( "last_quarter_moon", { name = "LAST QUARTER MOON SYMBOL", native = "🌗", sortOrder = 997, skinVariations = Dict.fromList [], keywords = [ "last quarter moon", "moon", "quarter" ] } )
        , ( "waning_crescent_moon", { name = "WANING CRESCENT MOON SYMBOL", native = "🌘", sortOrder = 998, skinVariations = Dict.fromList [], keywords = [ "crescent", "moon", "waning" ] } )
        , ( "crescent_moon", { name = "CRESCENT MOON", native = "🌙", sortOrder = 999, skinVariations = Dict.fromList [], keywords = [ "crescent", "moon" ] } )
        , ( "new_moon_with_face", { name = "NEW MOON WITH FACE", native = "🌚", sortOrder = 1000, skinVariations = Dict.fromList [], keywords = [ "face", "moon", "new moon face" ] } )
        , ( "first_quarter_moon_with_face", { name = "FIRST QUARTER MOON WITH FACE", native = "🌛", sortOrder = 1001, skinVariations = Dict.fromList [], keywords = [ "face", "first quarter moon face", "moon", "quarter" ] } )
        , ( "last_quarter_moon_with_face", { name = "LAST QUARTER MOON WITH FACE", native = "🌜", sortOrder = 1002, skinVariations = Dict.fromList [], keywords = [ "face", "last quarter moon face", "moon", "quarter" ] } )
        , ( "full_moon_with_face", { name = "FULL MOON WITH FACE", native = "🌝", sortOrder = 1005, skinVariations = Dict.fromList [], keywords = [ "bright", "face", "full", "moon" ] } )
        , ( "sun_with_face", { name = "SUN WITH FACE", native = "🌞", sortOrder = 1006, skinVariations = Dict.fromList [], keywords = [ "bright", "face", "sun", "sun with face" ] } )
        , ( "star2", { name = "GLOWING STAR", native = "🌟", sortOrder = 1009, skinVariations = Dict.fromList [], keywords = [ "glittery", "glow", "glowing star", "shining", "sparkle", "star" ] } )
        , ( "stars", { name = "SHOOTING STAR", native = "🌠", sortOrder = 1010, skinVariations = Dict.fromList [], keywords = [ "falling", "shooting", "star" ] } )
        , ( "thermometer", { name = "THERMOMETER", native = "🌡️", sortOrder = 1003, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "mostly_sunny", { name = "SUN BEHIND SMALL CLOUD", native = "🌤️", sortOrder = 1015, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "barely_sunny", { name = "SUN BEHIND LARGE CLOUD", native = "🌥️", sortOrder = 1016, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "partly_sunny_rain", { name = "SUN BEHIND RAIN CLOUD", native = "🌦️", sortOrder = 1017, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "rain_cloud", { name = "CLOUD WITH RAIN", native = "🌧️", sortOrder = 1018, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "snow_cloud", { name = "CLOUD WITH SNOW", native = "🌨️", sortOrder = 1019, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "lightning", { name = "CLOUD WITH LIGHTNING", native = "🌩️", sortOrder = 1020, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "tornado", { name = "TORNADO", native = "🌪️", sortOrder = 1021, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "fog", { name = "FOG", native = "🌫️", sortOrder = 1022, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "wind_blowing_face", { name = "WIND FACE", native = "🌬️", sortOrder = 1023, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "hotdog", { name = "HOT DOG", native = "🌭", sortOrder = 739, skinVariations = Dict.fromList [], keywords = [ "frankfurter", "hot dog", "hotdog", "sausage" ] } )
        , ( "taco", { name = "TACO", native = "🌮", sortOrder = 741, skinVariations = Dict.fromList [], keywords = [ "mexican", "taco" ] } )
        , ( "burrito", { name = "BURRITO", native = "🌯", sortOrder = 742, skinVariations = Dict.fromList [], keywords = [ "burrito", "mexican", "wrap" ] } )
        , ( "chestnut", { name = "CHESTNUT", native = "🌰", sortOrder = 720, skinVariations = Dict.fromList [], keywords = [ "chestnut", "plant" ] } )
        , ( "seedling", { name = "SEEDLING", native = "🌱", sortOrder = 671, skinVariations = Dict.fromList [], keywords = [ "seedling", "young" ] } )
        , ( "evergreen_tree", { name = "EVERGREEN TREE", native = "🌲", sortOrder = 673, skinVariations = Dict.fromList [], keywords = [ "evergreen tree", "tree" ] } )
        , ( "deciduous_tree", { name = "DECIDUOUS TREE", native = "🌳", sortOrder = 674, skinVariations = Dict.fromList [], keywords = [ "deciduous", "shedding", "tree" ] } )
        , ( "palm_tree", { name = "PALM TREE", native = "🌴", sortOrder = 675, skinVariations = Dict.fromList [], keywords = [ "palm", "tree" ] } )
        , ( "cactus", { name = "CACTUS", native = "🌵", sortOrder = 676, skinVariations = Dict.fromList [], keywords = [ "cactus", "plant" ] } )
        , ( "hot_pepper", { name = "HOT PEPPER", native = "🌶️", sortOrder = 711, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "tulip", { name = "TULIP", native = "🌷", sortOrder = 669, skinVariations = Dict.fromList [], keywords = [ "flower", "tulip" ] } )
        , ( "cherry_blossom", { name = "CHERRY BLOSSOM", native = "🌸", sortOrder = 660, skinVariations = Dict.fromList [], keywords = [ "blossom", "cherry", "flower" ] } )
        , ( "rose", { name = "ROSE", native = "🌹", sortOrder = 664, skinVariations = Dict.fromList [], keywords = [ "flower", "rose" ] } )
        , ( "hibiscus", { name = "HIBISCUS", native = "🌺", sortOrder = 666, skinVariations = Dict.fromList [], keywords = [ "flower", "hibiscus" ] } )
        , ( "sunflower", { name = "SUNFLOWER", native = "🌻", sortOrder = 667, skinVariations = Dict.fromList [], keywords = [ "flower", "sun", "sunflower" ] } )
        , ( "blossom", { name = "BLOSSOM", native = "🌼", sortOrder = 668, skinVariations = Dict.fromList [], keywords = [ "blossom", "flower" ] } )
        , ( "corn", { name = "EAR OF MAIZE", native = "🌽", sortOrder = 710, skinVariations = Dict.fromList [], keywords = [ "corn", "ear", "ear of corn", "maize", "maze" ] } )
        , ( "ear_of_rice", { name = "EAR OF RICE", native = "🌾", sortOrder = 677, skinVariations = Dict.fromList [], keywords = [ "ear", "grain", "rice", "sheaf of rice" ] } )
        , ( "herb", { name = "HERB", native = "🌿", sortOrder = 678, skinVariations = Dict.fromList [], keywords = [ "herb", "leaf" ] } )
        , ( "four_leaf_clover", { name = "FOUR LEAF CLOVER", native = "🍀", sortOrder = 680, skinVariations = Dict.fromList [], keywords = [ "4", "clover", "four", "four-leaf clover", "leaf" ] } )
        , ( "maple_leaf", { name = "MAPLE LEAF", native = "🍁", sortOrder = 681, skinVariations = Dict.fromList [], keywords = [ "falling", "leaf", "maple" ] } )
        , ( "fallen_leaf", { name = "FALLEN LEAF", native = "🍂", sortOrder = 682, skinVariations = Dict.fromList [], keywords = [ "fallen leaf", "falling", "leaf" ] } )
        , ( "leaves", { name = "LEAF FLUTTERING IN WIND", native = "🍃", sortOrder = 683, skinVariations = Dict.fromList [], keywords = [ "blow", "flutter", "leaf", "leaf fluttering in wind", "wind" ] } )
        , ( "mushroom", { name = "MUSHROOM", native = "🍄", sortOrder = 686, skinVariations = Dict.fromList [], keywords = [ "mushroom", "toadstool" ] } )
        , ( "tomato", { name = "TOMATO", native = "🍅", sortOrder = 703, skinVariations = Dict.fromList [], keywords = [ "fruit", "tomato", "vegetable" ] } )
        , ( "eggplant", { name = "AUBERGINE", native = "🍆", sortOrder = 707, skinVariations = Dict.fromList [], keywords = [ "aubergine", "eggplant", "vegetable" ] } )
        , ( "grapes", { name = "GRAPES", native = "🍇", sortOrder = 687, skinVariations = Dict.fromList [], keywords = [ "fruit", "grape", "grapes" ] } )
        , ( "melon", { name = "MELON", native = "🍈", sortOrder = 688, skinVariations = Dict.fromList [], keywords = [ "fruit", "melon" ] } )
        , ( "watermelon", { name = "WATERMELON", native = "🍉", sortOrder = 689, skinVariations = Dict.fromList [], keywords = [ "fruit", "watermelon" ] } )
        , ( "tangerine", { name = "TANGERINE", native = "🍊", sortOrder = 690, skinVariations = Dict.fromList [], keywords = [ "fruit", "orange", "tangerine" ] } )
        , ( "lemon", { name = "LEMON", native = "🍋", sortOrder = 691, skinVariations = Dict.fromList [], keywords = [ "citrus", "fruit", "lemon" ] } )
        , ( "banana", { name = "BANANA", native = "🍌", sortOrder = 692, skinVariations = Dict.fromList [], keywords = [ "banana", "fruit" ] } )
        , ( "pineapple", { name = "PINEAPPLE", native = "🍍", sortOrder = 693, skinVariations = Dict.fromList [], keywords = [ "fruit", "pineapple" ] } )
        , ( "apple", { name = "RED APPLE", native = "🍎", sortOrder = 695, skinVariations = Dict.fromList [], keywords = [ "apple", "fruit", "red" ] } )
        , ( "green_apple", { name = "GREEN APPLE", native = "🍏", sortOrder = 696, skinVariations = Dict.fromList [], keywords = [ "apple", "fruit", "green" ] } )
        , ( "pear", { name = "PEAR", native = "🍐", sortOrder = 697, skinVariations = Dict.fromList [], keywords = [ "fruit", "pear" ] } )
        , ( "peach", { name = "PEACH", native = "🍑", sortOrder = 698, skinVariations = Dict.fromList [], keywords = [ "fruit", "peach" ] } )
        , ( "cherries", { name = "CHERRIES", native = "🍒", sortOrder = 699, skinVariations = Dict.fromList [], keywords = [ "berries", "cherries", "cherry", "fruit", "red" ] } )
        , ( "strawberry", { name = "STRAWBERRY", native = "🍓", sortOrder = 700, skinVariations = Dict.fromList [], keywords = [ "berry", "fruit", "strawberry" ] } )
        , ( "hamburger", { name = "HAMBURGER", native = "🍔", sortOrder = 736, skinVariations = Dict.fromList [], keywords = [ "burger", "hamburger" ] } )
        , ( "pizza", { name = "SLICE OF PIZZA", native = "🍕", sortOrder = 738, skinVariations = Dict.fromList [], keywords = [ "cheese", "pizza", "slice" ] } )
        , ( "meat_on_bone", { name = "MEAT ON BONE", native = "🍖", sortOrder = 732, skinVariations = Dict.fromList [], keywords = [ "bone", "meat", "meat on bone" ] } )
        , ( "poultry_leg", { name = "POULTRY LEG", native = "🍗", sortOrder = 733, skinVariations = Dict.fromList [], keywords = [ "bone", "chicken", "drumstick", "leg", "poultry" ] } )
        , ( "rice_cracker", { name = "RICE CRACKER", native = "🍘", sortOrder = 758, skinVariations = Dict.fromList [], keywords = [ "cracker", "rice" ] } )
        , ( "rice_ball", { name = "RICE BALL", native = "🍙", sortOrder = 759, skinVariations = Dict.fromList [], keywords = [ "ball", "Japanese", "rice" ] } )
        , ( "rice", { name = "COOKED RICE", native = "🍚", sortOrder = 760, skinVariations = Dict.fromList [], keywords = [ "cooked", "rice" ] } )
        , ( "curry", { name = "CURRY AND RICE", native = "🍛", sortOrder = 761, skinVariations = Dict.fromList [], keywords = [ "curry", "rice" ] } )
        , ( "ramen", { name = "STEAMING BOWL", native = "🍜", sortOrder = 762, skinVariations = Dict.fromList [], keywords = [ "bowl", "noodle", "ramen", "steaming" ] } )
        , ( "spaghetti", { name = "SPAGHETTI", native = "🍝", sortOrder = 763, skinVariations = Dict.fromList [], keywords = [ "pasta", "spaghetti" ] } )
        , ( "bread", { name = "BREAD", native = "🍞", sortOrder = 723, skinVariations = Dict.fromList [], keywords = [ "bread", "loaf" ] } )
        , ( "fries", { name = "FRENCH FRIES", native = "🍟", sortOrder = 737, skinVariations = Dict.fromList [], keywords = [ "french", "fries" ] } )
        , ( "sweet_potato", { name = "ROASTED SWEET POTATO", native = "🍠", sortOrder = 764, skinVariations = Dict.fromList [], keywords = [ "potato", "roasted", "sweet" ] } )
        , ( "dango", { name = "DANGO", native = "🍡", sortOrder = 770, skinVariations = Dict.fromList [], keywords = [ "dango", "dessert", "Japanese", "skewer", "stick", "sweet" ] } )
        , ( "oden", { name = "ODEN", native = "🍢", sortOrder = 765, skinVariations = Dict.fromList [], keywords = [ "kebab", "oden", "seafood", "skewer", "stick" ] } )
        , ( "sushi", { name = "SUSHI", native = "🍣", sortOrder = 766, skinVariations = Dict.fromList [], keywords = [ "sushi" ] } )
        , ( "fried_shrimp", { name = "FRIED SHRIMP", native = "🍤", sortOrder = 767, skinVariations = Dict.fromList [], keywords = [ "fried", "prawn", "shrimp", "tempura" ] } )
        , ( "fish_cake", { name = "FISH CAKE WITH SWIRL DESIGN", native = "🍥", sortOrder = 768, skinVariations = Dict.fromList [], keywords = [ "cake", "fish", "fish cake with swirl", "pastry", "swirl" ] } )
        , ( "icecream", { name = "SOFT ICE CREAM", native = "🍦", sortOrder = 779, skinVariations = Dict.fromList [], keywords = [ "cream", "dessert", "ice", "icecream", "soft", "sweet" ] } )
        , ( "shaved_ice", { name = "SHAVED ICE", native = "🍧", sortOrder = 780, skinVariations = Dict.fromList [], keywords = [ "dessert", "ice", "shaved", "sweet" ] } )
        , ( "ice_cream", { name = "ICE CREAM", native = "🍨", sortOrder = 781, skinVariations = Dict.fromList [], keywords = [ "cream", "dessert", "ice", "sweet" ] } )
        , ( "doughnut", { name = "DOUGHNUT", native = "🍩", sortOrder = 782, skinVariations = Dict.fromList [], keywords = [ "breakfast", "dessert", "donut", "doughnut", "sweet" ] } )
        , ( "cookie", { name = "COOKIE", native = "🍪", sortOrder = 783, skinVariations = Dict.fromList [], keywords = [ "cookie", "dessert", "sweet" ] } )
        , ( "chocolate_bar", { name = "CHOCOLATE BAR", native = "🍫", sortOrder = 788, skinVariations = Dict.fromList [], keywords = [ "bar", "chocolate", "dessert", "sweet" ] } )
        , ( "candy", { name = "CANDY", native = "🍬", sortOrder = 789, skinVariations = Dict.fromList [], keywords = [ "candy", "dessert", "sweet" ] } )
        , ( "lollipop", { name = "LOLLIPOP", native = "🍭", sortOrder = 790, skinVariations = Dict.fromList [], keywords = [ "candy", "dessert", "lollipop", "sweet" ] } )
        , ( "custard", { name = "CUSTARD", native = "🍮", sortOrder = 791, skinVariations = Dict.fromList [], keywords = [ "custard", "dessert", "pudding", "sweet" ] } )
        , ( "honey_pot", { name = "HONEY POT", native = "🍯", sortOrder = 792, skinVariations = Dict.fromList [], keywords = [ "honey", "honeypot", "pot", "sweet" ] } )
        , ( "cake", { name = "SHORTCAKE", native = "🍰", sortOrder = 785, skinVariations = Dict.fromList [], keywords = [ "cake", "dessert", "pastry", "shortcake", "slice", "sweet" ] } )
        , ( "bento", { name = "BENTO BOX", native = "🍱", sortOrder = 757, skinVariations = Dict.fromList [], keywords = [ "bento", "box" ] } )
        , ( "stew", { name = "POT OF FOOD", native = "🍲", sortOrder = 749, skinVariations = Dict.fromList [], keywords = [ "pot", "pot of food", "stew" ] } )
        , ( "fried_egg", { name = "COOKING", native = "🍳", sortOrder = 747, skinVariations = Dict.fromList [], keywords = [ "breakfast", "cooking", "egg", "frying", "pan" ] } )
        , ( "fork_and_knife", { name = "FORK AND KNIFE", native = "🍴", sortOrder = 815, skinVariations = Dict.fromList [], keywords = [ "cooking", "cutlery", "fork", "fork and knife", "knife" ] } )
        , ( "tea", { name = "TEACUP WITHOUT HANDLE", native = "🍵", sortOrder = 797, skinVariations = Dict.fromList [], keywords = [ "beverage", "cup", "drink", "tea", "teacup", "teacup without handle" ] } )
        , ( "sake", { name = "SAKE BOTTLE AND CUP", native = "🍶", sortOrder = 798, skinVariations = Dict.fromList [], keywords = [ "bar", "beverage", "bottle", "cup", "drink", "sake" ] } )
        , ( "wine_glass", { name = "WINE GLASS", native = "🍷", sortOrder = 800, skinVariations = Dict.fromList [], keywords = [ "bar", "beverage", "drink", "glass", "wine" ] } )
        , ( "cocktail", { name = "COCKTAIL GLASS", native = "🍸", sortOrder = 801, skinVariations = Dict.fromList [], keywords = [ "bar", "cocktail", "drink", "glass" ] } )
        , ( "tropical_drink", { name = "TROPICAL DRINK", native = "🍹", sortOrder = 802, skinVariations = Dict.fromList [], keywords = [ "bar", "drink", "tropical" ] } )
        , ( "beer", { name = "BEER MUG", native = "🍺", sortOrder = 803, skinVariations = Dict.fromList [], keywords = [ "bar", "beer", "drink", "mug" ] } )
        , ( "beers", { name = "CLINKING BEER MUGS", native = "🍻", sortOrder = 804, skinVariations = Dict.fromList [], keywords = [ "bar", "beer", "clink", "clinking beer mugs", "drink", "mug" ] } )
        , ( "baby_bottle", { name = "BABY BOTTLE", native = "🍼", sortOrder = 793, skinVariations = Dict.fromList [], keywords = [ "baby", "bottle", "drink", "milk" ] } )
        , ( "knife_fork_plate", { name = "FORK AND KNIFE WITH PLATE", native = "🍽️", sortOrder = 814, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "champagne", { name = "BOTTLE WITH POPPING CORK", native = "🍾", sortOrder = 799, skinVariations = Dict.fromList [], keywords = [ "bar", "bottle", "bottle with popping cork", "cork", "drink", "popping" ] } )
        , ( "popcorn", { name = "POPCORN", native = "🍿", sortOrder = 753, skinVariations = Dict.fromList [], keywords = [ "popcorn" ] } )
        , ( "ribbon", { name = "RIBBON", native = "🎀", sortOrder = 1054, skinVariations = Dict.fromList [], keywords = [ "celebration", "ribbon" ] } )
        , ( "gift", { name = "WRAPPED PRESENT", native = "🎁", sortOrder = 1055, skinVariations = Dict.fromList [], keywords = [ "box", "celebration", "gift", "present", "wrapped" ] } )
        , ( "birthday", { name = "BIRTHDAY CAKE", native = "🎂", sortOrder = 784, skinVariations = Dict.fromList [], keywords = [ "birthday", "cake", "celebration", "dessert", "pastry", "sweet" ] } )
        , ( "jack_o_lantern", { name = "JACK-O-LANTERN", native = "🎃", sortOrder = 1038, skinVariations = Dict.fromList [], keywords = [ "celebration", "halloween", "jack", "jack-o-lantern", "lantern" ] } )
        , ( "christmas_tree", { name = "CHRISTMAS TREE", native = "🎄", sortOrder = 1039, skinVariations = Dict.fromList [], keywords = [ "celebration", "Christmas", "tree" ] } )
        , ( "santa", { name = "FATHER CHRISTMAS", native = "🎅", sortOrder = 369, skinVariations = Dict.fromList [ ( "1F3FB", "🎅🏻" ), ( "1F3FC", "🎅🏼" ), ( "1F3FD", "🎅🏽" ), ( "1F3FE", "🎅🏾" ), ( "1F3FF", "🎅🏿" ) ], keywords = [ "celebration", "Christmas", "claus", "father", "santa" ] } )
        , ( "fireworks", { name = "FIREWORKS", native = "🎆", sortOrder = 1040, skinVariations = Dict.fromList [], keywords = [ "celebration", "fireworks" ] } )
        , ( "sparkler", { name = "FIREWORK SPARKLER", native = "🎇", sortOrder = 1041, skinVariations = Dict.fromList [], keywords = [ "celebration", "fireworks", "sparkle", "sparkler" ] } )
        , ( "balloon", { name = "BALLOON", native = "🎈", sortOrder = 1044, skinVariations = Dict.fromList [], keywords = [ "balloon", "celebration" ] } )
        , ( "tada", { name = "PARTY POPPER", native = "🎉", sortOrder = 1045, skinVariations = Dict.fromList [], keywords = [ "celebration", "party", "popper", "tada" ] } )
        , ( "confetti_ball", { name = "CONFETTI BALL", native = "🎊", sortOrder = 1046, skinVariations = Dict.fromList [], keywords = [ "ball", "celebration", "confetti" ] } )
        , ( "tanabata_tree", { name = "TANABATA TREE", native = "🎋", sortOrder = 1047, skinVariations = Dict.fromList [], keywords = [ "banner", "celebration", "Japanese", "tanabata tree", "tree" ] } )
        , ( "crossed_flags", { name = "CROSSED FLAGS", native = "🎌", sortOrder = 1609, skinVariations = Dict.fromList [], keywords = [ "celebration", "cross", "crossed", "crossed flags", "Japanese" ] } )
        , ( "bamboo", { name = "PINE DECORATION", native = "🎍", sortOrder = 1048, skinVariations = Dict.fromList [], keywords = [ "bamboo", "celebration", "Japanese", "pine", "pine decoration" ] } )
        , ( "dolls", { name = "JAPANESE DOLLS", native = "🎎", sortOrder = 1049, skinVariations = Dict.fromList [], keywords = [ "celebration", "doll", "festival", "Japanese", "Japanese dolls" ] } )
        , ( "flags", { name = "CARP STREAMER", native = "🎏", sortOrder = 1050, skinVariations = Dict.fromList [], keywords = [ "carp", "celebration", "streamer" ] } )
        , ( "wind_chime", { name = "WIND CHIME", native = "🎐", sortOrder = 1051, skinVariations = Dict.fromList [], keywords = [ "bell", "celebration", "chime", "wind" ] } )
        , ( "rice_scene", { name = "MOON VIEWING CEREMONY", native = "🎑", sortOrder = 1052, skinVariations = Dict.fromList [], keywords = [ "celebration", "ceremony", "moon", "moon viewing ceremony" ] } )
        , ( "school_satchel", { name = "SCHOOL SATCHEL", native = "🎒", sortOrder = 1148, skinVariations = Dict.fromList [], keywords = [ "backpack", "bag", "rucksack", "satchel", "school" ] } )
        , ( "mortar_board", { name = "GRADUATION CAP", native = "🎓", sortOrder = 1162, skinVariations = Dict.fromList [], keywords = [ "cap", "celebration", "clothing", "graduation", "hat" ] } )
        , ( "medal", { name = "MILITARY MEDAL", native = "🎖️", sortOrder = 1059, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "reminder_ribbon", { name = "REMINDER RIBBON", native = "🎗️", sortOrder = 1056, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "studio_microphone", { name = "STUDIO MICROPHONE", native = "🎙️", sortOrder = 1182, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "level_slider", { name = "LEVEL SLIDER", native = "🎚️", sortOrder = 1183, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "control_knobs", { name = "CONTROL KNOBS", native = "🎛️", sortOrder = 1184, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "film_frames", { name = "FILM FRAMES", native = "🎞️", sortOrder = 1220, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "admission_tickets", { name = "ADMISSION TICKETS", native = "🎟️", sortOrder = 1057, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "carousel_horse", { name = "CAROUSEL HORSE", native = "🎠", sortOrder = 880, skinVariations = Dict.fromList [], keywords = [ "carousel", "horse" ] } )
        , ( "ferris_wheel", { name = "FERRIS WHEEL", native = "🎡", sortOrder = 882, skinVariations = Dict.fromList [], keywords = [ "amusement park", "ferris", "theme park", "wheel" ] } )
        , ( "roller_coaster", { name = "ROLLER COASTER", native = "🎢", sortOrder = 883, skinVariations = Dict.fromList [], keywords = [ "amusement park", "coaster", "roller", "theme park" ] } )
        , ( "fishing_pole_and_fish", { name = "FISHING POLE AND FISH", native = "🎣", sortOrder = 1086, skinVariations = Dict.fromList [], keywords = [ "fish", "fishing pole", "pole" ] } )
        , ( "microphone", { name = "MICROPHONE", native = "🎤", sortOrder = 1185, skinVariations = Dict.fromList [], keywords = [ "karaoke", "mic", "microphone" ] } )
        , ( "movie_camera", { name = "MOVIE CAMERA", native = "🎥", sortOrder = 1219, skinVariations = Dict.fromList [], keywords = [ "camera", "cinema", "movie" ] } )
        , ( "cinema", { name = "CINEMA", native = "🎦", sortOrder = 1475, skinVariations = Dict.fromList [], keywords = [ "camera", "cinema", "film", "movie" ] } )
        , ( "headphones", { name = "HEADPHONE", native = "🎧", sortOrder = 1186, skinVariations = Dict.fromList [], keywords = [ "earbud", "headphone" ] } )
        , ( "art", { name = "ARTIST PALETTE", native = "🎨", sortOrder = 1118, skinVariations = Dict.fromList [], keywords = [ "art", "artist palette", "museum", "painting", "palette" ] } )
        , ( "tophat", { name = "TOP HAT", native = "🎩", sortOrder = 1161, skinVariations = Dict.fromList [], keywords = [ "clothing", "hat", "top", "tophat" ] } )
        , ( "circus_tent", { name = "CIRCUS TENT", native = "🎪", sortOrder = 885, skinVariations = Dict.fromList [], keywords = [ "circus", "tent" ] } )
        , ( "ticket", { name = "TICKET", native = "🎫", sortOrder = 1058, skinVariations = Dict.fromList [], keywords = [ "admission", "ticket" ] } )
        , ( "clapper", { name = "CLAPPER BOARD", native = "🎬", sortOrder = 1222, skinVariations = Dict.fromList [], keywords = [ "clapper", "clapper board", "movie" ] } )
        , ( "performing_arts", { name = "PERFORMING ARTS", native = "🎭", sortOrder = 1116, skinVariations = Dict.fromList [], keywords = [ "art", "mask", "performing", "performing arts", "theater", "theatre" ] } )
        , ( "video_game", { name = "VIDEO GAME", native = "🎮", sortOrder = 1099, skinVariations = Dict.fromList [], keywords = [ "controller", "game", "video game" ] } )
        , ( "dart", { name = "DIRECT HIT", native = "🎯", sortOrder = 1092, skinVariations = Dict.fromList [], keywords = [ "bullseye", "dart", "direct hit", "game", "hit", "target" ] } )
        , ( "slot_machine", { name = "SLOT MACHINE", native = "🎰", sortOrder = 1101, skinVariations = Dict.fromList [], keywords = [ "game", "slot", "slot machine" ] } )
        , ( "8ball", { name = "BILLIARDS", native = "🎱", sortOrder = 1096, skinVariations = Dict.fromList [], keywords = [ "8", "ball", "billiard", "eight", "game", "pool 8 ball" ] } )
        , ( "game_die", { name = "GAME DIE", native = "🎲", sortOrder = 1102, skinVariations = Dict.fromList [], keywords = [ "dice", "die", "game" ] } )
        , ( "bowling", { name = "BOWLING", native = "🎳", sortOrder = 1074, skinVariations = Dict.fromList [], keywords = [ "ball", "bowling", "game" ] } )
        , ( "flower_playing_cards", { name = "FLOWER PLAYING CARDS", native = "🎴", sortOrder = 1115, skinVariations = Dict.fromList [], keywords = [ "card", "flower", "flower playing cards", "game", "Japanese", "playing" ] } )
        , ( "musical_note", { name = "MUSICAL NOTE", native = "🎵", sortOrder = 1180, skinVariations = Dict.fromList [], keywords = [ "music", "musical note", "note" ] } )
        , ( "notes", { name = "MULTIPLE MUSICAL NOTES", native = "🎶", sortOrder = 1181, skinVariations = Dict.fromList [], keywords = [ "music", "musical notes", "note", "notes" ] } )
        , ( "saxophone", { name = "SAXOPHONE", native = "🎷", sortOrder = 1188, skinVariations = Dict.fromList [], keywords = [ "instrument", "music", "sax", "saxophone" ] } )
        , ( "guitar", { name = "GUITAR", native = "🎸", sortOrder = 1190, skinVariations = Dict.fromList [], keywords = [ "guitar", "instrument", "music" ] } )
        , ( "musical_keyboard", { name = "MUSICAL KEYBOARD", native = "🎹", sortOrder = 1191, skinVariations = Dict.fromList [], keywords = [ "instrument", "keyboard", "music", "musical keyboard", "piano" ] } )
        , ( "trumpet", { name = "TRUMPET", native = "🎺", sortOrder = 1192, skinVariations = Dict.fromList [], keywords = [ "instrument", "music", "trumpet" ] } )
        , ( "violin", { name = "VIOLIN", native = "🎻", sortOrder = 1193, skinVariations = Dict.fromList [], keywords = [ "instrument", "music", "violin" ] } )
        , ( "musical_score", { name = "MUSICAL SCORE", native = "🎼", sortOrder = 1179, skinVariations = Dict.fromList [], keywords = [ "music", "musical score", "score" ] } )
        , ( "running_shirt_with_sash", { name = "RUNNING SHIRT WITH SASH", native = "🎽", sortOrder = 1088, skinVariations = Dict.fromList [], keywords = [ "athletics", "running", "sash", "shirt" ] } )
        , ( "tennis", { name = "TENNIS RACQUET AND BALL", native = "🎾", sortOrder = 1072, skinVariations = Dict.fromList [], keywords = [ "ball", "racquet", "tennis" ] } )
        , ( "ski", { name = "SKI AND SKI BOOT", native = "🎿", sortOrder = 1089, skinVariations = Dict.fromList [], keywords = [ "ski", "skis", "snow" ] } )
        , ( "basketball", { name = "BASKETBALL AND HOOP", native = "🏀", sortOrder = 1068, skinVariations = Dict.fromList [], keywords = [ "ball", "basketball", "hoop" ] } )
        , ( "checkered_flag", { name = "CHEQUERED FLAG", native = "🏁", sortOrder = 1607, skinVariations = Dict.fromList [], keywords = [ "checkered", "chequered", "chequered flag", "racing" ] } )
        , ( "snowboarder", { name = "SNOWBOARDER", native = "🏂", sortOrder = 442, skinVariations = Dict.fromList [ ( "1F3FB", "🏂🏻" ), ( "1F3FC", "🏂🏼" ), ( "1F3FD", "🏂🏽" ), ( "1F3FE", "🏂🏾" ), ( "1F3FF", "🏂🏿" ) ], keywords = [ "ski", "snow", "snowboard", "snowboarder" ] } )
        , ( "woman-running", { name = "WOMAN RUNNING", native = "🏃\u{200D}♀️", sortOrder = 426, skinVariations = Dict.fromList [ ( "1F3FB", "🏃🏻\u{200D}♀️" ), ( "1F3FC", "🏃🏼\u{200D}♀️" ), ( "1F3FD", "🏃🏽\u{200D}♀️" ), ( "1F3FE", "🏃🏾\u{200D}♀️" ), ( "1F3FF", "🏃🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-running", { name = "MAN RUNNING", native = "🏃\u{200D}♂️", sortOrder = 425, skinVariations = Dict.fromList [ ( "1F3FB", "🏃🏻\u{200D}♂️" ), ( "1F3FC", "🏃🏼\u{200D}♂️" ), ( "1F3FD", "🏃🏽\u{200D}♂️" ), ( "1F3FE", "🏃🏾\u{200D}♂️" ), ( "1F3FF", "🏃🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "runner", { name = "RUNNER", native = "🏃", sortOrder = 424, skinVariations = Dict.fromList [ ( "1F3FB", "🏃🏻" ), ( "1F3FC", "🏃🏼" ), ( "1F3FD", "🏃🏽" ), ( "1F3FE", "🏃🏾" ), ( "1F3FF", "🏃🏿" ) ], keywords = [ "marathon", "person running", "running" ] } )
        , ( "woman-surfing", { name = "WOMAN SURFING", native = "🏄\u{200D}♀️", sortOrder = 448, skinVariations = Dict.fromList [ ( "1F3FB", "🏄🏻\u{200D}♀️" ), ( "1F3FC", "🏄🏼\u{200D}♀️" ), ( "1F3FD", "🏄🏽\u{200D}♀️" ), ( "1F3FE", "🏄🏾\u{200D}♀️" ), ( "1F3FF", "🏄🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-surfing", { name = "MAN SURFING", native = "🏄\u{200D}♂️", sortOrder = 447, skinVariations = Dict.fromList [ ( "1F3FB", "🏄🏻\u{200D}♂️" ), ( "1F3FC", "🏄🏼\u{200D}♂️" ), ( "1F3FD", "🏄🏽\u{200D}♂️" ), ( "1F3FE", "🏄🏾\u{200D}♂️" ), ( "1F3FF", "🏄🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "surfer", { name = "SURFER", native = "🏄", sortOrder = 446, skinVariations = Dict.fromList [ ( "1F3FB", "🏄🏻" ), ( "1F3FC", "🏄🏼" ), ( "1F3FD", "🏄🏽" ), ( "1F3FE", "🏄🏾" ), ( "1F3FF", "🏄🏿" ) ], keywords = [ "person surfing", "surfing" ] } )
        , ( "sports_medal", { name = "SPORTS MEDAL", native = "🏅", sortOrder = 1061, skinVariations = Dict.fromList [], keywords = [ "medal", "sports medal" ] } )
        , ( "trophy", { name = "TROPHY", native = "🏆", sortOrder = 1060, skinVariations = Dict.fromList [], keywords = [ "prize", "trophy" ] } )
        , ( "horse_racing", { name = "HORSE RACING", native = "🏇", sortOrder = 440, skinVariations = Dict.fromList [ ( "1F3FB", "🏇🏻" ), ( "1F3FC", "🏇🏼" ), ( "1F3FD", "🏇🏽" ), ( "1F3FE", "🏇🏾" ), ( "1F3FF", "🏇🏿" ) ], keywords = [ "horse", "jockey", "racehorse", "racing" ] } )
        , ( "football", { name = "AMERICAN FOOTBALL", native = "🏈", sortOrder = 1070, skinVariations = Dict.fromList [], keywords = [ "american", "ball", "football" ] } )
        , ( "rugby_football", { name = "RUGBY FOOTBALL", native = "🏉", sortOrder = 1071, skinVariations = Dict.fromList [], keywords = [ "ball", "football", "rugby" ] } )
        , ( "woman-swimming", { name = "WOMAN SWIMMING", native = "🏊\u{200D}♀️", sortOrder = 454, skinVariations = Dict.fromList [ ( "1F3FB", "🏊🏻\u{200D}♀️" ), ( "1F3FC", "🏊🏼\u{200D}♀️" ), ( "1F3FD", "🏊🏽\u{200D}♀️" ), ( "1F3FE", "🏊🏾\u{200D}♀️" ), ( "1F3FF", "🏊🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-swimming", { name = "MAN SWIMMING", native = "🏊\u{200D}♂️", sortOrder = 453, skinVariations = Dict.fromList [ ( "1F3FB", "🏊🏻\u{200D}♂️" ), ( "1F3FC", "🏊🏼\u{200D}♂️" ), ( "1F3FD", "🏊🏽\u{200D}♂️" ), ( "1F3FE", "🏊🏾\u{200D}♂️" ), ( "1F3FF", "🏊🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "swimmer", { name = "SWIMMER", native = "🏊", sortOrder = 452, skinVariations = Dict.fromList [ ( "1F3FB", "🏊🏻" ), ( "1F3FC", "🏊🏼" ), ( "1F3FD", "🏊🏽" ), ( "1F3FE", "🏊🏾" ), ( "1F3FF", "🏊🏿" ) ], keywords = [ "person swimming", "swim" ] } )
        , ( "woman-lifting-weights", { name = "WOMAN LIFTING WEIGHTS", native = "🏋️\u{200D}♀️", sortOrder = 460, skinVariations = Dict.fromList [ ( "1F3FB", "🏋🏻\u{200D}♀️" ), ( "1F3FC", "🏋🏼\u{200D}♀️" ), ( "1F3FD", "🏋🏽\u{200D}♀️" ), ( "1F3FE", "🏋🏾\u{200D}♀️" ), ( "1F3FF", "🏋🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-lifting-weights", { name = "MAN LIFTING WEIGHTS", native = "🏋️\u{200D}♂️", sortOrder = 459, skinVariations = Dict.fromList [ ( "1F3FB", "🏋🏻\u{200D}♂️" ), ( "1F3FC", "🏋🏼\u{200D}♂️" ), ( "1F3FD", "🏋🏽\u{200D}♂️" ), ( "1F3FE", "🏋🏾\u{200D}♂️" ), ( "1F3FF", "🏋🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "weight_lifter", { name = "PERSON LIFTING WEIGHTS", native = "🏋️", sortOrder = 458, skinVariations = Dict.fromList [ ( "1F3FB", "🏋🏻" ), ( "1F3FC", "🏋🏼" ), ( "1F3FD", "🏋🏽" ), ( "1F3FE", "🏋🏾" ), ( "1F3FF", "🏋🏿" ) ], keywords = [] } )
        , ( "woman-golfing", { name = "WOMAN GOLFING", native = "🏌️\u{200D}♀️", sortOrder = 445, skinVariations = Dict.fromList [ ( "1F3FB", "🏌🏻\u{200D}♀️" ), ( "1F3FC", "🏌🏼\u{200D}♀️" ), ( "1F3FD", "🏌🏽\u{200D}♀️" ), ( "1F3FE", "🏌🏾\u{200D}♀️" ), ( "1F3FF", "🏌🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-golfing", { name = "MAN GOLFING", native = "🏌️\u{200D}♂️", sortOrder = 444, skinVariations = Dict.fromList [ ( "1F3FB", "🏌🏻\u{200D}♂️" ), ( "1F3FC", "🏌🏼\u{200D}♂️" ), ( "1F3FD", "🏌🏽\u{200D}♂️" ), ( "1F3FE", "🏌🏾\u{200D}♂️" ), ( "1F3FF", "🏌🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "golfer", { name = "PERSON GOLFING", native = "🏌️", sortOrder = 443, skinVariations = Dict.fromList [ ( "1F3FB", "🏌🏻" ), ( "1F3FC", "🏌🏼" ), ( "1F3FD", "🏌🏽" ), ( "1F3FE", "🏌🏾" ), ( "1F3FF", "🏌🏿" ) ], keywords = [] } )
        , ( "racing_motorcycle", { name = "MOTORCYCLE", native = "🏍️", sortOrder = 916, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "racing_car", { name = "RACING CAR", native = "🏎️", sortOrder = 915, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "cricket_bat_and_ball", { name = "CRICKET BAT AND BALL", native = "🏏", sortOrder = 1075, skinVariations = Dict.fromList [], keywords = [ "ball", "bat", "cricket game", "game" ] } )
        , ( "volleyball", { name = "VOLLEYBALL", native = "🏐", sortOrder = 1069, skinVariations = Dict.fromList [], keywords = [ "ball", "game", "volleyball" ] } )
        , ( "field_hockey_stick_and_ball", { name = "FIELD HOCKEY STICK AND BALL", native = "🏑", sortOrder = 1076, skinVariations = Dict.fromList [], keywords = [ "ball", "field", "game", "hockey", "stick" ] } )
        , ( "ice_hockey_stick_and_puck", { name = "ICE HOCKEY STICK AND PUCK", native = "🏒", sortOrder = 1077, skinVariations = Dict.fromList [], keywords = [ "game", "hockey", "ice", "puck", "stick" ] } )
        , ( "table_tennis_paddle_and_ball", { name = "TABLE TENNIS PADDLE AND BALL", native = "🏓", sortOrder = 1079, skinVariations = Dict.fromList [], keywords = [ "ball", "bat", "game", "paddle", "ping pong", "table tennis" ] } )
        , ( "snow_capped_mountain", { name = "SNOW-CAPPED MOUNTAIN", native = "🏔️", sortOrder = 827, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "camping", { name = "CAMPING", native = "🏕️", sortOrder = 831, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "beach_with_umbrella", { name = "BEACH WITH UMBRELLA", native = "🏖️", sortOrder = 832, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "building_construction", { name = "BUILDING CONSTRUCTION", native = "🏗️", sortOrder = 838, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "house_buildings", { name = "HOUSES", native = "🏘️", sortOrder = 843, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "cityscape", { name = "CITYSCAPE", native = "🏙️", sortOrder = 873, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "derelict_house_building", { name = "DERELICT HOUSE", native = "🏚️", sortOrder = 844, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "classical_building", { name = "CLASSICAL BUILDING", native = "🏛️", sortOrder = 837, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "desert", { name = "DESERT", native = "🏜️", sortOrder = 833, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "desert_island", { name = "DESERT ISLAND", native = "🏝️", sortOrder = 834, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "national_park", { name = "NATIONAL PARK", native = "🏞️", sortOrder = 835, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "stadium", { name = "STADIUM", native = "🏟️", sortOrder = 836, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "house", { name = "HOUSE BUILDING", native = "🏠", sortOrder = 845, skinVariations = Dict.fromList [], keywords = [ "home", "house" ] } )
        , ( "house_with_garden", { name = "HOUSE WITH GARDEN", native = "🏡", sortOrder = 846, skinVariations = Dict.fromList [], keywords = [ "garden", "home", "house", "house with garden" ] } )
        , ( "office", { name = "OFFICE BUILDING", native = "🏢", sortOrder = 847, skinVariations = Dict.fromList [], keywords = [ "building", "office building" ] } )
        , ( "post_office", { name = "JAPANESE POST OFFICE", native = "🏣", sortOrder = 848, skinVariations = Dict.fromList [], keywords = [ "Japanese", "Japanese post office", "post" ] } )
        , ( "european_post_office", { name = "EUROPEAN POST OFFICE", native = "🏤", sortOrder = 849, skinVariations = Dict.fromList [], keywords = [ "European", "post", "post office" ] } )
        , ( "hospital", { name = "HOSPITAL", native = "🏥", sortOrder = 850, skinVariations = Dict.fromList [], keywords = [ "doctor", "hospital", "medicine" ] } )
        , ( "bank", { name = "BANK", native = "🏦", sortOrder = 851, skinVariations = Dict.fromList [], keywords = [ "bank", "building" ] } )
        , ( "atm", { name = "AUTOMATED TELLER MACHINE", native = "🏧", sortOrder = 1384, skinVariations = Dict.fromList [], keywords = [ "ATM", "ATM sign", "automated", "bank", "teller" ] } )
        , ( "hotel", { name = "HOTEL", native = "🏨", sortOrder = 852, skinVariations = Dict.fromList [], keywords = [ "building", "hotel" ] } )
        , ( "love_hotel", { name = "LOVE HOTEL", native = "🏩", sortOrder = 853, skinVariations = Dict.fromList [], keywords = [ "hotel", "love" ] } )
        , ( "convenience_store", { name = "CONVENIENCE STORE", native = "🏪", sortOrder = 854, skinVariations = Dict.fromList [], keywords = [ "convenience", "store" ] } )
        , ( "school", { name = "SCHOOL", native = "🏫", sortOrder = 855, skinVariations = Dict.fromList [], keywords = [ "building", "school" ] } )
        , ( "department_store", { name = "DEPARTMENT STORE", native = "🏬", sortOrder = 856, skinVariations = Dict.fromList [], keywords = [ "department", "store" ] } )
        , ( "factory", { name = "FACTORY", native = "🏭", sortOrder = 857, skinVariations = Dict.fromList [], keywords = [ "building", "factory" ] } )
        , ( "izakaya_lantern", { name = "IZAKAYA LANTERN", native = "🏮", sortOrder = 1233, skinVariations = Dict.fromList [], keywords = [ "bar", "lantern", "light", "red", "red paper lantern" ] } )
        , ( "japanese_castle", { name = "JAPANESE CASTLE", native = "🏯", sortOrder = 858, skinVariations = Dict.fromList [], keywords = [ "castle", "Japanese" ] } )
        , ( "european_castle", { name = "EUROPEAN CASTLE", native = "🏰", sortOrder = 859, skinVariations = Dict.fromList [], keywords = [ "castle", "European" ] } )
        , ( "rainbow-flag", { name = "RAINBOW FLAG", native = "🏳️\u{200D}🌈", sortOrder = 1612, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "transgender_flag", { name = "TRANSGENDER FLAG", native = "🏳️\u{200D}⚧️", sortOrder = 1613, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "waving_white_flag", { name = "WHITE FLAG", native = "🏳️", sortOrder = 1611, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "pirate_flag", { name = "PIRATE FLAG", native = "🏴\u{200D}☠️", sortOrder = 1614, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-england", { name = "England Flag", native = "🏴\u{E0067}\u{E0062}\u{E0065}\u{E006E}\u{E0067}\u{E007F}", sortOrder = 1873, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-scotland", { name = "Scotland Flag", native = "🏴\u{E0067}\u{E0062}\u{E0073}\u{E0063}\u{E0074}\u{E007F}", sortOrder = 1874, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "flag-wales", { name = "Wales Flag", native = "🏴\u{E0067}\u{E0062}\u{E0077}\u{E006C}\u{E0073}\u{E007F}", sortOrder = 1875, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "waving_black_flag", { name = "WAVING BLACK FLAG", native = "🏴", sortOrder = 1610, skinVariations = Dict.fromList [], keywords = [ "black flag", "waving" ] } )
        , ( "rosette", { name = "ROSETTE", native = "🏵️", sortOrder = 663, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "label", { name = "LABEL", native = "🏷️", sortOrder = 1251, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "badminton_racquet_and_shuttlecock", { name = "BADMINTON RACQUET AND SHUTTLECOCK", native = "🏸", sortOrder = 1080, skinVariations = Dict.fromList [], keywords = [ "badminton", "birdie", "game", "racquet", "shuttlecock" ] } )
        , ( "bow_and_arrow", { name = "BOW AND ARROW", native = "🏹", sortOrder = 1320, skinVariations = Dict.fromList [], keywords = [ "archer", "arrow", "bow", "bow and arrow", "Sagittarius", "zodiac" ] } )
        , ( "amphora", { name = "AMPHORA", native = "🏺", sortOrder = 819, skinVariations = Dict.fromList [], keywords = [ "amphora", "Aquarius", "cooking", "drink", "jug", "zodiac" ] } )
        , ( "skin-tone-2", { name = "EMOJI MODIFIER FITZPATRICK TYPE-1-2", native = "🏻", sortOrder = 530, skinVariations = Dict.fromList [], keywords = [ "light skin tone", "skin tone", "type 1–2" ] } )
        , ( "skin-tone-3", { name = "EMOJI MODIFIER FITZPATRICK TYPE-3", native = "🏼", sortOrder = 531, skinVariations = Dict.fromList [], keywords = [ "medium-light skin tone", "skin tone", "type 3" ] } )
        , ( "skin-tone-4", { name = "EMOJI MODIFIER FITZPATRICK TYPE-4", native = "🏽", sortOrder = 532, skinVariations = Dict.fromList [], keywords = [ "medium skin tone", "skin tone", "type 4" ] } )
        , ( "skin-tone-5", { name = "EMOJI MODIFIER FITZPATRICK TYPE-5", native = "🏾", sortOrder = 533, skinVariations = Dict.fromList [], keywords = [ "medium-dark skin tone", "skin tone", "type 5" ] } )
        , ( "skin-tone-6", { name = "EMOJI MODIFIER FITZPATRICK TYPE-6", native = "🏿", sortOrder = 534, skinVariations = Dict.fromList [], keywords = [ "dark skin tone", "skin tone", "type 6" ] } )
        , ( "rat", { name = "RAT", native = "🐀", sortOrder = 583, skinVariations = Dict.fromList [], keywords = [ "rat" ] } )
        , ( "mouse2", { name = "MOUSE", native = "🐁", sortOrder = 582, skinVariations = Dict.fromList [], keywords = [ "mouse" ] } )
        , ( "ox", { name = "OX", native = "🐂", sortOrder = 563, skinVariations = Dict.fromList [], keywords = [ "bull", "ox", "Taurus", "zodiac" ] } )
        , ( "water_buffalo", { name = "WATER BUFFALO", native = "🐃", sortOrder = 564, skinVariations = Dict.fromList [], keywords = [ "buffalo", "water" ] } )
        , ( "cow2", { name = "COW", native = "🐄", sortOrder = 565, skinVariations = Dict.fromList [], keywords = [ "cow" ] } )
        , ( "tiger2", { name = "TIGER", native = "🐅", sortOrder = 552, skinVariations = Dict.fromList [], keywords = [ "tiger" ] } )
        , ( "leopard", { name = "LEOPARD", native = "🐆", sortOrder = 553, skinVariations = Dict.fromList [], keywords = [ "leopard" ] } )
        , ( "rabbit2", { name = "RABBIT", native = "🐇", sortOrder = 586, skinVariations = Dict.fromList [], keywords = [ "bunny", "pet", "rabbit" ] } )
        , ( "black_cat", { name = "BLACK CAT", native = "🐈\u{200D}⬛", sortOrder = 549, skinVariations = Dict.fromList [], keywords = [ "black", "cat", "unlucky" ] } )
        , ( "cat2", { name = "CAT", native = "🐈", sortOrder = 548, skinVariations = Dict.fromList [], keywords = [ "cat", "pet" ] } )
        , ( "dragon", { name = "DRAGON", native = "🐉", sortOrder = 628, skinVariations = Dict.fromList [], keywords = [ "dragon", "fairy tale" ] } )
        , ( "crocodile", { name = "CROCODILE", native = "🐊", sortOrder = 623, skinVariations = Dict.fromList [], keywords = [ "crocodile" ] } )
        , ( "whale2", { name = "WHALE", native = "🐋", sortOrder = 632, skinVariations = Dict.fromList [], keywords = [ "whale" ] } )
        , ( "snail", { name = "SNAIL", native = "🐌", sortOrder = 643, skinVariations = Dict.fromList [], keywords = [ "snail" ] } )
        , ( "snake", { name = "SNAKE", native = "🐍", sortOrder = 626, skinVariations = Dict.fromList [], keywords = [ "bearer", "Ophiuchus", "serpent", "snake", "zodiac" ] } )
        , ( "racehorse", { name = "HORSE", native = "🐎", sortOrder = 557, skinVariations = Dict.fromList [], keywords = [ "equestrian", "horse", "racehorse", "racing" ] } )
        , ( "ram", { name = "RAM", native = "🐏", sortOrder = 570, skinVariations = Dict.fromList [], keywords = [ "Aries", "male", "ram", "sheep", "zodiac" ] } )
        , ( "goat", { name = "GOAT", native = "🐐", sortOrder = 572, skinVariations = Dict.fromList [], keywords = [ "Capricorn", "goat", "zodiac" ] } )
        , ( "sheep", { name = "SHEEP", native = "🐑", sortOrder = 571, skinVariations = Dict.fromList [], keywords = [ "ewe", "female", "sheep" ] } )
        , ( "monkey", { name = "MONKEY", native = "🐒", sortOrder = 536, skinVariations = Dict.fromList [], keywords = [ "monkey" ] } )
        , ( "rooster", { name = "ROOSTER", native = "🐓", sortOrder = 603, skinVariations = Dict.fromList [], keywords = [ "bird", "rooster" ] } )
        , ( "chicken", { name = "CHICKEN", native = "🐔", sortOrder = 602, skinVariations = Dict.fromList [], keywords = [ "bird", "chicken" ] } )
        , ( "service_dog", { name = "SERVICE DOG", native = "🐕\u{200D}🦺", sortOrder = 542, skinVariations = Dict.fromList [], keywords = [ "accessibility", "assistance", "dog", "service" ] } )
        , ( "dog2", { name = "DOG", native = "🐕", sortOrder = 540, skinVariations = Dict.fromList [], keywords = [ "dog", "pet" ] } )
        , ( "pig2", { name = "PIG", native = "🐖", sortOrder = 567, skinVariations = Dict.fromList [], keywords = [ "pig", "sow" ] } )
        , ( "boar", { name = "BOAR", native = "🐗", sortOrder = 568, skinVariations = Dict.fromList [], keywords = [ "boar", "pig" ] } )
        , ( "elephant", { name = "ELEPHANT", native = "🐘", sortOrder = 577, skinVariations = Dict.fromList [], keywords = [ "elephant" ] } )
        , ( "octopus", { name = "OCTOPUS", native = "🐙", sortOrder = 639, skinVariations = Dict.fromList [], keywords = [ "octopus" ] } )
        , ( "shell", { name = "SPIRAL SHELL", native = "🐚", sortOrder = 640, skinVariations = Dict.fromList [], keywords = [ "shell", "spiral" ] } )
        , ( "bug", { name = "BUG", native = "🐛", sortOrder = 645, skinVariations = Dict.fromList [], keywords = [ "bug", "insect" ] } )
        , ( "ant", { name = "ANT", native = "🐜", sortOrder = 646, skinVariations = Dict.fromList [], keywords = [ "ant", "insect" ] } )
        , ( "bee", { name = "HONEYBEE", native = "🐝", sortOrder = 647, skinVariations = Dict.fromList [], keywords = [ "bee", "honeybee", "insect" ] } )
        , ( "ladybug", { name = "LADY BEETLE", native = "🐞", sortOrder = 649, skinVariations = Dict.fromList [], keywords = [ "beetle", "insect", "lady beetle", "ladybird", "ladybug" ] } )
        , ( "fish", { name = "FISH", native = "🐟", sortOrder = 635, skinVariations = Dict.fromList [], keywords = [ "fish", "Pisces", "zodiac" ] } )
        , ( "tropical_fish", { name = "TROPICAL FISH", native = "🐠", sortOrder = 636, skinVariations = Dict.fromList [], keywords = [ "fish", "tropical" ] } )
        , ( "blowfish", { name = "BLOWFISH", native = "🐡", sortOrder = 637, skinVariations = Dict.fromList [], keywords = [ "blowfish", "fish" ] } )
        , ( "turtle", { name = "TURTLE", native = "🐢", sortOrder = 624, skinVariations = Dict.fromList [], keywords = [ "terrapin", "tortoise", "turtle" ] } )
        , ( "hatching_chick", { name = "HATCHING CHICK", native = "🐣", sortOrder = 604, skinVariations = Dict.fromList [], keywords = [ "baby", "bird", "chick", "hatching" ] } )
        , ( "baby_chick", { name = "BABY CHICK", native = "🐤", sortOrder = 605, skinVariations = Dict.fromList [], keywords = [ "baby", "bird", "chick" ] } )
        , ( "hatched_chick", { name = "FRONT-FACING BABY CHICK", native = "🐥", sortOrder = 606, skinVariations = Dict.fromList [], keywords = [ "baby", "bird", "chick", "front-facing baby chick" ] } )
        , ( "black_bird", { name = "BLACK BIRD", native = "🐦\u{200D}⬛", sortOrder = 620, skinVariations = Dict.fromList [], keywords = [ "bird", "black", "crow", "raven", "rook" ] } )
        , ( "bird", { name = "BIRD", native = "🐦", sortOrder = 607, skinVariations = Dict.fromList [], keywords = [ "bird" ] } )
        , ( "penguin", { name = "PENGUIN", native = "🐧", sortOrder = 608, skinVariations = Dict.fromList [], keywords = [ "bird", "penguin" ] } )
        , ( "koala", { name = "KOALA", native = "🐨", sortOrder = 593, skinVariations = Dict.fromList [], keywords = [ "face", "koala", "marsupial" ] } )
        , ( "poodle", { name = "POODLE", native = "🐩", sortOrder = 543, skinVariations = Dict.fromList [], keywords = [ "dog", "poodle" ] } )
        , ( "dromedary_camel", { name = "DROMEDARY CAMEL", native = "🐪", sortOrder = 573, skinVariations = Dict.fromList [], keywords = [ "camel", "dromedary", "hump" ] } )
        , ( "camel", { name = "BACTRIAN CAMEL", native = "🐫", sortOrder = 574, skinVariations = Dict.fromList [], keywords = [ "bactrian", "camel", "hump", "two-hump camel" ] } )
        , ( "dolphin", { name = "DOLPHIN", native = "🐬", sortOrder = 633, skinVariations = Dict.fromList [], keywords = [ "dolphin", "flipper" ] } )
        , ( "mouse", { name = "MOUSE FACE", native = "🐭", sortOrder = 581, skinVariations = Dict.fromList [], keywords = [ "face", "mouse" ] } )
        , ( "cow", { name = "COW FACE", native = "🐮", sortOrder = 562, skinVariations = Dict.fromList [], keywords = [ "cow", "face" ] } )
        , ( "tiger", { name = "TIGER FACE", native = "🐯", sortOrder = 551, skinVariations = Dict.fromList [], keywords = [ "face", "tiger" ] } )
        , ( "rabbit", { name = "RABBIT FACE", native = "🐰", sortOrder = 585, skinVariations = Dict.fromList [], keywords = [ "bunny", "face", "pet", "rabbit" ] } )
        , ( "cat", { name = "CAT FACE", native = "🐱", sortOrder = 547, skinVariations = Dict.fromList [], keywords = [ "cat", "face", "pet" ] } )
        , ( "dragon_face", { name = "DRAGON FACE", native = "🐲", sortOrder = 627, skinVariations = Dict.fromList [], keywords = [ "dragon", "face", "fairy tale" ] } )
        , ( "whale", { name = "SPOUTING WHALE", native = "🐳", sortOrder = 631, skinVariations = Dict.fromList [], keywords = [ "face", "spouting", "whale" ] } )
        , ( "horse", { name = "HORSE FACE", native = "🐴", sortOrder = 554, skinVariations = Dict.fromList [], keywords = [ "face", "horse" ] } )
        , ( "monkey_face", { name = "MONKEY FACE", native = "🐵", sortOrder = 535, skinVariations = Dict.fromList [], keywords = [ "face", "monkey" ] } )
        , ( "dog", { name = "DOG FACE", native = "🐶", sortOrder = 539, skinVariations = Dict.fromList [], keywords = [ "dog", "face", "pet" ] } )
        , ( "pig", { name = "PIG FACE", native = "🐷", sortOrder = 566, skinVariations = Dict.fromList [], keywords = [ "face", "pig" ] } )
        , ( "frog", { name = "FROG FACE", native = "🐸", sortOrder = 622, skinVariations = Dict.fromList [], keywords = [ "face", "frog" ] } )
        , ( "hamster", { name = "HAMSTER FACE", native = "🐹", sortOrder = 584, skinVariations = Dict.fromList [], keywords = [ "face", "hamster", "pet" ] } )
        , ( "wolf", { name = "WOLF FACE", native = "🐺", sortOrder = 544, skinVariations = Dict.fromList [], keywords = [ "face", "wolf" ] } )
        , ( "polar_bear", { name = "POLAR BEAR", native = "🐻\u{200D}❄️", sortOrder = 592, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "bear", { name = "BEAR FACE", native = "🐻", sortOrder = 591, skinVariations = Dict.fromList [], keywords = [ "bear", "face" ] } )
        , ( "panda_face", { name = "PANDA FACE", native = "🐼", sortOrder = 594, skinVariations = Dict.fromList [], keywords = [ "face", "panda" ] } )
        , ( "pig_nose", { name = "PIG NOSE", native = "🐽", sortOrder = 569, skinVariations = Dict.fromList [], keywords = [ "face", "nose", "pig" ] } )
        , ( "feet", { name = "PAW PRINTS", native = "🐾", sortOrder = 600, skinVariations = Dict.fromList [], keywords = [ "feet", "paw", "paw prints", "print" ] } )
        , ( "chipmunk", { name = "CHIPMUNK", native = "🐿️", sortOrder = 587, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "eyes", { name = "EYES", native = "👀", sortOrder = 223, skinVariations = Dict.fromList [], keywords = [ "eye", "eyes", "face" ] } )
        , ( "eye-in-speech-bubble", { name = "EYE IN SPEECH BUBBLE", native = "👁️\u{200D}🗨️", sortOrder = 162, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "eye", { name = "EYE", native = "👁️", sortOrder = 224, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ear", { name = "EAR", native = "👂", sortOrder = 215, skinVariations = Dict.fromList [ ( "1F3FB", "👂🏻" ), ( "1F3FC", "👂🏼" ), ( "1F3FD", "👂🏽" ), ( "1F3FE", "👂🏾" ), ( "1F3FF", "👂🏿" ) ], keywords = [ "body", "ear" ] } )
        , ( "nose", { name = "NOSE", native = "👃", sortOrder = 217, skinVariations = Dict.fromList [ ( "1F3FB", "👃🏻" ), ( "1F3FC", "👃🏼" ), ( "1F3FD", "👃🏽" ), ( "1F3FE", "👃🏾" ), ( "1F3FF", "👃🏿" ) ], keywords = [ "body", "nose" ] } )
        , ( "lips", { name = "MOUTH", native = "👄", sortOrder = 226, skinVariations = Dict.fromList [], keywords = [ "lips", "mouth" ] } )
        , ( "tongue", { name = "TONGUE", native = "👅", sortOrder = 225, skinVariations = Dict.fromList [], keywords = [ "body", "tongue" ] } )
        , ( "point_up_2", { name = "WHITE UP POINTING BACKHAND INDEX", native = "👆", sortOrder = 189, skinVariations = Dict.fromList [ ( "1F3FB", "👆🏻" ), ( "1F3FC", "👆🏼" ), ( "1F3FD", "👆🏽" ), ( "1F3FE", "👆🏾" ), ( "1F3FF", "👆🏿" ) ], keywords = [ "backhand", "backhand index pointing up", "finger", "hand", "point", "up" ] } )
        , ( "point_down", { name = "WHITE DOWN POINTING BACKHAND INDEX", native = "👇", sortOrder = 191, skinVariations = Dict.fromList [ ( "1F3FB", "👇🏻" ), ( "1F3FC", "👇🏼" ), ( "1F3FD", "👇🏽" ), ( "1F3FE", "👇🏾" ), ( "1F3FF", "👇🏿" ) ], keywords = [ "backhand", "backhand index pointing down", "down", "finger", "hand", "point" ] } )
        , ( "point_left", { name = "WHITE LEFT POINTING BACKHAND INDEX", native = "👈", sortOrder = 187, skinVariations = Dict.fromList [ ( "1F3FB", "👈🏻" ), ( "1F3FC", "👈🏼" ), ( "1F3FD", "👈🏽" ), ( "1F3FE", "👈🏾" ), ( "1F3FF", "👈🏿" ) ], keywords = [ "backhand", "backhand index pointing left", "finger", "hand", "index", "point" ] } )
        , ( "point_right", { name = "WHITE RIGHT POINTING BACKHAND INDEX", native = "👉", sortOrder = 188, skinVariations = Dict.fromList [ ( "1F3FB", "👉🏻" ), ( "1F3FC", "👉🏼" ), ( "1F3FD", "👉🏽" ), ( "1F3FE", "👉🏾" ), ( "1F3FF", "👉🏿" ) ], keywords = [ "backhand", "backhand index pointing right", "finger", "hand", "index", "point" ] } )
        , ( "facepunch", { name = "FISTED HAND SIGN", native = "👊", sortOrder = 197, skinVariations = Dict.fromList [ ( "1F3FB", "👊🏻" ), ( "1F3FC", "👊🏼" ), ( "1F3FD", "👊🏽" ), ( "1F3FE", "👊🏾" ), ( "1F3FF", "👊🏿" ) ], keywords = [ "clenched", "fist", "hand", "oncoming fist", "punch" ] } )
        , ( "wave", { name = "WAVING HAND SIGN", native = "👋", sortOrder = 167, skinVariations = Dict.fromList [ ( "1F3FB", "👋🏻" ), ( "1F3FC", "👋🏼" ), ( "1F3FD", "👋🏽" ), ( "1F3FE", "👋🏾" ), ( "1F3FF", "👋🏿" ) ], keywords = [ "hand", "wave", "waving" ] } )
        , ( "ok_hand", { name = "OK HAND SIGN", native = "👌", sortOrder = 178, skinVariations = Dict.fromList [ ( "1F3FB", "👌🏻" ), ( "1F3FC", "👌🏼" ), ( "1F3FD", "👌🏽" ), ( "1F3FE", "👌🏾" ), ( "1F3FF", "👌🏿" ) ], keywords = [ "hand", "OK" ] } )
        , ( "+1", { name = "THUMBS UP SIGN", native = "👍", sortOrder = 194, skinVariations = Dict.fromList [ ( "1F3FB", "👍🏻" ), ( "1F3FC", "👍🏼" ), ( "1F3FD", "👍🏽" ), ( "1F3FE", "👍🏾" ), ( "1F3FF", "👍🏿" ) ], keywords = [ "+1", "hand", "thumb", "thumbs up", "up" ] } )
        , ( "-1", { name = "THUMBS DOWN SIGN", native = "👎", sortOrder = 195, skinVariations = Dict.fromList [ ( "1F3FB", "👎🏻" ), ( "1F3FC", "👎🏼" ), ( "1F3FD", "👎🏽" ), ( "1F3FE", "👎🏾" ), ( "1F3FF", "👎🏿" ) ], keywords = [ "-1", "down", "hand", "thumb", "thumbs down" ] } )
        , ( "clap", { name = "CLAPPING HANDS SIGN", native = "👏", sortOrder = 200, skinVariations = Dict.fromList [ ( "1F3FB", "👏🏻" ), ( "1F3FC", "👏🏼" ), ( "1F3FD", "👏🏽" ), ( "1F3FE", "👏🏾" ), ( "1F3FF", "👏🏿" ) ], keywords = [ "clap", "clapping hands", "hand" ] } )
        , ( "open_hands", { name = "OPEN HANDS SIGN", native = "👐", sortOrder = 203, skinVariations = Dict.fromList [ ( "1F3FB", "👐🏻" ), ( "1F3FC", "👐🏼" ), ( "1F3FD", "👐🏽" ), ( "1F3FE", "👐🏾" ), ( "1F3FF", "👐🏿" ) ], keywords = [ "hand", "open", "open hands" ] } )
        , ( "crown", { name = "CROWN", native = "👑", sortOrder = 1159, skinVariations = Dict.fromList [], keywords = [ "clothing", "crown", "king", "queen" ] } )
        , ( "womans_hat", { name = "WOMANS HAT", native = "👒", sortOrder = 1160, skinVariations = Dict.fromList [], keywords = [ "clothing", "hat", "woman", "woman’s hat" ] } )
        , ( "eyeglasses", { name = "EYEGLASSES", native = "👓", sortOrder = 1123, skinVariations = Dict.fromList [], keywords = [ "clothing", "eye", "eyeglasses", "eyewear", "glasses" ] } )
        , ( "necktie", { name = "NECKTIE", native = "👔", sortOrder = 1128, skinVariations = Dict.fromList [], keywords = [ "clothing", "necktie", "tie" ] } )
        , ( "shirt", { name = "T-SHIRT", native = "👕", sortOrder = 1129, skinVariations = Dict.fromList [], keywords = [ "clothing", "shirt", "t-shirt", "tshirt" ] } )
        , ( "jeans", { name = "JEANS", native = "👖", sortOrder = 1130, skinVariations = Dict.fromList [], keywords = [ "clothing", "jeans", "pants", "trousers" ] } )
        , ( "dress", { name = "DRESS", native = "👗", sortOrder = 1135, skinVariations = Dict.fromList [], keywords = [ "clothing", "dress" ] } )
        , ( "kimono", { name = "KIMONO", native = "👘", sortOrder = 1136, skinVariations = Dict.fromList [], keywords = [ "clothing", "kimono" ] } )
        , ( "bikini", { name = "BIKINI", native = "👙", sortOrder = 1141, skinVariations = Dict.fromList [], keywords = [ "bikini", "clothing", "swim" ] } )
        , ( "womans_clothes", { name = "WOMANS CLOTHES", native = "👚", sortOrder = 1142, skinVariations = Dict.fromList [], keywords = [ "clothing", "woman", "woman’s clothes" ] } )
        , ( "purse", { name = "PURSE", native = "👛", sortOrder = 1144, skinVariations = Dict.fromList [], keywords = [ "clothing", "coin", "purse" ] } )
        , ( "handbag", { name = "HANDBAG", native = "👜", sortOrder = 1145, skinVariations = Dict.fromList [], keywords = [ "bag", "clothing", "handbag", "purse" ] } )
        , ( "pouch", { name = "POUCH", native = "👝", sortOrder = 1146, skinVariations = Dict.fromList [], keywords = [ "bag", "clothing", "clutch bag", "pouch" ] } )
        , ( "mans_shoe", { name = "MANS SHOE", native = "👞", sortOrder = 1150, skinVariations = Dict.fromList [], keywords = [ "clothing", "man", "man’s shoe", "shoe" ] } )
        , ( "athletic_shoe", { name = "ATHLETIC SHOE", native = "👟", sortOrder = 1151, skinVariations = Dict.fromList [], keywords = [ "athletic", "clothing", "running shoe", "shoe", "sneaker" ] } )
        , ( "high_heel", { name = "HIGH-HEELED SHOE", native = "👠", sortOrder = 1154, skinVariations = Dict.fromList [], keywords = [ "clothing", "heel", "high-heeled shoe", "shoe", "woman" ] } )
        , ( "sandal", { name = "WOMANS SANDAL", native = "👡", sortOrder = 1155, skinVariations = Dict.fromList [], keywords = [ "clothing", "sandal", "shoe", "woman", "woman’s sandal" ] } )
        , ( "boot", { name = "WOMANS BOOTS", native = "👢", sortOrder = 1157, skinVariations = Dict.fromList [], keywords = [ "boot", "clothing", "shoe", "woman", "woman’s boot" ] } )
        , ( "footprints", { name = "FOOTPRINTS", native = "👣", sortOrder = 529, skinVariations = Dict.fromList [], keywords = [ "clothing", "footprint", "footprints", "print" ] } )
        , ( "bust_in_silhouette", { name = "BUST IN SILHOUETTE", native = "👤", sortOrder = 526, skinVariations = Dict.fromList [], keywords = [ "bust", "bust in silhouette", "silhouette" ] } )
        , ( "busts_in_silhouette", { name = "BUSTS IN SILHOUETTE", native = "👥", sortOrder = 527, skinVariations = Dict.fromList [], keywords = [ "bust", "busts in silhouette", "silhouette" ] } )
        , ( "boy", { name = "BOY", native = "👦", sortOrder = 230, skinVariations = Dict.fromList [ ( "1F3FB", "👦🏻" ), ( "1F3FC", "👦🏼" ), ( "1F3FD", "👦🏽" ), ( "1F3FE", "👦🏾" ), ( "1F3FF", "👦🏿" ) ], keywords = [ "boy", "young" ] } )
        , ( "girl", { name = "GIRL", native = "👧", sortOrder = 231, skinVariations = Dict.fromList [ ( "1F3FB", "👧🏻" ), ( "1F3FC", "👧🏼" ), ( "1F3FD", "👧🏽" ), ( "1F3FE", "👧🏾" ), ( "1F3FF", "👧🏿" ) ], keywords = [ "girl", "Virgo", "young", "zodiac" ] } )
        , ( "male-farmer", { name = "MAN FARMER", native = "👨\u{200D}🌾", sortOrder = 299, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🌾" ), ( "1F3FC", "👨🏼\u{200D}🌾" ), ( "1F3FD", "👨🏽\u{200D}🌾" ), ( "1F3FE", "👨🏾\u{200D}🌾" ), ( "1F3FF", "👨🏿\u{200D}🌾" ) ], keywords = [ "farmer", "gardener", "man", "rancher" ] } )
        , ( "male-cook", { name = "MAN COOK", native = "👨\u{200D}🍳", sortOrder = 302, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🍳" ), ( "1F3FC", "👨🏼\u{200D}🍳" ), ( "1F3FD", "👨🏽\u{200D}🍳" ), ( "1F3FE", "👨🏾\u{200D}🍳" ), ( "1F3FF", "👨🏿\u{200D}🍳" ) ], keywords = [ "chef", "cook", "man" ] } )
        , ( "man_feeding_baby", { name = "MAN FEEDING BABY", native = "👨\u{200D}🍼", sortOrder = 366, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🍼" ), ( "1F3FC", "👨🏼\u{200D}🍼" ), ( "1F3FD", "👨🏽\u{200D}🍼" ), ( "1F3FE", "👨🏾\u{200D}🍼" ), ( "1F3FF", "👨🏿\u{200D}🍼" ) ], keywords = [ "baby", "feeding", "man", "nursing" ] } )
        , ( "male-student", { name = "MAN STUDENT", native = "👨\u{200D}🎓", sortOrder = 290, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🎓" ), ( "1F3FC", "👨🏼\u{200D}🎓" ), ( "1F3FD", "👨🏽\u{200D}🎓" ), ( "1F3FE", "👨🏾\u{200D}🎓" ), ( "1F3FF", "👨🏿\u{200D}🎓" ) ], keywords = [ "graduate", "man", "student" ] } )
        , ( "male-singer", { name = "MAN SINGER", native = "👨\u{200D}🎤", sortOrder = 320, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🎤" ), ( "1F3FC", "👨🏼\u{200D}🎤" ), ( "1F3FD", "👨🏽\u{200D}🎤" ), ( "1F3FE", "👨🏾\u{200D}🎤" ), ( "1F3FF", "👨🏿\u{200D}🎤" ) ], keywords = [ "actor", "entertainer", "man", "rock", "singer", "star" ] } )
        , ( "male-artist", { name = "MAN ARTIST", native = "👨\u{200D}🎨", sortOrder = 323, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🎨" ), ( "1F3FC", "👨🏼\u{200D}🎨" ), ( "1F3FD", "👨🏽\u{200D}🎨" ), ( "1F3FE", "👨🏾\u{200D}🎨" ), ( "1F3FF", "👨🏿\u{200D}🎨" ) ], keywords = [ "artist", "man", "palette" ] } )
        , ( "male-teacher", { name = "MAN TEACHER", native = "👨\u{200D}🏫", sortOrder = 293, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🏫" ), ( "1F3FC", "👨🏼\u{200D}🏫" ), ( "1F3FD", "👨🏽\u{200D}🏫" ), ( "1F3FE", "👨🏾\u{200D}🏫" ), ( "1F3FF", "👨🏿\u{200D}🏫" ) ], keywords = [ "instructor", "lecturer", "man", "professor", "teacher" ] } )
        , ( "male-factory-worker", { name = "MAN FACTORY WORKER", native = "👨\u{200D}🏭", sortOrder = 308, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🏭" ), ( "1F3FC", "👨🏼\u{200D}🏭" ), ( "1F3FD", "👨🏽\u{200D}🏭" ), ( "1F3FE", "👨🏾\u{200D}🏭" ), ( "1F3FF", "👨🏿\u{200D}🏭" ) ], keywords = [ "assembly", "factory", "industrial", "man", "worker" ] } )
        , ( "man-boy-boy", { name = "FAMILY: MAN, BOY, BOY", native = "👨\u{200D}👦\u{200D}👦", sortOrder = 516, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-boy", { name = "FAMILY: MAN, BOY", native = "👨\u{200D}👦", sortOrder = 515, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-girl-boy", { name = "FAMILY: MAN, GIRL, BOY", native = "👨\u{200D}👧\u{200D}👦", sortOrder = 518, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-girl-girl", { name = "FAMILY: MAN, GIRL, GIRL", native = "👨\u{200D}👧\u{200D}👧", sortOrder = 519, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-girl", { name = "FAMILY: MAN, GIRL", native = "👨\u{200D}👧", sortOrder = 517, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-man-boy", { name = "FAMILY: MAN, MAN, BOY", native = "👨\u{200D}👨\u{200D}👦", sortOrder = 505, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-man-boy-boy", { name = "FAMILY: MAN, MAN, BOY, BOY", native = "👨\u{200D}👨\u{200D}👦\u{200D}👦", sortOrder = 508, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-man-girl", { name = "FAMILY: MAN, MAN, GIRL", native = "👨\u{200D}👨\u{200D}👧", sortOrder = 506, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-man-girl-boy", { name = "FAMILY: MAN, MAN, GIRL, BOY", native = "👨\u{200D}👨\u{200D}👧\u{200D}👦", sortOrder = 507, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-man-girl-girl", { name = "FAMILY: MAN, MAN, GIRL, GIRL", native = "👨\u{200D}👨\u{200D}👧\u{200D}👧", sortOrder = 509, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-woman-boy", { name = "FAMILY: MAN, WOMAN, BOY", native = "👨\u{200D}👩\u{200D}👦", sortOrder = 500, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-woman-boy-boy", { name = "FAMILY: MAN, WOMAN, BOY, BOY", native = "👨\u{200D}👩\u{200D}👦\u{200D}👦", sortOrder = 503, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-woman-girl", { name = "FAMILY: MAN, WOMAN, GIRL", native = "👨\u{200D}👩\u{200D}👧", sortOrder = 501, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-woman-girl-boy", { name = "FAMILY: MAN, WOMAN, GIRL, BOY", native = "👨\u{200D}👩\u{200D}👧\u{200D}👦", sortOrder = 502, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-woman-girl-girl", { name = "FAMILY: MAN, WOMAN, GIRL, GIRL", native = "👨\u{200D}👩\u{200D}👧\u{200D}👧", sortOrder = 504, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "male-technologist", { name = "MAN TECHNOLOGIST", native = "👨\u{200D}💻", sortOrder = 317, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}💻" ), ( "1F3FC", "👨🏼\u{200D}💻" ), ( "1F3FD", "👨🏽\u{200D}💻" ), ( "1F3FE", "👨🏾\u{200D}💻" ), ( "1F3FF", "👨🏿\u{200D}💻" ) ], keywords = [ "coder", "developer", "inventor", "man", "software", "technologist" ] } )
        , ( "male-office-worker", { name = "MAN OFFICE WORKER", native = "👨\u{200D}💼", sortOrder = 311, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}💼" ), ( "1F3FC", "👨🏼\u{200D}💼" ), ( "1F3FD", "👨🏽\u{200D}💼" ), ( "1F3FE", "👨🏾\u{200D}💼" ), ( "1F3FF", "👨🏿\u{200D}💼" ) ], keywords = [ "architect", "business", "man", "man office worker", "manager", "white-collar" ] } )
        , ( "male-mechanic", { name = "MAN MECHANIC", native = "👨\u{200D}🔧", sortOrder = 305, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🔧" ), ( "1F3FC", "👨🏼\u{200D}🔧" ), ( "1F3FD", "👨🏽\u{200D}🔧" ), ( "1F3FE", "👨🏾\u{200D}🔧" ), ( "1F3FF", "👨🏿\u{200D}🔧" ) ], keywords = [ "electrician", "man", "mechanic", "plumber", "tradesperson" ] } )
        , ( "male-scientist", { name = "MAN SCIENTIST", native = "👨\u{200D}🔬", sortOrder = 314, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🔬" ), ( "1F3FC", "👨🏼\u{200D}🔬" ), ( "1F3FD", "👨🏽\u{200D}🔬" ), ( "1F3FE", "👨🏾\u{200D}🔬" ), ( "1F3FF", "👨🏿\u{200D}🔬" ) ], keywords = [ "biologist", "chemist", "engineer", "man", "physicist", "scientist" ] } )
        , ( "male-astronaut", { name = "MAN ASTRONAUT", native = "👨\u{200D}🚀", sortOrder = 329, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🚀" ), ( "1F3FC", "👨🏼\u{200D}🚀" ), ( "1F3FD", "👨🏽\u{200D}🚀" ), ( "1F3FE", "👨🏾\u{200D}🚀" ), ( "1F3FF", "👨🏿\u{200D}🚀" ) ], keywords = [ "astronaut", "man", "rocket" ] } )
        , ( "male-firefighter", { name = "MAN FIREFIGHTER", native = "👨\u{200D}🚒", sortOrder = 332, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🚒" ), ( "1F3FC", "👨🏼\u{200D}🚒" ), ( "1F3FD", "👨🏽\u{200D}🚒" ), ( "1F3FE", "👨🏾\u{200D}🚒" ), ( "1F3FF", "👨🏿\u{200D}🚒" ) ], keywords = [ "firefighter", "firetruck", "man" ] } )
        , ( "man_with_probing_cane", { name = "MAN WITH WHITE CANE", native = "👨\u{200D}🦯", sortOrder = 416, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦯" ), ( "1F3FC", "👨🏼\u{200D}🦯" ), ( "1F3FD", "👨🏽\u{200D}🦯" ), ( "1F3FE", "👨🏾\u{200D}🦯" ), ( "1F3FF", "👨🏿\u{200D}🦯" ) ], keywords = [ "accessibility", "blind", "man", "man with white cane" ] } )
        , ( "red_haired_man", { name = "MAN: RED HAIR", native = "👨\u{200D}🦰", sortOrder = 238, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦰" ), ( "1F3FC", "👨🏼\u{200D}🦰" ), ( "1F3FD", "👨🏽\u{200D}🦰" ), ( "1F3FE", "👨🏾\u{200D}🦰" ), ( "1F3FF", "👨🏿\u{200D}🦰" ) ], keywords = [] } )
        , ( "curly_haired_man", { name = "MAN: CURLY HAIR", native = "👨\u{200D}🦱", sortOrder = 239, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦱" ), ( "1F3FC", "👨🏼\u{200D}🦱" ), ( "1F3FD", "👨🏽\u{200D}🦱" ), ( "1F3FE", "👨🏾\u{200D}🦱" ), ( "1F3FF", "👨🏿\u{200D}🦱" ) ], keywords = [] } )
        , ( "bald_man", { name = "MAN: BALD", native = "👨\u{200D}🦲", sortOrder = 241, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦲" ), ( "1F3FC", "👨🏼\u{200D}🦲" ), ( "1F3FD", "👨🏽\u{200D}🦲" ), ( "1F3FE", "👨🏾\u{200D}🦲" ), ( "1F3FF", "👨🏿\u{200D}🦲" ) ], keywords = [] } )
        , ( "white_haired_man", { name = "MAN: WHITE HAIR", native = "👨\u{200D}🦳", sortOrder = 240, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦳" ), ( "1F3FC", "👨🏼\u{200D}🦳" ), ( "1F3FD", "👨🏽\u{200D}🦳" ), ( "1F3FE", "👨🏾\u{200D}🦳" ), ( "1F3FF", "👨🏿\u{200D}🦳" ) ], keywords = [] } )
        , ( "man_in_motorized_wheelchair", { name = "MAN IN MOTORIZED WHEELCHAIR", native = "👨\u{200D}🦼", sortOrder = 419, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦼" ), ( "1F3FC", "👨🏼\u{200D}🦼" ), ( "1F3FD", "👨🏽\u{200D}🦼" ), ( "1F3FE", "👨🏾\u{200D}🦼" ), ( "1F3FF", "👨🏿\u{200D}🦼" ) ], keywords = [ "accessibility", "man", "man in motorized wheelchair", "wheelchair" ] } )
        , ( "man_in_manual_wheelchair", { name = "MAN IN MANUAL WHEELCHAIR", native = "👨\u{200D}🦽", sortOrder = 422, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}🦽" ), ( "1F3FC", "👨🏼\u{200D}🦽" ), ( "1F3FD", "👨🏽\u{200D}🦽" ), ( "1F3FE", "👨🏾\u{200D}🦽" ), ( "1F3FF", "👨🏿\u{200D}🦽" ) ], keywords = [ "accessibility", "man", "man in manual wheelchair", "wheelchair" ] } )
        , ( "male-doctor", { name = "MAN HEALTH WORKER", native = "👨\u{200D}⚕️", sortOrder = 287, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}⚕️" ), ( "1F3FC", "👨🏼\u{200D}⚕️" ), ( "1F3FD", "👨🏽\u{200D}⚕️" ), ( "1F3FE", "👨🏾\u{200D}⚕️" ), ( "1F3FF", "👨🏿\u{200D}⚕️" ) ], keywords = [] } )
        , ( "male-judge", { name = "MAN JUDGE", native = "👨\u{200D}⚖️", sortOrder = 296, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}⚖️" ), ( "1F3FC", "👨🏼\u{200D}⚖️" ), ( "1F3FD", "👨🏽\u{200D}⚖️" ), ( "1F3FE", "👨🏾\u{200D}⚖️" ), ( "1F3FF", "👨🏿\u{200D}⚖️" ) ], keywords = [] } )
        , ( "male-pilot", { name = "MAN PILOT", native = "👨\u{200D}✈️", sortOrder = 326, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻\u{200D}✈️" ), ( "1F3FC", "👨🏼\u{200D}✈️" ), ( "1F3FD", "👨🏽\u{200D}✈️" ), ( "1F3FE", "👨🏾\u{200D}✈️" ), ( "1F3FF", "👨🏿\u{200D}✈️" ) ], keywords = [] } )
        , ( "man-heart-man", { name = "COUPLE WITH HEART: MAN, MAN", native = "👨\u{200D}❤️\u{200D}👨", sortOrder = 497, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "👨🏻\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FB-1F3FC", "👨🏻\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FB-1F3FD", "👨🏻\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FB-1F3FE", "👨🏻\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FB-1F3FF", "👨🏻\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FC-1F3FB", "👨🏼\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FC-1F3FC", "👨🏼\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FC-1F3FD", "👨🏼\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FC-1F3FE", "👨🏼\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FC-1F3FF", "👨🏼\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FD-1F3FB", "👨🏽\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FD-1F3FC", "👨🏽\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FD-1F3FD", "👨🏽\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FD-1F3FE", "👨🏽\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FD-1F3FF", "👨🏽\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FE-1F3FB", "👨🏾\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FE-1F3FC", "👨🏾\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FE-1F3FD", "👨🏾\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FE-1F3FE", "👨🏾\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FE-1F3FF", "👨🏾\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FF-1F3FB", "👨🏿\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FF-1F3FC", "👨🏿\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FF-1F3FD", "👨🏿\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FF-1F3FE", "👨🏿\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FF-1F3FF", "👨🏿\u{200D}❤️\u{200D}👨🏿" ) ], keywords = [] } )
        , ( "man-kiss-man", { name = "KISS: MAN, MAN", native = "👨\u{200D}❤️\u{200D}💋\u{200D}👨", sortOrder = 493, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "👨🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FB-1F3FC", "👨🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FB-1F3FD", "👨🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FB-1F3FE", "👨🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FB-1F3FF", "👨🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FC-1F3FB", "👨🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FC-1F3FC", "👨🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FC-1F3FD", "👨🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FC-1F3FE", "👨🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FC-1F3FF", "👨🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FD-1F3FB", "👨🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FD-1F3FC", "👨🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FD-1F3FD", "👨🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FD-1F3FE", "👨🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FD-1F3FF", "👨🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FE-1F3FB", "👨🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FE-1F3FC", "👨🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FE-1F3FD", "👨🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FE-1F3FE", "👨🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FE-1F3FF", "👨🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FF-1F3FB", "👨🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FF-1F3FC", "👨🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FF-1F3FD", "👨🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FF-1F3FE", "👨🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FF-1F3FF", "👨🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ) ], keywords = [] } )
        , ( "man", { name = "MAN", native = "👨", sortOrder = 234, skinVariations = Dict.fromList [ ( "1F3FB", "👨🏻" ), ( "1F3FC", "👨🏼" ), ( "1F3FD", "👨🏽" ), ( "1F3FE", "👨🏾" ), ( "1F3FF", "👨🏿" ) ], keywords = [ "adult", "man" ] } )
        , ( "female-farmer", { name = "WOMAN FARMER", native = "👩\u{200D}🌾", sortOrder = 300, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🌾" ), ( "1F3FC", "👩🏼\u{200D}🌾" ), ( "1F3FD", "👩🏽\u{200D}🌾" ), ( "1F3FE", "👩🏾\u{200D}🌾" ), ( "1F3FF", "👩🏿\u{200D}🌾" ) ], keywords = [ "farmer", "gardener", "rancher", "woman" ] } )
        , ( "female-cook", { name = "WOMAN COOK", native = "👩\u{200D}🍳", sortOrder = 303, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🍳" ), ( "1F3FC", "👩🏼\u{200D}🍳" ), ( "1F3FD", "👩🏽\u{200D}🍳" ), ( "1F3FE", "👩🏾\u{200D}🍳" ), ( "1F3FF", "👩🏿\u{200D}🍳" ) ], keywords = [ "chef", "cook", "woman" ] } )
        , ( "woman_feeding_baby", { name = "WOMAN FEEDING BABY", native = "👩\u{200D}🍼", sortOrder = 365, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🍼" ), ( "1F3FC", "👩🏼\u{200D}🍼" ), ( "1F3FD", "👩🏽\u{200D}🍼" ), ( "1F3FE", "👩🏾\u{200D}🍼" ), ( "1F3FF", "👩🏿\u{200D}🍼" ) ], keywords = [ "baby", "feeding", "nursing", "woman" ] } )
        , ( "female-student", { name = "WOMAN STUDENT", native = "👩\u{200D}🎓", sortOrder = 291, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🎓" ), ( "1F3FC", "👩🏼\u{200D}🎓" ), ( "1F3FD", "👩🏽\u{200D}🎓" ), ( "1F3FE", "👩🏾\u{200D}🎓" ), ( "1F3FF", "👩🏿\u{200D}🎓" ) ], keywords = [ "graduate", "student", "woman" ] } )
        , ( "female-singer", { name = "WOMAN SINGER", native = "👩\u{200D}🎤", sortOrder = 321, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🎤" ), ( "1F3FC", "👩🏼\u{200D}🎤" ), ( "1F3FD", "👩🏽\u{200D}🎤" ), ( "1F3FE", "👩🏾\u{200D}🎤" ), ( "1F3FF", "👩🏿\u{200D}🎤" ) ], keywords = [ "actor", "entertainer", "rock", "singer", "star", "woman" ] } )
        , ( "female-artist", { name = "WOMAN ARTIST", native = "👩\u{200D}🎨", sortOrder = 324, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🎨" ), ( "1F3FC", "👩🏼\u{200D}🎨" ), ( "1F3FD", "👩🏽\u{200D}🎨" ), ( "1F3FE", "👩🏾\u{200D}🎨" ), ( "1F3FF", "👩🏿\u{200D}🎨" ) ], keywords = [ "artist", "palette", "woman" ] } )
        , ( "female-teacher", { name = "WOMAN TEACHER", native = "👩\u{200D}🏫", sortOrder = 294, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🏫" ), ( "1F3FC", "👩🏼\u{200D}🏫" ), ( "1F3FD", "👩🏽\u{200D}🏫" ), ( "1F3FE", "👩🏾\u{200D}🏫" ), ( "1F3FF", "👩🏿\u{200D}🏫" ) ], keywords = [ "instructor", "lecturer", "professor", "teacher", "woman" ] } )
        , ( "female-factory-worker", { name = "WOMAN FACTORY WORKER", native = "👩\u{200D}🏭", sortOrder = 309, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🏭" ), ( "1F3FC", "👩🏼\u{200D}🏭" ), ( "1F3FD", "👩🏽\u{200D}🏭" ), ( "1F3FE", "👩🏾\u{200D}🏭" ), ( "1F3FF", "👩🏿\u{200D}🏭" ) ], keywords = [ "assembly", "factory", "industrial", "woman", "worker" ] } )
        , ( "woman-boy-boy", { name = "FAMILY: WOMAN, BOY, BOY", native = "👩\u{200D}👦\u{200D}👦", sortOrder = 521, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-boy", { name = "FAMILY: WOMAN, BOY", native = "👩\u{200D}👦", sortOrder = 520, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-girl-boy", { name = "FAMILY: WOMAN, GIRL, BOY", native = "👩\u{200D}👧\u{200D}👦", sortOrder = 523, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-girl-girl", { name = "FAMILY: WOMAN, GIRL, GIRL", native = "👩\u{200D}👧\u{200D}👧", sortOrder = 524, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-girl", { name = "FAMILY: WOMAN, GIRL", native = "👩\u{200D}👧", sortOrder = 522, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-woman-boy", { name = "FAMILY: WOMAN, WOMAN, BOY", native = "👩\u{200D}👩\u{200D}👦", sortOrder = 510, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-woman-boy-boy", { name = "FAMILY: WOMAN, WOMAN, BOY, BOY", native = "👩\u{200D}👩\u{200D}👦\u{200D}👦", sortOrder = 513, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-woman-girl", { name = "FAMILY: WOMAN, WOMAN, GIRL", native = "👩\u{200D}👩\u{200D}👧", sortOrder = 511, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-woman-girl-boy", { name = "FAMILY: WOMAN, WOMAN, GIRL, BOY", native = "👩\u{200D}👩\u{200D}👧\u{200D}👦", sortOrder = 512, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-woman-girl-girl", { name = "FAMILY: WOMAN, WOMAN, GIRL, GIRL", native = "👩\u{200D}👩\u{200D}👧\u{200D}👧", sortOrder = 514, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "female-technologist", { name = "WOMAN TECHNOLOGIST", native = "👩\u{200D}💻", sortOrder = 318, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}💻" ), ( "1F3FC", "👩🏼\u{200D}💻" ), ( "1F3FD", "👩🏽\u{200D}💻" ), ( "1F3FE", "👩🏾\u{200D}💻" ), ( "1F3FF", "👩🏿\u{200D}💻" ) ], keywords = [ "coder", "developer", "inventor", "software", "technologist", "woman" ] } )
        , ( "female-office-worker", { name = "WOMAN OFFICE WORKER", native = "👩\u{200D}💼", sortOrder = 312, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}💼" ), ( "1F3FC", "👩🏼\u{200D}💼" ), ( "1F3FD", "👩🏽\u{200D}💼" ), ( "1F3FE", "👩🏾\u{200D}💼" ), ( "1F3FF", "👩🏿\u{200D}💼" ) ], keywords = [ "architect", "business", "manager", "white-collar", "woman", "woman office worker" ] } )
        , ( "female-mechanic", { name = "WOMAN MECHANIC", native = "👩\u{200D}🔧", sortOrder = 306, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🔧" ), ( "1F3FC", "👩🏼\u{200D}🔧" ), ( "1F3FD", "👩🏽\u{200D}🔧" ), ( "1F3FE", "👩🏾\u{200D}🔧" ), ( "1F3FF", "👩🏿\u{200D}🔧" ) ], keywords = [ "electrician", "mechanic", "plumber", "tradesperson", "woman" ] } )
        , ( "female-scientist", { name = "WOMAN SCIENTIST", native = "👩\u{200D}🔬", sortOrder = 315, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🔬" ), ( "1F3FC", "👩🏼\u{200D}🔬" ), ( "1F3FD", "👩🏽\u{200D}🔬" ), ( "1F3FE", "👩🏾\u{200D}🔬" ), ( "1F3FF", "👩🏿\u{200D}🔬" ) ], keywords = [ "biologist", "chemist", "engineer", "physicist", "scientist", "woman" ] } )
        , ( "female-astronaut", { name = "WOMAN ASTRONAUT", native = "👩\u{200D}🚀", sortOrder = 330, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🚀" ), ( "1F3FC", "👩🏼\u{200D}🚀" ), ( "1F3FD", "👩🏽\u{200D}🚀" ), ( "1F3FE", "👩🏾\u{200D}🚀" ), ( "1F3FF", "👩🏿\u{200D}🚀" ) ], keywords = [ "astronaut", "rocket", "woman" ] } )
        , ( "female-firefighter", { name = "WOMAN FIREFIGHTER", native = "👩\u{200D}🚒", sortOrder = 333, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🚒" ), ( "1F3FC", "👩🏼\u{200D}🚒" ), ( "1F3FD", "👩🏽\u{200D}🚒" ), ( "1F3FE", "👩🏾\u{200D}🚒" ), ( "1F3FF", "👩🏿\u{200D}🚒" ) ], keywords = [ "firefighter", "firetruck", "woman" ] } )
        , ( "woman_with_probing_cane", { name = "WOMAN WITH WHITE CANE", native = "👩\u{200D}🦯", sortOrder = 417, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦯" ), ( "1F3FC", "👩🏼\u{200D}🦯" ), ( "1F3FD", "👩🏽\u{200D}🦯" ), ( "1F3FE", "👩🏾\u{200D}🦯" ), ( "1F3FF", "👩🏿\u{200D}🦯" ) ], keywords = [ "accessibility", "blind", "woman", "woman with white cane" ] } )
        , ( "red_haired_woman", { name = "WOMAN: RED HAIR", native = "👩\u{200D}🦰", sortOrder = 243, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦰" ), ( "1F3FC", "👩🏼\u{200D}🦰" ), ( "1F3FD", "👩🏽\u{200D}🦰" ), ( "1F3FE", "👩🏾\u{200D}🦰" ), ( "1F3FF", "👩🏿\u{200D}🦰" ) ], keywords = [] } )
        , ( "curly_haired_woman", { name = "WOMAN: CURLY HAIR", native = "👩\u{200D}🦱", sortOrder = 245, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦱" ), ( "1F3FC", "👩🏼\u{200D}🦱" ), ( "1F3FD", "👩🏽\u{200D}🦱" ), ( "1F3FE", "👩🏾\u{200D}🦱" ), ( "1F3FF", "👩🏿\u{200D}🦱" ) ], keywords = [] } )
        , ( "bald_woman", { name = "WOMAN: BALD", native = "👩\u{200D}🦲", sortOrder = 249, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦲" ), ( "1F3FC", "👩🏼\u{200D}🦲" ), ( "1F3FD", "👩🏽\u{200D}🦲" ), ( "1F3FE", "👩🏾\u{200D}🦲" ), ( "1F3FF", "👩🏿\u{200D}🦲" ) ], keywords = [] } )
        , ( "white_haired_woman", { name = "WOMAN: WHITE HAIR", native = "👩\u{200D}🦳", sortOrder = 247, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦳" ), ( "1F3FC", "👩🏼\u{200D}🦳" ), ( "1F3FD", "👩🏽\u{200D}🦳" ), ( "1F3FE", "👩🏾\u{200D}🦳" ), ( "1F3FF", "👩🏿\u{200D}🦳" ) ], keywords = [] } )
        , ( "woman_in_motorized_wheelchair", { name = "WOMAN IN MOTORIZED WHEELCHAIR", native = "👩\u{200D}🦼", sortOrder = 420, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦼" ), ( "1F3FC", "👩🏼\u{200D}🦼" ), ( "1F3FD", "👩🏽\u{200D}🦼" ), ( "1F3FE", "👩🏾\u{200D}🦼" ), ( "1F3FF", "👩🏿\u{200D}🦼" ) ], keywords = [ "accessibility", "wheelchair", "woman", "woman in motorized wheelchair" ] } )
        , ( "woman_in_manual_wheelchair", { name = "WOMAN IN MANUAL WHEELCHAIR", native = "👩\u{200D}🦽", sortOrder = 423, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}🦽" ), ( "1F3FC", "👩🏼\u{200D}🦽" ), ( "1F3FD", "👩🏽\u{200D}🦽" ), ( "1F3FE", "👩🏾\u{200D}🦽" ), ( "1F3FF", "👩🏿\u{200D}🦽" ) ], keywords = [ "accessibility", "wheelchair", "woman", "woman in manual wheelchair" ] } )
        , ( "female-doctor", { name = "WOMAN HEALTH WORKER", native = "👩\u{200D}⚕️", sortOrder = 288, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}⚕️" ), ( "1F3FC", "👩🏼\u{200D}⚕️" ), ( "1F3FD", "👩🏽\u{200D}⚕️" ), ( "1F3FE", "👩🏾\u{200D}⚕️" ), ( "1F3FF", "👩🏿\u{200D}⚕️" ) ], keywords = [] } )
        , ( "female-judge", { name = "WOMAN JUDGE", native = "👩\u{200D}⚖️", sortOrder = 297, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}⚖️" ), ( "1F3FC", "👩🏼\u{200D}⚖️" ), ( "1F3FD", "👩🏽\u{200D}⚖️" ), ( "1F3FE", "👩🏾\u{200D}⚖️" ), ( "1F3FF", "👩🏿\u{200D}⚖️" ) ], keywords = [] } )
        , ( "female-pilot", { name = "WOMAN PILOT", native = "👩\u{200D}✈️", sortOrder = 327, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻\u{200D}✈️" ), ( "1F3FC", "👩🏼\u{200D}✈️" ), ( "1F3FD", "👩🏽\u{200D}✈️" ), ( "1F3FE", "👩🏾\u{200D}✈️" ), ( "1F3FF", "👩🏿\u{200D}✈️" ) ], keywords = [] } )
        , ( "woman-heart-man", { name = "COUPLE WITH HEART: WOMAN, MAN", native = "👩\u{200D}❤️\u{200D}👨", sortOrder = 496, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "👩🏻\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FB-1F3FC", "👩🏻\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FB-1F3FD", "👩🏻\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FB-1F3FE", "👩🏻\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FB-1F3FF", "👩🏻\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FC-1F3FB", "👩🏼\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FC-1F3FC", "👩🏼\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FC-1F3FD", "👩🏼\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FC-1F3FE", "👩🏼\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FC-1F3FF", "👩🏼\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FD-1F3FB", "👩🏽\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FD-1F3FC", "👩🏽\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FD-1F3FD", "👩🏽\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FD-1F3FE", "👩🏽\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FD-1F3FF", "👩🏽\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FE-1F3FB", "👩🏾\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FE-1F3FC", "👩🏾\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FE-1F3FD", "👩🏾\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FE-1F3FE", "👩🏾\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FE-1F3FF", "👩🏾\u{200D}❤️\u{200D}👨🏿" ), ( "1F3FF-1F3FB", "👩🏿\u{200D}❤️\u{200D}👨🏻" ), ( "1F3FF-1F3FC", "👩🏿\u{200D}❤️\u{200D}👨🏼" ), ( "1F3FF-1F3FD", "👩🏿\u{200D}❤️\u{200D}👨🏽" ), ( "1F3FF-1F3FE", "👩🏿\u{200D}❤️\u{200D}👨🏾" ), ( "1F3FF-1F3FF", "👩🏿\u{200D}❤️\u{200D}👨🏿" ) ], keywords = [] } )
        , ( "woman-heart-woman", { name = "COUPLE WITH HEART: WOMAN, WOMAN", native = "👩\u{200D}❤️\u{200D}👩", sortOrder = 498, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "👩🏻\u{200D}❤️\u{200D}👩🏻" ), ( "1F3FB-1F3FC", "👩🏻\u{200D}❤️\u{200D}👩🏼" ), ( "1F3FB-1F3FD", "👩🏻\u{200D}❤️\u{200D}👩🏽" ), ( "1F3FB-1F3FE", "👩🏻\u{200D}❤️\u{200D}👩🏾" ), ( "1F3FB-1F3FF", "👩🏻\u{200D}❤️\u{200D}👩🏿" ), ( "1F3FC-1F3FB", "👩🏼\u{200D}❤️\u{200D}👩🏻" ), ( "1F3FC-1F3FC", "👩🏼\u{200D}❤️\u{200D}👩🏼" ), ( "1F3FC-1F3FD", "👩🏼\u{200D}❤️\u{200D}👩🏽" ), ( "1F3FC-1F3FE", "👩🏼\u{200D}❤️\u{200D}👩🏾" ), ( "1F3FC-1F3FF", "👩🏼\u{200D}❤️\u{200D}👩🏿" ), ( "1F3FD-1F3FB", "👩🏽\u{200D}❤️\u{200D}👩🏻" ), ( "1F3FD-1F3FC", "👩🏽\u{200D}❤️\u{200D}👩🏼" ), ( "1F3FD-1F3FD", "👩🏽\u{200D}❤️\u{200D}👩🏽" ), ( "1F3FD-1F3FE", "👩🏽\u{200D}❤️\u{200D}👩🏾" ), ( "1F3FD-1F3FF", "👩🏽\u{200D}❤️\u{200D}👩🏿" ), ( "1F3FE-1F3FB", "👩🏾\u{200D}❤️\u{200D}👩🏻" ), ( "1F3FE-1F3FC", "👩🏾\u{200D}❤️\u{200D}👩🏼" ), ( "1F3FE-1F3FD", "👩🏾\u{200D}❤️\u{200D}👩🏽" ), ( "1F3FE-1F3FE", "👩🏾\u{200D}❤️\u{200D}👩🏾" ), ( "1F3FE-1F3FF", "👩🏾\u{200D}❤️\u{200D}👩🏿" ), ( "1F3FF-1F3FB", "👩🏿\u{200D}❤️\u{200D}👩🏻" ), ( "1F3FF-1F3FC", "👩🏿\u{200D}❤️\u{200D}👩🏼" ), ( "1F3FF-1F3FD", "👩🏿\u{200D}❤️\u{200D}👩🏽" ), ( "1F3FF-1F3FE", "👩🏿\u{200D}❤️\u{200D}👩🏾" ), ( "1F3FF-1F3FF", "👩🏿\u{200D}❤️\u{200D}👩🏿" ) ], keywords = [] } )
        , ( "woman-kiss-man", { name = "KISS: WOMAN, MAN", native = "👩\u{200D}❤️\u{200D}💋\u{200D}👨", sortOrder = 492, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FB-1F3FC", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FB-1F3FD", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FB-1F3FE", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FB-1F3FF", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FC-1F3FB", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FC-1F3FC", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FC-1F3FD", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FC-1F3FE", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FC-1F3FF", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FD-1F3FB", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FD-1F3FC", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FD-1F3FD", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FD-1F3FE", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FD-1F3FF", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FE-1F3FB", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FE-1F3FC", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FE-1F3FD", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FE-1F3FE", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FE-1F3FF", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ), ( "1F3FF-1F3FB", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏻" ), ( "1F3FF-1F3FC", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏼" ), ( "1F3FF-1F3FD", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏽" ), ( "1F3FF-1F3FE", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏾" ), ( "1F3FF-1F3FF", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👨🏿" ) ], keywords = [] } )
        , ( "woman-kiss-woman", { name = "KISS: WOMAN, WOMAN", native = "👩\u{200D}❤️\u{200D}💋\u{200D}👩", sortOrder = 494, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👩🏻" ), ( "1F3FB-1F3FC", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👩🏼" ), ( "1F3FB-1F3FD", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👩🏽" ), ( "1F3FB-1F3FE", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👩🏾" ), ( "1F3FB-1F3FF", "👩🏻\u{200D}❤️\u{200D}💋\u{200D}👩🏿" ), ( "1F3FC-1F3FB", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👩🏻" ), ( "1F3FC-1F3FC", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👩🏼" ), ( "1F3FC-1F3FD", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👩🏽" ), ( "1F3FC-1F3FE", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👩🏾" ), ( "1F3FC-1F3FF", "👩🏼\u{200D}❤️\u{200D}💋\u{200D}👩🏿" ), ( "1F3FD-1F3FB", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👩🏻" ), ( "1F3FD-1F3FC", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👩🏼" ), ( "1F3FD-1F3FD", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👩🏽" ), ( "1F3FD-1F3FE", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👩🏾" ), ( "1F3FD-1F3FF", "👩🏽\u{200D}❤️\u{200D}💋\u{200D}👩🏿" ), ( "1F3FE-1F3FB", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👩🏻" ), ( "1F3FE-1F3FC", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👩🏼" ), ( "1F3FE-1F3FD", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👩🏽" ), ( "1F3FE-1F3FE", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👩🏾" ), ( "1F3FE-1F3FF", "👩🏾\u{200D}❤️\u{200D}💋\u{200D}👩🏿" ), ( "1F3FF-1F3FB", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👩🏻" ), ( "1F3FF-1F3FC", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👩🏼" ), ( "1F3FF-1F3FD", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👩🏽" ), ( "1F3FF-1F3FE", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👩🏾" ), ( "1F3FF-1F3FF", "👩🏿\u{200D}❤️\u{200D}💋\u{200D}👩🏿" ) ], keywords = [] } )
        , ( "woman", { name = "WOMAN", native = "👩", sortOrder = 242, skinVariations = Dict.fromList [ ( "1F3FB", "👩🏻" ), ( "1F3FC", "👩🏼" ), ( "1F3FD", "👩🏽" ), ( "1F3FE", "👩🏾" ), ( "1F3FF", "👩🏿" ) ], keywords = [ "adult", "woman" ] } )
        , ( "family", { name = "FAMILY", native = "👪", sortOrder = 499, skinVariations = Dict.fromList [], keywords = [ "family" ] } )
        , ( "man_and_woman_holding_hands", { name = "MAN AND WOMAN HOLDING HANDS", native = "👫", sortOrder = 489, skinVariations = Dict.fromList [ ( "1F3FB", "👫🏻" ), ( "1F3FC", "👫🏼" ), ( "1F3FD", "👫🏽" ), ( "1F3FE", "👫🏾" ), ( "1F3FF", "👫🏿" ), ( "1F3FB-1F3FC", "👩🏻\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FB-1F3FD", "👩🏻\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FB-1F3FE", "👩🏻\u{200D}🤝\u{200D}👨🏾" ), ( "1F3FB-1F3FF", "👩🏻\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FC-1F3FB", "👩🏼\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FC-1F3FD", "👩🏼\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FC-1F3FE", "👩🏼\u{200D}🤝\u{200D}👨🏾" ), ( "1F3FC-1F3FF", "👩🏼\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FD-1F3FB", "👩🏽\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FD-1F3FC", "👩🏽\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FD-1F3FE", "👩🏽\u{200D}🤝\u{200D}👨🏾" ), ( "1F3FD-1F3FF", "👩🏽\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FE-1F3FB", "👩🏾\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FE-1F3FC", "👩🏾\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FE-1F3FD", "👩🏾\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FE-1F3FF", "👩🏾\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FF-1F3FB", "👩🏿\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FF-1F3FC", "👩🏿\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FF-1F3FD", "👩🏿\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FF-1F3FE", "👩🏿\u{200D}🤝\u{200D}👨🏾" ) ], keywords = [ "couple", "hand", "hold", "holding hands", "man", "woman", "woman and man holding hands" ] } )
        , ( "two_men_holding_hands", { name = "TWO MEN HOLDING HANDS", native = "👬", sortOrder = 490, skinVariations = Dict.fromList [ ( "1F3FB", "👬🏻" ), ( "1F3FC", "👬🏼" ), ( "1F3FD", "👬🏽" ), ( "1F3FE", "👬🏾" ), ( "1F3FF", "👬🏿" ), ( "1F3FB-1F3FC", "👨🏻\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FB-1F3FD", "👨🏻\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FB-1F3FE", "👨🏻\u{200D}🤝\u{200D}👨🏾" ), ( "1F3FB-1F3FF", "👨🏻\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FC-1F3FB", "👨🏼\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FC-1F3FD", "👨🏼\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FC-1F3FE", "👨🏼\u{200D}🤝\u{200D}👨🏾" ), ( "1F3FC-1F3FF", "👨🏼\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FD-1F3FB", "👨🏽\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FD-1F3FC", "👨🏽\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FD-1F3FE", "👨🏽\u{200D}🤝\u{200D}👨🏾" ), ( "1F3FD-1F3FF", "👨🏽\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FE-1F3FB", "👨🏾\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FE-1F3FC", "👨🏾\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FE-1F3FD", "👨🏾\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FE-1F3FF", "👨🏾\u{200D}🤝\u{200D}👨🏿" ), ( "1F3FF-1F3FB", "👨🏿\u{200D}🤝\u{200D}👨🏻" ), ( "1F3FF-1F3FC", "👨🏿\u{200D}🤝\u{200D}👨🏼" ), ( "1F3FF-1F3FD", "👨🏿\u{200D}🤝\u{200D}👨🏽" ), ( "1F3FF-1F3FE", "👨🏿\u{200D}🤝\u{200D}👨🏾" ) ], keywords = [ "couple", "Gemini", "holding hands", "man", "men", "men holding hands", "twins", "zodiac" ] } )
        , ( "two_women_holding_hands", { name = "TWO WOMEN HOLDING HANDS", native = "👭", sortOrder = 488, skinVariations = Dict.fromList [ ( "1F3FB", "👭🏻" ), ( "1F3FC", "👭🏼" ), ( "1F3FD", "👭🏽" ), ( "1F3FE", "👭🏾" ), ( "1F3FF", "👭🏿" ), ( "1F3FB-1F3FC", "👩🏻\u{200D}🤝\u{200D}👩🏼" ), ( "1F3FB-1F3FD", "👩🏻\u{200D}🤝\u{200D}👩🏽" ), ( "1F3FB-1F3FE", "👩🏻\u{200D}🤝\u{200D}👩🏾" ), ( "1F3FB-1F3FF", "👩🏻\u{200D}🤝\u{200D}👩🏿" ), ( "1F3FC-1F3FB", "👩🏼\u{200D}🤝\u{200D}👩🏻" ), ( "1F3FC-1F3FD", "👩🏼\u{200D}🤝\u{200D}👩🏽" ), ( "1F3FC-1F3FE", "👩🏼\u{200D}🤝\u{200D}👩🏾" ), ( "1F3FC-1F3FF", "👩🏼\u{200D}🤝\u{200D}👩🏿" ), ( "1F3FD-1F3FB", "👩🏽\u{200D}🤝\u{200D}👩🏻" ), ( "1F3FD-1F3FC", "👩🏽\u{200D}🤝\u{200D}👩🏼" ), ( "1F3FD-1F3FE", "👩🏽\u{200D}🤝\u{200D}👩🏾" ), ( "1F3FD-1F3FF", "👩🏽\u{200D}🤝\u{200D}👩🏿" ), ( "1F3FE-1F3FB", "👩🏾\u{200D}🤝\u{200D}👩🏻" ), ( "1F3FE-1F3FC", "👩🏾\u{200D}🤝\u{200D}👩🏼" ), ( "1F3FE-1F3FD", "👩🏾\u{200D}🤝\u{200D}👩🏽" ), ( "1F3FE-1F3FF", "👩🏾\u{200D}🤝\u{200D}👩🏿" ), ( "1F3FF-1F3FB", "👩🏿\u{200D}🤝\u{200D}👩🏻" ), ( "1F3FF-1F3FC", "👩🏿\u{200D}🤝\u{200D}👩🏼" ), ( "1F3FF-1F3FD", "👩🏿\u{200D}🤝\u{200D}👩🏽" ), ( "1F3FF-1F3FE", "👩🏿\u{200D}🤝\u{200D}👩🏾" ) ], keywords = [ "couple", "hand", "holding hands", "women", "women holding hands" ] } )
        , ( "female-police-officer", { name = "WOMAN POLICE OFFICER", native = "👮\u{200D}♀️", sortOrder = 336, skinVariations = Dict.fromList [ ( "1F3FB", "👮🏻\u{200D}♀️" ), ( "1F3FC", "👮🏼\u{200D}♀️" ), ( "1F3FD", "👮🏽\u{200D}♀️" ), ( "1F3FE", "👮🏾\u{200D}♀️" ), ( "1F3FF", "👮🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male-police-officer", { name = "MAN POLICE OFFICER", native = "👮\u{200D}♂️", sortOrder = 335, skinVariations = Dict.fromList [ ( "1F3FB", "👮🏻\u{200D}♂️" ), ( "1F3FC", "👮🏼\u{200D}♂️" ), ( "1F3FD", "👮🏽\u{200D}♂️" ), ( "1F3FE", "👮🏾\u{200D}♂️" ), ( "1F3FF", "👮🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "cop", { name = "POLICE OFFICER", native = "👮", sortOrder = 334, skinVariations = Dict.fromList [ ( "1F3FB", "👮🏻" ), ( "1F3FC", "👮🏼" ), ( "1F3FD", "👮🏽" ), ( "1F3FE", "👮🏾" ), ( "1F3FF", "👮🏿" ) ], keywords = [ "cop", "officer", "police" ] } )
        , ( "women-with-bunny-ears-partying", { name = "WOMEN WITH BUNNY EARS", native = "👯\u{200D}♀️", sortOrder = 432, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "men-with-bunny-ears-partying", { name = "MEN WITH BUNNY EARS", native = "👯\u{200D}♂️", sortOrder = 431, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "dancers", { name = "WOMAN WITH BUNNY EARS", native = "👯", sortOrder = 430, skinVariations = Dict.fromList [], keywords = [ "bunny ear", "dancer", "partying", "people with bunny ears" ] } )
        , ( "woman_with_veil", { name = "WOMAN WITH VEIL", native = "👰\u{200D}♀️", sortOrder = 360, skinVariations = Dict.fromList [ ( "1F3FB", "👰🏻\u{200D}♀️" ), ( "1F3FC", "👰🏼\u{200D}♀️" ), ( "1F3FD", "👰🏽\u{200D}♀️" ), ( "1F3FE", "👰🏾\u{200D}♀️" ), ( "1F3FF", "👰🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_with_veil", { name = "MAN WITH VEIL", native = "👰\u{200D}♂️", sortOrder = 359, skinVariations = Dict.fromList [ ( "1F3FB", "👰🏻\u{200D}♂️" ), ( "1F3FC", "👰🏼\u{200D}♂️" ), ( "1F3FD", "👰🏽\u{200D}♂️" ), ( "1F3FE", "👰🏾\u{200D}♂️" ), ( "1F3FF", "👰🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "bride_with_veil", { name = "BRIDE WITH VEIL", native = "👰", sortOrder = 358, skinVariations = Dict.fromList [ ( "1F3FB", "👰🏻" ), ( "1F3FC", "👰🏼" ), ( "1F3FD", "👰🏽" ), ( "1F3FE", "👰🏾" ), ( "1F3FF", "👰🏿" ) ], keywords = [ "bride", "person", "person with veil", "veil", "wedding" ] } )
        , ( "blond-haired-woman", { name = "WOMAN: BLOND HAIR", native = "👱\u{200D}♀️", sortOrder = 251, skinVariations = Dict.fromList [ ( "1F3FB", "👱🏻\u{200D}♀️" ), ( "1F3FC", "👱🏼\u{200D}♀️" ), ( "1F3FD", "👱🏽\u{200D}♀️" ), ( "1F3FE", "👱🏾\u{200D}♀️" ), ( "1F3FF", "👱🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "blond-haired-man", { name = "MAN: BLOND HAIR", native = "👱\u{200D}♂️", sortOrder = 252, skinVariations = Dict.fromList [ ( "1F3FB", "👱🏻\u{200D}♂️" ), ( "1F3FC", "👱🏼\u{200D}♂️" ), ( "1F3FD", "👱🏽\u{200D}♂️" ), ( "1F3FE", "👱🏾\u{200D}♂️" ), ( "1F3FF", "👱🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_with_blond_hair", { name = "PERSON WITH BLOND HAIR", native = "👱", sortOrder = 233, skinVariations = Dict.fromList [ ( "1F3FB", "👱🏻" ), ( "1F3FC", "👱🏼" ), ( "1F3FD", "👱🏽" ), ( "1F3FE", "👱🏾" ), ( "1F3FF", "👱🏿" ) ], keywords = [ "blond", "blond-haired person", "hair", "person: blond hair" ] } )
        , ( "man_with_gua_pi_mao", { name = "MAN WITH GUA PI MAO", native = "👲", sortOrder = 353, skinVariations = Dict.fromList [ ( "1F3FB", "👲🏻" ), ( "1F3FC", "👲🏼" ), ( "1F3FD", "👲🏽" ), ( "1F3FE", "👲🏾" ), ( "1F3FF", "👲🏿" ) ], keywords = [ "cap", "gua pi mao", "hat", "person", "person with skullcap", "skullcap" ] } )
        , ( "woman-wearing-turban", { name = "WOMAN WEARING TURBAN", native = "👳\u{200D}♀️", sortOrder = 352, skinVariations = Dict.fromList [ ( "1F3FB", "👳🏻\u{200D}♀️" ), ( "1F3FC", "👳🏼\u{200D}♀️" ), ( "1F3FD", "👳🏽\u{200D}♀️" ), ( "1F3FE", "👳🏾\u{200D}♀️" ), ( "1F3FF", "👳🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-wearing-turban", { name = "MAN WEARING TURBAN", native = "👳\u{200D}♂️", sortOrder = 351, skinVariations = Dict.fromList [ ( "1F3FB", "👳🏻\u{200D}♂️" ), ( "1F3FC", "👳🏼\u{200D}♂️" ), ( "1F3FD", "👳🏽\u{200D}♂️" ), ( "1F3FE", "👳🏾\u{200D}♂️" ), ( "1F3FF", "👳🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "man_with_turban", { name = "MAN WITH TURBAN", native = "👳", sortOrder = 350, skinVariations = Dict.fromList [ ( "1F3FB", "👳🏻" ), ( "1F3FC", "👳🏼" ), ( "1F3FD", "👳🏽" ), ( "1F3FE", "👳🏾" ), ( "1F3FF", "👳🏿" ) ], keywords = [ "person wearing turban", "turban" ] } )
        , ( "older_man", { name = "OLDER MAN", native = "👴", sortOrder = 254, skinVariations = Dict.fromList [ ( "1F3FB", "👴🏻" ), ( "1F3FC", "👴🏼" ), ( "1F3FD", "👴🏽" ), ( "1F3FE", "👴🏾" ), ( "1F3FF", "👴🏿" ) ], keywords = [ "adult", "man", "old" ] } )
        , ( "older_woman", { name = "OLDER WOMAN", native = "👵", sortOrder = 255, skinVariations = Dict.fromList [ ( "1F3FB", "👵🏻" ), ( "1F3FC", "👵🏼" ), ( "1F3FD", "👵🏽" ), ( "1F3FE", "👵🏾" ), ( "1F3FF", "👵🏿" ) ], keywords = [ "adult", "old", "woman" ] } )
        , ( "baby", { name = "BABY", native = "👶", sortOrder = 228, skinVariations = Dict.fromList [ ( "1F3FB", "👶🏻" ), ( "1F3FC", "👶🏼" ), ( "1F3FD", "👶🏽" ), ( "1F3FE", "👶🏾" ), ( "1F3FF", "👶🏿" ) ], keywords = [ "baby", "young" ] } )
        , ( "female-construction-worker", { name = "WOMAN CONSTRUCTION WORKER", native = "👷\u{200D}♀️", sortOrder = 346, skinVariations = Dict.fromList [ ( "1F3FB", "👷🏻\u{200D}♀️" ), ( "1F3FC", "👷🏼\u{200D}♀️" ), ( "1F3FD", "👷🏽\u{200D}♀️" ), ( "1F3FE", "👷🏾\u{200D}♀️" ), ( "1F3FF", "👷🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male-construction-worker", { name = "MAN CONSTRUCTION WORKER", native = "👷\u{200D}♂️", sortOrder = 345, skinVariations = Dict.fromList [ ( "1F3FB", "👷🏻\u{200D}♂️" ), ( "1F3FC", "👷🏼\u{200D}♂️" ), ( "1F3FD", "👷🏽\u{200D}♂️" ), ( "1F3FE", "👷🏾\u{200D}♂️" ), ( "1F3FF", "👷🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "construction_worker", { name = "CONSTRUCTION WORKER", native = "👷", sortOrder = 344, skinVariations = Dict.fromList [ ( "1F3FB", "👷🏻" ), ( "1F3FC", "👷🏼" ), ( "1F3FD", "👷🏽" ), ( "1F3FE", "👷🏾" ), ( "1F3FF", "👷🏿" ) ], keywords = [ "construction", "hat", "worker" ] } )
        , ( "princess", { name = "PRINCESS", native = "👸", sortOrder = 349, skinVariations = Dict.fromList [ ( "1F3FB", "👸🏻" ), ( "1F3FC", "👸🏼" ), ( "1F3FD", "👸🏽" ), ( "1F3FE", "👸🏾" ), ( "1F3FF", "👸🏿" ) ], keywords = [ "fairy tale", "fantasy", "princess" ] } )
        , ( "japanese_ogre", { name = "JAPANESE OGRE", native = "👹", sortOrder = 110, skinVariations = Dict.fromList [], keywords = [ "creature", "face", "fairy tale", "fantasy", "monster", "ogre" ] } )
        , ( "japanese_goblin", { name = "JAPANESE GOBLIN", native = "👺", sortOrder = 111, skinVariations = Dict.fromList [], keywords = [ "creature", "face", "fairy tale", "fantasy", "goblin", "monster" ] } )
        , ( "ghost", { name = "GHOST", native = "👻", sortOrder = 112, skinVariations = Dict.fromList [], keywords = [ "creature", "face", "fairy tale", "fantasy", "ghost", "monster" ] } )
        , ( "angel", { name = "BABY ANGEL", native = "👼", sortOrder = 368, skinVariations = Dict.fromList [ ( "1F3FB", "👼🏻" ), ( "1F3FC", "👼🏼" ), ( "1F3FD", "👼🏽" ), ( "1F3FE", "👼🏾" ), ( "1F3FF", "👼🏿" ) ], keywords = [ "angel", "baby", "face", "fairy tale", "fantasy" ] } )
        , ( "alien", { name = "EXTRATERRESTRIAL ALIEN", native = "👽", sortOrder = 113, skinVariations = Dict.fromList [], keywords = [ "alien", "creature", "extraterrestrial", "face", "fantasy", "ufo" ] } )
        , ( "space_invader", { name = "ALIEN MONSTER", native = "👾", sortOrder = 114, skinVariations = Dict.fromList [], keywords = [ "alien", "creature", "extraterrestrial", "face", "monster", "ufo" ] } )
        , ( "imp", { name = "IMP", native = "👿", sortOrder = 105, skinVariations = Dict.fromList [], keywords = [ "angry face with horns", "demon", "devil", "face", "fantasy", "imp" ] } )
        , ( "skull", { name = "SKULL", native = "💀", sortOrder = 106, skinVariations = Dict.fromList [], keywords = [ "death", "face", "fairy tale", "monster", "skull" ] } )
        , ( "woman-tipping-hand", { name = "WOMAN TIPPING HAND", native = "💁\u{200D}♀️", sortOrder = 270, skinVariations = Dict.fromList [ ( "1F3FB", "💁🏻\u{200D}♀️" ), ( "1F3FC", "💁🏼\u{200D}♀️" ), ( "1F3FD", "💁🏽\u{200D}♀️" ), ( "1F3FE", "💁🏾\u{200D}♀️" ), ( "1F3FF", "💁🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-tipping-hand", { name = "MAN TIPPING HAND", native = "💁\u{200D}♂️", sortOrder = 269, skinVariations = Dict.fromList [ ( "1F3FB", "💁🏻\u{200D}♂️" ), ( "1F3FC", "💁🏼\u{200D}♂️" ), ( "1F3FD", "💁🏽\u{200D}♂️" ), ( "1F3FE", "💁🏾\u{200D}♂️" ), ( "1F3FF", "💁🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "information_desk_person", { name = "INFORMATION DESK PERSON", native = "💁", sortOrder = 268, skinVariations = Dict.fromList [ ( "1F3FB", "💁🏻" ), ( "1F3FC", "💁🏼" ), ( "1F3FD", "💁🏽" ), ( "1F3FE", "💁🏾" ), ( "1F3FF", "💁🏿" ) ], keywords = [ "hand", "help", "information", "person tipping hand", "sassy", "tipping" ] } )
        , ( "female-guard", { name = "WOMAN GUARD", native = "💂\u{200D}♀️", sortOrder = 342, skinVariations = Dict.fromList [ ( "1F3FB", "💂🏻\u{200D}♀️" ), ( "1F3FC", "💂🏼\u{200D}♀️" ), ( "1F3FD", "💂🏽\u{200D}♀️" ), ( "1F3FE", "💂🏾\u{200D}♀️" ), ( "1F3FF", "💂🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male-guard", { name = "MAN GUARD", native = "💂\u{200D}♂️", sortOrder = 341, skinVariations = Dict.fromList [ ( "1F3FB", "💂🏻\u{200D}♂️" ), ( "1F3FC", "💂🏼\u{200D}♂️" ), ( "1F3FD", "💂🏽\u{200D}♂️" ), ( "1F3FE", "💂🏾\u{200D}♂️" ), ( "1F3FF", "💂🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "guardsman", { name = "GUARDSMAN", native = "💂", sortOrder = 340, skinVariations = Dict.fromList [ ( "1F3FB", "💂🏻" ), ( "1F3FC", "💂🏼" ), ( "1F3FD", "💂🏽" ), ( "1F3FE", "💂🏾" ), ( "1F3FF", "💂🏿" ) ], keywords = [ "guard" ] } )
        , ( "dancer", { name = "DANCER", native = "💃", sortOrder = 427, skinVariations = Dict.fromList [ ( "1F3FB", "💃🏻" ), ( "1F3FC", "💃🏼" ), ( "1F3FD", "💃🏽" ), ( "1F3FE", "💃🏾" ), ( "1F3FF", "💃🏿" ) ], keywords = [ "dance", "dancing", "woman" ] } )
        , ( "lipstick", { name = "LIPSTICK", native = "💄", sortOrder = 1167, skinVariations = Dict.fromList [], keywords = [ "cosmetics", "lipstick", "makeup" ] } )
        , ( "nail_care", { name = "NAIL POLISH", native = "💅", sortOrder = 208, skinVariations = Dict.fromList [ ( "1F3FB", "💅🏻" ), ( "1F3FC", "💅🏼" ), ( "1F3FD", "💅🏽" ), ( "1F3FE", "💅🏾" ), ( "1F3FF", "💅🏿" ) ], keywords = [ "care", "cosmetics", "manicure", "nail", "polish" ] } )
        , ( "woman-getting-massage", { name = "WOMAN GETTING MASSAGE", native = "💆\u{200D}♀️", sortOrder = 402, skinVariations = Dict.fromList [ ( "1F3FB", "💆🏻\u{200D}♀️" ), ( "1F3FC", "💆🏼\u{200D}♀️" ), ( "1F3FD", "💆🏽\u{200D}♀️" ), ( "1F3FE", "💆🏾\u{200D}♀️" ), ( "1F3FF", "💆🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-getting-massage", { name = "MAN GETTING MASSAGE", native = "💆\u{200D}♂️", sortOrder = 401, skinVariations = Dict.fromList [ ( "1F3FB", "💆🏻\u{200D}♂️" ), ( "1F3FC", "💆🏼\u{200D}♂️" ), ( "1F3FD", "💆🏽\u{200D}♂️" ), ( "1F3FE", "💆🏾\u{200D}♂️" ), ( "1F3FF", "💆🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "massage", { name = "FACE MASSAGE", native = "💆", sortOrder = 400, skinVariations = Dict.fromList [ ( "1F3FB", "💆🏻" ), ( "1F3FC", "💆🏼" ), ( "1F3FD", "💆🏽" ), ( "1F3FE", "💆🏾" ), ( "1F3FF", "💆🏿" ) ], keywords = [ "face", "massage", "person getting massage", "salon" ] } )
        , ( "woman-getting-haircut", { name = "WOMAN GETTING HAIRCUT", native = "💇\u{200D}♀️", sortOrder = 405, skinVariations = Dict.fromList [ ( "1F3FB", "💇🏻\u{200D}♀️" ), ( "1F3FC", "💇🏼\u{200D}♀️" ), ( "1F3FD", "💇🏽\u{200D}♀️" ), ( "1F3FE", "💇🏾\u{200D}♀️" ), ( "1F3FF", "💇🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-getting-haircut", { name = "MAN GETTING HAIRCUT", native = "💇\u{200D}♂️", sortOrder = 404, skinVariations = Dict.fromList [ ( "1F3FB", "💇🏻\u{200D}♂️" ), ( "1F3FC", "💇🏼\u{200D}♂️" ), ( "1F3FD", "💇🏽\u{200D}♂️" ), ( "1F3FE", "💇🏾\u{200D}♂️" ), ( "1F3FF", "💇🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "haircut", { name = "HAIRCUT", native = "💇", sortOrder = 403, skinVariations = Dict.fromList [ ( "1F3FB", "💇🏻" ), ( "1F3FC", "💇🏼" ), ( "1F3FD", "💇🏽" ), ( "1F3FE", "💇🏾" ), ( "1F3FF", "💇🏿" ) ], keywords = [ "barber", "beauty", "haircut", "parlor", "person getting haircut" ] } )
        , ( "barber", { name = "BARBER POLE", native = "💈", sortOrder = 884, skinVariations = Dict.fromList [], keywords = [ "barber", "haircut", "pole" ] } )
        , ( "syringe", { name = "SYRINGE", native = "💉", sortOrder = 1343, skinVariations = Dict.fromList [], keywords = [ "medicine", "needle", "shot", "sick", "syringe" ] } )
        , ( "pill", { name = "PILL", native = "💊", sortOrder = 1345, skinVariations = Dict.fromList [], keywords = [ "doctor", "medicine", "pill", "sick" ] } )
        , ( "kiss", { name = "KISS MARK", native = "💋", sortOrder = 153, skinVariations = Dict.fromList [], keywords = [ "kiss", "kiss mark", "lips" ] } )
        , ( "love_letter", { name = "LOVE LETTER", native = "💌", sortOrder = 128, skinVariations = Dict.fromList [], keywords = [ "heart", "letter", "love", "mail" ] } )
        , ( "ring", { name = "RING", native = "💍", sortOrder = 1168, skinVariations = Dict.fromList [], keywords = [ "diamond", "ring" ] } )
        , ( "gem", { name = "GEM STONE", native = "💎", sortOrder = 1169, skinVariations = Dict.fromList [], keywords = [ "diamond", "gem", "gem stone", "jewel" ] } )
        , ( "couplekiss", { name = "KISS", native = "💏", sortOrder = 491, skinVariations = Dict.fromList [ ( "1F3FB", "💏🏻" ), ( "1F3FC", "💏🏼" ), ( "1F3FD", "💏🏽" ), ( "1F3FE", "💏🏾" ), ( "1F3FF", "💏🏿" ), ( "1F3FB-1F3FC", "🧑🏻\u{200D}❤️\u{200D}💋\u{200D}🧑🏼" ), ( "1F3FB-1F3FD", "🧑🏻\u{200D}❤️\u{200D}💋\u{200D}🧑🏽" ), ( "1F3FB-1F3FE", "🧑🏻\u{200D}❤️\u{200D}💋\u{200D}🧑🏾" ), ( "1F3FB-1F3FF", "🧑🏻\u{200D}❤️\u{200D}💋\u{200D}🧑🏿" ), ( "1F3FC-1F3FB", "🧑🏼\u{200D}❤️\u{200D}💋\u{200D}🧑🏻" ), ( "1F3FC-1F3FD", "🧑🏼\u{200D}❤️\u{200D}💋\u{200D}🧑🏽" ), ( "1F3FC-1F3FE", "🧑🏼\u{200D}❤️\u{200D}💋\u{200D}🧑🏾" ), ( "1F3FC-1F3FF", "🧑🏼\u{200D}❤️\u{200D}💋\u{200D}🧑🏿" ), ( "1F3FD-1F3FB", "🧑🏽\u{200D}❤️\u{200D}💋\u{200D}🧑🏻" ), ( "1F3FD-1F3FC", "🧑🏽\u{200D}❤️\u{200D}💋\u{200D}🧑🏼" ), ( "1F3FD-1F3FE", "🧑🏽\u{200D}❤️\u{200D}💋\u{200D}🧑🏾" ), ( "1F3FD-1F3FF", "🧑🏽\u{200D}❤️\u{200D}💋\u{200D}🧑🏿" ), ( "1F3FE-1F3FB", "🧑🏾\u{200D}❤️\u{200D}💋\u{200D}🧑🏻" ), ( "1F3FE-1F3FC", "🧑🏾\u{200D}❤️\u{200D}💋\u{200D}🧑🏼" ), ( "1F3FE-1F3FD", "🧑🏾\u{200D}❤️\u{200D}💋\u{200D}🧑🏽" ), ( "1F3FE-1F3FF", "🧑🏾\u{200D}❤️\u{200D}💋\u{200D}🧑🏿" ), ( "1F3FF-1F3FB", "🧑🏿\u{200D}❤️\u{200D}💋\u{200D}🧑🏻" ), ( "1F3FF-1F3FC", "🧑🏿\u{200D}❤️\u{200D}💋\u{200D}🧑🏼" ), ( "1F3FF-1F3FD", "🧑🏿\u{200D}❤️\u{200D}💋\u{200D}🧑🏽" ), ( "1F3FF-1F3FE", "🧑🏿\u{200D}❤️\u{200D}💋\u{200D}🧑🏾" ) ], keywords = [ "couple", "kiss" ] } )
        , ( "bouquet", { name = "BOUQUET", native = "💐", sortOrder = 659, skinVariations = Dict.fromList [], keywords = [ "bouquet", "flower" ] } )
        , ( "couple_with_heart", { name = "COUPLE WITH HEART", native = "💑", sortOrder = 495, skinVariations = Dict.fromList [ ( "1F3FB", "💑🏻" ), ( "1F3FC", "💑🏼" ), ( "1F3FD", "💑🏽" ), ( "1F3FE", "💑🏾" ), ( "1F3FF", "💑🏿" ), ( "1F3FB-1F3FC", "🧑🏻\u{200D}❤️\u{200D}🧑🏼" ), ( "1F3FB-1F3FD", "🧑🏻\u{200D}❤️\u{200D}🧑🏽" ), ( "1F3FB-1F3FE", "🧑🏻\u{200D}❤️\u{200D}🧑🏾" ), ( "1F3FB-1F3FF", "🧑🏻\u{200D}❤️\u{200D}🧑🏿" ), ( "1F3FC-1F3FB", "🧑🏼\u{200D}❤️\u{200D}🧑🏻" ), ( "1F3FC-1F3FD", "🧑🏼\u{200D}❤️\u{200D}🧑🏽" ), ( "1F3FC-1F3FE", "🧑🏼\u{200D}❤️\u{200D}🧑🏾" ), ( "1F3FC-1F3FF", "🧑🏼\u{200D}❤️\u{200D}🧑🏿" ), ( "1F3FD-1F3FB", "🧑🏽\u{200D}❤️\u{200D}🧑🏻" ), ( "1F3FD-1F3FC", "🧑🏽\u{200D}❤️\u{200D}🧑🏼" ), ( "1F3FD-1F3FE", "🧑🏽\u{200D}❤️\u{200D}🧑🏾" ), ( "1F3FD-1F3FF", "🧑🏽\u{200D}❤️\u{200D}🧑🏿" ), ( "1F3FE-1F3FB", "🧑🏾\u{200D}❤️\u{200D}🧑🏻" ), ( "1F3FE-1F3FC", "🧑🏾\u{200D}❤️\u{200D}🧑🏼" ), ( "1F3FE-1F3FD", "🧑🏾\u{200D}❤️\u{200D}🧑🏽" ), ( "1F3FE-1F3FF", "🧑🏾\u{200D}❤️\u{200D}🧑🏿" ), ( "1F3FF-1F3FB", "🧑🏿\u{200D}❤️\u{200D}🧑🏻" ), ( "1F3FF-1F3FC", "🧑🏿\u{200D}❤️\u{200D}🧑🏼" ), ( "1F3FF-1F3FD", "🧑🏿\u{200D}❤️\u{200D}🧑🏽" ), ( "1F3FF-1F3FE", "🧑🏿\u{200D}❤️\u{200D}🧑🏾" ) ], keywords = [ "couple", "couple with heart", "love" ] } )
        , ( "wedding", { name = "WEDDING", native = "💒", sortOrder = 860, skinVariations = Dict.fromList [], keywords = [ "chapel", "romance", "wedding" ] } )
        , ( "heartbeat", { name = "BEATING HEART", native = "💓", sortOrder = 133, skinVariations = Dict.fromList [], keywords = [ "beating", "beating heart", "heartbeat", "pulsating" ] } )
        , ( "broken_heart", { name = "BROKEN HEART", native = "💔", sortOrder = 138, skinVariations = Dict.fromList [], keywords = [ "break", "broken", "broken heart" ] } )
        , ( "two_hearts", { name = "TWO HEARTS", native = "💕", sortOrder = 135, skinVariations = Dict.fromList [], keywords = [ "love", "two hearts" ] } )
        , ( "sparkling_heart", { name = "SPARKLING HEART", native = "💖", sortOrder = 131, skinVariations = Dict.fromList [], keywords = [ "excited", "sparkle", "sparkling heart" ] } )
        , ( "heartpulse", { name = "GROWING HEART", native = "💗", sortOrder = 132, skinVariations = Dict.fromList [], keywords = [ "excited", "growing", "growing heart", "nervous", "pulse" ] } )
        , ( "cupid", { name = "HEART WITH ARROW", native = "💘", sortOrder = 129, skinVariations = Dict.fromList [], keywords = [ "arrow", "cupid", "heart with arrow" ] } )
        , ( "blue_heart", { name = "BLUE HEART", native = "💙", sortOrder = 146, skinVariations = Dict.fromList [], keywords = [ "blue", "blue heart" ] } )
        , ( "green_heart", { name = "GREEN HEART", native = "💚", sortOrder = 145, skinVariations = Dict.fromList [], keywords = [ "green", "green heart" ] } )
        , ( "yellow_heart", { name = "YELLOW HEART", native = "💛", sortOrder = 144, skinVariations = Dict.fromList [], keywords = [ "yellow", "yellow heart" ] } )
        , ( "purple_heart", { name = "PURPLE HEART", native = "💜", sortOrder = 148, skinVariations = Dict.fromList [], keywords = [ "purple", "purple heart" ] } )
        , ( "gift_heart", { name = "HEART WITH RIBBON", native = "💝", sortOrder = 130, skinVariations = Dict.fromList [], keywords = [ "heart with ribbon", "ribbon", "valentine" ] } )
        , ( "revolving_hearts", { name = "REVOLVING HEARTS", native = "💞", sortOrder = 134, skinVariations = Dict.fromList [], keywords = [ "revolving", "revolving hearts" ] } )
        , ( "heart_decoration", { name = "HEART DECORATION", native = "💟", sortOrder = 136, skinVariations = Dict.fromList [], keywords = [ "heart", "heart decoration" ] } )
        , ( "diamond_shape_with_a_dot_inside", { name = "DIAMOND SHAPE WITH A DOT INSIDE", native = "💠", sortOrder = 1603, skinVariations = Dict.fromList [], keywords = [ "comic", "diamond", "diamond with a dot", "geometric", "inside" ] } )
        , ( "bulb", { name = "ELECTRIC LIGHT BULB", native = "💡", sortOrder = 1231, skinVariations = Dict.fromList [], keywords = [ "bulb", "comic", "electric", "idea", "light" ] } )
        , ( "anger", { name = "ANGER SYMBOL", native = "💢", sortOrder = 155, skinVariations = Dict.fromList [], keywords = [ "anger symbol", "angry", "comic", "mad" ] } )
        , ( "bomb", { name = "BOMB", native = "💣", sortOrder = 1318, skinVariations = Dict.fromList [], keywords = [ "bomb", "comic" ] } )
        , ( "zzz", { name = "SLEEPING SYMBOL", native = "💤", sortOrder = 166, skinVariations = Dict.fromList [], keywords = [ "comic", "good night", "sleep", "ZZZ" ] } )
        , ( "boom", { name = "COLLISION SYMBOL", native = "💥", sortOrder = 156, skinVariations = Dict.fromList [], keywords = [ "boom", "collision", "comic" ] } )
        , ( "sweat_drops", { name = "SPLASHING SWEAT SYMBOL", native = "💦", sortOrder = 158, skinVariations = Dict.fromList [], keywords = [ "comic", "splashing", "sweat", "sweat droplets" ] } )
        , ( "droplet", { name = "DROPLET", native = "💧", sortOrder = 1036, skinVariations = Dict.fromList [], keywords = [ "cold", "comic", "drop", "droplet", "sweat" ] } )
        , ( "dash", { name = "DASH SYMBOL", native = "💨", sortOrder = 159, skinVariations = Dict.fromList [], keywords = [ "comic", "dash", "dashing away", "running" ] } )
        , ( "hankey", { name = "PILE OF POO", native = "💩", sortOrder = 108, skinVariations = Dict.fromList [], keywords = [ "dung", "face", "monster", "pile of poo", "poo", "poop" ] } )
        , ( "muscle", { name = "FLEXED BICEPS", native = "💪", sortOrder = 210, skinVariations = Dict.fromList [ ( "1F3FB", "💪🏻" ), ( "1F3FC", "💪🏼" ), ( "1F3FD", "💪🏽" ), ( "1F3FE", "💪🏾" ), ( "1F3FF", "💪🏿" ) ], keywords = [ "biceps", "comic", "flex", "flexed biceps", "muscle" ] } )
        , ( "dizzy", { name = "DIZZY SYMBOL", native = "💫", sortOrder = 157, skinVariations = Dict.fromList [], keywords = [ "comic", "dizzy", "star" ] } )
        , ( "speech_balloon", { name = "SPEECH BALLOON", native = "💬", sortOrder = 161, skinVariations = Dict.fromList [], keywords = [ "balloon", "bubble", "comic", "dialog", "speech" ] } )
        , ( "thought_balloon", { name = "THOUGHT BALLOON", native = "💭", sortOrder = 165, skinVariations = Dict.fromList [], keywords = [ "balloon", "bubble", "comic", "thought" ] } )
        , ( "white_flower", { name = "WHITE FLOWER", native = "💮", sortOrder = 661, skinVariations = Dict.fromList [], keywords = [ "flower", "white flower" ] } )
        , ( "100", { name = "HUNDRED POINTS SYMBOL", native = "💯", sortOrder = 154, skinVariations = Dict.fromList [], keywords = [ "100", "full", "hundred", "hundred points", "score" ] } )
        , ( "moneybag", { name = "MONEY BAG", native = "💰", sortOrder = 1252, skinVariations = Dict.fromList [], keywords = [ "bag", "dollar", "money", "moneybag" ] } )
        , ( "currency_exchange", { name = "CURRENCY EXCHANGE", native = "💱", sortOrder = 1498, skinVariations = Dict.fromList [], keywords = [ "bank", "currency", "exchange", "money" ] } )
        , ( "heavy_dollar_sign", { name = "HEAVY DOLLAR SIGN", native = "💲", sortOrder = 1499, skinVariations = Dict.fromList [], keywords = [ "currency", "dollar", "heavy dollar sign", "money" ] } )
        , ( "credit_card", { name = "CREDIT CARD", native = "💳", sortOrder = 1259, skinVariations = Dict.fromList [], keywords = [ "card", "credit", "money" ] } )
        , ( "yen", { name = "BANKNOTE WITH YEN SIGN", native = "💴", sortOrder = 1254, skinVariations = Dict.fromList [], keywords = [ "banknote", "bill", "currency", "money", "note", "yen" ] } )
        , ( "dollar", { name = "BANKNOTE WITH DOLLAR SIGN", native = "💵", sortOrder = 1255, skinVariations = Dict.fromList [], keywords = [ "banknote", "bill", "currency", "dollar", "money", "note" ] } )
        , ( "euro", { name = "BANKNOTE WITH EURO SIGN", native = "💶", sortOrder = 1256, skinVariations = Dict.fromList [], keywords = [ "banknote", "bill", "currency", "euro", "money", "note" ] } )
        , ( "pound", { name = "BANKNOTE WITH POUND SIGN", native = "💷", sortOrder = 1257, skinVariations = Dict.fromList [], keywords = [ "banknote", "bill", "currency", "money", "note", "pound" ] } )
        , ( "money_with_wings", { name = "MONEY WITH WINGS", native = "💸", sortOrder = 1258, skinVariations = Dict.fromList [], keywords = [ "banknote", "bill", "fly", "money", "money with wings", "wings" ] } )
        , ( "chart", { name = "CHART WITH UPWARDS TREND AND YEN SIGN", native = "💹", sortOrder = 1261, skinVariations = Dict.fromList [], keywords = [ "chart", "chart increasing with yen", "graph", "growth", "money", "yen" ] } )
        , ( "seat", { name = "SEAT", native = "💺", sortOrder = 950, skinVariations = Dict.fromList [], keywords = [ "chair", "seat" ] } )
        , ( "computer", { name = "PERSONAL COMPUTER", native = "💻", sortOrder = 1208, skinVariations = Dict.fromList [], keywords = [ "computer", "laptop", "pc", "personal" ] } )
        , ( "briefcase", { name = "BRIEFCASE", native = "💼", sortOrder = 1282, skinVariations = Dict.fromList [], keywords = [ "briefcase" ] } )
        , ( "minidisc", { name = "MINIDISC", native = "💽", sortOrder = 1214, skinVariations = Dict.fromList [], keywords = [ "computer", "disk", "minidisk", "optical" ] } )
        , ( "floppy_disk", { name = "FLOPPY DISK", native = "💾", sortOrder = 1215, skinVariations = Dict.fromList [], keywords = [ "computer", "disk", "floppy" ] } )
        , ( "cd", { name = "OPTICAL DISC", native = "💿", sortOrder = 1216, skinVariations = Dict.fromList [], keywords = [ "CD", "computer", "disk", "optical" ] } )
        , ( "dvd", { name = "DVD", native = "📀", sortOrder = 1217, skinVariations = Dict.fromList [], keywords = [ "Blu-ray", "computer", "disk", "DVD", "optical" ] } )
        , ( "file_folder", { name = "FILE FOLDER", native = "📁", sortOrder = 1283, skinVariations = Dict.fromList [], keywords = [ "file", "folder" ] } )
        , ( "open_file_folder", { name = "OPEN FILE FOLDER", native = "📂", sortOrder = 1284, skinVariations = Dict.fromList [], keywords = [ "file", "folder", "open" ] } )
        , ( "page_with_curl", { name = "PAGE WITH CURL", native = "📃", sortOrder = 1244, skinVariations = Dict.fromList [], keywords = [ "curl", "document", "page", "page with curl" ] } )
        , ( "page_facing_up", { name = "PAGE FACING UP", native = "📄", sortOrder = 1246, skinVariations = Dict.fromList [], keywords = [ "document", "page", "page facing up" ] } )
        , ( "date", { name = "CALENDAR", native = "📅", sortOrder = 1286, skinVariations = Dict.fromList [], keywords = [ "calendar", "date" ] } )
        , ( "calendar", { name = "TEAR-OFF CALENDAR", native = "📆", sortOrder = 1287, skinVariations = Dict.fromList [], keywords = [ "calendar", "tear-off calendar" ] } )
        , ( "card_index", { name = "CARD INDEX", native = "📇", sortOrder = 1290, skinVariations = Dict.fromList [], keywords = [ "card", "index", "rolodex" ] } )
        , ( "chart_with_upwards_trend", { name = "CHART WITH UPWARDS TREND", native = "📈", sortOrder = 1291, skinVariations = Dict.fromList [], keywords = [ "chart", "chart increasing", "graph", "growth", "trend", "upward" ] } )
        , ( "chart_with_downwards_trend", { name = "CHART WITH DOWNWARDS TREND", native = "📉", sortOrder = 1292, skinVariations = Dict.fromList [], keywords = [ "chart", "chart decreasing", "down", "graph", "trend" ] } )
        , ( "bar_chart", { name = "BAR CHART", native = "📊", sortOrder = 1293, skinVariations = Dict.fromList [], keywords = [ "bar", "chart", "graph" ] } )
        , ( "clipboard", { name = "CLIPBOARD", native = "📋", sortOrder = 1294, skinVariations = Dict.fromList [], keywords = [ "clipboard" ] } )
        , ( "pushpin", { name = "PUSHPIN", native = "📌", sortOrder = 1295, skinVariations = Dict.fromList [], keywords = [ "pin", "pushpin" ] } )
        , ( "round_pushpin", { name = "ROUND PUSHPIN", native = "📍", sortOrder = 1296, skinVariations = Dict.fromList [], keywords = [ "pin", "pushpin", "round pushpin" ] } )
        , ( "paperclip", { name = "PAPERCLIP", native = "📎", sortOrder = 1297, skinVariations = Dict.fromList [], keywords = [ "paperclip" ] } )
        , ( "straight_ruler", { name = "STRAIGHT RULER", native = "📏", sortOrder = 1299, skinVariations = Dict.fromList [], keywords = [ "ruler", "straight edge", "straight ruler" ] } )
        , ( "triangular_ruler", { name = "TRIANGULAR RULER", native = "📐", sortOrder = 1300, skinVariations = Dict.fromList [], keywords = [ "ruler", "set", "triangle", "triangular ruler" ] } )
        , ( "bookmark_tabs", { name = "BOOKMARK TABS", native = "📑", sortOrder = 1249, skinVariations = Dict.fromList [], keywords = [ "bookmark", "mark", "marker", "tabs" ] } )
        , ( "ledger", { name = "LEDGER", native = "📒", sortOrder = 1243, skinVariations = Dict.fromList [], keywords = [ "ledger", "notebook" ] } )
        , ( "notebook", { name = "NOTEBOOK", native = "📓", sortOrder = 1242, skinVariations = Dict.fromList [], keywords = [ "notebook" ] } )
        , ( "notebook_with_decorative_cover", { name = "NOTEBOOK WITH DECORATIVE COVER", native = "📔", sortOrder = 1235, skinVariations = Dict.fromList [], keywords = [ "book", "cover", "decorated", "notebook", "notebook with decorative cover" ] } )
        , ( "closed_book", { name = "CLOSED BOOK", native = "📕", sortOrder = 1236, skinVariations = Dict.fromList [], keywords = [ "book", "closed" ] } )
        , ( "book", { name = "OPEN BOOK", native = "📖", sortOrder = 1237, skinVariations = Dict.fromList [], keywords = [ "book", "open" ] } )
        , ( "green_book", { name = "GREEN BOOK", native = "📗", sortOrder = 1238, skinVariations = Dict.fromList [], keywords = [ "book", "green" ] } )
        , ( "blue_book", { name = "BLUE BOOK", native = "📘", sortOrder = 1239, skinVariations = Dict.fromList [], keywords = [ "blue", "book" ] } )
        , ( "orange_book", { name = "ORANGE BOOK", native = "📙", sortOrder = 1240, skinVariations = Dict.fromList [], keywords = [ "book", "orange" ] } )
        , ( "books", { name = "BOOKS", native = "📚", sortOrder = 1241, skinVariations = Dict.fromList [], keywords = [ "book", "books" ] } )
        , ( "name_badge", { name = "NAME BADGE", native = "📛", sortOrder = 1504, skinVariations = Dict.fromList [], keywords = [ "badge", "name" ] } )
        , ( "scroll", { name = "SCROLL", native = "📜", sortOrder = 1245, skinVariations = Dict.fromList [], keywords = [ "paper", "scroll" ] } )
        , ( "memo", { name = "MEMO", native = "📝", sortOrder = 1281, skinVariations = Dict.fromList [], keywords = [ "memo", "pencil" ] } )
        , ( "telephone_receiver", { name = "TELEPHONE RECEIVER", native = "📞", sortOrder = 1202, skinVariations = Dict.fromList [], keywords = [ "phone", "receiver", "telephone" ] } )
        , ( "pager", { name = "PAGER", native = "📟", sortOrder = 1203, skinVariations = Dict.fromList [], keywords = [ "pager" ] } )
        , ( "fax", { name = "FAX MACHINE", native = "📠", sortOrder = 1204, skinVariations = Dict.fromList [], keywords = [ "fax", "fax machine" ] } )
        , ( "satellite_antenna", { name = "SATELLITE ANTENNA", native = "📡", sortOrder = 1342, skinVariations = Dict.fromList [], keywords = [ "antenna", "dish", "satellite" ] } )
        , ( "loudspeaker", { name = "PUBLIC ADDRESS LOUDSPEAKER", native = "📢", sortOrder = 1174, skinVariations = Dict.fromList [], keywords = [ "loud", "loudspeaker", "public address" ] } )
        , ( "mega", { name = "CHEERING MEGAPHONE", native = "📣", sortOrder = 1175, skinVariations = Dict.fromList [], keywords = [ "cheering", "megaphone" ] } )
        , ( "outbox_tray", { name = "OUTBOX TRAY", native = "📤", sortOrder = 1266, skinVariations = Dict.fromList [], keywords = [ "box", "letter", "mail", "outbox", "sent", "tray" ] } )
        , ( "inbox_tray", { name = "INBOX TRAY", native = "📥", sortOrder = 1267, skinVariations = Dict.fromList [], keywords = [ "box", "inbox", "letter", "mail", "receive", "tray" ] } )
        , ( "package", { name = "PACKAGE", native = "📦", sortOrder = 1268, skinVariations = Dict.fromList [], keywords = [ "box", "package", "parcel" ] } )
        , ( "e-mail", { name = "E-MAIL SYMBOL", native = "📧", sortOrder = 1263, skinVariations = Dict.fromList [], keywords = [ "e-mail", "email", "letter", "mail" ] } )
        , ( "incoming_envelope", { name = "INCOMING ENVELOPE", native = "📨", sortOrder = 1264, skinVariations = Dict.fromList [], keywords = [ "e-mail", "email", "envelope", "incoming", "letter", "receive" ] } )
        , ( "envelope_with_arrow", { name = "ENVELOPE WITH DOWNWARDS ARROW ABOVE", native = "📩", sortOrder = 1265, skinVariations = Dict.fromList [], keywords = [ "arrow", "e-mail", "email", "envelope", "envelope with arrow", "outgoing" ] } )
        , ( "mailbox_closed", { name = "CLOSED MAILBOX WITH LOWERED FLAG", native = "📪", sortOrder = 1270, skinVariations = Dict.fromList [], keywords = [ "closed", "closed mailbox with lowered flag", "lowered", "mail", "mailbox", "postbox" ] } )
        , ( "mailbox", { name = "CLOSED MAILBOX WITH RAISED FLAG", native = "📫", sortOrder = 1269, skinVariations = Dict.fromList [], keywords = [ "closed", "closed mailbox with raised flag", "mail", "mailbox", "postbox" ] } )
        , ( "mailbox_with_mail", { name = "OPEN MAILBOX WITH RAISED FLAG", native = "📬", sortOrder = 1271, skinVariations = Dict.fromList [], keywords = [ "mail", "mailbox", "open", "open mailbox with raised flag", "postbox" ] } )
        , ( "mailbox_with_no_mail", { name = "OPEN MAILBOX WITH LOWERED FLAG", native = "📭", sortOrder = 1272, skinVariations = Dict.fromList [], keywords = [ "lowered", "mail", "mailbox", "open", "open mailbox with lowered flag", "postbox" ] } )
        , ( "postbox", { name = "POSTBOX", native = "📮", sortOrder = 1273, skinVariations = Dict.fromList [], keywords = [ "mail", "mailbox", "postbox" ] } )
        , ( "postal_horn", { name = "POSTAL HORN", native = "📯", sortOrder = 1176, skinVariations = Dict.fromList [], keywords = [ "horn", "post", "postal" ] } )
        , ( "newspaper", { name = "NEWSPAPER", native = "📰", sortOrder = 1247, skinVariations = Dict.fromList [], keywords = [ "news", "newspaper", "paper" ] } )
        , ( "iphone", { name = "MOBILE PHONE", native = "📱", sortOrder = 1199, skinVariations = Dict.fromList [], keywords = [ "cell", "mobile", "phone", "telephone" ] } )
        , ( "calling", { name = "MOBILE PHONE WITH RIGHTWARDS ARROW AT LEFT", native = "📲", sortOrder = 1200, skinVariations = Dict.fromList [], keywords = [ "arrow", "cell", "mobile", "mobile phone with arrow", "phone", "receive" ] } )
        , ( "vibration_mode", { name = "VIBRATION MODE", native = "📳", sortOrder = 1480, skinVariations = Dict.fromList [], keywords = [ "cell", "mobile", "mode", "phone", "telephone", "vibration" ] } )
        , ( "mobile_phone_off", { name = "MOBILE PHONE OFF", native = "📴", sortOrder = 1481, skinVariations = Dict.fromList [], keywords = [ "cell", "mobile", "off", "phone", "telephone" ] } )
        , ( "no_mobile_phones", { name = "NO MOBILE PHONES", native = "📵", sortOrder = 1406, skinVariations = Dict.fromList [], keywords = [ "cell", "forbidden", "mobile", "no", "no mobile phones", "phone" ] } )
        , ( "signal_strength", { name = "ANTENNA WITH BARS", native = "📶", sortOrder = 1478, skinVariations = Dict.fromList [], keywords = [ "antenna", "antenna bars", "bar", "cell", "mobile", "phone" ] } )
        , ( "camera", { name = "CAMERA", native = "📷", sortOrder = 1224, skinVariations = Dict.fromList [], keywords = [ "camera", "video" ] } )
        , ( "camera_with_flash", { name = "CAMERA WITH FLASH", native = "📸", sortOrder = 1225, skinVariations = Dict.fromList [], keywords = [ "camera", "camera with flash", "flash", "video" ] } )
        , ( "video_camera", { name = "VIDEO CAMERA", native = "📹", sortOrder = 1226, skinVariations = Dict.fromList [], keywords = [ "camera", "video" ] } )
        , ( "tv", { name = "TELEVISION", native = "📺", sortOrder = 1223, skinVariations = Dict.fromList [], keywords = [ "television", "tv", "video" ] } )
        , ( "radio", { name = "RADIO", native = "📻", sortOrder = 1187, skinVariations = Dict.fromList [], keywords = [ "radio", "video" ] } )
        , ( "vhs", { name = "VIDEOCASSETTE", native = "📼", sortOrder = 1227, skinVariations = Dict.fromList [], keywords = [ "tape", "vhs", "video", "videocassette" ] } )
        , ( "film_projector", { name = "FILM PROJECTOR", native = "📽️", sortOrder = 1221, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "prayer_beads", { name = "PRAYER BEADS", native = "📿", sortOrder = 1166, skinVariations = Dict.fromList [], keywords = [ "beads", "clothing", "necklace", "prayer", "religion" ] } )
        , ( "twisted_rightwards_arrows", { name = "TWISTED RIGHTWARDS ARROWS", native = "🔀", sortOrder = 1457, skinVariations = Dict.fromList [], keywords = [ "arrow", "crossed", "shuffle tracks button" ] } )
        , ( "repeat", { name = "CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS", native = "🔁", sortOrder = 1458, skinVariations = Dict.fromList [], keywords = [ "arrow", "clockwise", "repeat", "repeat button" ] } )
        , ( "repeat_one", { name = "CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS WITH CIRCLED ONE OVERLAY", native = "🔂", sortOrder = 1459, skinVariations = Dict.fromList [], keywords = [ "arrow", "clockwise", "once", "repeat single button" ] } )
        , ( "arrows_clockwise", { name = "CLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS", native = "🔃", sortOrder = 1424, skinVariations = Dict.fromList [], keywords = [ "arrow", "clockwise", "clockwise vertical arrows", "reload" ] } )
        , ( "arrows_counterclockwise", { name = "ANTICLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS", native = "🔄", sortOrder = 1425, skinVariations = Dict.fromList [], keywords = [ "anticlockwise", "arrow", "counterclockwise", "counterclockwise arrows button", "withershins" ] } )
        , ( "low_brightness", { name = "LOW BRIGHTNESS SYMBOL", native = "🔅", sortOrder = 1476, skinVariations = Dict.fromList [], keywords = [ "brightness", "dim", "dim button", "low" ] } )
        , ( "high_brightness", { name = "HIGH BRIGHTNESS SYMBOL", native = "🔆", sortOrder = 1477, skinVariations = Dict.fromList [], keywords = [ "bright", "bright button", "brightness" ] } )
        , ( "mute", { name = "SPEAKER WITH CANCELLATION STROKE", native = "🔇", sortOrder = 1170, skinVariations = Dict.fromList [], keywords = [ "mute", "muted speaker", "quiet", "silent", "speaker" ] } )
        , ( "speaker", { name = "SPEAKER", native = "🔈", sortOrder = 1171, skinVariations = Dict.fromList [], keywords = [ "soft", "speaker low volume" ] } )
        , ( "sound", { name = "SPEAKER WITH ONE SOUND WAVE", native = "🔉", sortOrder = 1172, skinVariations = Dict.fromList [], keywords = [ "medium", "speaker medium volume" ] } )
        , ( "loud_sound", { name = "SPEAKER WITH THREE SOUND WAVES", native = "🔊", sortOrder = 1173, skinVariations = Dict.fromList [], keywords = [ "loud", "speaker high volume" ] } )
        , ( "battery", { name = "BATTERY", native = "🔋", sortOrder = 1205, skinVariations = Dict.fromList [], keywords = [ "battery" ] } )
        , ( "electric_plug", { name = "ELECTRIC PLUG", native = "🔌", sortOrder = 1207, skinVariations = Dict.fromList [], keywords = [ "electric", "electricity", "plug" ] } )
        , ( "mag", { name = "LEFT-POINTING MAGNIFYING GLASS", native = "🔍", sortOrder = 1228, skinVariations = Dict.fromList [], keywords = [ "glass", "magnifying", "magnifying glass tilted left", "search", "tool" ] } )
        , ( "mag_right", { name = "RIGHT-POINTING MAGNIFYING GLASS", native = "🔎", sortOrder = 1229, skinVariations = Dict.fromList [], keywords = [ "glass", "magnifying", "magnifying glass tilted right", "search", "tool" ] } )
        , ( "lock_with_ink_pen", { name = "LOCK WITH INK PEN", native = "🔏", sortOrder = 1307, skinVariations = Dict.fromList [], keywords = [ "ink", "lock", "locked with pen", "nib", "pen", "privacy" ] } )
        , ( "closed_lock_with_key", { name = "CLOSED LOCK WITH KEY", native = "🔐", sortOrder = 1308, skinVariations = Dict.fromList [], keywords = [ "closed", "key", "lock", "locked with key", "secure" ] } )
        , ( "key", { name = "KEY", native = "🔑", sortOrder = 1309, skinVariations = Dict.fromList [], keywords = [ "key", "lock", "password" ] } )
        , ( "lock", { name = "LOCK", native = "🔒", sortOrder = 1305, skinVariations = Dict.fromList [], keywords = [ "closed", "locked" ] } )
        , ( "unlock", { name = "OPEN LOCK", native = "🔓", sortOrder = 1306, skinVariations = Dict.fromList [], keywords = [ "lock", "open", "unlock", "unlocked" ] } )
        , ( "bell", { name = "BELL", native = "🔔", sortOrder = 1177, skinVariations = Dict.fromList [], keywords = [ "bell" ] } )
        , ( "no_bell", { name = "BELL WITH CANCELLATION STROKE", native = "🔕", sortOrder = 1178, skinVariations = Dict.fromList [], keywords = [ "bell", "bell with slash", "forbidden", "mute", "quiet", "silent" ] } )
        , ( "bookmark", { name = "BOOKMARK", native = "🔖", sortOrder = 1250, skinVariations = Dict.fromList [], keywords = [ "bookmark", "mark" ] } )
        , ( "link", { name = "LINK SYMBOL", native = "🔗", sortOrder = 1330, skinVariations = Dict.fromList [], keywords = [ "link" ] } )
        , ( "radio_button", { name = "RADIO BUTTON", native = "🔘", sortOrder = 1604, skinVariations = Dict.fromList [], keywords = [ "button", "geometric", "radio" ] } )
        , ( "back", { name = "BACK WITH LEFTWARDS ARROW ABOVE", native = "🔙", sortOrder = 1426, skinVariations = Dict.fromList [], keywords = [ "arrow", "BACK" ] } )
        , ( "end", { name = "END WITH LEFTWARDS ARROW ABOVE", native = "🔚", sortOrder = 1427, skinVariations = Dict.fromList [], keywords = [ "arrow", "END" ] } )
        , ( "on", { name = "ON WITH EXCLAMATION MARK WITH LEFT RIGHT ARROW ABOVE", native = "🔛", sortOrder = 1428, skinVariations = Dict.fromList [], keywords = [ "arrow", "mark", "ON", "ON!" ] } )
        , ( "soon", { name = "SOON WITH RIGHTWARDS ARROW ABOVE", native = "🔜", sortOrder = 1429, skinVariations = Dict.fromList [], keywords = [ "arrow", "SOON" ] } )
        , ( "top", { name = "TOP WITH UPWARDS ARROW ABOVE", native = "🔝", sortOrder = 1430, skinVariations = Dict.fromList [], keywords = [ "arrow", "TOP", "up" ] } )
        , ( "underage", { name = "NO ONE UNDER EIGHTEEN SYMBOL", native = "🔞", sortOrder = 1407, skinVariations = Dict.fromList [], keywords = [ "18", "age restriction", "eighteen", "no one under eighteen", "prohibited", "underage" ] } )
        , ( "keycap_ten", { name = "KEYCAP TEN", native = "🔟", sortOrder = 1533, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "capital_abcd", { name = "INPUT SYMBOL FOR LATIN CAPITAL LETTERS", native = "🔠", sortOrder = 1534, skinVariations = Dict.fromList [], keywords = [ "ABCD", "input", "latin", "letters", "uppercase" ] } )
        , ( "abcd", { name = "INPUT SYMBOL FOR LATIN SMALL LETTERS", native = "🔡", sortOrder = 1535, skinVariations = Dict.fromList [], keywords = [ "abcd", "input", "latin", "letters", "lowercase" ] } )
        , ( "1234", { name = "INPUT SYMBOL FOR NUMBERS", native = "🔢", sortOrder = 1536, skinVariations = Dict.fromList [], keywords = [ "1234", "input", "numbers" ] } )
        , ( "symbols", { name = "INPUT SYMBOL FOR SYMBOLS", native = "🔣", sortOrder = 1537, skinVariations = Dict.fromList [], keywords = [ "〒♪&%", "input", "input symbols" ] } )
        , ( "abc", { name = "INPUT SYMBOL FOR LATIN LETTERS", native = "🔤", sortOrder = 1538, skinVariations = Dict.fromList [], keywords = [ "abc", "alphabet", "input", "latin", "letters" ] } )
        , ( "fire", { name = "FIRE", native = "🔥", sortOrder = 1035, skinVariations = Dict.fromList [], keywords = [ "fire", "flame", "tool" ] } )
        , ( "flashlight", { name = "ELECTRIC TORCH", native = "🔦", sortOrder = 1232, skinVariations = Dict.fromList [], keywords = [ "electric", "flashlight", "light", "tool", "torch" ] } )
        , ( "wrench", { name = "WRENCH", native = "🔧", sortOrder = 1323, skinVariations = Dict.fromList [], keywords = [ "spanner", "tool", "wrench" ] } )
        , ( "hammer", { name = "HAMMER", native = "🔨", sortOrder = 1311, skinVariations = Dict.fromList [], keywords = [ "hammer", "tool" ] } )
        , ( "nut_and_bolt", { name = "NUT AND BOLT", native = "🔩", sortOrder = 1325, skinVariations = Dict.fromList [], keywords = [ "bolt", "nut", "nut and bolt", "tool" ] } )
        , ( "hocho", { name = "HOCHO", native = "🔪", sortOrder = 817, skinVariations = Dict.fromList [], keywords = [ "cooking", "hocho", "kitchen knife", "knife", "tool", "weapon" ] } )
        , ( "gun", { name = "PISTOL", native = "🔫", sortOrder = 1095, skinVariations = Dict.fromList [], keywords = [ "gun", "handgun", "pistol", "revolver", "tool", "water", "weapon" ] } )
        , ( "microscope", { name = "MICROSCOPE", native = "🔬", sortOrder = 1340, skinVariations = Dict.fromList [], keywords = [ "microscope", "science", "tool" ] } )
        , ( "telescope", { name = "TELESCOPE", native = "🔭", sortOrder = 1341, skinVariations = Dict.fromList [], keywords = [ "science", "telescope", "tool" ] } )
        , ( "crystal_ball", { name = "CRYSTAL BALL", native = "🔮", sortOrder = 1097, skinVariations = Dict.fromList [], keywords = [ "ball", "crystal", "fairy tale", "fantasy", "fortune", "tool" ] } )
        , ( "six_pointed_star", { name = "SIX POINTED STAR WITH MIDDLE DOT", native = "🔯", sortOrder = 1442, skinVariations = Dict.fromList [], keywords = [ "dotted six-pointed star", "fortune", "star" ] } )
        , ( "beginner", { name = "JAPANESE SYMBOL FOR BEGINNER", native = "🔰", sortOrder = 1505, skinVariations = Dict.fromList [], keywords = [ "beginner", "chevron", "Japanese", "Japanese symbol for beginner", "leaf" ] } )
        , ( "trident", { name = "TRIDENT EMBLEM", native = "🔱", sortOrder = 1503, skinVariations = Dict.fromList [], keywords = [ "anchor", "emblem", "ship", "tool", "trident" ] } )
        , ( "black_square_button", { name = "BLACK SQUARE BUTTON", native = "🔲", sortOrder = 1606, skinVariations = Dict.fromList [], keywords = [ "black square button", "button", "geometric", "square" ] } )
        , ( "white_square_button", { name = "WHITE SQUARE BUTTON", native = "🔳", sortOrder = 1605, skinVariations = Dict.fromList [], keywords = [ "button", "geometric", "outlined", "square", "white square button" ] } )
        , ( "red_circle", { name = "LARGE RED CIRCLE", native = "🔴", sortOrder = 1573, skinVariations = Dict.fromList [], keywords = [ "circle", "geometric", "red" ] } )
        , ( "large_blue_circle", { name = "LARGE BLUE CIRCLE", native = "🔵", sortOrder = 1577, skinVariations = Dict.fromList [], keywords = [ "blue", "circle", "geometric" ] } )
        , ( "large_orange_diamond", { name = "LARGE ORANGE DIAMOND", native = "🔶", sortOrder = 1597, skinVariations = Dict.fromList [], keywords = [ "diamond", "geometric", "large orange diamond", "orange" ] } )
        , ( "large_blue_diamond", { name = "LARGE BLUE DIAMOND", native = "🔷", sortOrder = 1598, skinVariations = Dict.fromList [], keywords = [ "blue", "diamond", "geometric", "large blue diamond" ] } )
        , ( "small_orange_diamond", { name = "SMALL ORANGE DIAMOND", native = "🔸", sortOrder = 1599, skinVariations = Dict.fromList [], keywords = [ "diamond", "geometric", "orange", "small orange diamond" ] } )
        , ( "small_blue_diamond", { name = "SMALL BLUE DIAMOND", native = "🔹", sortOrder = 1600, skinVariations = Dict.fromList [], keywords = [ "blue", "diamond", "geometric", "small blue diamond" ] } )
        , ( "small_red_triangle", { name = "UP-POINTING RED TRIANGLE", native = "🔺", sortOrder = 1601, skinVariations = Dict.fromList [], keywords = [ "geometric", "red", "red triangle pointed up" ] } )
        , ( "small_red_triangle_down", { name = "DOWN-POINTING RED TRIANGLE", native = "🔻", sortOrder = 1602, skinVariations = Dict.fromList [], keywords = [ "down", "geometric", "red", "red triangle pointed down" ] } )
        , ( "arrow_up_small", { name = "UP-POINTING SMALL RED TRIANGLE", native = "🔼", sortOrder = 1467, skinVariations = Dict.fromList [], keywords = [ "arrow", "button", "upwards button" ] } )
        , ( "arrow_down_small", { name = "DOWN-POINTING SMALL RED TRIANGLE", native = "🔽", sortOrder = 1469, skinVariations = Dict.fromList [], keywords = [ "arrow", "button", "down", "downwards button" ] } )
        , ( "om_symbol", { name = "OM", native = "🕉️", sortOrder = 1433, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "dove_of_peace", { name = "DOVE", native = "🕊️", sortOrder = 609, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "kaaba", { name = "KAABA", native = "🕋", sortOrder = 868, skinVariations = Dict.fromList [], keywords = [ "islam", "kaaba", "Muslim", "religion" ] } )
        , ( "mosque", { name = "MOSQUE", native = "🕌", sortOrder = 864, skinVariations = Dict.fromList [], keywords = [ "islam", "mosque", "Muslim", "religion" ] } )
        , ( "synagogue", { name = "SYNAGOGUE", native = "🕍", sortOrder = 866, skinVariations = Dict.fromList [], keywords = [ "Jew", "Jewish", "religion", "synagogue", "temple" ] } )
        , ( "menorah_with_nine_branches", { name = "MENORAH WITH NINE BRANCHES", native = "🕎", sortOrder = 1441, skinVariations = Dict.fromList [], keywords = [ "candelabrum", "candlestick", "menorah", "religion" ] } )
        , ( "clock1", { name = "CLOCK FACE ONE OCLOCK", native = "🕐", sortOrder = 969, skinVariations = Dict.fromList [], keywords = [ "00", "1", "1:00", "clock", "o’clock", "one" ] } )
        , ( "clock2", { name = "CLOCK FACE TWO OCLOCK", native = "🕑", sortOrder = 971, skinVariations = Dict.fromList [], keywords = [ "00", "2", "2:00", "clock", "o’clock", "two" ] } )
        , ( "clock3", { name = "CLOCK FACE THREE OCLOCK", native = "🕒", sortOrder = 973, skinVariations = Dict.fromList [], keywords = [ "00", "3", "3:00", "clock", "o’clock", "three" ] } )
        , ( "clock4", { name = "CLOCK FACE FOUR OCLOCK", native = "🕓", sortOrder = 975, skinVariations = Dict.fromList [], keywords = [ "00", "4", "4:00", "clock", "four", "o’clock" ] } )
        , ( "clock5", { name = "CLOCK FACE FIVE OCLOCK", native = "🕔", sortOrder = 977, skinVariations = Dict.fromList [], keywords = [ "00", "5", "5:00", "clock", "five", "o’clock" ] } )
        , ( "clock6", { name = "CLOCK FACE SIX OCLOCK", native = "🕕", sortOrder = 979, skinVariations = Dict.fromList [], keywords = [ "00", "6", "6:00", "clock", "o’clock", "six" ] } )
        , ( "clock7", { name = "CLOCK FACE SEVEN OCLOCK", native = "🕖", sortOrder = 981, skinVariations = Dict.fromList [], keywords = [ "00", "7", "7:00", "clock", "o’clock", "seven" ] } )
        , ( "clock8", { name = "CLOCK FACE EIGHT OCLOCK", native = "🕗", sortOrder = 983, skinVariations = Dict.fromList [], keywords = [ "00", "8", "8:00", "clock", "eight", "o’clock" ] } )
        , ( "clock9", { name = "CLOCK FACE NINE OCLOCK", native = "🕘", sortOrder = 985, skinVariations = Dict.fromList [], keywords = [ "00", "9", "9:00", "clock", "nine", "o’clock" ] } )
        , ( "clock10", { name = "CLOCK FACE TEN OCLOCK", native = "🕙", sortOrder = 987, skinVariations = Dict.fromList [], keywords = [ "00", "10", "10:00", "clock", "o’clock", "ten" ] } )
        , ( "clock11", { name = "CLOCK FACE ELEVEN OCLOCK", native = "🕚", sortOrder = 989, skinVariations = Dict.fromList [], keywords = [ "00", "11", "11:00", "clock", "eleven", "o’clock" ] } )
        , ( "clock12", { name = "CLOCK FACE TWELVE OCLOCK", native = "🕛", sortOrder = 967, skinVariations = Dict.fromList [], keywords = [ "00", "12", "12:00", "clock", "o’clock", "twelve" ] } )
        , ( "clock130", { name = "CLOCK FACE ONE-THIRTY", native = "🕜", sortOrder = 970, skinVariations = Dict.fromList [], keywords = [ "1", "1:30", "clock", "one", "one-thirty", "thirty" ] } )
        , ( "clock230", { name = "CLOCK FACE TWO-THIRTY", native = "🕝", sortOrder = 972, skinVariations = Dict.fromList [], keywords = [ "2", "2:30", "clock", "thirty", "two", "two-thirty" ] } )
        , ( "clock330", { name = "CLOCK FACE THREE-THIRTY", native = "🕞", sortOrder = 974, skinVariations = Dict.fromList [], keywords = [ "3", "3:30", "clock", "thirty", "three", "three-thirty" ] } )
        , ( "clock430", { name = "CLOCK FACE FOUR-THIRTY", native = "🕟", sortOrder = 976, skinVariations = Dict.fromList [], keywords = [ "4", "4:30", "clock", "four", "four-thirty", "thirty" ] } )
        , ( "clock530", { name = "CLOCK FACE FIVE-THIRTY", native = "🕠", sortOrder = 978, skinVariations = Dict.fromList [], keywords = [ "5", "5:30", "clock", "five", "five-thirty", "thirty" ] } )
        , ( "clock630", { name = "CLOCK FACE SIX-THIRTY", native = "🕡", sortOrder = 980, skinVariations = Dict.fromList [], keywords = [ "6", "6:30", "clock", "six", "six-thirty", "thirty" ] } )
        , ( "clock730", { name = "CLOCK FACE SEVEN-THIRTY", native = "🕢", sortOrder = 982, skinVariations = Dict.fromList [], keywords = [ "7", "7:30", "clock", "seven", "seven-thirty", "thirty" ] } )
        , ( "clock830", { name = "CLOCK FACE EIGHT-THIRTY", native = "🕣", sortOrder = 984, skinVariations = Dict.fromList [], keywords = [ "8", "8:30", "clock", "eight", "eight-thirty", "thirty" ] } )
        , ( "clock930", { name = "CLOCK FACE NINE-THIRTY", native = "🕤", sortOrder = 986, skinVariations = Dict.fromList [], keywords = [ "9", "9:30", "clock", "nine", "nine-thirty", "thirty" ] } )
        , ( "clock1030", { name = "CLOCK FACE TEN-THIRTY", native = "🕥", sortOrder = 988, skinVariations = Dict.fromList [], keywords = [ "10", "10:30", "clock", "ten", "ten-thirty", "thirty" ] } )
        , ( "clock1130", { name = "CLOCK FACE ELEVEN-THIRTY", native = "🕦", sortOrder = 990, skinVariations = Dict.fromList [], keywords = [ "11", "11:30", "clock", "eleven", "eleven-thirty", "thirty" ] } )
        , ( "clock1230", { name = "CLOCK FACE TWELVE-THIRTY", native = "🕧", sortOrder = 968, skinVariations = Dict.fromList [], keywords = [ "12", "12:30", "clock", "thirty", "twelve", "twelve-thirty" ] } )
        , ( "candle", { name = "CANDLE", native = "🕯️", sortOrder = 1230, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "mantelpiece_clock", { name = "MANTELPIECE CLOCK", native = "🕰️", sortOrder = 966, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "hole", { name = "HOLE", native = "🕳️", sortOrder = 160, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man_in_business_suit_levitating", { name = "PERSON IN SUIT LEVITATING", native = "🕴️", sortOrder = 429, skinVariations = Dict.fromList [ ( "1F3FB", "🕴🏻" ), ( "1F3FC", "🕴🏼" ), ( "1F3FD", "🕴🏽" ), ( "1F3FE", "🕴🏾" ), ( "1F3FF", "🕴🏿" ) ], keywords = [] } )
        , ( "female-detective", { name = "WOMAN DETECTIVE", native = "🕵️\u{200D}♀️", sortOrder = 339, skinVariations = Dict.fromList [ ( "1F3FB", "🕵🏻\u{200D}♀️" ), ( "1F3FC", "🕵🏼\u{200D}♀️" ), ( "1F3FD", "🕵🏽\u{200D}♀️" ), ( "1F3FE", "🕵🏾\u{200D}♀️" ), ( "1F3FF", "🕵🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male-detective", { name = "MAN DETECTIVE", native = "🕵️\u{200D}♂️", sortOrder = 338, skinVariations = Dict.fromList [ ( "1F3FB", "🕵🏻\u{200D}♂️" ), ( "1F3FC", "🕵🏼\u{200D}♂️" ), ( "1F3FD", "🕵🏽\u{200D}♂️" ), ( "1F3FE", "🕵🏾\u{200D}♂️" ), ( "1F3FF", "🕵🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "sleuth_or_spy", { name = "DETECTIVE", native = "🕵️", sortOrder = 337, skinVariations = Dict.fromList [ ( "1F3FB", "🕵🏻" ), ( "1F3FC", "🕵🏼" ), ( "1F3FD", "🕵🏽" ), ( "1F3FE", "🕵🏾" ), ( "1F3FF", "🕵🏿" ) ], keywords = [] } )
        , ( "dark_sunglasses", { name = "SUNGLASSES", native = "🕶️", sortOrder = 1124, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "spider", { name = "SPIDER", native = "🕷️", sortOrder = 652, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "spider_web", { name = "SPIDER WEB", native = "🕸️", sortOrder = 653, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "joystick", { name = "JOYSTICK", native = "🕹️", sortOrder = 1100, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man_dancing", { name = "MAN DANCING", native = "🕺", sortOrder = 428, skinVariations = Dict.fromList [ ( "1F3FB", "🕺🏻" ), ( "1F3FC", "🕺🏼" ), ( "1F3FD", "🕺🏽" ), ( "1F3FE", "🕺🏾" ), ( "1F3FF", "🕺🏿" ) ], keywords = [ "dance", "dancing", "man" ] } )
        , ( "linked_paperclips", { name = "LINKED PAPERCLIPS", native = "🖇️", sortOrder = 1298, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "lower_left_ballpoint_pen", { name = "PEN", native = "🖊️", sortOrder = 1278, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "lower_left_fountain_pen", { name = "FOUNTAIN PEN", native = "🖋️", sortOrder = 1277, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "lower_left_paintbrush", { name = "PAINTBRUSH", native = "🖌️", sortOrder = 1279, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "lower_left_crayon", { name = "CRAYON", native = "🖍️", sortOrder = 1280, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "raised_hand_with_fingers_splayed", { name = "HAND WITH FINGERS SPLAYED", native = "🖐️", sortOrder = 169, skinVariations = Dict.fromList [ ( "1F3FB", "🖐🏻" ), ( "1F3FC", "🖐🏼" ), ( "1F3FD", "🖐🏽" ), ( "1F3FE", "🖐🏾" ), ( "1F3FF", "🖐🏿" ) ], keywords = [] } )
        , ( "middle_finger", { name = "REVERSED HAND WITH MIDDLE FINGER EXTENDED", native = "🖕", sortOrder = 190, skinVariations = Dict.fromList [ ( "1F3FB", "🖕🏻" ), ( "1F3FC", "🖕🏼" ), ( "1F3FD", "🖕🏽" ), ( "1F3FE", "🖕🏾" ), ( "1F3FF", "🖕🏿" ) ], keywords = [ "finger", "hand", "middle finger" ] } )
        , ( "spock-hand", { name = "RAISED HAND WITH PART BETWEEN MIDDLE AND RING FINGERS", native = "🖖", sortOrder = 171, skinVariations = Dict.fromList [ ( "1F3FB", "🖖🏻" ), ( "1F3FC", "🖖🏼" ), ( "1F3FD", "🖖🏽" ), ( "1F3FE", "🖖🏾" ), ( "1F3FF", "🖖🏿" ) ], keywords = [ "finger", "hand", "spock", "vulcan", "vulcan salute" ] } )
        , ( "black_heart", { name = "BLACK HEART", native = "🖤", sortOrder = 150, skinVariations = Dict.fromList [], keywords = [ "black", "black heart", "evil", "wicked" ] } )
        , ( "desktop_computer", { name = "DESKTOP COMPUTER", native = "🖥️", sortOrder = 1209, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "printer", { name = "PRINTER", native = "🖨️", sortOrder = 1210, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "three_button_mouse", { name = "COMPUTER MOUSE", native = "🖱️", sortOrder = 1212, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "trackball", { name = "TRACKBALL", native = "🖲️", sortOrder = 1213, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "frame_with_picture", { name = "FRAMED PICTURE", native = "🖼️", sortOrder = 1117, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "card_index_dividers", { name = "CARD INDEX DIVIDERS", native = "🗂️", sortOrder = 1285, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "card_file_box", { name = "CARD FILE BOX", native = "🗃️", sortOrder = 1302, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "file_cabinet", { name = "FILE CABINET", native = "🗄️", sortOrder = 1303, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "wastebasket", { name = "WASTEBASKET", native = "🗑️", sortOrder = 1304, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "spiral_note_pad", { name = "SPIRAL NOTEPAD", native = "🗒️", sortOrder = 1288, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "spiral_calendar_pad", { name = "SPIRAL CALENDAR", native = "🗓️", sortOrder = 1289, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "compression", { name = "CLAMP", native = "🗜️", sortOrder = 1327, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "old_key", { name = "OLD KEY", native = "🗝️", sortOrder = 1310, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "rolled_up_newspaper", { name = "ROLLED-UP NEWSPAPER", native = "🗞️", sortOrder = 1248, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "dagger_knife", { name = "DAGGER", native = "🗡️", sortOrder = 1316, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "speaking_head_in_silhouette", { name = "SPEAKING HEAD", native = "🗣️", sortOrder = 525, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "left_speech_bubble", { name = "LEFT SPEECH BUBBLE", native = "🗨️", sortOrder = 163, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "right_anger_bubble", { name = "RIGHT ANGER BUBBLE", native = "🗯️", sortOrder = 164, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ballot_box_with_ballot", { name = "BALLOT BOX WITH BALLOT", native = "🗳️", sortOrder = 1274, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "world_map", { name = "WORLD MAP", native = "🗺️", sortOrder = 824, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "mount_fuji", { name = "MOUNT FUJI", native = "🗻", sortOrder = 830, skinVariations = Dict.fromList [], keywords = [ "fuji", "mount fuji", "mountain" ] } )
        , ( "tokyo_tower", { name = "TOKYO TOWER", native = "🗼", sortOrder = 861, skinVariations = Dict.fromList [], keywords = [ "Tokyo", "tower" ] } )
        , ( "statue_of_liberty", { name = "STATUE OF LIBERTY", native = "🗽", sortOrder = 862, skinVariations = Dict.fromList [], keywords = [ "liberty", "statue", "Statue of Liberty" ] } )
        , ( "japan", { name = "SILHOUETTE OF JAPAN", native = "🗾", sortOrder = 825, skinVariations = Dict.fromList [], keywords = [ "Japan", "map", "map of Japan" ] } )
        , ( "moyai", { name = "MOYAI", native = "🗿", sortOrder = 1381, skinVariations = Dict.fromList [], keywords = [ "face", "moai", "moyai", "statue" ] } )
        , ( "grinning", { name = "GRINNING FACE", native = "😀", sortOrder = 1, skinVariations = Dict.fromList [], keywords = [ "face", "grin", "grinning face" ] } )
        , ( "grin", { name = "GRINNING FACE WITH SMILING EYES", native = "😁", sortOrder = 4, skinVariations = Dict.fromList [], keywords = [ "beaming face with smiling eyes", "eye", "face", "grin", "smile" ] } )
        , ( "joy", { name = "FACE WITH TEARS OF JOY", native = "😂", sortOrder = 8, skinVariations = Dict.fromList [], keywords = [ "face", "face with tears of joy", "joy", "laugh", "tear" ] } )
        , ( "smiley", { name = "SMILING FACE WITH OPEN MOUTH", native = "😃", sortOrder = 2, skinVariations = Dict.fromList [], keywords = [ "face", "grinning face with big eyes", "mouth", "open", "smile" ] } )
        , ( "smile", { name = "SMILING FACE WITH OPEN MOUTH AND SMILING EYES", native = "😄", sortOrder = 3, skinVariations = Dict.fromList [], keywords = [ "eye", "face", "grinning face with smiling eyes", "mouth", "open", "smile" ] } )
        , ( "sweat_smile", { name = "SMILING FACE WITH OPEN MOUTH AND COLD SWEAT", native = "😅", sortOrder = 6, skinVariations = Dict.fromList [], keywords = [ "cold", "face", "grinning face with sweat", "open", "smile", "sweat" ] } )
        , ( "laughing", { name = "SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES", native = "😆", sortOrder = 5, skinVariations = Dict.fromList [], keywords = [ "face", "grinning squinting face", "laugh", "mouth", "satisfied", "smile" ] } )
        , ( "innocent", { name = "SMILING FACE WITH HALO", native = "😇", sortOrder = 14, skinVariations = Dict.fromList [], keywords = [ "angel", "face", "fantasy", "halo", "innocent", "smiling face with halo" ] } )
        , ( "smiling_imp", { name = "SMILING FACE WITH HORNS", native = "😈", sortOrder = 104, skinVariations = Dict.fromList [], keywords = [ "face", "fairy tale", "fantasy", "horns", "smile", "smiling face with horns" ] } )
        , ( "wink", { name = "WINKING FACE", native = "😉", sortOrder = 12, skinVariations = Dict.fromList [], keywords = [ "face", "wink", "winking face" ] } )
        , ( "blush", { name = "SMILING FACE WITH SMILING EYES", native = "😊", sortOrder = 13, skinVariations = Dict.fromList [], keywords = [ "blush", "eye", "face", "smile", "smiling face with smiling eyes" ] } )
        , ( "yum", { name = "FACE SAVOURING DELICIOUS FOOD", native = "😋", sortOrder = 24, skinVariations = Dict.fromList [], keywords = [ "delicious", "face", "face savoring food", "savouring", "smile", "yum" ] } )
        , ( "relieved", { name = "RELIEVED FACE", native = "😌", sortOrder = 51, skinVariations = Dict.fromList [], keywords = [ "face", "relieved" ] } )
        , ( "heart_eyes", { name = "SMILING FACE WITH HEART-SHAPED EYES", native = "😍", sortOrder = 16, skinVariations = Dict.fromList [], keywords = [ "eye", "face", "love", "smile", "smiling face with heart-eyes" ] } )
        , ( "sunglasses", { name = "SMILING FACE WITH SUNGLASSES", native = "😎", sortOrder = 71, skinVariations = Dict.fromList [], keywords = [ "bright", "cool", "face", "smiling face with sunglasses", "sun", "sunglasses" ] } )
        , ( "smirk", { name = "SMIRKING FACE", native = "😏", sortOrder = 44, skinVariations = Dict.fromList [], keywords = [ "face", "smirk", "smirking face" ] } )
        , ( "neutral_face", { name = "NEUTRAL FACE", native = "😐", sortOrder = 39, skinVariations = Dict.fromList [], keywords = [ "deadpan", "face", "meh", "neutral" ] } )
        , ( "expressionless", { name = "EXPRESSIONLESS FACE", native = "😑", sortOrder = 40, skinVariations = Dict.fromList [], keywords = [ "expressionless", "face", "inexpressive", "meh", "unexpressive" ] } )
        , ( "unamused", { name = "UNAMUSED FACE", native = "😒", sortOrder = 45, skinVariations = Dict.fromList [], keywords = [ "face", "unamused", "unhappy" ] } )
        , ( "sweat", { name = "FACE WITH COLD SWEAT", native = "😓", sortOrder = 96, skinVariations = Dict.fromList [], keywords = [ "cold", "downcast face with sweat", "face", "sweat" ] } )
        , ( "pensive", { name = "PENSIVE FACE", native = "😔", sortOrder = 52, skinVariations = Dict.fromList [], keywords = [ "dejected", "face", "pensive" ] } )
        , ( "confused", { name = "CONFUSED FACE", native = "😕", sortOrder = 74, skinVariations = Dict.fromList [], keywords = [ "confused", "face", "meh" ] } )
        , ( "confounded", { name = "CONFOUNDED FACE", native = "😖", sortOrder = 93, skinVariations = Dict.fromList [], keywords = [ "confounded", "face" ] } )
        , ( "kissing", { name = "KISSING FACE", native = "😗", sortOrder = 19, skinVariations = Dict.fromList [], keywords = [ "face", "kiss", "kissing face" ] } )
        , ( "kissing_heart", { name = "FACE THROWING A KISS", native = "😘", sortOrder = 18, skinVariations = Dict.fromList [], keywords = [ "face", "face blowing a kiss", "kiss" ] } )
        , ( "kissing_smiling_eyes", { name = "KISSING FACE WITH SMILING EYES", native = "😙", sortOrder = 22, skinVariations = Dict.fromList [], keywords = [ "eye", "face", "kiss", "kissing face with smiling eyes", "smile" ] } )
        , ( "kissing_closed_eyes", { name = "KISSING FACE WITH CLOSED EYES", native = "😚", sortOrder = 21, skinVariations = Dict.fromList [], keywords = [ "closed", "eye", "face", "kiss", "kissing face with closed eyes" ] } )
        , ( "stuck_out_tongue", { name = "FACE WITH STUCK-OUT TONGUE", native = "😛", sortOrder = 25, skinVariations = Dict.fromList [], keywords = [ "face", "face with tongue", "tongue" ] } )
        , ( "stuck_out_tongue_winking_eye", { name = "FACE WITH STUCK-OUT TONGUE AND WINKING EYE", native = "😜", sortOrder = 26, skinVariations = Dict.fromList [], keywords = [ "eye", "face", "joke", "tongue", "wink", "winking face with tongue" ] } )
        , ( "stuck_out_tongue_closed_eyes", { name = "FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES", native = "😝", sortOrder = 28, skinVariations = Dict.fromList [], keywords = [ "eye", "face", "horrible", "squinting face with tongue", "taste", "tongue" ] } )
        , ( "disappointed", { name = "DISAPPOINTED FACE", native = "😞", sortOrder = 95, skinVariations = Dict.fromList [], keywords = [ "disappointed", "face" ] } )
        , ( "worried", { name = "WORRIED FACE", native = "😟", sortOrder = 76, skinVariations = Dict.fromList [], keywords = [ "face", "worried" ] } )
        , ( "angry", { name = "ANGRY FACE", native = "😠", sortOrder = 102, skinVariations = Dict.fromList [], keywords = [ "anger", "angry", "face", "mad" ] } )
        , ( "rage", { name = "POUTING FACE", native = "😡", sortOrder = 101, skinVariations = Dict.fromList [], keywords = [ "angry", "enraged", "face", "mad", "pouting", "rage", "red" ] } )
        , ( "cry", { name = "CRYING FACE", native = "😢", sortOrder = 90, skinVariations = Dict.fromList [], keywords = [ "cry", "crying face", "face", "sad", "tear" ] } )
        , ( "persevere", { name = "PERSEVERING FACE", native = "😣", sortOrder = 94, skinVariations = Dict.fromList [], keywords = [ "face", "persevere", "persevering face" ] } )
        , ( "triumph", { name = "FACE WITH LOOK OF TRIUMPH", native = "😤", sortOrder = 100, skinVariations = Dict.fromList [], keywords = [ "face", "face with steam from nose", "triumph", "won" ] } )
        , ( "disappointed_relieved", { name = "DISAPPOINTED BUT RELIEVED FACE", native = "😥", sortOrder = 89, skinVariations = Dict.fromList [], keywords = [ "disappointed", "face", "relieved", "sad but relieved face", "whew" ] } )
        , ( "frowning", { name = "FROWNING FACE WITH OPEN MOUTH", native = "😦", sortOrder = 85, skinVariations = Dict.fromList [], keywords = [ "face", "frown", "frowning face with open mouth", "mouth", "open" ] } )
        , ( "anguished", { name = "ANGUISHED FACE", native = "😧", sortOrder = 86, skinVariations = Dict.fromList [], keywords = [ "anguished", "face" ] } )
        , ( "fearful", { name = "FEARFUL FACE", native = "😨", sortOrder = 87, skinVariations = Dict.fromList [], keywords = [ "face", "fear", "fearful", "scared" ] } )
        , ( "weary", { name = "WEARY FACE", native = "😩", sortOrder = 97, skinVariations = Dict.fromList [], keywords = [ "face", "tired", "weary" ] } )
        , ( "sleepy", { name = "SLEEPY FACE", native = "😪", sortOrder = 53, skinVariations = Dict.fromList [], keywords = [ "face", "good night", "sleep", "sleepy face" ] } )
        , ( "tired_face", { name = "TIRED FACE", native = "😫", sortOrder = 98, skinVariations = Dict.fromList [], keywords = [ "face", "tired" ] } )
        , ( "grimacing", { name = "GRIMACING FACE", native = "😬", sortOrder = 47, skinVariations = Dict.fromList [], keywords = [ "face", "grimace", "grimacing face" ] } )
        , ( "sob", { name = "LOUDLY CRYING FACE", native = "😭", sortOrder = 91, skinVariations = Dict.fromList [], keywords = [ "cry", "face", "loudly crying face", "sad", "sob", "tear" ] } )
        , ( "face_exhaling", { name = "FACE EXHALING", native = "😮\u{200D}💨", sortOrder = 48, skinVariations = Dict.fromList [], keywords = [ "exhale", "face exhaling", "gasp", "groan", "relief", "whisper", "whistle" ] } )
        , ( "open_mouth", { name = "FACE WITH OPEN MOUTH", native = "😮", sortOrder = 79, skinVariations = Dict.fromList [], keywords = [ "face", "face with open mouth", "mouth", "open", "sympathy" ] } )
        , ( "hushed", { name = "HUSHED FACE", native = "😯", sortOrder = 80, skinVariations = Dict.fromList [], keywords = [ "face", "hushed", "stunned", "surprised" ] } )
        , ( "cold_sweat", { name = "FACE WITH OPEN MOUTH AND COLD SWEAT", native = "😰", sortOrder = 88, skinVariations = Dict.fromList [], keywords = [ "anxious face with sweat", "blue", "cold", "face", "rushed", "sweat" ] } )
        , ( "scream", { name = "FACE SCREAMING IN FEAR", native = "😱", sortOrder = 92, skinVariations = Dict.fromList [], keywords = [ "face", "face screaming in fear", "fear", "munch", "scared", "scream" ] } )
        , ( "astonished", { name = "ASTONISHED FACE", native = "😲", sortOrder = 81, skinVariations = Dict.fromList [], keywords = [ "astonished", "face", "shocked", "totally" ] } )
        , ( "flushed", { name = "FLUSHED FACE", native = "😳", sortOrder = 82, skinVariations = Dict.fromList [], keywords = [ "dazed", "face", "flushed" ] } )
        , ( "sleeping", { name = "SLEEPING FACE", native = "😴", sortOrder = 55, skinVariations = Dict.fromList [], keywords = [ "face", "good night", "sleep", "sleeping face", "ZZZ" ] } )
        , ( "face_with_spiral_eyes", { name = "FACE WITH SPIRAL EYES", native = "😵\u{200D}💫", sortOrder = 66, skinVariations = Dict.fromList [], keywords = [ "dizzy", "face with spiral eyes", "hypnotized", "spiral", "trouble", "whoa" ] } )
        , ( "dizzy_face", { name = "DIZZY FACE", native = "😵", sortOrder = 65, skinVariations = Dict.fromList [], keywords = [ "crossed-out eyes", "dead", "face", "face with crossed-out eyes", "knocked out" ] } )
        , ( "face_in_clouds", { name = "FACE IN CLOUDS", native = "😶\u{200D}🌫️", sortOrder = 43, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "no_mouth", { name = "FACE WITHOUT MOUTH", native = "😶", sortOrder = 41, skinVariations = Dict.fromList [], keywords = [ "face", "face without mouth", "mouth", "quiet", "silent" ] } )
        , ( "mask", { name = "FACE WITH MEDICAL MASK", native = "😷", sortOrder = 56, skinVariations = Dict.fromList [], keywords = [ "cold", "doctor", "face", "face with medical mask", "mask", "sick" ] } )
        , ( "smile_cat", { name = "GRINNING CAT FACE WITH SMILING EYES", native = "😸", sortOrder = 117, skinVariations = Dict.fromList [], keywords = [ "cat", "eye", "face", "grin", "grinning cat with smiling eyes", "smile" ] } )
        , ( "joy_cat", { name = "CAT FACE WITH TEARS OF JOY", native = "😹", sortOrder = 118, skinVariations = Dict.fromList [], keywords = [ "cat", "cat with tears of joy", "face", "joy", "tear" ] } )
        , ( "smiley_cat", { name = "SMILING CAT FACE WITH OPEN MOUTH", native = "😺", sortOrder = 116, skinVariations = Dict.fromList [], keywords = [ "cat", "face", "grinning", "mouth", "open", "smile" ] } )
        , ( "heart_eyes_cat", { name = "SMILING CAT FACE WITH HEART-SHAPED EYES", native = "😻", sortOrder = 119, skinVariations = Dict.fromList [], keywords = [ "cat", "eye", "face", "heart", "love", "smile", "smiling cat with heart-eyes" ] } )
        , ( "smirk_cat", { name = "CAT FACE WITH WRY SMILE", native = "😼", sortOrder = 120, skinVariations = Dict.fromList [], keywords = [ "cat", "cat with wry smile", "face", "ironic", "smile", "wry" ] } )
        , ( "kissing_cat", { name = "KISSING CAT FACE WITH CLOSED EYES", native = "😽", sortOrder = 121, skinVariations = Dict.fromList [], keywords = [ "cat", "eye", "face", "kiss", "kissing cat" ] } )
        , ( "pouting_cat", { name = "POUTING CAT FACE", native = "😾", sortOrder = 124, skinVariations = Dict.fromList [], keywords = [ "cat", "face", "pouting" ] } )
        , ( "crying_cat_face", { name = "CRYING CAT FACE", native = "😿", sortOrder = 123, skinVariations = Dict.fromList [], keywords = [ "cat", "cry", "crying cat", "face", "sad", "tear" ] } )
        , ( "scream_cat", { name = "WEARY CAT FACE", native = "🙀", sortOrder = 122, skinVariations = Dict.fromList [], keywords = [ "cat", "face", "oh", "surprised", "weary" ] } )
        , ( "slightly_frowning_face", { name = "SLIGHTLY FROWNING FACE", native = "🙁", sortOrder = 77, skinVariations = Dict.fromList [], keywords = [ "face", "frown", "slightly frowning face" ] } )
        , ( "slightly_smiling_face", { name = "SLIGHTLY SMILING FACE", native = "🙂", sortOrder = 9, skinVariations = Dict.fromList [], keywords = [ "face", "slightly smiling face", "smile" ] } )
        , ( "upside_down_face", { name = "UPSIDE-DOWN FACE", native = "🙃", sortOrder = 10, skinVariations = Dict.fromList [], keywords = [ "face", "upside-down" ] } )
        , ( "face_with_rolling_eyes", { name = "FACE WITH ROLLING EYES", native = "🙄", sortOrder = 46, skinVariations = Dict.fromList [], keywords = [ "eyeroll", "eyes", "face", "face with rolling eyes", "rolling" ] } )
        , ( "woman-gesturing-no", { name = "WOMAN GESTURING NO", native = "🙅\u{200D}♀️", sortOrder = 264, skinVariations = Dict.fromList [ ( "1F3FB", "🙅🏻\u{200D}♀️" ), ( "1F3FC", "🙅🏼\u{200D}♀️" ), ( "1F3FD", "🙅🏽\u{200D}♀️" ), ( "1F3FE", "🙅🏾\u{200D}♀️" ), ( "1F3FF", "🙅🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-gesturing-no", { name = "MAN GESTURING NO", native = "🙅\u{200D}♂️", sortOrder = 263, skinVariations = Dict.fromList [ ( "1F3FB", "🙅🏻\u{200D}♂️" ), ( "1F3FC", "🙅🏼\u{200D}♂️" ), ( "1F3FD", "🙅🏽\u{200D}♂️" ), ( "1F3FE", "🙅🏾\u{200D}♂️" ), ( "1F3FF", "🙅🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "no_good", { name = "FACE WITH NO GOOD GESTURE", native = "🙅", sortOrder = 262, skinVariations = Dict.fromList [ ( "1F3FB", "🙅🏻" ), ( "1F3FC", "🙅🏼" ), ( "1F3FD", "🙅🏽" ), ( "1F3FE", "🙅🏾" ), ( "1F3FF", "🙅🏿" ) ], keywords = [ "forbidden", "gesture", "hand", "person gesturing NO", "prohibited" ] } )
        , ( "woman-gesturing-ok", { name = "WOMAN GESTURING OK", native = "🙆\u{200D}♀️", sortOrder = 267, skinVariations = Dict.fromList [ ( "1F3FB", "🙆🏻\u{200D}♀️" ), ( "1F3FC", "🙆🏼\u{200D}♀️" ), ( "1F3FD", "🙆🏽\u{200D}♀️" ), ( "1F3FE", "🙆🏾\u{200D}♀️" ), ( "1F3FF", "🙆🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-gesturing-ok", { name = "MAN GESTURING OK", native = "🙆\u{200D}♂️", sortOrder = 266, skinVariations = Dict.fromList [ ( "1F3FB", "🙆🏻\u{200D}♂️" ), ( "1F3FC", "🙆🏼\u{200D}♂️" ), ( "1F3FD", "🙆🏽\u{200D}♂️" ), ( "1F3FE", "🙆🏾\u{200D}♂️" ), ( "1F3FF", "🙆🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "ok_woman", { name = "FACE WITH OK GESTURE", native = "🙆", sortOrder = 265, skinVariations = Dict.fromList [ ( "1F3FB", "🙆🏻" ), ( "1F3FC", "🙆🏼" ), ( "1F3FD", "🙆🏽" ), ( "1F3FE", "🙆🏾" ), ( "1F3FF", "🙆🏿" ) ], keywords = [ "gesture", "hand", "OK", "person gesturing OK" ] } )
        , ( "woman-bowing", { name = "WOMAN BOWING", native = "🙇\u{200D}♀️", sortOrder = 279, skinVariations = Dict.fromList [ ( "1F3FB", "🙇🏻\u{200D}♀️" ), ( "1F3FC", "🙇🏼\u{200D}♀️" ), ( "1F3FD", "🙇🏽\u{200D}♀️" ), ( "1F3FE", "🙇🏾\u{200D}♀️" ), ( "1F3FF", "🙇🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-bowing", { name = "MAN BOWING", native = "🙇\u{200D}♂️", sortOrder = 278, skinVariations = Dict.fromList [ ( "1F3FB", "🙇🏻\u{200D}♂️" ), ( "1F3FC", "🙇🏼\u{200D}♂️" ), ( "1F3FD", "🙇🏽\u{200D}♂️" ), ( "1F3FE", "🙇🏾\u{200D}♂️" ), ( "1F3FF", "🙇🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "bow", { name = "PERSON BOWING DEEPLY", native = "🙇", sortOrder = 277, skinVariations = Dict.fromList [ ( "1F3FB", "🙇🏻" ), ( "1F3FC", "🙇🏼" ), ( "1F3FD", "🙇🏽" ), ( "1F3FE", "🙇🏾" ), ( "1F3FF", "🙇🏿" ) ], keywords = [ "apology", "bow", "gesture", "person bowing", "sorry" ] } )
        , ( "see_no_evil", { name = "SEE-NO-EVIL MONKEY", native = "🙈", sortOrder = 125, skinVariations = Dict.fromList [], keywords = [ "evil", "face", "forbidden", "monkey", "see", "see-no-evil monkey" ] } )
        , ( "hear_no_evil", { name = "HEAR-NO-EVIL MONKEY", native = "🙉", sortOrder = 126, skinVariations = Dict.fromList [], keywords = [ "evil", "face", "forbidden", "hear", "hear-no-evil monkey", "monkey" ] } )
        , ( "speak_no_evil", { name = "SPEAK-NO-EVIL MONKEY", native = "🙊", sortOrder = 127, skinVariations = Dict.fromList [], keywords = [ "evil", "face", "forbidden", "monkey", "speak", "speak-no-evil monkey" ] } )
        , ( "woman-raising-hand", { name = "WOMAN RAISING HAND", native = "🙋\u{200D}♀️", sortOrder = 273, skinVariations = Dict.fromList [ ( "1F3FB", "🙋🏻\u{200D}♀️" ), ( "1F3FC", "🙋🏼\u{200D}♀️" ), ( "1F3FD", "🙋🏽\u{200D}♀️" ), ( "1F3FE", "🙋🏾\u{200D}♀️" ), ( "1F3FF", "🙋🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-raising-hand", { name = "MAN RAISING HAND", native = "🙋\u{200D}♂️", sortOrder = 272, skinVariations = Dict.fromList [ ( "1F3FB", "🙋🏻\u{200D}♂️" ), ( "1F3FC", "🙋🏼\u{200D}♂️" ), ( "1F3FD", "🙋🏽\u{200D}♂️" ), ( "1F3FE", "🙋🏾\u{200D}♂️" ), ( "1F3FF", "🙋🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "raising_hand", { name = "HAPPY PERSON RAISING ONE HAND", native = "🙋", sortOrder = 271, skinVariations = Dict.fromList [ ( "1F3FB", "🙋🏻" ), ( "1F3FC", "🙋🏼" ), ( "1F3FD", "🙋🏽" ), ( "1F3FE", "🙋🏾" ), ( "1F3FF", "🙋🏿" ) ], keywords = [ "gesture", "hand", "happy", "person raising hand", "raised" ] } )
        , ( "raised_hands", { name = "PERSON RAISING BOTH HANDS IN CELEBRATION", native = "🙌", sortOrder = 201, skinVariations = Dict.fromList [ ( "1F3FB", "🙌🏻" ), ( "1F3FC", "🙌🏼" ), ( "1F3FD", "🙌🏽" ), ( "1F3FE", "🙌🏾" ), ( "1F3FF", "🙌🏿" ) ], keywords = [ "celebration", "gesture", "hand", "hooray", "raised", "raising hands" ] } )
        , ( "woman-frowning", { name = "WOMAN FROWNING", native = "🙍\u{200D}♀️", sortOrder = 258, skinVariations = Dict.fromList [ ( "1F3FB", "🙍🏻\u{200D}♀️" ), ( "1F3FC", "🙍🏼\u{200D}♀️" ), ( "1F3FD", "🙍🏽\u{200D}♀️" ), ( "1F3FE", "🙍🏾\u{200D}♀️" ), ( "1F3FF", "🙍🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-frowning", { name = "MAN FROWNING", native = "🙍\u{200D}♂️", sortOrder = 257, skinVariations = Dict.fromList [ ( "1F3FB", "🙍🏻\u{200D}♂️" ), ( "1F3FC", "🙍🏼\u{200D}♂️" ), ( "1F3FD", "🙍🏽\u{200D}♂️" ), ( "1F3FE", "🙍🏾\u{200D}♂️" ), ( "1F3FF", "🙍🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_frowning", { name = "PERSON FROWNING", native = "🙍", sortOrder = 256, skinVariations = Dict.fromList [ ( "1F3FB", "🙍🏻" ), ( "1F3FC", "🙍🏼" ), ( "1F3FD", "🙍🏽" ), ( "1F3FE", "🙍🏾" ), ( "1F3FF", "🙍🏿" ) ], keywords = [ "frown", "gesture", "person frowning" ] } )
        , ( "woman-pouting", { name = "WOMAN POUTING", native = "🙎\u{200D}♀️", sortOrder = 261, skinVariations = Dict.fromList [ ( "1F3FB", "🙎🏻\u{200D}♀️" ), ( "1F3FC", "🙎🏼\u{200D}♀️" ), ( "1F3FD", "🙎🏽\u{200D}♀️" ), ( "1F3FE", "🙎🏾\u{200D}♀️" ), ( "1F3FF", "🙎🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-pouting", { name = "MAN POUTING", native = "🙎\u{200D}♂️", sortOrder = 260, skinVariations = Dict.fromList [ ( "1F3FB", "🙎🏻\u{200D}♂️" ), ( "1F3FC", "🙎🏼\u{200D}♂️" ), ( "1F3FD", "🙎🏽\u{200D}♂️" ), ( "1F3FE", "🙎🏾\u{200D}♂️" ), ( "1F3FF", "🙎🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_with_pouting_face", { name = "PERSON WITH POUTING FACE", native = "🙎", sortOrder = 259, skinVariations = Dict.fromList [ ( "1F3FB", "🙎🏻" ), ( "1F3FC", "🙎🏼" ), ( "1F3FD", "🙎🏽" ), ( "1F3FE", "🙎🏾" ), ( "1F3FF", "🙎🏿" ) ], keywords = [ "gesture", "person pouting", "pouting" ] } )
        , ( "pray", { name = "PERSON WITH FOLDED HANDS", native = "🙏", sortOrder = 206, skinVariations = Dict.fromList [ ( "1F3FB", "🙏🏻" ), ( "1F3FC", "🙏🏼" ), ( "1F3FD", "🙏🏽" ), ( "1F3FE", "🙏🏾" ), ( "1F3FF", "🙏🏿" ) ], keywords = [ "ask", "folded hands", "hand", "high 5", "high five", "please", "pray", "thanks" ] } )
        , ( "rocket", { name = "ROCKET", native = "🚀", sortOrder = 956, skinVariations = Dict.fromList [], keywords = [ "rocket", "space" ] } )
        , ( "helicopter", { name = "HELICOPTER", native = "🚁", sortOrder = 951, skinVariations = Dict.fromList [], keywords = [ "helicopter", "vehicle" ] } )
        , ( "steam_locomotive", { name = "STEAM LOCOMOTIVE", native = "🚂", sortOrder = 886, skinVariations = Dict.fromList [], keywords = [ "engine", "locomotive", "railway", "steam", "train" ] } )
        , ( "railway_car", { name = "RAILWAY CAR", native = "🚃", sortOrder = 887, skinVariations = Dict.fromList [], keywords = [ "car", "electric", "railway", "train", "tram", "trolleybus" ] } )
        , ( "bullettrain_side", { name = "HIGH-SPEED TRAIN", native = "🚄", sortOrder = 888, skinVariations = Dict.fromList [], keywords = [ "high-speed train", "railway", "shinkansen", "speed", "train" ] } )
        , ( "bullettrain_front", { name = "HIGH-SPEED TRAIN WITH BULLET NOSE", native = "🚅", sortOrder = 889, skinVariations = Dict.fromList [], keywords = [ "bullet", "railway", "shinkansen", "speed", "train" ] } )
        , ( "train2", { name = "TRAIN", native = "🚆", sortOrder = 890, skinVariations = Dict.fromList [], keywords = [ "railway", "train" ] } )
        , ( "metro", { name = "METRO", native = "🚇", sortOrder = 891, skinVariations = Dict.fromList [], keywords = [ "metro", "subway" ] } )
        , ( "light_rail", { name = "LIGHT RAIL", native = "🚈", sortOrder = 892, skinVariations = Dict.fromList [], keywords = [ "light rail", "railway" ] } )
        , ( "station", { name = "STATION", native = "🚉", sortOrder = 893, skinVariations = Dict.fromList [], keywords = [ "railway", "station", "train" ] } )
        , ( "tram", { name = "TRAM", native = "🚊", sortOrder = 894, skinVariations = Dict.fromList [], keywords = [ "tram", "trolleybus" ] } )
        , ( "train", { name = "TRAM CAR", native = "🚋", sortOrder = 897, skinVariations = Dict.fromList [], keywords = [ "car", "tram", "trolleybus" ] } )
        , ( "bus", { name = "BUS", native = "🚌", sortOrder = 898, skinVariations = Dict.fromList [], keywords = [ "bus", "vehicle" ] } )
        , ( "oncoming_bus", { name = "ONCOMING BUS", native = "🚍", sortOrder = 899, skinVariations = Dict.fromList [], keywords = [ "bus", "oncoming" ] } )
        , ( "trolleybus", { name = "TROLLEYBUS", native = "🚎", sortOrder = 900, skinVariations = Dict.fromList [], keywords = [ "bus", "tram", "trolley", "trolleybus" ] } )
        , ( "busstop", { name = "BUS STOP", native = "🚏", sortOrder = 925, skinVariations = Dict.fromList [], keywords = [ "bus", "stop" ] } )
        , ( "minibus", { name = "MINIBUS", native = "🚐", sortOrder = 901, skinVariations = Dict.fromList [], keywords = [ "bus", "minibus" ] } )
        , ( "ambulance", { name = "AMBULANCE", native = "🚑", sortOrder = 902, skinVariations = Dict.fromList [], keywords = [ "ambulance", "vehicle" ] } )
        , ( "fire_engine", { name = "FIRE ENGINE", native = "🚒", sortOrder = 903, skinVariations = Dict.fromList [], keywords = [ "engine", "fire", "truck" ] } )
        , ( "police_car", { name = "POLICE CAR", native = "🚓", sortOrder = 904, skinVariations = Dict.fromList [], keywords = [ "car", "patrol", "police" ] } )
        , ( "oncoming_police_car", { name = "ONCOMING POLICE CAR", native = "🚔", sortOrder = 905, skinVariations = Dict.fromList [], keywords = [ "car", "oncoming", "police" ] } )
        , ( "taxi", { name = "TAXI", native = "🚕", sortOrder = 906, skinVariations = Dict.fromList [], keywords = [ "taxi", "vehicle" ] } )
        , ( "oncoming_taxi", { name = "ONCOMING TAXI", native = "🚖", sortOrder = 907, skinVariations = Dict.fromList [], keywords = [ "oncoming", "taxi" ] } )
        , ( "car", { name = "AUTOMOBILE", native = "🚗", sortOrder = 908, skinVariations = Dict.fromList [], keywords = [ "automobile", "car" ] } )
        , ( "oncoming_automobile", { name = "ONCOMING AUTOMOBILE", native = "🚘", sortOrder = 909, skinVariations = Dict.fromList [], keywords = [ "automobile", "car", "oncoming" ] } )
        , ( "blue_car", { name = "RECREATIONAL VEHICLE", native = "🚙", sortOrder = 910, skinVariations = Dict.fromList [], keywords = [ "recreational", "sport utility", "sport utility vehicle" ] } )
        , ( "truck", { name = "DELIVERY TRUCK", native = "🚚", sortOrder = 912, skinVariations = Dict.fromList [], keywords = [ "delivery", "truck" ] } )
        , ( "articulated_lorry", { name = "ARTICULATED LORRY", native = "🚛", sortOrder = 913, skinVariations = Dict.fromList [], keywords = [ "articulated lorry", "lorry", "semi", "truck" ] } )
        , ( "tractor", { name = "TRACTOR", native = "🚜", sortOrder = 914, skinVariations = Dict.fromList [], keywords = [ "tractor", "vehicle" ] } )
        , ( "monorail", { name = "MONORAIL", native = "🚝", sortOrder = 895, skinVariations = Dict.fromList [], keywords = [ "monorail", "vehicle" ] } )
        , ( "mountain_railway", { name = "MOUNTAIN RAILWAY", native = "🚞", sortOrder = 896, skinVariations = Dict.fromList [], keywords = [ "car", "mountain", "railway" ] } )
        , ( "suspension_railway", { name = "SUSPENSION RAILWAY", native = "🚟", sortOrder = 952, skinVariations = Dict.fromList [], keywords = [ "railway", "suspension" ] } )
        , ( "mountain_cableway", { name = "MOUNTAIN CABLEWAY", native = "🚠", sortOrder = 953, skinVariations = Dict.fromList [], keywords = [ "cable", "gondola", "mountain", "mountain cableway" ] } )
        , ( "aerial_tramway", { name = "AERIAL TRAMWAY", native = "🚡", sortOrder = 954, skinVariations = Dict.fromList [], keywords = [ "aerial", "cable", "car", "gondola", "tramway" ] } )
        , ( "ship", { name = "SHIP", native = "🚢", sortOrder = 944, skinVariations = Dict.fromList [], keywords = [ "boat", "passenger", "ship" ] } )
        , ( "woman-rowing-boat", { name = "WOMAN ROWING BOAT", native = "🚣\u{200D}♀️", sortOrder = 451, skinVariations = Dict.fromList [ ( "1F3FB", "🚣🏻\u{200D}♀️" ), ( "1F3FC", "🚣🏼\u{200D}♀️" ), ( "1F3FD", "🚣🏽\u{200D}♀️" ), ( "1F3FE", "🚣🏾\u{200D}♀️" ), ( "1F3FF", "🚣🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-rowing-boat", { name = "MAN ROWING BOAT", native = "🚣\u{200D}♂️", sortOrder = 450, skinVariations = Dict.fromList [ ( "1F3FB", "🚣🏻\u{200D}♂️" ), ( "1F3FC", "🚣🏼\u{200D}♂️" ), ( "1F3FD", "🚣🏽\u{200D}♂️" ), ( "1F3FE", "🚣🏾\u{200D}♂️" ), ( "1F3FF", "🚣🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "rowboat", { name = "ROWBOAT", native = "🚣", sortOrder = 449, skinVariations = Dict.fromList [ ( "1F3FB", "🚣🏻" ), ( "1F3FC", "🚣🏼" ), ( "1F3FD", "🚣🏽" ), ( "1F3FE", "🚣🏾" ), ( "1F3FF", "🚣🏿" ) ], keywords = [ "boat", "person rowing boat", "rowboat" ] } )
        , ( "speedboat", { name = "SPEEDBOAT", native = "🚤", sortOrder = 940, skinVariations = Dict.fromList [], keywords = [ "boat", "speedboat" ] } )
        , ( "traffic_light", { name = "HORIZONTAL TRAFFIC LIGHT", native = "🚥", sortOrder = 932, skinVariations = Dict.fromList [], keywords = [ "horizontal traffic light", "light", "signal", "traffic" ] } )
        , ( "vertical_traffic_light", { name = "VERTICAL TRAFFIC LIGHT", native = "🚦", sortOrder = 933, skinVariations = Dict.fromList [], keywords = [ "light", "signal", "traffic", "vertical traffic light" ] } )
        , ( "construction", { name = "CONSTRUCTION SIGN", native = "🚧", sortOrder = 935, skinVariations = Dict.fromList [], keywords = [ "barrier", "construction" ] } )
        , ( "rotating_light", { name = "POLICE CARS REVOLVING LIGHT", native = "🚨", sortOrder = 931, skinVariations = Dict.fromList [], keywords = [ "beacon", "car", "light", "police", "revolving" ] } )
        , ( "triangular_flag_on_post", { name = "TRIANGULAR FLAG ON POST", native = "🚩", sortOrder = 1608, skinVariations = Dict.fromList [], keywords = [ "post", "triangular flag" ] } )
        , ( "door", { name = "DOOR", native = "🚪", sortOrder = 1350, skinVariations = Dict.fromList [], keywords = [ "door" ] } )
        , ( "no_entry_sign", { name = "NO ENTRY SIGN", native = "🚫", sortOrder = 1400, skinVariations = Dict.fromList [], keywords = [ "entry", "forbidden", "no", "not", "prohibited" ] } )
        , ( "smoking", { name = "SMOKING SYMBOL", native = "🚬", sortOrder = 1375, skinVariations = Dict.fromList [], keywords = [ "cigarette", "smoking" ] } )
        , ( "no_smoking", { name = "NO SMOKING SYMBOL", native = "🚭", sortOrder = 1402, skinVariations = Dict.fromList [], keywords = [ "forbidden", "no", "not", "prohibited", "smoking" ] } )
        , ( "put_litter_in_its_place", { name = "PUT LITTER IN ITS PLACE SYMBOL", native = "🚮", sortOrder = 1385, skinVariations = Dict.fromList [], keywords = [ "litter", "litter bin", "litter in bin sign" ] } )
        , ( "do_not_litter", { name = "DO NOT LITTER SYMBOL", native = "🚯", sortOrder = 1403, skinVariations = Dict.fromList [], keywords = [ "forbidden", "litter", "no", "no littering", "not", "prohibited" ] } )
        , ( "potable_water", { name = "POTABLE WATER SYMBOL", native = "🚰", sortOrder = 1386, skinVariations = Dict.fromList [], keywords = [ "drinking", "potable", "water" ] } )
        , ( "non-potable_water", { name = "NON-POTABLE WATER SYMBOL", native = "🚱", sortOrder = 1404, skinVariations = Dict.fromList [], keywords = [ "non-drinking", "non-potable", "water" ] } )
        , ( "bike", { name = "BICYCLE", native = "🚲", sortOrder = 921, skinVariations = Dict.fromList [], keywords = [ "bicycle", "bike" ] } )
        , ( "no_bicycles", { name = "NO BICYCLES", native = "🚳", sortOrder = 1401, skinVariations = Dict.fromList [], keywords = [ "bicycle", "bike", "forbidden", "no", "no bicycles", "prohibited" ] } )
        , ( "woman-biking", { name = "WOMAN BIKING", native = "🚴\u{200D}♀️", sortOrder = 463, skinVariations = Dict.fromList [ ( "1F3FB", "🚴🏻\u{200D}♀️" ), ( "1F3FC", "🚴🏼\u{200D}♀️" ), ( "1F3FD", "🚴🏽\u{200D}♀️" ), ( "1F3FE", "🚴🏾\u{200D}♀️" ), ( "1F3FF", "🚴🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-biking", { name = "MAN BIKING", native = "🚴\u{200D}♂️", sortOrder = 462, skinVariations = Dict.fromList [ ( "1F3FB", "🚴🏻\u{200D}♂️" ), ( "1F3FC", "🚴🏼\u{200D}♂️" ), ( "1F3FD", "🚴🏽\u{200D}♂️" ), ( "1F3FE", "🚴🏾\u{200D}♂️" ), ( "1F3FF", "🚴🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "bicyclist", { name = "BICYCLIST", native = "🚴", sortOrder = 461, skinVariations = Dict.fromList [ ( "1F3FB", "🚴🏻" ), ( "1F3FC", "🚴🏼" ), ( "1F3FD", "🚴🏽" ), ( "1F3FE", "🚴🏾" ), ( "1F3FF", "🚴🏿" ) ], keywords = [ "bicycle", "biking", "cyclist", "person biking" ] } )
        , ( "woman-mountain-biking", { name = "WOMAN MOUNTAIN BIKING", native = "🚵\u{200D}♀️", sortOrder = 466, skinVariations = Dict.fromList [ ( "1F3FB", "🚵🏻\u{200D}♀️" ), ( "1F3FC", "🚵🏼\u{200D}♀️" ), ( "1F3FD", "🚵🏽\u{200D}♀️" ), ( "1F3FE", "🚵🏾\u{200D}♀️" ), ( "1F3FF", "🚵🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-mountain-biking", { name = "MAN MOUNTAIN BIKING", native = "🚵\u{200D}♂️", sortOrder = 465, skinVariations = Dict.fromList [ ( "1F3FB", "🚵🏻\u{200D}♂️" ), ( "1F3FC", "🚵🏼\u{200D}♂️" ), ( "1F3FD", "🚵🏽\u{200D}♂️" ), ( "1F3FE", "🚵🏾\u{200D}♂️" ), ( "1F3FF", "🚵🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "mountain_bicyclist", { name = "MOUNTAIN BICYCLIST", native = "🚵", sortOrder = 464, skinVariations = Dict.fromList [ ( "1F3FB", "🚵🏻" ), ( "1F3FC", "🚵🏼" ), ( "1F3FD", "🚵🏽" ), ( "1F3FE", "🚵🏾" ), ( "1F3FF", "🚵🏿" ) ], keywords = [ "bicycle", "bicyclist", "bike", "cyclist", "mountain", "person mountain biking" ] } )
        , ( "woman-walking", { name = "WOMAN WALKING", native = "🚶\u{200D}♀️", sortOrder = 408, skinVariations = Dict.fromList [ ( "1F3FB", "🚶🏻\u{200D}♀️" ), ( "1F3FC", "🚶🏼\u{200D}♀️" ), ( "1F3FD", "🚶🏽\u{200D}♀️" ), ( "1F3FE", "🚶🏾\u{200D}♀️" ), ( "1F3FF", "🚶🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-walking", { name = "MAN WALKING", native = "🚶\u{200D}♂️", sortOrder = 407, skinVariations = Dict.fromList [ ( "1F3FB", "🚶🏻\u{200D}♂️" ), ( "1F3FC", "🚶🏼\u{200D}♂️" ), ( "1F3FD", "🚶🏽\u{200D}♂️" ), ( "1F3FE", "🚶🏾\u{200D}♂️" ), ( "1F3FF", "🚶🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "walking", { name = "PEDESTRIAN", native = "🚶", sortOrder = 406, skinVariations = Dict.fromList [ ( "1F3FB", "🚶🏻" ), ( "1F3FC", "🚶🏼" ), ( "1F3FD", "🚶🏽" ), ( "1F3FE", "🚶🏾" ), ( "1F3FF", "🚶🏿" ) ], keywords = [ "hike", "person walking", "walk", "walking" ] } )
        , ( "no_pedestrians", { name = "NO PEDESTRIANS", native = "🚷", sortOrder = 1405, skinVariations = Dict.fromList [], keywords = [ "forbidden", "no", "no pedestrians", "not", "pedestrian", "prohibited" ] } )
        , ( "children_crossing", { name = "CHILDREN CROSSING", native = "🚸", sortOrder = 1398, skinVariations = Dict.fromList [], keywords = [ "child", "children crossing", "crossing", "pedestrian", "traffic" ] } )
        , ( "mens", { name = "MENS SYMBOL", native = "🚹", sortOrder = 1388, skinVariations = Dict.fromList [], keywords = [ "bathroom", "lavatory", "man", "men’s room", "restroom", "toilet", "WC" ] } )
        , ( "womens", { name = "WOMENS SYMBOL", native = "🚺", sortOrder = 1389, skinVariations = Dict.fromList [], keywords = [ "bathroom", "lavatory", "restroom", "toilet", "WC", "woman", "women’s room" ] } )
        , ( "restroom", { name = "RESTROOM", native = "🚻", sortOrder = 1390, skinVariations = Dict.fromList [], keywords = [ "bathroom", "lavatory", "restroom", "toilet", "WC" ] } )
        , ( "baby_symbol", { name = "BABY SYMBOL", native = "🚼", sortOrder = 1391, skinVariations = Dict.fromList [], keywords = [ "baby", "baby symbol", "changing" ] } )
        , ( "toilet", { name = "TOILET", native = "🚽", sortOrder = 1357, skinVariations = Dict.fromList [], keywords = [ "toilet" ] } )
        , ( "wc", { name = "WATER CLOSET", native = "🚾", sortOrder = 1392, skinVariations = Dict.fromList [], keywords = [ "bathroom", "closet", "lavatory", "restroom", "toilet", "water", "WC" ] } )
        , ( "shower", { name = "SHOWER", native = "🚿", sortOrder = 1359, skinVariations = Dict.fromList [], keywords = [ "shower", "water" ] } )
        , ( "bath", { name = "BATH", native = "🛀", sortOrder = 485, skinVariations = Dict.fromList [ ( "1F3FB", "🛀🏻" ), ( "1F3FC", "🛀🏼" ), ( "1F3FD", "🛀🏽" ), ( "1F3FE", "🛀🏾" ), ( "1F3FF", "🛀🏿" ) ], keywords = [ "bath", "bathtub", "person taking bath" ] } )
        , ( "bathtub", { name = "BATHTUB", native = "🛁", sortOrder = 1360, skinVariations = Dict.fromList [], keywords = [ "bath", "bathtub" ] } )
        , ( "passport_control", { name = "PASSPORT CONTROL", native = "🛂", sortOrder = 1393, skinVariations = Dict.fromList [], keywords = [ "control", "passport" ] } )
        , ( "customs", { name = "CUSTOMS", native = "🛃", sortOrder = 1394, skinVariations = Dict.fromList [], keywords = [ "customs" ] } )
        , ( "baggage_claim", { name = "BAGGAGE CLAIM", native = "🛄", sortOrder = 1395, skinVariations = Dict.fromList [], keywords = [ "baggage", "claim" ] } )
        , ( "left_luggage", { name = "LEFT LUGGAGE", native = "🛅", sortOrder = 1396, skinVariations = Dict.fromList [], keywords = [ "baggage", "left luggage", "locker", "luggage" ] } )
        , ( "couch_and_lamp", { name = "COUCH AND LAMP", native = "🛋️", sortOrder = 1355, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "sleeping_accommodation", { name = "SLEEPING ACCOMMODATION", native = "🛌", sortOrder = 486, skinVariations = Dict.fromList [ ( "1F3FB", "🛌🏻" ), ( "1F3FC", "🛌🏼" ), ( "1F3FD", "🛌🏽" ), ( "1F3FE", "🛌🏾" ), ( "1F3FF", "🛌🏿" ) ], keywords = [ "good night", "hotel", "person in bed", "sleep" ] } )
        , ( "shopping_bags", { name = "SHOPPING BAGS", native = "🛍️", sortOrder = 1147, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "bellhop_bell", { name = "BELLHOP BELL", native = "🛎️", sortOrder = 958, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "bed", { name = "BED", native = "🛏️", sortOrder = 1354, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "place_of_worship", { name = "PLACE OF WORSHIP", native = "🛐", sortOrder = 1431, skinVariations = Dict.fromList [], keywords = [ "place of worship", "religion", "worship" ] } )
        , ( "octagonal_sign", { name = "OCTAGONAL SIGN", native = "🛑", sortOrder = 934, skinVariations = Dict.fromList [], keywords = [ "octagonal", "sign", "stop" ] } )
        , ( "shopping_trolley", { name = "SHOPPING TROLLEY", native = "🛒", sortOrder = 1374, skinVariations = Dict.fromList [], keywords = [ "cart", "shopping", "trolley" ] } )
        , ( "hindu_temple", { name = "HINDU TEMPLE", native = "🛕", sortOrder = 865, skinVariations = Dict.fromList [], keywords = [ "hindu", "temple" ] } )
        , ( "hut", { name = "HUT", native = "🛖", sortOrder = 842, skinVariations = Dict.fromList [], keywords = [ "house", "hut", "roundhouse", "yurt" ] } )
        , ( "elevator", { name = "ELEVATOR", native = "🛗", sortOrder = 1351, skinVariations = Dict.fromList [], keywords = [ "accessibility", "elevator", "hoist", "lift" ] } )
        , ( "wireless", { name = "WIRELESS", native = "\u{1F6DC}", sortOrder = 1479, skinVariations = Dict.fromList [], keywords = [ "computer", "internet", "network", "wi-fi", "wifi", "wireless" ] } )
        , ( "playground_slide", { name = "PLAYGROUND SLIDE", native = "🛝", sortOrder = 881, skinVariations = Dict.fromList [], keywords = [ "amusement park", "play", "playground slide", "theme park" ] } )
        , ( "wheel", { name = "WHEEL", native = "🛞", sortOrder = 930, skinVariations = Dict.fromList [], keywords = [ "circle", "tire", "turn", "wheel" ] } )
        , ( "ring_buoy", { name = "RING BUOY", native = "🛟", sortOrder = 937, skinVariations = Dict.fromList [], keywords = [ "float", "life preserver", "life saver", "rescue", "ring buoy", "safety" ] } )
        , ( "hammer_and_wrench", { name = "HAMMER AND WRENCH", native = "🛠️", sortOrder = 1315, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "shield", { name = "SHIELD", native = "🛡️", sortOrder = 1321, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "oil_drum", { name = "OIL DRUM", native = "🛢️", sortOrder = 928, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "motorway", { name = "MOTORWAY", native = "🛣️", sortOrder = 926, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "railway_track", { name = "RAILWAY TRACK", native = "🛤️", sortOrder = 927, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "motor_boat", { name = "MOTOR BOAT", native = "🛥️", sortOrder = 943, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "small_airplane", { name = "SMALL AIRPLANE", native = "🛩️", sortOrder = 946, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "airplane_departure", { name = "AIRPLANE DEPARTURE", native = "🛫", sortOrder = 947, skinVariations = Dict.fromList [], keywords = [ "aeroplane", "airplane", "check-in", "departure", "departures" ] } )
        , ( "airplane_arriving", { name = "AIRPLANE ARRIVING", native = "🛬", sortOrder = 948, skinVariations = Dict.fromList [], keywords = [ "aeroplane", "airplane", "airplane arrival", "arrivals", "arriving", "landing" ] } )
        , ( "satellite", { name = "SATELLITE", native = "🛰️", sortOrder = 955, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "passenger_ship", { name = "PASSENGER SHIP", native = "🛳️", sortOrder = 941, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "scooter", { name = "SCOOTER", native = "🛴", sortOrder = 922, skinVariations = Dict.fromList [], keywords = [ "kick", "scooter" ] } )
        , ( "motor_scooter", { name = "MOTOR SCOOTER", native = "🛵", sortOrder = 917, skinVariations = Dict.fromList [], keywords = [ "motor", "scooter" ] } )
        , ( "canoe", { name = "CANOE", native = "🛶", sortOrder = 939, skinVariations = Dict.fromList [], keywords = [ "boat", "canoe" ] } )
        , ( "sled", { name = "SLED", native = "🛷", sortOrder = 1090, skinVariations = Dict.fromList [], keywords = [ "sled", "sledge", "sleigh" ] } )
        , ( "flying_saucer", { name = "FLYING SAUCER", native = "🛸", sortOrder = 957, skinVariations = Dict.fromList [], keywords = [ "flying saucer", "UFO" ] } )
        , ( "skateboard", { name = "SKATEBOARD", native = "🛹", sortOrder = 923, skinVariations = Dict.fromList [], keywords = [ "board", "skateboard" ] } )
        , ( "auto_rickshaw", { name = "AUTO RICKSHAW", native = "🛺", sortOrder = 920, skinVariations = Dict.fromList [], keywords = [ "auto rickshaw", "tuk tuk" ] } )
        , ( "pickup_truck", { name = "PICKUP TRUCK", native = "🛻", sortOrder = 911, skinVariations = Dict.fromList [], keywords = [ "pick-up", "pickup", "truck" ] } )
        , ( "roller_skate", { name = "ROLLER SKATE", native = "🛼", sortOrder = 924, skinVariations = Dict.fromList [], keywords = [ "roller", "skate" ] } )
        , ( "large_orange_circle", { name = "LARGE ORANGE CIRCLE", native = "🟠", sortOrder = 1574, skinVariations = Dict.fromList [], keywords = [ "circle", "orange" ] } )
        , ( "large_yellow_circle", { name = "LARGE YELLOW CIRCLE", native = "🟡", sortOrder = 1575, skinVariations = Dict.fromList [], keywords = [ "circle", "yellow" ] } )
        , ( "large_green_circle", { name = "LARGE GREEN CIRCLE", native = "🟢", sortOrder = 1576, skinVariations = Dict.fromList [], keywords = [ "circle", "green" ] } )
        , ( "large_purple_circle", { name = "LARGE PURPLE CIRCLE", native = "🟣", sortOrder = 1578, skinVariations = Dict.fromList [], keywords = [ "circle", "purple" ] } )
        , ( "large_brown_circle", { name = "LARGE BROWN CIRCLE", native = "🟤", sortOrder = 1579, skinVariations = Dict.fromList [], keywords = [ "brown", "circle" ] } )
        , ( "large_red_square", { name = "LARGE RED SQUARE", native = "🟥", sortOrder = 1582, skinVariations = Dict.fromList [], keywords = [ "red", "square" ] } )
        , ( "large_blue_square", { name = "LARGE BLUE SQUARE", native = "🟦", sortOrder = 1586, skinVariations = Dict.fromList [], keywords = [ "blue", "square" ] } )
        , ( "large_orange_square", { name = "LARGE ORANGE SQUARE", native = "🟧", sortOrder = 1583, skinVariations = Dict.fromList [], keywords = [ "orange", "square" ] } )
        , ( "large_yellow_square", { name = "LARGE YELLOW SQUARE", native = "🟨", sortOrder = 1584, skinVariations = Dict.fromList [], keywords = [ "square", "yellow" ] } )
        , ( "large_green_square", { name = "LARGE GREEN SQUARE", native = "🟩", sortOrder = 1585, skinVariations = Dict.fromList [], keywords = [ "green", "square" ] } )
        , ( "large_purple_square", { name = "LARGE PURPLE SQUARE", native = "🟪", sortOrder = 1587, skinVariations = Dict.fromList [], keywords = [ "purple", "square" ] } )
        , ( "large_brown_square", { name = "LARGE BROWN SQUARE", native = "🟫", sortOrder = 1588, skinVariations = Dict.fromList [], keywords = [ "brown", "square" ] } )
        , ( "heavy_equals_sign", { name = "HEAVY EQUALS SIGN", native = "🟰", sortOrder = 1489, skinVariations = Dict.fromList [], keywords = [ "equality", "heavy equals sign", "math" ] } )
        , ( "pinched_fingers", { name = "PINCHED FINGERS", native = "🤌", sortOrder = 179, skinVariations = Dict.fromList [ ( "1F3FB", "🤌🏻" ), ( "1F3FC", "🤌🏼" ), ( "1F3FD", "🤌🏽" ), ( "1F3FE", "🤌🏾" ), ( "1F3FF", "🤌🏿" ) ], keywords = [ "fingers", "hand gesture", "interrogation", "pinched", "sarcastic" ] } )
        , ( "white_heart", { name = "WHITE HEART", native = "🤍", sortOrder = 152, skinVariations = Dict.fromList [], keywords = [ "heart", "white" ] } )
        , ( "brown_heart", { name = "BROWN HEART", native = "🤎", sortOrder = 149, skinVariations = Dict.fromList [], keywords = [ "brown", "heart" ] } )
        , ( "pinching_hand", { name = "PINCHING HAND", native = "🤏", sortOrder = 180, skinVariations = Dict.fromList [ ( "1F3FB", "🤏🏻" ), ( "1F3FC", "🤏🏼" ), ( "1F3FD", "🤏🏽" ), ( "1F3FE", "🤏🏾" ), ( "1F3FF", "🤏🏿" ) ], keywords = [ "pinching hand", "small amount" ] } )
        , ( "zipper_mouth_face", { name = "ZIPPER-MOUTH FACE", native = "🤐", sortOrder = 37, skinVariations = Dict.fromList [], keywords = [ "face", "mouth", "zip", "zipper", "zipper-mouth face" ] } )
        , ( "money_mouth_face", { name = "MONEY-MOUTH FACE", native = "🤑", sortOrder = 29, skinVariations = Dict.fromList [], keywords = [ "face", "money", "money-mouth face", "mouth" ] } )
        , ( "face_with_thermometer", { name = "FACE WITH THERMOMETER", native = "🤒", sortOrder = 57, skinVariations = Dict.fromList [], keywords = [ "face", "face with thermometer", "ill", "sick", "thermometer" ] } )
        , ( "nerd_face", { name = "NERD FACE", native = "🤓", sortOrder = 72, skinVariations = Dict.fromList [], keywords = [ "face", "geek", "nerd" ] } )
        , ( "thinking_face", { name = "THINKING FACE", native = "🤔", sortOrder = 35, skinVariations = Dict.fromList [], keywords = [ "face", "thinking" ] } )
        , ( "face_with_head_bandage", { name = "FACE WITH HEAD-BANDAGE", native = "🤕", sortOrder = 58, skinVariations = Dict.fromList [], keywords = [ "bandage", "face", "face with head-bandage", "hurt", "injury" ] } )
        , ( "robot_face", { name = "ROBOT FACE", native = "🤖", sortOrder = 115, skinVariations = Dict.fromList [], keywords = [ "face", "monster", "robot" ] } )
        , ( "hugging_face", { name = "HUGGING FACE", native = "🤗", sortOrder = 30, skinVariations = Dict.fromList [], keywords = [ "face", "hug", "hugging", "open hands", "smiling face", "smiling face with open hands" ] } )
        , ( "the_horns", { name = "SIGN OF THE HORNS", native = "🤘", sortOrder = 185, skinVariations = Dict.fromList [ ( "1F3FB", "🤘🏻" ), ( "1F3FC", "🤘🏼" ), ( "1F3FD", "🤘🏽" ), ( "1F3FE", "🤘🏾" ), ( "1F3FF", "🤘🏿" ) ], keywords = [ "finger", "hand", "horns", "rock-on", "sign of the horns" ] } )
        , ( "call_me_hand", { name = "CALL ME HAND", native = "🤙", sortOrder = 186, skinVariations = Dict.fromList [ ( "1F3FB", "🤙🏻" ), ( "1F3FC", "🤙🏼" ), ( "1F3FD", "🤙🏽" ), ( "1F3FE", "🤙🏾" ), ( "1F3FF", "🤙🏿" ) ], keywords = [ "call", "call me hand", "hand", "hang loose", "Shaka" ] } )
        , ( "raised_back_of_hand", { name = "RAISED BACK OF HAND", native = "🤚", sortOrder = 168, skinVariations = Dict.fromList [ ( "1F3FB", "🤚🏻" ), ( "1F3FC", "🤚🏼" ), ( "1F3FD", "🤚🏽" ), ( "1F3FE", "🤚🏾" ), ( "1F3FF", "🤚🏿" ) ], keywords = [ "backhand", "raised", "raised back of hand" ] } )
        , ( "left-facing_fist", { name = "LEFT-FACING FIST", native = "🤛", sortOrder = 198, skinVariations = Dict.fromList [ ( "1F3FB", "🤛🏻" ), ( "1F3FC", "🤛🏼" ), ( "1F3FD", "🤛🏽" ), ( "1F3FE", "🤛🏾" ), ( "1F3FF", "🤛🏿" ) ], keywords = [ "fist", "left-facing fist", "leftwards" ] } )
        , ( "right-facing_fist", { name = "RIGHT-FACING FIST", native = "🤜", sortOrder = 199, skinVariations = Dict.fromList [ ( "1F3FB", "🤜🏻" ), ( "1F3FC", "🤜🏼" ), ( "1F3FD", "🤜🏽" ), ( "1F3FE", "🤜🏾" ), ( "1F3FF", "🤜🏿" ) ], keywords = [ "fist", "right-facing fist", "rightwards" ] } )
        , ( "handshake", { name = "HANDSHAKE", native = "🤝", sortOrder = 205, skinVariations = Dict.fromList [ ( "1F3FB", "🤝🏻" ), ( "1F3FC", "🤝🏼" ), ( "1F3FD", "🤝🏽" ), ( "1F3FE", "🤝🏾" ), ( "1F3FF", "🤝🏿" ), ( "1F3FB-1F3FC", "🫱🏻\u{200D}🫲🏼" ), ( "1F3FB-1F3FD", "🫱🏻\u{200D}🫲🏽" ), ( "1F3FB-1F3FE", "🫱🏻\u{200D}🫲🏾" ), ( "1F3FB-1F3FF", "🫱🏻\u{200D}🫲🏿" ), ( "1F3FC-1F3FB", "🫱🏼\u{200D}🫲🏻" ), ( "1F3FC-1F3FD", "🫱🏼\u{200D}🫲🏽" ), ( "1F3FC-1F3FE", "🫱🏼\u{200D}🫲🏾" ), ( "1F3FC-1F3FF", "🫱🏼\u{200D}🫲🏿" ), ( "1F3FD-1F3FB", "🫱🏽\u{200D}🫲🏻" ), ( "1F3FD-1F3FC", "🫱🏽\u{200D}🫲🏼" ), ( "1F3FD-1F3FE", "🫱🏽\u{200D}🫲🏾" ), ( "1F3FD-1F3FF", "🫱🏽\u{200D}🫲🏿" ), ( "1F3FE-1F3FB", "🫱🏾\u{200D}🫲🏻" ), ( "1F3FE-1F3FC", "🫱🏾\u{200D}🫲🏼" ), ( "1F3FE-1F3FD", "🫱🏾\u{200D}🫲🏽" ), ( "1F3FE-1F3FF", "🫱🏾\u{200D}🫲🏿" ), ( "1F3FF-1F3FB", "🫱🏿\u{200D}🫲🏻" ), ( "1F3FF-1F3FC", "🫱🏿\u{200D}🫲🏼" ), ( "1F3FF-1F3FD", "🫱🏿\u{200D}🫲🏽" ), ( "1F3FF-1F3FE", "🫱🏿\u{200D}🫲🏾" ) ], keywords = [ "agreement", "hand", "handshake", "meeting", "shake" ] } )
        , ( "crossed_fingers", { name = "HAND WITH INDEX AND MIDDLE FINGERS CROSSED", native = "🤞", sortOrder = 182, skinVariations = Dict.fromList [ ( "1F3FB", "🤞🏻" ), ( "1F3FC", "🤞🏼" ), ( "1F3FD", "🤞🏽" ), ( "1F3FE", "🤞🏾" ), ( "1F3FF", "🤞🏿" ) ], keywords = [ "cross", "crossed fingers", "finger", "hand", "luck" ] } )
        , ( "i_love_you_hand_sign", { name = "I LOVE YOU HAND SIGN", native = "🤟", sortOrder = 184, skinVariations = Dict.fromList [ ( "1F3FB", "🤟🏻" ), ( "1F3FC", "🤟🏼" ), ( "1F3FD", "🤟🏽" ), ( "1F3FE", "🤟🏾" ), ( "1F3FF", "🤟🏿" ) ], keywords = [ "hand", "ILY", "love-you gesture" ] } )
        , ( "face_with_cowboy_hat", { name = "FACE WITH COWBOY HAT", native = "🤠", sortOrder = 68, skinVariations = Dict.fromList [], keywords = [ "cowboy", "cowgirl", "face", "hat" ] } )
        , ( "clown_face", { name = "CLOWN FACE", native = "🤡", sortOrder = 109, skinVariations = Dict.fromList [], keywords = [ "clown", "face" ] } )
        , ( "nauseated_face", { name = "NAUSEATED FACE", native = "🤢", sortOrder = 59, skinVariations = Dict.fromList [], keywords = [ "face", "nauseated", "vomit" ] } )
        , ( "rolling_on_the_floor_laughing", { name = "ROLLING ON THE FLOOR LAUGHING", native = "🤣", sortOrder = 7, skinVariations = Dict.fromList [], keywords = [ "face", "floor", "laugh", "rofl", "rolling", "rolling on the floor laughing", "rotfl" ] } )
        , ( "drooling_face", { name = "DROOLING FACE", native = "🤤", sortOrder = 54, skinVariations = Dict.fromList [], keywords = [ "drooling", "face" ] } )
        , ( "lying_face", { name = "LYING FACE", native = "🤥", sortOrder = 49, skinVariations = Dict.fromList [], keywords = [ "face", "lie", "lying face", "pinocchio" ] } )
        , ( "woman-facepalming", { name = "WOMAN FACEPALMING", native = "🤦\u{200D}♀️", sortOrder = 282, skinVariations = Dict.fromList [ ( "1F3FB", "🤦🏻\u{200D}♀️" ), ( "1F3FC", "🤦🏼\u{200D}♀️" ), ( "1F3FD", "🤦🏽\u{200D}♀️" ), ( "1F3FE", "🤦🏾\u{200D}♀️" ), ( "1F3FF", "🤦🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-facepalming", { name = "MAN FACEPALMING", native = "🤦\u{200D}♂️", sortOrder = 281, skinVariations = Dict.fromList [ ( "1F3FB", "🤦🏻\u{200D}♂️" ), ( "1F3FC", "🤦🏼\u{200D}♂️" ), ( "1F3FD", "🤦🏽\u{200D}♂️" ), ( "1F3FE", "🤦🏾\u{200D}♂️" ), ( "1F3FF", "🤦🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "face_palm", { name = "FACE PALM", native = "🤦", sortOrder = 280, skinVariations = Dict.fromList [ ( "1F3FB", "🤦🏻" ), ( "1F3FC", "🤦🏼" ), ( "1F3FD", "🤦🏽" ), ( "1F3FE", "🤦🏾" ), ( "1F3FF", "🤦🏿" ) ], keywords = [ "disbelief", "exasperation", "face", "palm", "person facepalming" ] } )
        , ( "sneezing_face", { name = "SNEEZING FACE", native = "🤧", sortOrder = 61, skinVariations = Dict.fromList [], keywords = [ "face", "gesundheit", "sneeze", "sneezing face" ] } )
        , ( "face_with_raised_eyebrow", { name = "FACE WITH ONE EYEBROW RAISED", native = "🤨", sortOrder = 38, skinVariations = Dict.fromList [], keywords = [ "distrust", "face with raised eyebrow", "skeptic" ] } )
        , ( "star-struck", { name = "GRINNING FACE WITH STAR EYES", native = "🤩", sortOrder = 17, skinVariations = Dict.fromList [], keywords = [ "eyes", "face", "grinning", "star", "star-struck" ] } )
        , ( "zany_face", { name = "GRINNING FACE WITH ONE LARGE AND ONE SMALL EYE", native = "🤪", sortOrder = 27, skinVariations = Dict.fromList [], keywords = [ "eye", "goofy", "large", "small", "zany face" ] } )
        , ( "shushing_face", { name = "FACE WITH FINGER COVERING CLOSED LIPS", native = "🤫", sortOrder = 34, skinVariations = Dict.fromList [], keywords = [ "quiet", "shush", "shushing face" ] } )
        , ( "face_with_symbols_on_mouth", { name = "SERIOUS FACE WITH SYMBOLS COVERING MOUTH", native = "🤬", sortOrder = 103, skinVariations = Dict.fromList [], keywords = [ "face with symbols on mouth", "swearing" ] } )
        , ( "face_with_hand_over_mouth", { name = "SMILING FACE WITH SMILING EYES AND HAND COVERING MOUTH", native = "🤭", sortOrder = 31, skinVariations = Dict.fromList [], keywords = [ "face with hand over mouth", "whoops" ] } )
        , ( "face_vomiting", { name = "FACE WITH OPEN MOUTH VOMITING", native = "🤮", sortOrder = 60, skinVariations = Dict.fromList [], keywords = [ "face vomiting", "puke", "sick", "vomit" ] } )
        , ( "exploding_head", { name = "SHOCKED FACE WITH EXPLODING HEAD", native = "🤯", sortOrder = 67, skinVariations = Dict.fromList [], keywords = [ "exploding head", "mind blown", "shocked" ] } )
        , ( "pregnant_woman", { name = "PREGNANT WOMAN", native = "🤰", sortOrder = 361, skinVariations = Dict.fromList [ ( "1F3FB", "🤰🏻" ), ( "1F3FC", "🤰🏼" ), ( "1F3FD", "🤰🏽" ), ( "1F3FE", "🤰🏾" ), ( "1F3FF", "🤰🏿" ) ], keywords = [ "pregnant", "woman" ] } )
        , ( "breast-feeding", { name = "BREAST-FEEDING", native = "🤱", sortOrder = 364, skinVariations = Dict.fromList [ ( "1F3FB", "🤱🏻" ), ( "1F3FC", "🤱🏼" ), ( "1F3FD", "🤱🏽" ), ( "1F3FE", "🤱🏾" ), ( "1F3FF", "🤱🏿" ) ], keywords = [ "baby", "breast", "breast-feeding", "nursing" ] } )
        , ( "palms_up_together", { name = "PALMS UP TOGETHER", native = "🤲", sortOrder = 204, skinVariations = Dict.fromList [ ( "1F3FB", "🤲🏻" ), ( "1F3FC", "🤲🏼" ), ( "1F3FD", "🤲🏽" ), ( "1F3FE", "🤲🏾" ), ( "1F3FF", "🤲🏿" ) ], keywords = [ "palms up together", "prayer" ] } )
        , ( "selfie", { name = "SELFIE", native = "🤳", sortOrder = 209, skinVariations = Dict.fromList [ ( "1F3FB", "🤳🏻" ), ( "1F3FC", "🤳🏼" ), ( "1F3FD", "🤳🏽" ), ( "1F3FE", "🤳🏾" ), ( "1F3FF", "🤳🏿" ) ], keywords = [ "camera", "phone", "selfie" ] } )
        , ( "prince", { name = "PRINCE", native = "🤴", sortOrder = 348, skinVariations = Dict.fromList [ ( "1F3FB", "🤴🏻" ), ( "1F3FC", "🤴🏼" ), ( "1F3FD", "🤴🏽" ), ( "1F3FE", "🤴🏾" ), ( "1F3FF", "🤴🏿" ) ], keywords = [ "prince" ] } )
        , ( "woman_in_tuxedo", { name = "WOMAN IN TUXEDO", native = "🤵\u{200D}♀️", sortOrder = 357, skinVariations = Dict.fromList [ ( "1F3FB", "🤵🏻\u{200D}♀️" ), ( "1F3FC", "🤵🏼\u{200D}♀️" ), ( "1F3FD", "🤵🏽\u{200D}♀️" ), ( "1F3FE", "🤵🏾\u{200D}♀️" ), ( "1F3FF", "🤵🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_in_tuxedo", { name = "MAN IN TUXEDO", native = "🤵\u{200D}♂️", sortOrder = 356, skinVariations = Dict.fromList [ ( "1F3FB", "🤵🏻\u{200D}♂️" ), ( "1F3FC", "🤵🏼\u{200D}♂️" ), ( "1F3FD", "🤵🏽\u{200D}♂️" ), ( "1F3FE", "🤵🏾\u{200D}♂️" ), ( "1F3FF", "🤵🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_in_tuxedo", { name = "MAN IN TUXEDO", native = "🤵", sortOrder = 355, skinVariations = Dict.fromList [ ( "1F3FB", "🤵🏻" ), ( "1F3FC", "🤵🏼" ), ( "1F3FD", "🤵🏽" ), ( "1F3FE", "🤵🏾" ), ( "1F3FF", "🤵🏿" ) ], keywords = [ "groom", "person", "person in tuxedo", "tuxedo" ] } )
        , ( "mrs_claus", { name = "MOTHER CHRISTMAS", native = "🤶", sortOrder = 370, skinVariations = Dict.fromList [ ( "1F3FB", "🤶🏻" ), ( "1F3FC", "🤶🏼" ), ( "1F3FD", "🤶🏽" ), ( "1F3FE", "🤶🏾" ), ( "1F3FF", "🤶🏿" ) ], keywords = [ "celebration", "Christmas", "claus", "mother", "Mrs." ] } )
        , ( "woman-shrugging", { name = "WOMAN SHRUGGING", native = "🤷\u{200D}♀️", sortOrder = 285, skinVariations = Dict.fromList [ ( "1F3FB", "🤷🏻\u{200D}♀️" ), ( "1F3FC", "🤷🏼\u{200D}♀️" ), ( "1F3FD", "🤷🏽\u{200D}♀️" ), ( "1F3FE", "🤷🏾\u{200D}♀️" ), ( "1F3FF", "🤷🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-shrugging", { name = "MAN SHRUGGING", native = "🤷\u{200D}♂️", sortOrder = 284, skinVariations = Dict.fromList [ ( "1F3FB", "🤷🏻\u{200D}♂️" ), ( "1F3FC", "🤷🏼\u{200D}♂️" ), ( "1F3FD", "🤷🏽\u{200D}♂️" ), ( "1F3FE", "🤷🏾\u{200D}♂️" ), ( "1F3FF", "🤷🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "shrug", { name = "SHRUG", native = "🤷", sortOrder = 283, skinVariations = Dict.fromList [ ( "1F3FB", "🤷🏻" ), ( "1F3FC", "🤷🏼" ), ( "1F3FD", "🤷🏽" ), ( "1F3FE", "🤷🏾" ), ( "1F3FF", "🤷🏿" ) ], keywords = [ "doubt", "ignorance", "indifference", "person shrugging", "shrug" ] } )
        , ( "woman-cartwheeling", { name = "WOMAN CARTWHEELING", native = "🤸\u{200D}♀️", sortOrder = 469, skinVariations = Dict.fromList [ ( "1F3FB", "🤸🏻\u{200D}♀️" ), ( "1F3FC", "🤸🏼\u{200D}♀️" ), ( "1F3FD", "🤸🏽\u{200D}♀️" ), ( "1F3FE", "🤸🏾\u{200D}♀️" ), ( "1F3FF", "🤸🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-cartwheeling", { name = "MAN CARTWHEELING", native = "🤸\u{200D}♂️", sortOrder = 468, skinVariations = Dict.fromList [ ( "1F3FB", "🤸🏻\u{200D}♂️" ), ( "1F3FC", "🤸🏼\u{200D}♂️" ), ( "1F3FD", "🤸🏽\u{200D}♂️" ), ( "1F3FE", "🤸🏾\u{200D}♂️" ), ( "1F3FF", "🤸🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_doing_cartwheel", { name = "PERSON DOING CARTWHEEL", native = "🤸", sortOrder = 467, skinVariations = Dict.fromList [ ( "1F3FB", "🤸🏻" ), ( "1F3FC", "🤸🏼" ), ( "1F3FD", "🤸🏽" ), ( "1F3FE", "🤸🏾" ), ( "1F3FF", "🤸🏿" ) ], keywords = [ "cartwheel", "gymnastics", "person cartwheeling" ] } )
        , ( "woman-juggling", { name = "WOMAN JUGGLING", native = "🤹\u{200D}♀️", sortOrder = 481, skinVariations = Dict.fromList [ ( "1F3FB", "🤹🏻\u{200D}♀️" ), ( "1F3FC", "🤹🏼\u{200D}♀️" ), ( "1F3FD", "🤹🏽\u{200D}♀️" ), ( "1F3FE", "🤹🏾\u{200D}♀️" ), ( "1F3FF", "🤹🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-juggling", { name = "MAN JUGGLING", native = "🤹\u{200D}♂️", sortOrder = 480, skinVariations = Dict.fromList [ ( "1F3FB", "🤹🏻\u{200D}♂️" ), ( "1F3FC", "🤹🏼\u{200D}♂️" ), ( "1F3FD", "🤹🏽\u{200D}♂️" ), ( "1F3FE", "🤹🏾\u{200D}♂️" ), ( "1F3FF", "🤹🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "juggling", { name = "JUGGLING", native = "🤹", sortOrder = 479, skinVariations = Dict.fromList [ ( "1F3FB", "🤹🏻" ), ( "1F3FC", "🤹🏼" ), ( "1F3FD", "🤹🏽" ), ( "1F3FE", "🤹🏾" ), ( "1F3FF", "🤹🏿" ) ], keywords = [ "balance", "juggle", "multitask", "person juggling", "skill" ] } )
        , ( "fencer", { name = "FENCER", native = "🤺", sortOrder = 439, skinVariations = Dict.fromList [], keywords = [ "fencer", "fencing", "person fencing", "sword" ] } )
        , ( "woman-wrestling", { name = "WOMEN WRESTLING", native = "🤼\u{200D}♀️", sortOrder = 472, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "man-wrestling", { name = "MEN WRESTLING", native = "🤼\u{200D}♂️", sortOrder = 471, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "wrestlers", { name = "WRESTLERS", native = "🤼", sortOrder = 470, skinVariations = Dict.fromList [], keywords = [ "people wrestling", "wrestle", "wrestler" ] } )
        , ( "woman-playing-water-polo", { name = "WOMAN PLAYING WATER POLO", native = "🤽\u{200D}♀️", sortOrder = 475, skinVariations = Dict.fromList [ ( "1F3FB", "🤽🏻\u{200D}♀️" ), ( "1F3FC", "🤽🏼\u{200D}♀️" ), ( "1F3FD", "🤽🏽\u{200D}♀️" ), ( "1F3FE", "🤽🏾\u{200D}♀️" ), ( "1F3FF", "🤽🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-playing-water-polo", { name = "MAN PLAYING WATER POLO", native = "🤽\u{200D}♂️", sortOrder = 474, skinVariations = Dict.fromList [ ( "1F3FB", "🤽🏻\u{200D}♂️" ), ( "1F3FC", "🤽🏼\u{200D}♂️" ), ( "1F3FD", "🤽🏽\u{200D}♂️" ), ( "1F3FE", "🤽🏾\u{200D}♂️" ), ( "1F3FF", "🤽🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "water_polo", { name = "WATER POLO", native = "🤽", sortOrder = 473, skinVariations = Dict.fromList [ ( "1F3FB", "🤽🏻" ), ( "1F3FC", "🤽🏼" ), ( "1F3FD", "🤽🏽" ), ( "1F3FE", "🤽🏾" ), ( "1F3FF", "🤽🏿" ) ], keywords = [ "person playing water polo", "polo", "water" ] } )
        , ( "woman-playing-handball", { name = "WOMAN PLAYING HANDBALL", native = "🤾\u{200D}♀️", sortOrder = 478, skinVariations = Dict.fromList [ ( "1F3FB", "🤾🏻\u{200D}♀️" ), ( "1F3FC", "🤾🏼\u{200D}♀️" ), ( "1F3FD", "🤾🏽\u{200D}♀️" ), ( "1F3FE", "🤾🏾\u{200D}♀️" ), ( "1F3FF", "🤾🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-playing-handball", { name = "MAN PLAYING HANDBALL", native = "🤾\u{200D}♂️", sortOrder = 477, skinVariations = Dict.fromList [ ( "1F3FB", "🤾🏻\u{200D}♂️" ), ( "1F3FC", "🤾🏼\u{200D}♂️" ), ( "1F3FD", "🤾🏽\u{200D}♂️" ), ( "1F3FE", "🤾🏾\u{200D}♂️" ), ( "1F3FF", "🤾🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "handball", { name = "HANDBALL", native = "🤾", sortOrder = 476, skinVariations = Dict.fromList [ ( "1F3FB", "🤾🏻" ), ( "1F3FC", "🤾🏼" ), ( "1F3FD", "🤾🏽" ), ( "1F3FE", "🤾🏾" ), ( "1F3FF", "🤾🏿" ) ], keywords = [ "ball", "handball", "person playing handball" ] } )
        , ( "diving_mask", { name = "DIVING MASK", native = "🤿", sortOrder = 1087, skinVariations = Dict.fromList [], keywords = [ "diving", "diving mask", "scuba", "snorkeling" ] } )
        , ( "wilted_flower", { name = "WILTED FLOWER", native = "🥀", sortOrder = 665, skinVariations = Dict.fromList [], keywords = [ "flower", "wilted" ] } )
        , ( "drum_with_drumsticks", { name = "DRUM WITH DRUMSTICKS", native = "🥁", sortOrder = 1195, skinVariations = Dict.fromList [], keywords = [ "drum", "drumsticks", "music" ] } )
        , ( "clinking_glasses", { name = "CLINKING GLASSES", native = "🥂", sortOrder = 805, skinVariations = Dict.fromList [], keywords = [ "celebrate", "clink", "clinking glasses", "drink", "glass" ] } )
        , ( "tumbler_glass", { name = "TUMBLER GLASS", native = "🥃", sortOrder = 806, skinVariations = Dict.fromList [], keywords = [ "glass", "liquor", "shot", "tumbler", "whisky" ] } )
        , ( "spoon", { name = "SPOON", native = "🥄", sortOrder = 816, skinVariations = Dict.fromList [], keywords = [ "spoon", "tableware" ] } )
        , ( "goal_net", { name = "GOAL NET", native = "🥅", sortOrder = 1083, skinVariations = Dict.fromList [], keywords = [ "goal", "net" ] } )
        , ( "first_place_medal", { name = "FIRST PLACE MEDAL", native = "🥇", sortOrder = 1062, skinVariations = Dict.fromList [], keywords = [ "1st place medal", "first", "gold", "medal" ] } )
        , ( "second_place_medal", { name = "SECOND PLACE MEDAL", native = "🥈", sortOrder = 1063, skinVariations = Dict.fromList [], keywords = [ "2nd place medal", "medal", "second", "silver" ] } )
        , ( "third_place_medal", { name = "THIRD PLACE MEDAL", native = "🥉", sortOrder = 1064, skinVariations = Dict.fromList [], keywords = [ "3rd place medal", "bronze", "medal", "third" ] } )
        , ( "boxing_glove", { name = "BOXING GLOVE", native = "🥊", sortOrder = 1081, skinVariations = Dict.fromList [], keywords = [ "boxing", "glove" ] } )
        , ( "martial_arts_uniform", { name = "MARTIAL ARTS UNIFORM", native = "🥋", sortOrder = 1082, skinVariations = Dict.fromList [], keywords = [ "judo", "karate", "martial arts", "martial arts uniform", "taekwondo", "uniform" ] } )
        , ( "curling_stone", { name = "CURLING STONE", native = "🥌", sortOrder = 1091, skinVariations = Dict.fromList [], keywords = [ "curling stone", "game", "rock" ] } )
        , ( "lacrosse", { name = "LACROSSE STICK AND BALL", native = "🥍", sortOrder = 1078, skinVariations = Dict.fromList [], keywords = [ "ball", "goal", "lacrosse", "stick" ] } )
        , ( "softball", { name = "SOFTBALL", native = "🥎", sortOrder = 1067, skinVariations = Dict.fromList [], keywords = [ "ball", "glove", "softball", "underarm" ] } )
        , ( "flying_disc", { name = "FLYING DISC", native = "🥏", sortOrder = 1073, skinVariations = Dict.fromList [], keywords = [ "flying disc", "ultimate" ] } )
        , ( "croissant", { name = "CROISSANT", native = "🥐", sortOrder = 724, skinVariations = Dict.fromList [], keywords = [ "bread", "breakfast", "croissant", "food", "french", "roll" ] } )
        , ( "avocado", { name = "AVOCADO", native = "🥑", sortOrder = 706, skinVariations = Dict.fromList [], keywords = [ "avocado", "food", "fruit" ] } )
        , ( "cucumber", { name = "CUCUMBER", native = "🥒", sortOrder = 713, skinVariations = Dict.fromList [], keywords = [ "cucumber", "food", "pickle", "vegetable" ] } )
        , ( "bacon", { name = "BACON", native = "🥓", sortOrder = 735, skinVariations = Dict.fromList [], keywords = [ "bacon", "breakfast", "food", "meat" ] } )
        , ( "potato", { name = "POTATO", native = "🥔", sortOrder = 708, skinVariations = Dict.fromList [], keywords = [ "food", "potato", "vegetable" ] } )
        , ( "carrot", { name = "CARROT", native = "🥕", sortOrder = 709, skinVariations = Dict.fromList [], keywords = [ "carrot", "food", "vegetable" ] } )
        , ( "baguette_bread", { name = "BAGUETTE BREAD", native = "🥖", sortOrder = 725, skinVariations = Dict.fromList [], keywords = [ "baguette", "bread", "food", "french" ] } )
        , ( "green_salad", { name = "GREEN SALAD", native = "🥗", sortOrder = 752, skinVariations = Dict.fromList [], keywords = [ "food", "green", "salad" ] } )
        , ( "shallow_pan_of_food", { name = "SHALLOW PAN OF FOOD", native = "🥘", sortOrder = 748, skinVariations = Dict.fromList [], keywords = [ "casserole", "food", "paella", "pan", "shallow", "shallow pan of food" ] } )
        , ( "stuffed_flatbread", { name = "STUFFED FLATBREAD", native = "🥙", sortOrder = 744, skinVariations = Dict.fromList [], keywords = [ "falafel", "flatbread", "food", "gyro", "kebab", "stuffed" ] } )
        , ( "egg", { name = "EGG", native = "🥚", sortOrder = 746, skinVariations = Dict.fromList [], keywords = [ "breakfast", "egg", "food" ] } )
        , ( "glass_of_milk", { name = "GLASS OF MILK", native = "🥛", sortOrder = 794, skinVariations = Dict.fromList [], keywords = [ "drink", "glass", "glass of milk", "milk" ] } )
        , ( "peanuts", { name = "PEANUTS", native = "🥜", sortOrder = 718, skinVariations = Dict.fromList [], keywords = [ "food", "nut", "peanut", "peanuts", "vegetable" ] } )
        , ( "kiwifruit", { name = "KIWIFRUIT", native = "🥝", sortOrder = 702, skinVariations = Dict.fromList [], keywords = [ "food", "fruit", "kiwi" ] } )
        , ( "pancakes", { name = "PANCAKES", native = "🥞", sortOrder = 729, skinVariations = Dict.fromList [], keywords = [ "breakfast", "crêpe", "food", "hotcake", "pancake", "pancakes" ] } )
        , ( "dumpling", { name = "DUMPLING", native = "🥟", sortOrder = 771, skinVariations = Dict.fromList [], keywords = [ "dumpling", "empanada", "gyōza", "jiaozi", "pierogi", "potsticker" ] } )
        , ( "fortune_cookie", { name = "FORTUNE COOKIE", native = "🥠", sortOrder = 772, skinVariations = Dict.fromList [], keywords = [ "fortune cookie", "prophecy" ] } )
        , ( "takeout_box", { name = "TAKEOUT BOX", native = "🥡", sortOrder = 773, skinVariations = Dict.fromList [], keywords = [ "oyster pail", "takeout box" ] } )
        , ( "chopsticks", { name = "CHOPSTICKS", native = "🥢", sortOrder = 813, skinVariations = Dict.fromList [], keywords = [ "chopsticks", "hashi" ] } )
        , ( "bowl_with_spoon", { name = "BOWL WITH SPOON", native = "🥣", sortOrder = 751, skinVariations = Dict.fromList [], keywords = [ "bowl with spoon", "breakfast", "cereal", "congee" ] } )
        , ( "cup_with_straw", { name = "CUP WITH STRAW", native = "🥤", sortOrder = 808, skinVariations = Dict.fromList [], keywords = [ "cup with straw", "juice", "soda" ] } )
        , ( "coconut", { name = "COCONUT", native = "🥥", sortOrder = 705, skinVariations = Dict.fromList [], keywords = [ "coconut", "palm", "piña colada" ] } )
        , ( "broccoli", { name = "BROCCOLI", native = "🥦", sortOrder = 715, skinVariations = Dict.fromList [], keywords = [ "broccoli", "wild cabbage" ] } )
        , ( "pie", { name = "PIE", native = "🥧", sortOrder = 787, skinVariations = Dict.fromList [], keywords = [ "filling", "pastry", "pie" ] } )
        , ( "pretzel", { name = "PRETZEL", native = "🥨", sortOrder = 727, skinVariations = Dict.fromList [], keywords = [ "pretzel", "twisted" ] } )
        , ( "cut_of_meat", { name = "CUT OF MEAT", native = "🥩", sortOrder = 734, skinVariations = Dict.fromList [], keywords = [ "chop", "cut of meat", "lambchop", "porkchop", "steak" ] } )
        , ( "sandwich", { name = "SANDWICH", native = "🥪", sortOrder = 740, skinVariations = Dict.fromList [], keywords = [ "bread", "sandwich" ] } )
        , ( "canned_food", { name = "CANNED FOOD", native = "🥫", sortOrder = 756, skinVariations = Dict.fromList [], keywords = [ "can", "canned food" ] } )
        , ( "leafy_green", { name = "LEAFY GREEN", native = "🥬", sortOrder = 714, skinVariations = Dict.fromList [], keywords = [ "bok choy", "cabbage", "kale", "leafy green", "lettuce" ] } )
        , ( "mango", { name = "MANGO", native = "🥭", sortOrder = 694, skinVariations = Dict.fromList [], keywords = [ "fruit", "mango", "tropical" ] } )
        , ( "moon_cake", { name = "MOON CAKE", native = "🥮", sortOrder = 769, skinVariations = Dict.fromList [], keywords = [ "autumn", "festival", "moon cake", "yuèbǐng" ] } )
        , ( "bagel", { name = "BAGEL", native = "🥯", sortOrder = 728, skinVariations = Dict.fromList [], keywords = [ "bagel", "bakery", "breakfast", "schmear" ] } )
        , ( "smiling_face_with_3_hearts", { name = "SMILING FACE WITH SMILING EYES AND THREE HEARTS", native = "🥰", sortOrder = 15, skinVariations = Dict.fromList [], keywords = [ "adore", "crush", "hearts", "in love", "smiling face with hearts" ] } )
        , ( "yawning_face", { name = "YAWNING FACE", native = "🥱", sortOrder = 99, skinVariations = Dict.fromList [], keywords = [ "bored", "tired", "yawn", "yawning face" ] } )
        , ( "smiling_face_with_tear", { name = "SMILING FACE WITH TEAR", native = "🥲", sortOrder = 23, skinVariations = Dict.fromList [], keywords = [ "grateful", "proud", "relieved", "smiling", "smiling face with tear", "tear", "touched" ] } )
        , ( "partying_face", { name = "FACE WITH PARTY HORN AND PARTY HAT", native = "🥳", sortOrder = 69, skinVariations = Dict.fromList [], keywords = [ "celebration", "hat", "horn", "party", "partying face" ] } )
        , ( "woozy_face", { name = "FACE WITH UNEVEN EYES AND WAVY MOUTH", native = "🥴", sortOrder = 64, skinVariations = Dict.fromList [], keywords = [ "dizzy", "intoxicated", "tipsy", "uneven eyes", "wavy mouth", "woozy face" ] } )
        , ( "hot_face", { name = "OVERHEATED FACE", native = "🥵", sortOrder = 62, skinVariations = Dict.fromList [], keywords = [ "feverish", "heat stroke", "hot", "hot face", "red-faced", "sweating" ] } )
        , ( "cold_face", { name = "FREEZING FACE", native = "🥶", sortOrder = 63, skinVariations = Dict.fromList [], keywords = [ "blue-faced", "cold", "cold face", "freezing", "frostbite", "icicles" ] } )
        , ( "ninja", { name = "NINJA", native = "🥷", sortOrder = 343, skinVariations = Dict.fromList [ ( "1F3FB", "🥷🏻" ), ( "1F3FC", "🥷🏼" ), ( "1F3FD", "🥷🏽" ), ( "1F3FE", "🥷🏾" ), ( "1F3FF", "🥷🏿" ) ], keywords = [ "fighter", "hidden", "ninja", "stealth" ] } )
        , ( "disguised_face", { name = "DISGUISED FACE", native = "🥸", sortOrder = 70, skinVariations = Dict.fromList [], keywords = [ "disguise", "disguised face", "face", "glasses", "incognito", "nose" ] } )
        , ( "face_holding_back_tears", { name = "FACE HOLDING BACK TEARS", native = "🥹", sortOrder = 84, skinVariations = Dict.fromList [], keywords = [ "angry", "cry", "face holding back tears", "proud", "resist", "sad" ] } )
        , ( "pleading_face", { name = "FACE WITH PLEADING EYES", native = "🥺", sortOrder = 83, skinVariations = Dict.fromList [], keywords = [ "begging", "mercy", "pleading face", "puppy eyes" ] } )
        , ( "sari", { name = "SARI", native = "🥻", sortOrder = 1137, skinVariations = Dict.fromList [], keywords = [ "clothing", "dress", "sari" ] } )
        , ( "lab_coat", { name = "LAB COAT", native = "🥼", sortOrder = 1126, skinVariations = Dict.fromList [], keywords = [ "doctor", "experiment", "lab coat", "scientist" ] } )
        , ( "goggles", { name = "GOGGLES", native = "🥽", sortOrder = 1125, skinVariations = Dict.fromList [], keywords = [ "eye protection", "goggles", "swimming", "welding" ] } )
        , ( "hiking_boot", { name = "HIKING BOOT", native = "🥾", sortOrder = 1152, skinVariations = Dict.fromList [], keywords = [ "backpacking", "boot", "camping", "hiking" ] } )
        , ( "womans_flat_shoe", { name = "FLAT SHOE", native = "🥿", sortOrder = 1153, skinVariations = Dict.fromList [], keywords = [ "ballet flat", "flat shoe", "slip-on", "slipper" ] } )
        , ( "crab", { name = "CRAB", native = "🦀", sortOrder = 774, skinVariations = Dict.fromList [], keywords = [ "Cancer", "crab", "zodiac" ] } )
        , ( "lion_face", { name = "LION FACE", native = "🦁", sortOrder = 550, skinVariations = Dict.fromList [], keywords = [ "face", "Leo", "lion", "zodiac" ] } )
        , ( "scorpion", { name = "SCORPION", native = "🦂", sortOrder = 654, skinVariations = Dict.fromList [], keywords = [ "Scorpio", "scorpion", "zodiac" ] } )
        , ( "turkey", { name = "TURKEY", native = "🦃", sortOrder = 601, skinVariations = Dict.fromList [], keywords = [ "bird", "turkey" ] } )
        , ( "unicorn_face", { name = "UNICORN FACE", native = "🦄", sortOrder = 558, skinVariations = Dict.fromList [], keywords = [ "face", "unicorn" ] } )
        , ( "eagle", { name = "EAGLE", native = "🦅", sortOrder = 610, skinVariations = Dict.fromList [], keywords = [ "bird", "eagle" ] } )
        , ( "duck", { name = "DUCK", native = "🦆", sortOrder = 611, skinVariations = Dict.fromList [], keywords = [ "bird", "duck" ] } )
        , ( "bat", { name = "BAT", native = "🦇", sortOrder = 590, skinVariations = Dict.fromList [], keywords = [ "bat", "vampire" ] } )
        , ( "shark", { name = "SHARK", native = "🦈", sortOrder = 638, skinVariations = Dict.fromList [], keywords = [ "fish", "shark" ] } )
        , ( "owl", { name = "OWL", native = "🦉", sortOrder = 613, skinVariations = Dict.fromList [], keywords = [ "bird", "owl", "wise" ] } )
        , ( "fox_face", { name = "FOX FACE", native = "🦊", sortOrder = 545, skinVariations = Dict.fromList [], keywords = [ "face", "fox" ] } )
        , ( "butterfly", { name = "BUTTERFLY", native = "🦋", sortOrder = 644, skinVariations = Dict.fromList [], keywords = [ "butterfly", "insect", "pretty" ] } )
        , ( "deer", { name = "DEER", native = "🦌", sortOrder = 560, skinVariations = Dict.fromList [], keywords = [ "deer" ] } )
        , ( "gorilla", { name = "GORILLA", native = "🦍", sortOrder = 537, skinVariations = Dict.fromList [], keywords = [ "gorilla" ] } )
        , ( "lizard", { name = "LIZARD", native = "🦎", sortOrder = 625, skinVariations = Dict.fromList [], keywords = [ "lizard", "reptile" ] } )
        , ( "rhinoceros", { name = "RHINOCEROS", native = "🦏", sortOrder = 579, skinVariations = Dict.fromList [], keywords = [ "rhinoceros" ] } )
        , ( "shrimp", { name = "SHRIMP", native = "🦐", sortOrder = 776, skinVariations = Dict.fromList [], keywords = [ "food", "shellfish", "shrimp", "small" ] } )
        , ( "squid", { name = "SQUID", native = "🦑", sortOrder = 777, skinVariations = Dict.fromList [], keywords = [ "food", "molusc", "squid" ] } )
        , ( "giraffe_face", { name = "GIRAFFE FACE", native = "🦒", sortOrder = 576, skinVariations = Dict.fromList [], keywords = [ "giraffe", "spots" ] } )
        , ( "zebra_face", { name = "ZEBRA FACE", native = "🦓", sortOrder = 559, skinVariations = Dict.fromList [], keywords = [ "stripe", "zebra" ] } )
        , ( "hedgehog", { name = "HEDGEHOG", native = "🦔", sortOrder = 589, skinVariations = Dict.fromList [], keywords = [ "hedgehog", "spiny" ] } )
        , ( "sauropod", { name = "SAUROPOD", native = "🦕", sortOrder = 629, skinVariations = Dict.fromList [], keywords = [ "brachiosaurus", "brontosaurus", "diplodocus", "sauropod" ] } )
        , ( "t-rex", { name = "T-REX", native = "🦖", sortOrder = 630, skinVariations = Dict.fromList [], keywords = [ "T-Rex", "Tyrannosaurus Rex" ] } )
        , ( "cricket", { name = "CRICKET", native = "🦗", sortOrder = 650, skinVariations = Dict.fromList [], keywords = [ "cricket", "grasshopper" ] } )
        , ( "kangaroo", { name = "KANGAROO", native = "🦘", sortOrder = 598, skinVariations = Dict.fromList [], keywords = [ "joey", "jump", "kangaroo", "marsupial" ] } )
        , ( "llama", { name = "LLAMA", native = "🦙", sortOrder = 575, skinVariations = Dict.fromList [], keywords = [ "alpaca", "guanaco", "llama", "vicuña", "wool" ] } )
        , ( "peacock", { name = "PEACOCK", native = "🦚", sortOrder = 617, skinVariations = Dict.fromList [], keywords = [ "bird", "ostentatious", "peacock", "peahen", "proud" ] } )
        , ( "hippopotamus", { name = "HIPPOPOTAMUS", native = "🦛", sortOrder = 580, skinVariations = Dict.fromList [], keywords = [ "hippo", "hippopotamus" ] } )
        , ( "parrot", { name = "PARROT", native = "🦜", sortOrder = 618, skinVariations = Dict.fromList [], keywords = [ "bird", "parrot", "pirate", "talk" ] } )
        , ( "raccoon", { name = "RACCOON", native = "🦝", sortOrder = 546, skinVariations = Dict.fromList [], keywords = [ "curious", "raccoon", "sly" ] } )
        , ( "lobster", { name = "LOBSTER", native = "🦞", sortOrder = 775, skinVariations = Dict.fromList [], keywords = [ "bisque", "claws", "lobster", "seafood" ] } )
        , ( "mosquito", { name = "MOSQUITO", native = "🦟", sortOrder = 655, skinVariations = Dict.fromList [], keywords = [ "disease", "fever", "malaria", "mosquito", "pest", "virus" ] } )
        , ( "microbe", { name = "MICROBE", native = "🦠", sortOrder = 658, skinVariations = Dict.fromList [], keywords = [ "amoeba", "bacteria", "microbe", "virus" ] } )
        , ( "badger", { name = "BADGER", native = "🦡", sortOrder = 599, skinVariations = Dict.fromList [], keywords = [ "badger", "honey badger", "pester" ] } )
        , ( "swan", { name = "SWAN", native = "🦢", sortOrder = 612, skinVariations = Dict.fromList [], keywords = [ "bird", "cygnet", "swan", "ugly duckling" ] } )
        , ( "mammoth", { name = "MAMMOTH", native = "🦣", sortOrder = 578, skinVariations = Dict.fromList [], keywords = [ "extinction", "large", "mammoth", "tusk", "woolly" ] } )
        , ( "dodo", { name = "DODO", native = "🦤", sortOrder = 614, skinVariations = Dict.fromList [], keywords = [ "dodo", "extinction", "large", "Mauritius" ] } )
        , ( "sloth", { name = "SLOTH", native = "🦥", sortOrder = 595, skinVariations = Dict.fromList [], keywords = [ "lazy", "sloth", "slow" ] } )
        , ( "otter", { name = "OTTER", native = "🦦", sortOrder = 596, skinVariations = Dict.fromList [], keywords = [ "fishing", "otter", "playful" ] } )
        , ( "orangutan", { name = "ORANGUTAN", native = "🦧", sortOrder = 538, skinVariations = Dict.fromList [], keywords = [ "ape", "orangutan" ] } )
        , ( "skunk", { name = "SKUNK", native = "🦨", sortOrder = 597, skinVariations = Dict.fromList [], keywords = [ "skunk", "stink" ] } )
        , ( "flamingo", { name = "FLAMINGO", native = "🦩", sortOrder = 616, skinVariations = Dict.fromList [], keywords = [ "flamboyant", "flamingo", "tropical" ] } )
        , ( "oyster", { name = "OYSTER", native = "🦪", sortOrder = 778, skinVariations = Dict.fromList [], keywords = [ "diving", "oyster", "pearl" ] } )
        , ( "beaver", { name = "BEAVER", native = "🦫", sortOrder = 588, skinVariations = Dict.fromList [], keywords = [ "beaver", "dam" ] } )
        , ( "bison", { name = "BISON", native = "🦬", sortOrder = 561, skinVariations = Dict.fromList [], keywords = [ "bison", "buffalo", "herd", "wisent" ] } )
        , ( "seal", { name = "SEAL", native = "🦭", sortOrder = 634, skinVariations = Dict.fromList [], keywords = [ "sea lion", "seal" ] } )
        , ( "guide_dog", { name = "GUIDE DOG", native = "🦮", sortOrder = 541, skinVariations = Dict.fromList [], keywords = [ "accessibility", "blind", "guide", "guide dog" ] } )
        , ( "probing_cane", { name = "PROBING CANE", native = "🦯", sortOrder = 1329, skinVariations = Dict.fromList [], keywords = [ "accessibility", "blind", "white cane" ] } )
        , ( "bone", { name = "BONE", native = "🦴", sortOrder = 222, skinVariations = Dict.fromList [], keywords = [ "bone", "skeleton" ] } )
        , ( "leg", { name = "LEG", native = "🦵", sortOrder = 213, skinVariations = Dict.fromList [ ( "1F3FB", "🦵🏻" ), ( "1F3FC", "🦵🏼" ), ( "1F3FD", "🦵🏽" ), ( "1F3FE", "🦵🏾" ), ( "1F3FF", "🦵🏿" ) ], keywords = [ "kick", "leg", "limb" ] } )
        , ( "foot", { name = "FOOT", native = "🦶", sortOrder = 214, skinVariations = Dict.fromList [ ( "1F3FB", "🦶🏻" ), ( "1F3FC", "🦶🏼" ), ( "1F3FD", "🦶🏽" ), ( "1F3FE", "🦶🏾" ), ( "1F3FF", "🦶🏿" ) ], keywords = [ "foot", "kick", "stomp" ] } )
        , ( "tooth", { name = "TOOTH", native = "🦷", sortOrder = 221, skinVariations = Dict.fromList [], keywords = [ "dentist", "tooth" ] } )
        , ( "female_superhero", { name = "WOMAN SUPERHERO", native = "🦸\u{200D}♀️", sortOrder = 374, skinVariations = Dict.fromList [ ( "1F3FB", "🦸🏻\u{200D}♀️" ), ( "1F3FC", "🦸🏼\u{200D}♀️" ), ( "1F3FD", "🦸🏽\u{200D}♀️" ), ( "1F3FE", "🦸🏾\u{200D}♀️" ), ( "1F3FF", "🦸🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male_superhero", { name = "MAN SUPERHERO", native = "🦸\u{200D}♂️", sortOrder = 373, skinVariations = Dict.fromList [ ( "1F3FB", "🦸🏻\u{200D}♂️" ), ( "1F3FC", "🦸🏼\u{200D}♂️" ), ( "1F3FD", "🦸🏽\u{200D}♂️" ), ( "1F3FE", "🦸🏾\u{200D}♂️" ), ( "1F3FF", "🦸🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "superhero", { name = "SUPERHERO", native = "🦸", sortOrder = 372, skinVariations = Dict.fromList [ ( "1F3FB", "🦸🏻" ), ( "1F3FC", "🦸🏼" ), ( "1F3FD", "🦸🏽" ), ( "1F3FE", "🦸🏾" ), ( "1F3FF", "🦸🏿" ) ], keywords = [ "good", "hero", "heroine", "superhero", "superpower" ] } )
        , ( "female_supervillain", { name = "WOMAN SUPERVILLAIN", native = "🦹\u{200D}♀️", sortOrder = 377, skinVariations = Dict.fromList [ ( "1F3FB", "🦹🏻\u{200D}♀️" ), ( "1F3FC", "🦹🏼\u{200D}♀️" ), ( "1F3FD", "🦹🏽\u{200D}♀️" ), ( "1F3FE", "🦹🏾\u{200D}♀️" ), ( "1F3FF", "🦹🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male_supervillain", { name = "MAN SUPERVILLAIN", native = "🦹\u{200D}♂️", sortOrder = 376, skinVariations = Dict.fromList [ ( "1F3FB", "🦹🏻\u{200D}♂️" ), ( "1F3FC", "🦹🏼\u{200D}♂️" ), ( "1F3FD", "🦹🏽\u{200D}♂️" ), ( "1F3FE", "🦹🏾\u{200D}♂️" ), ( "1F3FF", "🦹🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "supervillain", { name = "SUPERVILLAIN", native = "🦹", sortOrder = 375, skinVariations = Dict.fromList [ ( "1F3FB", "🦹🏻" ), ( "1F3FC", "🦹🏼" ), ( "1F3FD", "🦹🏽" ), ( "1F3FE", "🦹🏾" ), ( "1F3FF", "🦹🏿" ) ], keywords = [ "criminal", "evil", "superpower", "supervillain", "villain" ] } )
        , ( "safety_vest", { name = "SAFETY VEST", native = "🦺", sortOrder = 1127, skinVariations = Dict.fromList [], keywords = [ "emergency", "safety", "vest" ] } )
        , ( "ear_with_hearing_aid", { name = "EAR WITH HEARING AID", native = "🦻", sortOrder = 216, skinVariations = Dict.fromList [ ( "1F3FB", "🦻🏻" ), ( "1F3FC", "🦻🏼" ), ( "1F3FD", "🦻🏽" ), ( "1F3FE", "🦻🏾" ), ( "1F3FF", "🦻🏿" ) ], keywords = [ "accessibility", "ear with hearing aid", "hard of hearing" ] } )
        , ( "motorized_wheelchair", { name = "MOTORIZED WHEELCHAIR", native = "🦼", sortOrder = 919, skinVariations = Dict.fromList [], keywords = [ "accessibility", "motorized wheelchair" ] } )
        , ( "manual_wheelchair", { name = "MANUAL WHEELCHAIR", native = "🦽", sortOrder = 918, skinVariations = Dict.fromList [], keywords = [ "accessibility", "manual wheelchair" ] } )
        , ( "mechanical_arm", { name = "MECHANICAL ARM", native = "🦾", sortOrder = 211, skinVariations = Dict.fromList [], keywords = [ "accessibility", "mechanical arm", "prosthetic" ] } )
        , ( "mechanical_leg", { name = "MECHANICAL LEG", native = "🦿", sortOrder = 212, skinVariations = Dict.fromList [], keywords = [ "accessibility", "mechanical leg", "prosthetic" ] } )
        , ( "cheese_wedge", { name = "CHEESE WEDGE", native = "🧀", sortOrder = 731, skinVariations = Dict.fromList [], keywords = [ "cheese", "cheese wedge" ] } )
        , ( "cupcake", { name = "CUPCAKE", native = "🧁", sortOrder = 786, skinVariations = Dict.fromList [], keywords = [ "bakery", "cupcake", "sweet" ] } )
        , ( "salt", { name = "SALT SHAKER", native = "🧂", sortOrder = 755, skinVariations = Dict.fromList [], keywords = [ "condiment", "salt", "shaker" ] } )
        , ( "beverage_box", { name = "BEVERAGE BOX", native = "🧃", sortOrder = 810, skinVariations = Dict.fromList [], keywords = [ "beverage", "box", "juice", "straw", "sweet" ] } )
        , ( "garlic", { name = "GARLIC", native = "🧄", sortOrder = 716, skinVariations = Dict.fromList [], keywords = [ "flavoring", "garlic" ] } )
        , ( "onion", { name = "ONION", native = "🧅", sortOrder = 717, skinVariations = Dict.fromList [], keywords = [ "flavoring", "onion" ] } )
        , ( "falafel", { name = "FALAFEL", native = "🧆", sortOrder = 745, skinVariations = Dict.fromList [], keywords = [ "chickpea", "falafel", "meatball" ] } )
        , ( "waffle", { name = "WAFFLE", native = "🧇", sortOrder = 730, skinVariations = Dict.fromList [], keywords = [ "breakfast", "indecisive", "iron", "waffle" ] } )
        , ( "butter", { name = "BUTTER", native = "🧈", sortOrder = 754, skinVariations = Dict.fromList [], keywords = [ "butter", "dairy" ] } )
        , ( "mate_drink", { name = "MATE DRINK", native = "🧉", sortOrder = 811, skinVariations = Dict.fromList [], keywords = [ "drink", "mate" ] } )
        , ( "ice_cube", { name = "ICE CUBE", native = "🧊", sortOrder = 812, skinVariations = Dict.fromList [], keywords = [ "cold", "ice", "ice cube", "iceberg" ] } )
        , ( "bubble_tea", { name = "BUBBLE TEA", native = "🧋", sortOrder = 809, skinVariations = Dict.fromList [], keywords = [ "bubble", "milk", "pearl", "tea" ] } )
        , ( "troll", { name = "TROLL", native = "🧌", sortOrder = 399, skinVariations = Dict.fromList [], keywords = [ "fairy tale", "fantasy", "monster", "troll" ] } )
        , ( "woman_standing", { name = "WOMAN STANDING", native = "🧍\u{200D}♀️", sortOrder = 411, skinVariations = Dict.fromList [ ( "1F3FB", "🧍🏻\u{200D}♀️" ), ( "1F3FC", "🧍🏼\u{200D}♀️" ), ( "1F3FD", "🧍🏽\u{200D}♀️" ), ( "1F3FE", "🧍🏾\u{200D}♀️" ), ( "1F3FF", "🧍🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_standing", { name = "MAN STANDING", native = "🧍\u{200D}♂️", sortOrder = 410, skinVariations = Dict.fromList [ ( "1F3FB", "🧍🏻\u{200D}♂️" ), ( "1F3FC", "🧍🏼\u{200D}♂️" ), ( "1F3FD", "🧍🏽\u{200D}♂️" ), ( "1F3FE", "🧍🏾\u{200D}♂️" ), ( "1F3FF", "🧍🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "standing_person", { name = "STANDING PERSON", native = "🧍", sortOrder = 409, skinVariations = Dict.fromList [ ( "1F3FB", "🧍🏻" ), ( "1F3FC", "🧍🏼" ), ( "1F3FD", "🧍🏽" ), ( "1F3FE", "🧍🏾" ), ( "1F3FF", "🧍🏿" ) ], keywords = [ "person standing", "stand", "standing" ] } )
        , ( "woman_kneeling", { name = "WOMAN KNEELING", native = "🧎\u{200D}♀️", sortOrder = 414, skinVariations = Dict.fromList [ ( "1F3FB", "🧎🏻\u{200D}♀️" ), ( "1F3FC", "🧎🏼\u{200D}♀️" ), ( "1F3FD", "🧎🏽\u{200D}♀️" ), ( "1F3FE", "🧎🏾\u{200D}♀️" ), ( "1F3FF", "🧎🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_kneeling", { name = "MAN KNEELING", native = "🧎\u{200D}♂️", sortOrder = 413, skinVariations = Dict.fromList [ ( "1F3FB", "🧎🏻\u{200D}♂️" ), ( "1F3FC", "🧎🏼\u{200D}♂️" ), ( "1F3FD", "🧎🏽\u{200D}♂️" ), ( "1F3FE", "🧎🏾\u{200D}♂️" ), ( "1F3FF", "🧎🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "kneeling_person", { name = "KNEELING PERSON", native = "🧎", sortOrder = 412, skinVariations = Dict.fromList [ ( "1F3FB", "🧎🏻" ), ( "1F3FC", "🧎🏼" ), ( "1F3FD", "🧎🏽" ), ( "1F3FE", "🧎🏾" ), ( "1F3FF", "🧎🏿" ) ], keywords = [ "kneel", "kneeling", "person kneeling" ] } )
        , ( "deaf_woman", { name = "DEAF WOMAN", native = "🧏\u{200D}♀️", sortOrder = 276, skinVariations = Dict.fromList [ ( "1F3FB", "🧏🏻\u{200D}♀️" ), ( "1F3FC", "🧏🏼\u{200D}♀️" ), ( "1F3FD", "🧏🏽\u{200D}♀️" ), ( "1F3FE", "🧏🏾\u{200D}♀️" ), ( "1F3FF", "🧏🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "deaf_man", { name = "DEAF MAN", native = "🧏\u{200D}♂️", sortOrder = 275, skinVariations = Dict.fromList [ ( "1F3FB", "🧏🏻\u{200D}♂️" ), ( "1F3FC", "🧏🏼\u{200D}♂️" ), ( "1F3FD", "🧏🏽\u{200D}♂️" ), ( "1F3FE", "🧏🏾\u{200D}♂️" ), ( "1F3FF", "🧏🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "deaf_person", { name = "DEAF PERSON", native = "🧏", sortOrder = 274, skinVariations = Dict.fromList [ ( "1F3FB", "🧏🏻" ), ( "1F3FC", "🧏🏼" ), ( "1F3FD", "🧏🏽" ), ( "1F3FE", "🧏🏾" ), ( "1F3FF", "🧏🏿" ) ], keywords = [ "accessibility", "deaf", "deaf person", "ear", "hear" ] } )
        , ( "face_with_monocle", { name = "FACE WITH MONOCLE", native = "🧐", sortOrder = 73, skinVariations = Dict.fromList [], keywords = [ "face", "face with monocle", "monocle", "stuffy" ] } )
        , ( "farmer", { name = "FARMER", native = "🧑\u{200D}🌾", sortOrder = 298, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🌾" ), ( "1F3FC", "🧑🏼\u{200D}🌾" ), ( "1F3FD", "🧑🏽\u{200D}🌾" ), ( "1F3FE", "🧑🏾\u{200D}🌾" ), ( "1F3FF", "🧑🏿\u{200D}🌾" ) ], keywords = [ "farmer", "gardener", "rancher" ] } )
        , ( "cook", { name = "COOK", native = "🧑\u{200D}🍳", sortOrder = 301, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🍳" ), ( "1F3FC", "🧑🏼\u{200D}🍳" ), ( "1F3FD", "🧑🏽\u{200D}🍳" ), ( "1F3FE", "🧑🏾\u{200D}🍳" ), ( "1F3FF", "🧑🏿\u{200D}🍳" ) ], keywords = [ "chef", "cook" ] } )
        , ( "person_feeding_baby", { name = "PERSON FEEDING BABY", native = "🧑\u{200D}🍼", sortOrder = 367, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🍼" ), ( "1F3FC", "🧑🏼\u{200D}🍼" ), ( "1F3FD", "🧑🏽\u{200D}🍼" ), ( "1F3FE", "🧑🏾\u{200D}🍼" ), ( "1F3FF", "🧑🏿\u{200D}🍼" ) ], keywords = [ "baby", "feeding", "nursing", "person" ] } )
        , ( "mx_claus", { name = "MX CLAUS", native = "🧑\u{200D}🎄", sortOrder = 371, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🎄" ), ( "1F3FC", "🧑🏼\u{200D}🎄" ), ( "1F3FD", "🧑🏽\u{200D}🎄" ), ( "1F3FE", "🧑🏾\u{200D}🎄" ), ( "1F3FF", "🧑🏿\u{200D}🎄" ) ], keywords = [ "christmas", "claus", "mx claus" ] } )
        , ( "student", { name = "STUDENT", native = "🧑\u{200D}🎓", sortOrder = 289, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🎓" ), ( "1F3FC", "🧑🏼\u{200D}🎓" ), ( "1F3FD", "🧑🏽\u{200D}🎓" ), ( "1F3FE", "🧑🏾\u{200D}🎓" ), ( "1F3FF", "🧑🏿\u{200D}🎓" ) ], keywords = [ "graduate", "student" ] } )
        , ( "singer", { name = "SINGER", native = "🧑\u{200D}🎤", sortOrder = 319, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🎤" ), ( "1F3FC", "🧑🏼\u{200D}🎤" ), ( "1F3FD", "🧑🏽\u{200D}🎤" ), ( "1F3FE", "🧑🏾\u{200D}🎤" ), ( "1F3FF", "🧑🏿\u{200D}🎤" ) ], keywords = [ "actor", "entertainer", "rock", "singer", "star" ] } )
        , ( "artist", { name = "ARTIST", native = "🧑\u{200D}🎨", sortOrder = 322, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🎨" ), ( "1F3FC", "🧑🏼\u{200D}🎨" ), ( "1F3FD", "🧑🏽\u{200D}🎨" ), ( "1F3FE", "🧑🏾\u{200D}🎨" ), ( "1F3FF", "🧑🏿\u{200D}🎨" ) ], keywords = [ "artist", "palette" ] } )
        , ( "teacher", { name = "TEACHER", native = "🧑\u{200D}🏫", sortOrder = 292, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🏫" ), ( "1F3FC", "🧑🏼\u{200D}🏫" ), ( "1F3FD", "🧑🏽\u{200D}🏫" ), ( "1F3FE", "🧑🏾\u{200D}🏫" ), ( "1F3FF", "🧑🏿\u{200D}🏫" ) ], keywords = [ "instructor", "lecturer", "professor", "teacher" ] } )
        , ( "factory_worker", { name = "FACTORY WORKER", native = "🧑\u{200D}🏭", sortOrder = 307, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🏭" ), ( "1F3FC", "🧑🏼\u{200D}🏭" ), ( "1F3FD", "🧑🏽\u{200D}🏭" ), ( "1F3FE", "🧑🏾\u{200D}🏭" ), ( "1F3FF", "🧑🏿\u{200D}🏭" ) ], keywords = [ "assembly", "factory", "industrial", "worker" ] } )
        , ( "technologist", { name = "TECHNOLOGIST", native = "🧑\u{200D}💻", sortOrder = 316, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}💻" ), ( "1F3FC", "🧑🏼\u{200D}💻" ), ( "1F3FD", "🧑🏽\u{200D}💻" ), ( "1F3FE", "🧑🏾\u{200D}💻" ), ( "1F3FF", "🧑🏿\u{200D}💻" ) ], keywords = [ "coder", "developer", "inventor", "software", "technologist" ] } )
        , ( "office_worker", { name = "OFFICE WORKER", native = "🧑\u{200D}💼", sortOrder = 310, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}💼" ), ( "1F3FC", "🧑🏼\u{200D}💼" ), ( "1F3FD", "🧑🏽\u{200D}💼" ), ( "1F3FE", "🧑🏾\u{200D}💼" ), ( "1F3FF", "🧑🏿\u{200D}💼" ) ], keywords = [ "architect", "business", "manager", "office worker", "white-collar" ] } )
        , ( "mechanic", { name = "MECHANIC", native = "🧑\u{200D}🔧", sortOrder = 304, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🔧" ), ( "1F3FC", "🧑🏼\u{200D}🔧" ), ( "1F3FD", "🧑🏽\u{200D}🔧" ), ( "1F3FE", "🧑🏾\u{200D}🔧" ), ( "1F3FF", "🧑🏿\u{200D}🔧" ) ], keywords = [ "electrician", "mechanic", "plumber", "tradesperson" ] } )
        , ( "scientist", { name = "SCIENTIST", native = "🧑\u{200D}🔬", sortOrder = 313, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🔬" ), ( "1F3FC", "🧑🏼\u{200D}🔬" ), ( "1F3FD", "🧑🏽\u{200D}🔬" ), ( "1F3FE", "🧑🏾\u{200D}🔬" ), ( "1F3FF", "🧑🏿\u{200D}🔬" ) ], keywords = [ "biologist", "chemist", "engineer", "physicist", "scientist" ] } )
        , ( "astronaut", { name = "ASTRONAUT", native = "🧑\u{200D}🚀", sortOrder = 328, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🚀" ), ( "1F3FC", "🧑🏼\u{200D}🚀" ), ( "1F3FD", "🧑🏽\u{200D}🚀" ), ( "1F3FE", "🧑🏾\u{200D}🚀" ), ( "1F3FF", "🧑🏿\u{200D}🚀" ) ], keywords = [ "astronaut", "rocket" ] } )
        , ( "firefighter", { name = "FIREFIGHTER", native = "🧑\u{200D}🚒", sortOrder = 331, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🚒" ), ( "1F3FC", "🧑🏼\u{200D}🚒" ), ( "1F3FD", "🧑🏽\u{200D}🚒" ), ( "1F3FE", "🧑🏾\u{200D}🚒" ), ( "1F3FF", "🧑🏿\u{200D}🚒" ) ], keywords = [ "fire", "firefighter", "firetruck" ] } )
        , ( "people_holding_hands", { name = "PEOPLE HOLDING HANDS", native = "🧑\u{200D}🤝\u{200D}🧑", sortOrder = 487, skinVariations = Dict.fromList [ ( "1F3FB-1F3FB", "🧑🏻\u{200D}🤝\u{200D}🧑🏻" ), ( "1F3FB-1F3FC", "🧑🏻\u{200D}🤝\u{200D}🧑🏼" ), ( "1F3FB-1F3FD", "🧑🏻\u{200D}🤝\u{200D}🧑🏽" ), ( "1F3FB-1F3FE", "🧑🏻\u{200D}🤝\u{200D}🧑🏾" ), ( "1F3FB-1F3FF", "🧑🏻\u{200D}🤝\u{200D}🧑🏿" ), ( "1F3FC-1F3FB", "🧑🏼\u{200D}🤝\u{200D}🧑🏻" ), ( "1F3FC-1F3FC", "🧑🏼\u{200D}🤝\u{200D}🧑🏼" ), ( "1F3FC-1F3FD", "🧑🏼\u{200D}🤝\u{200D}🧑🏽" ), ( "1F3FC-1F3FE", "🧑🏼\u{200D}🤝\u{200D}🧑🏾" ), ( "1F3FC-1F3FF", "🧑🏼\u{200D}🤝\u{200D}🧑🏿" ), ( "1F3FD-1F3FB", "🧑🏽\u{200D}🤝\u{200D}🧑🏻" ), ( "1F3FD-1F3FC", "🧑🏽\u{200D}🤝\u{200D}🧑🏼" ), ( "1F3FD-1F3FD", "🧑🏽\u{200D}🤝\u{200D}🧑🏽" ), ( "1F3FD-1F3FE", "🧑🏽\u{200D}🤝\u{200D}🧑🏾" ), ( "1F3FD-1F3FF", "🧑🏽\u{200D}🤝\u{200D}🧑🏿" ), ( "1F3FE-1F3FB", "🧑🏾\u{200D}🤝\u{200D}🧑🏻" ), ( "1F3FE-1F3FC", "🧑🏾\u{200D}🤝\u{200D}🧑🏼" ), ( "1F3FE-1F3FD", "🧑🏾\u{200D}🤝\u{200D}🧑🏽" ), ( "1F3FE-1F3FE", "🧑🏾\u{200D}🤝\u{200D}🧑🏾" ), ( "1F3FE-1F3FF", "🧑🏾\u{200D}🤝\u{200D}🧑🏿" ), ( "1F3FF-1F3FB", "🧑🏿\u{200D}🤝\u{200D}🧑🏻" ), ( "1F3FF-1F3FC", "🧑🏿\u{200D}🤝\u{200D}🧑🏼" ), ( "1F3FF-1F3FD", "🧑🏿\u{200D}🤝\u{200D}🧑🏽" ), ( "1F3FF-1F3FE", "🧑🏿\u{200D}🤝\u{200D}🧑🏾" ), ( "1F3FF-1F3FF", "🧑🏿\u{200D}🤝\u{200D}🧑🏿" ) ], keywords = [ "couple", "hand", "hold", "holding hands", "people holding hands", "person" ] } )
        , ( "person_with_probing_cane", { name = "PERSON WITH WHITE CANE", native = "🧑\u{200D}🦯", sortOrder = 415, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦯" ), ( "1F3FC", "🧑🏼\u{200D}🦯" ), ( "1F3FD", "🧑🏽\u{200D}🦯" ), ( "1F3FE", "🧑🏾\u{200D}🦯" ), ( "1F3FF", "🧑🏿\u{200D}🦯" ) ], keywords = [ "accessibility", "blind", "person with white cane" ] } )
        , ( "red_haired_person", { name = "PERSON: RED HAIR", native = "🧑\u{200D}🦰", sortOrder = 244, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦰" ), ( "1F3FC", "🧑🏼\u{200D}🦰" ), ( "1F3FD", "🧑🏽\u{200D}🦰" ), ( "1F3FE", "🧑🏾\u{200D}🦰" ), ( "1F3FF", "🧑🏿\u{200D}🦰" ) ], keywords = [] } )
        , ( "curly_haired_person", { name = "PERSON: CURLY HAIR", native = "🧑\u{200D}🦱", sortOrder = 246, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦱" ), ( "1F3FC", "🧑🏼\u{200D}🦱" ), ( "1F3FD", "🧑🏽\u{200D}🦱" ), ( "1F3FE", "🧑🏾\u{200D}🦱" ), ( "1F3FF", "🧑🏿\u{200D}🦱" ) ], keywords = [] } )
        , ( "bald_person", { name = "PERSON: BALD", native = "🧑\u{200D}🦲", sortOrder = 250, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦲" ), ( "1F3FC", "🧑🏼\u{200D}🦲" ), ( "1F3FD", "🧑🏽\u{200D}🦲" ), ( "1F3FE", "🧑🏾\u{200D}🦲" ), ( "1F3FF", "🧑🏿\u{200D}🦲" ) ], keywords = [] } )
        , ( "white_haired_person", { name = "PERSON: WHITE HAIR", native = "🧑\u{200D}🦳", sortOrder = 248, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦳" ), ( "1F3FC", "🧑🏼\u{200D}🦳" ), ( "1F3FD", "🧑🏽\u{200D}🦳" ), ( "1F3FE", "🧑🏾\u{200D}🦳" ), ( "1F3FF", "🧑🏿\u{200D}🦳" ) ], keywords = [] } )
        , ( "person_in_motorized_wheelchair", { name = "PERSON IN MOTORIZED WHEELCHAIR", native = "🧑\u{200D}🦼", sortOrder = 418, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦼" ), ( "1F3FC", "🧑🏼\u{200D}🦼" ), ( "1F3FD", "🧑🏽\u{200D}🦼" ), ( "1F3FE", "🧑🏾\u{200D}🦼" ), ( "1F3FF", "🧑🏿\u{200D}🦼" ) ], keywords = [ "accessibility", "person in motorized wheelchair", "wheelchair" ] } )
        , ( "person_in_manual_wheelchair", { name = "PERSON IN MANUAL WHEELCHAIR", native = "🧑\u{200D}🦽", sortOrder = 421, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}🦽" ), ( "1F3FC", "🧑🏼\u{200D}🦽" ), ( "1F3FD", "🧑🏽\u{200D}🦽" ), ( "1F3FE", "🧑🏾\u{200D}🦽" ), ( "1F3FF", "🧑🏿\u{200D}🦽" ) ], keywords = [ "accessibility", "person in manual wheelchair", "wheelchair" ] } )
        , ( "health_worker", { name = "HEALTH WORKER", native = "🧑\u{200D}⚕️", sortOrder = 286, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}⚕️" ), ( "1F3FC", "🧑🏼\u{200D}⚕️" ), ( "1F3FD", "🧑🏽\u{200D}⚕️" ), ( "1F3FE", "🧑🏾\u{200D}⚕️" ), ( "1F3FF", "🧑🏿\u{200D}⚕️" ) ], keywords = [] } )
        , ( "judge", { name = "JUDGE", native = "🧑\u{200D}⚖️", sortOrder = 295, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}⚖️" ), ( "1F3FC", "🧑🏼\u{200D}⚖️" ), ( "1F3FD", "🧑🏽\u{200D}⚖️" ), ( "1F3FE", "🧑🏾\u{200D}⚖️" ), ( "1F3FF", "🧑🏿\u{200D}⚖️" ) ], keywords = [] } )
        , ( "pilot", { name = "PILOT", native = "🧑\u{200D}✈️", sortOrder = 325, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻\u{200D}✈️" ), ( "1F3FC", "🧑🏼\u{200D}✈️" ), ( "1F3FD", "🧑🏽\u{200D}✈️" ), ( "1F3FE", "🧑🏾\u{200D}✈️" ), ( "1F3FF", "🧑🏿\u{200D}✈️" ) ], keywords = [] } )
        , ( "adult", { name = "ADULT", native = "🧑", sortOrder = 232, skinVariations = Dict.fromList [ ( "1F3FB", "🧑🏻" ), ( "1F3FC", "🧑🏼" ), ( "1F3FD", "🧑🏽" ), ( "1F3FE", "🧑🏾" ), ( "1F3FF", "🧑🏿" ) ], keywords = [ "adult", "gender-neutral", "person", "unspecified gender" ] } )
        , ( "child", { name = "CHILD", native = "🧒", sortOrder = 229, skinVariations = Dict.fromList [ ( "1F3FB", "🧒🏻" ), ( "1F3FC", "🧒🏼" ), ( "1F3FD", "🧒🏽" ), ( "1F3FE", "🧒🏾" ), ( "1F3FF", "🧒🏿" ) ], keywords = [ "child", "gender-neutral", "unspecified gender", "young" ] } )
        , ( "older_adult", { name = "OLDER ADULT", native = "🧓", sortOrder = 253, skinVariations = Dict.fromList [ ( "1F3FB", "🧓🏻" ), ( "1F3FC", "🧓🏼" ), ( "1F3FD", "🧓🏽" ), ( "1F3FE", "🧓🏾" ), ( "1F3FF", "🧓🏿" ) ], keywords = [ "adult", "gender-neutral", "old", "older person", "unspecified gender" ] } )
        , ( "woman_with_beard", { name = "WOMAN: BEARD", native = "🧔\u{200D}♀️", sortOrder = 237, skinVariations = Dict.fromList [ ( "1F3FB", "🧔🏻\u{200D}♀️" ), ( "1F3FC", "🧔🏼\u{200D}♀️" ), ( "1F3FD", "🧔🏽\u{200D}♀️" ), ( "1F3FE", "🧔🏾\u{200D}♀️" ), ( "1F3FF", "🧔🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_with_beard", { name = "MAN: BEARD", native = "🧔\u{200D}♂️", sortOrder = 236, skinVariations = Dict.fromList [ ( "1F3FB", "🧔🏻\u{200D}♂️" ), ( "1F3FC", "🧔🏼\u{200D}♂️" ), ( "1F3FD", "🧔🏽\u{200D}♂️" ), ( "1F3FE", "🧔🏾\u{200D}♂️" ), ( "1F3FF", "🧔🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "bearded_person", { name = "BEARDED PERSON", native = "🧔", sortOrder = 235, skinVariations = Dict.fromList [ ( "1F3FB", "🧔🏻" ), ( "1F3FC", "🧔🏼" ), ( "1F3FD", "🧔🏽" ), ( "1F3FE", "🧔🏾" ), ( "1F3FF", "🧔🏿" ) ], keywords = [ "beard", "person", "person: beard" ] } )
        , ( "person_with_headscarf", { name = "PERSON WITH HEADSCARF", native = "🧕", sortOrder = 354, skinVariations = Dict.fromList [ ( "1F3FB", "🧕🏻" ), ( "1F3FC", "🧕🏼" ), ( "1F3FD", "🧕🏽" ), ( "1F3FE", "🧕🏾" ), ( "1F3FF", "🧕🏿" ) ], keywords = [ "headscarf", "hijab", "mantilla", "tichel", "woman with headscarf" ] } )
        , ( "woman_in_steamy_room", { name = "WOMAN IN STEAMY ROOM", native = "🧖\u{200D}♀️", sortOrder = 435, skinVariations = Dict.fromList [ ( "1F3FB", "🧖🏻\u{200D}♀️" ), ( "1F3FC", "🧖🏼\u{200D}♀️" ), ( "1F3FD", "🧖🏽\u{200D}♀️" ), ( "1F3FE", "🧖🏾\u{200D}♀️" ), ( "1F3FF", "🧖🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_in_steamy_room", { name = "MAN IN STEAMY ROOM", native = "🧖\u{200D}♂️", sortOrder = 434, skinVariations = Dict.fromList [ ( "1F3FB", "🧖🏻\u{200D}♂️" ), ( "1F3FC", "🧖🏼\u{200D}♂️" ), ( "1F3FD", "🧖🏽\u{200D}♂️" ), ( "1F3FE", "🧖🏾\u{200D}♂️" ), ( "1F3FF", "🧖🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_in_steamy_room", { name = "PERSON IN STEAMY ROOM", native = "🧖", sortOrder = 433, skinVariations = Dict.fromList [ ( "1F3FB", "🧖🏻" ), ( "1F3FC", "🧖🏼" ), ( "1F3FD", "🧖🏽" ), ( "1F3FE", "🧖🏾" ), ( "1F3FF", "🧖🏿" ) ], keywords = [ "person in steamy room", "sauna", "steam room" ] } )
        , ( "woman_climbing", { name = "WOMAN CLIMBING", native = "🧗\u{200D}♀️", sortOrder = 438, skinVariations = Dict.fromList [ ( "1F3FB", "🧗🏻\u{200D}♀️" ), ( "1F3FC", "🧗🏼\u{200D}♀️" ), ( "1F3FD", "🧗🏽\u{200D}♀️" ), ( "1F3FE", "🧗🏾\u{200D}♀️" ), ( "1F3FF", "🧗🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_climbing", { name = "MAN CLIMBING", native = "🧗\u{200D}♂️", sortOrder = 437, skinVariations = Dict.fromList [ ( "1F3FB", "🧗🏻\u{200D}♂️" ), ( "1F3FC", "🧗🏼\u{200D}♂️" ), ( "1F3FD", "🧗🏽\u{200D}♂️" ), ( "1F3FE", "🧗🏾\u{200D}♂️" ), ( "1F3FF", "🧗🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_climbing", { name = "PERSON CLIMBING", native = "🧗", sortOrder = 436, skinVariations = Dict.fromList [ ( "1F3FB", "🧗🏻" ), ( "1F3FC", "🧗🏼" ), ( "1F3FD", "🧗🏽" ), ( "1F3FE", "🧗🏾" ), ( "1F3FF", "🧗🏿" ) ], keywords = [ "climber", "person climbing" ] } )
        , ( "woman_in_lotus_position", { name = "WOMAN IN LOTUS POSITION", native = "🧘\u{200D}♀️", sortOrder = 484, skinVariations = Dict.fromList [ ( "1F3FB", "🧘🏻\u{200D}♀️" ), ( "1F3FC", "🧘🏼\u{200D}♀️" ), ( "1F3FD", "🧘🏽\u{200D}♀️" ), ( "1F3FE", "🧘🏾\u{200D}♀️" ), ( "1F3FF", "🧘🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man_in_lotus_position", { name = "MAN IN LOTUS POSITION", native = "🧘\u{200D}♂️", sortOrder = 483, skinVariations = Dict.fromList [ ( "1F3FB", "🧘🏻\u{200D}♂️" ), ( "1F3FC", "🧘🏼\u{200D}♂️" ), ( "1F3FD", "🧘🏽\u{200D}♂️" ), ( "1F3FE", "🧘🏾\u{200D}♂️" ), ( "1F3FF", "🧘🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_in_lotus_position", { name = "PERSON IN LOTUS POSITION", native = "🧘", sortOrder = 482, skinVariations = Dict.fromList [ ( "1F3FB", "🧘🏻" ), ( "1F3FC", "🧘🏼" ), ( "1F3FD", "🧘🏽" ), ( "1F3FE", "🧘🏾" ), ( "1F3FF", "🧘🏿" ) ], keywords = [ "meditation", "person in lotus position", "yoga" ] } )
        , ( "female_mage", { name = "WOMAN MAGE", native = "🧙\u{200D}♀️", sortOrder = 380, skinVariations = Dict.fromList [ ( "1F3FB", "🧙🏻\u{200D}♀️" ), ( "1F3FC", "🧙🏼\u{200D}♀️" ), ( "1F3FD", "🧙🏽\u{200D}♀️" ), ( "1F3FE", "🧙🏾\u{200D}♀️" ), ( "1F3FF", "🧙🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male_mage", { name = "MAN MAGE", native = "🧙\u{200D}♂️", sortOrder = 379, skinVariations = Dict.fromList [ ( "1F3FB", "🧙🏻\u{200D}♂️" ), ( "1F3FC", "🧙🏼\u{200D}♂️" ), ( "1F3FD", "🧙🏽\u{200D}♂️" ), ( "1F3FE", "🧙🏾\u{200D}♂️" ), ( "1F3FF", "🧙🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "mage", { name = "MAGE", native = "🧙", sortOrder = 378, skinVariations = Dict.fromList [ ( "1F3FB", "🧙🏻" ), ( "1F3FC", "🧙🏼" ), ( "1F3FD", "🧙🏽" ), ( "1F3FE", "🧙🏾" ), ( "1F3FF", "🧙🏿" ) ], keywords = [ "mage", "sorcerer", "sorceress", "witch", "wizard" ] } )
        , ( "female_fairy", { name = "WOMAN FAIRY", native = "🧚\u{200D}♀️", sortOrder = 383, skinVariations = Dict.fromList [ ( "1F3FB", "🧚🏻\u{200D}♀️" ), ( "1F3FC", "🧚🏼\u{200D}♀️" ), ( "1F3FD", "🧚🏽\u{200D}♀️" ), ( "1F3FE", "🧚🏾\u{200D}♀️" ), ( "1F3FF", "🧚🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male_fairy", { name = "MAN FAIRY", native = "🧚\u{200D}♂️", sortOrder = 382, skinVariations = Dict.fromList [ ( "1F3FB", "🧚🏻\u{200D}♂️" ), ( "1F3FC", "🧚🏼\u{200D}♂️" ), ( "1F3FD", "🧚🏽\u{200D}♂️" ), ( "1F3FE", "🧚🏾\u{200D}♂️" ), ( "1F3FF", "🧚🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "fairy", { name = "FAIRY", native = "🧚", sortOrder = 381, skinVariations = Dict.fromList [ ( "1F3FB", "🧚🏻" ), ( "1F3FC", "🧚🏼" ), ( "1F3FD", "🧚🏽" ), ( "1F3FE", "🧚🏾" ), ( "1F3FF", "🧚🏿" ) ], keywords = [ "fairy", "Oberon", "Puck", "Titania" ] } )
        , ( "female_vampire", { name = "WOMAN VAMPIRE", native = "🧛\u{200D}♀️", sortOrder = 386, skinVariations = Dict.fromList [ ( "1F3FB", "🧛🏻\u{200D}♀️" ), ( "1F3FC", "🧛🏼\u{200D}♀️" ), ( "1F3FD", "🧛🏽\u{200D}♀️" ), ( "1F3FE", "🧛🏾\u{200D}♀️" ), ( "1F3FF", "🧛🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male_vampire", { name = "MAN VAMPIRE", native = "🧛\u{200D}♂️", sortOrder = 385, skinVariations = Dict.fromList [ ( "1F3FB", "🧛🏻\u{200D}♂️" ), ( "1F3FC", "🧛🏼\u{200D}♂️" ), ( "1F3FD", "🧛🏽\u{200D}♂️" ), ( "1F3FE", "🧛🏾\u{200D}♂️" ), ( "1F3FF", "🧛🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "vampire", { name = "VAMPIRE", native = "🧛", sortOrder = 384, skinVariations = Dict.fromList [ ( "1F3FB", "🧛🏻" ), ( "1F3FC", "🧛🏼" ), ( "1F3FD", "🧛🏽" ), ( "1F3FE", "🧛🏾" ), ( "1F3FF", "🧛🏿" ) ], keywords = [ "Dracula", "undead", "vampire" ] } )
        , ( "mermaid", { name = "MERMAID", native = "🧜\u{200D}♀️", sortOrder = 389, skinVariations = Dict.fromList [ ( "1F3FB", "🧜🏻\u{200D}♀️" ), ( "1F3FC", "🧜🏼\u{200D}♀️" ), ( "1F3FD", "🧜🏽\u{200D}♀️" ), ( "1F3FE", "🧜🏾\u{200D}♀️" ), ( "1F3FF", "🧜🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "merman", { name = "MERMAN", native = "🧜\u{200D}♂️", sortOrder = 388, skinVariations = Dict.fromList [ ( "1F3FB", "🧜🏻\u{200D}♂️" ), ( "1F3FC", "🧜🏼\u{200D}♂️" ), ( "1F3FD", "🧜🏽\u{200D}♂️" ), ( "1F3FE", "🧜🏾\u{200D}♂️" ), ( "1F3FF", "🧜🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "merperson", { name = "MERPERSON", native = "🧜", sortOrder = 387, skinVariations = Dict.fromList [ ( "1F3FB", "🧜🏻" ), ( "1F3FC", "🧜🏼" ), ( "1F3FD", "🧜🏽" ), ( "1F3FE", "🧜🏾" ), ( "1F3FF", "🧜🏿" ) ], keywords = [ "mermaid", "merman", "merperson", "merwoman" ] } )
        , ( "female_elf", { name = "WOMAN ELF", native = "🧝\u{200D}♀️", sortOrder = 392, skinVariations = Dict.fromList [ ( "1F3FB", "🧝🏻\u{200D}♀️" ), ( "1F3FC", "🧝🏼\u{200D}♀️" ), ( "1F3FD", "🧝🏽\u{200D}♀️" ), ( "1F3FE", "🧝🏾\u{200D}♀️" ), ( "1F3FF", "🧝🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "male_elf", { name = "MAN ELF", native = "🧝\u{200D}♂️", sortOrder = 391, skinVariations = Dict.fromList [ ( "1F3FB", "🧝🏻\u{200D}♂️" ), ( "1F3FC", "🧝🏼\u{200D}♂️" ), ( "1F3FD", "🧝🏽\u{200D}♂️" ), ( "1F3FE", "🧝🏾\u{200D}♂️" ), ( "1F3FF", "🧝🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "elf", { name = "ELF", native = "🧝", sortOrder = 390, skinVariations = Dict.fromList [ ( "1F3FB", "🧝🏻" ), ( "1F3FC", "🧝🏼" ), ( "1F3FD", "🧝🏽" ), ( "1F3FE", "🧝🏾" ), ( "1F3FF", "🧝🏿" ) ], keywords = [ "elf", "magical" ] } )
        , ( "female_genie", { name = "WOMAN GENIE", native = "🧞\u{200D}♀️", sortOrder = 395, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "male_genie", { name = "MAN GENIE", native = "🧞\u{200D}♂️", sortOrder = 394, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "genie", { name = "GENIE", native = "🧞", sortOrder = 393, skinVariations = Dict.fromList [], keywords = [ "djinn", "genie" ] } )
        , ( "female_zombie", { name = "WOMAN ZOMBIE", native = "🧟\u{200D}♀️", sortOrder = 398, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "male_zombie", { name = "MAN ZOMBIE", native = "🧟\u{200D}♂️", sortOrder = 397, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "zombie", { name = "ZOMBIE", native = "🧟", sortOrder = 396, skinVariations = Dict.fromList [], keywords = [ "undead", "walking dead", "zombie" ] } )
        , ( "brain", { name = "BRAIN", native = "🧠", sortOrder = 218, skinVariations = Dict.fromList [], keywords = [ "brain", "intelligent" ] } )
        , ( "orange_heart", { name = "ORANGE HEART", native = "🧡", sortOrder = 143, skinVariations = Dict.fromList [], keywords = [ "orange", "orange heart" ] } )
        , ( "billed_cap", { name = "BILLED CAP", native = "🧢", sortOrder = 1163, skinVariations = Dict.fromList [], keywords = [ "baseball cap", "billed cap" ] } )
        , ( "scarf", { name = "SCARF", native = "🧣", sortOrder = 1131, skinVariations = Dict.fromList [], keywords = [ "neck", "scarf" ] } )
        , ( "gloves", { name = "GLOVES", native = "🧤", sortOrder = 1132, skinVariations = Dict.fromList [], keywords = [ "gloves", "hand" ] } )
        , ( "coat", { name = "COAT", native = "🧥", sortOrder = 1133, skinVariations = Dict.fromList [], keywords = [ "coat", "jacket" ] } )
        , ( "socks", { name = "SOCKS", native = "🧦", sortOrder = 1134, skinVariations = Dict.fromList [], keywords = [ "socks", "stocking" ] } )
        , ( "red_envelope", { name = "RED GIFT ENVELOPE", native = "🧧", sortOrder = 1053, skinVariations = Dict.fromList [], keywords = [ "gift", "good luck", "hóngbāo", "lai see", "money", "red envelope" ] } )
        , ( "firecracker", { name = "FIRECRACKER", native = "🧨", sortOrder = 1042, skinVariations = Dict.fromList [], keywords = [ "dynamite", "explosive", "firecracker", "fireworks" ] } )
        , ( "jigsaw", { name = "JIGSAW PUZZLE PIECE", native = "🧩", sortOrder = 1103, skinVariations = Dict.fromList [], keywords = [ "clue", "interlocking", "jigsaw", "piece", "puzzle" ] } )
        , ( "test_tube", { name = "TEST TUBE", native = "🧪", sortOrder = 1337, skinVariations = Dict.fromList [], keywords = [ "chemist", "chemistry", "experiment", "lab", "science", "test tube" ] } )
        , ( "petri_dish", { name = "PETRI DISH", native = "🧫", sortOrder = 1338, skinVariations = Dict.fromList [], keywords = [ "bacteria", "biologist", "biology", "culture", "lab", "petri dish" ] } )
        , ( "dna", { name = "DNA DOUBLE HELIX", native = "🧬", sortOrder = 1339, skinVariations = Dict.fromList [], keywords = [ "biologist", "dna", "evolution", "gene", "genetics", "life" ] } )
        , ( "compass", { name = "COMPASS", native = "🧭", sortOrder = 826, skinVariations = Dict.fromList [], keywords = [ "compass", "magnetic", "navigation", "orienteering" ] } )
        , ( "abacus", { name = "ABACUS", native = "🧮", sortOrder = 1218, skinVariations = Dict.fromList [], keywords = [ "abacus", "calculation" ] } )
        , ( "fire_extinguisher", { name = "FIRE EXTINGUISHER", native = "🧯", sortOrder = 1373, skinVariations = Dict.fromList [], keywords = [ "extinguish", "fire", "fire extinguisher", "quench" ] } )
        , ( "toolbox", { name = "TOOLBOX", native = "🧰", sortOrder = 1333, skinVariations = Dict.fromList [], keywords = [ "chest", "mechanic", "tool", "toolbox" ] } )
        , ( "bricks", { name = "BRICK", native = "🧱", sortOrder = 839, skinVariations = Dict.fromList [], keywords = [ "brick", "bricks", "clay", "mortar", "wall" ] } )
        , ( "magnet", { name = "MAGNET", native = "🧲", sortOrder = 1334, skinVariations = Dict.fromList [], keywords = [ "attraction", "horseshoe", "magnet", "magnetic" ] } )
        , ( "luggage", { name = "LUGGAGE", native = "🧳", sortOrder = 959, skinVariations = Dict.fromList [], keywords = [ "luggage", "packing", "travel" ] } )
        , ( "lotion_bottle", { name = "LOTION BOTTLE", native = "🧴", sortOrder = 1363, skinVariations = Dict.fromList [], keywords = [ "lotion", "lotion bottle", "moisturizer", "shampoo", "sunscreen" ] } )
        , ( "thread", { name = "SPOOL OF THREAD", native = "🧵", sortOrder = 1119, skinVariations = Dict.fromList [], keywords = [ "needle", "sewing", "spool", "string", "thread" ] } )
        , ( "yarn", { name = "BALL OF YARN", native = "🧶", sortOrder = 1121, skinVariations = Dict.fromList [], keywords = [ "ball", "crochet", "knit", "yarn" ] } )
        , ( "safety_pin", { name = "SAFETY PIN", native = "🧷", sortOrder = 1364, skinVariations = Dict.fromList [], keywords = [ "diaper", "punk rock", "safety pin" ] } )
        , ( "teddy_bear", { name = "TEDDY BEAR", native = "🧸", sortOrder = 1104, skinVariations = Dict.fromList [], keywords = [ "plaything", "plush", "stuffed", "teddy bear", "toy" ] } )
        , ( "broom", { name = "BROOM", native = "🧹", sortOrder = 1365, skinVariations = Dict.fromList [], keywords = [ "broom", "cleaning", "sweeping", "witch" ] } )
        , ( "basket", { name = "BASKET", native = "🧺", sortOrder = 1366, skinVariations = Dict.fromList [], keywords = [ "basket", "farming", "laundry", "picnic" ] } )
        , ( "roll_of_paper", { name = "ROLL OF PAPER", native = "🧻", sortOrder = 1367, skinVariations = Dict.fromList [], keywords = [ "paper towels", "roll of paper", "toilet paper" ] } )
        , ( "soap", { name = "BAR OF SOAP", native = "🧼", sortOrder = 1369, skinVariations = Dict.fromList [], keywords = [ "bar", "bathing", "cleaning", "lather", "soap", "soapdish" ] } )
        , ( "sponge", { name = "SPONGE", native = "🧽", sortOrder = 1372, skinVariations = Dict.fromList [], keywords = [ "absorbing", "cleaning", "porous", "sponge" ] } )
        , ( "receipt", { name = "RECEIPT", native = "🧾", sortOrder = 1260, skinVariations = Dict.fromList [], keywords = [ "accounting", "bookkeeping", "evidence", "proof", "receipt" ] } )
        , ( "nazar_amulet", { name = "NAZAR AMULET", native = "🧿", sortOrder = 1379, skinVariations = Dict.fromList [], keywords = [ "bead", "charm", "evil-eye", "nazar", "nazar amulet", "talisman" ] } )
        , ( "ballet_shoes", { name = "BALLET SHOES", native = "🩰", sortOrder = 1156, skinVariations = Dict.fromList [], keywords = [ "ballet", "ballet shoes", "dance" ] } )
        , ( "one-piece_swimsuit", { name = "ONE-PIECE SWIMSUIT", native = "🩱", sortOrder = 1138, skinVariations = Dict.fromList [], keywords = [ "bathing suit", "one-piece swimsuit" ] } )
        , ( "briefs", { name = "BRIEFS", native = "🩲", sortOrder = 1139, skinVariations = Dict.fromList [], keywords = [ "bathing suit", "briefs", "one-piece", "swimsuit", "underwear" ] } )
        , ( "shorts", { name = "SHORTS", native = "🩳", sortOrder = 1140, skinVariations = Dict.fromList [], keywords = [ "bathing suit", "pants", "shorts", "underwear" ] } )
        , ( "thong_sandal", { name = "THONG SANDAL", native = "🩴", sortOrder = 1149, skinVariations = Dict.fromList [], keywords = [ "beach sandals", "sandals", "thong sandal", "thong sandals", "thongs", "zōri" ] } )
        , ( "light_blue_heart", { name = "LIGHT BLUE HEART", native = "\u{1FA75}", sortOrder = 147, skinVariations = Dict.fromList [], keywords = [ "cyan", "heart", "light blue", "light blue heart", "teal" ] } )
        , ( "grey_heart", { name = "GREY HEART", native = "\u{1FA76}", sortOrder = 151, skinVariations = Dict.fromList [], keywords = [ "gray", "grey heart", "heart", "silver", "slate" ] } )
        , ( "pink_heart", { name = "PINK HEART", native = "\u{1FA77}", sortOrder = 142, skinVariations = Dict.fromList [], keywords = [ "cute", "heart", "like", "love", "pink" ] } )
        , ( "drop_of_blood", { name = "DROP OF BLOOD", native = "🩸", sortOrder = 1344, skinVariations = Dict.fromList [], keywords = [ "bleed", "blood donation", "drop of blood", "injury", "medicine", "menstruation" ] } )
        , ( "adhesive_bandage", { name = "ADHESIVE BANDAGE", native = "🩹", sortOrder = 1346, skinVariations = Dict.fromList [], keywords = [ "adhesive bandage", "bandage" ] } )
        , ( "stethoscope", { name = "STETHOSCOPE", native = "🩺", sortOrder = 1348, skinVariations = Dict.fromList [], keywords = [ "doctor", "heart", "medicine", "stethoscope" ] } )
        , ( "x-ray", { name = "X-RAY", native = "🩻", sortOrder = 1349, skinVariations = Dict.fromList [], keywords = [ "bones", "doctor", "medical", "skeleton", "x-ray" ] } )
        , ( "crutch", { name = "CRUTCH", native = "🩼", sortOrder = 1347, skinVariations = Dict.fromList [], keywords = [ "cane", "crutch", "disability", "hurt", "mobility aid", "stick" ] } )
        , ( "yo-yo", { name = "YO-YO", native = "🪀", sortOrder = 1093, skinVariations = Dict.fromList [], keywords = [ "fluctuate", "toy", "yo-yo" ] } )
        , ( "kite", { name = "KITE", native = "🪁", sortOrder = 1094, skinVariations = Dict.fromList [], keywords = [ "fly", "kite", "soar" ] } )
        , ( "parachute", { name = "PARACHUTE", native = "🪂", sortOrder = 949, skinVariations = Dict.fromList [], keywords = [ "hang-glide", "parachute", "parasail", "skydive" ] } )
        , ( "boomerang", { name = "BOOMERANG", native = "🪃", sortOrder = 1319, skinVariations = Dict.fromList [], keywords = [ "boomerang", "rebound", "repercussion" ] } )
        , ( "magic_wand", { name = "MAGIC WAND", native = "🪄", sortOrder = 1098, skinVariations = Dict.fromList [], keywords = [ "magic", "magic wand", "witch", "wizard" ] } )
        , ( "pinata", { name = "PINATA", native = "🪅", sortOrder = 1105, skinVariations = Dict.fromList [], keywords = [ "celebration", "party", "piñata" ] } )
        , ( "nesting_dolls", { name = "NESTING DOLLS", native = "🪆", sortOrder = 1107, skinVariations = Dict.fromList [], keywords = [ "doll", "nesting", "nesting dolls", "russia" ] } )
        , ( "maracas", { name = "MARACAS", native = "\u{1FA87}", sortOrder = 1197, skinVariations = Dict.fromList [], keywords = [ "instrument", "maracas", "music", "percussion", "rattle", "shake" ] } )
        , ( "flute", { name = "FLUTE", native = "\u{1FA88}", sortOrder = 1198, skinVariations = Dict.fromList [], keywords = [ "fife", "flute", "music", "pipe", "recorder", "woodwind" ] } )
        , ( "ringed_planet", { name = "RINGED PLANET", native = "🪐", sortOrder = 1007, skinVariations = Dict.fromList [], keywords = [ "ringed planet", "saturn", "saturnine" ] } )
        , ( "chair", { name = "CHAIR", native = "🪑", sortOrder = 1356, skinVariations = Dict.fromList [], keywords = [ "chair", "seat", "sit" ] } )
        , ( "razor", { name = "RAZOR", native = "🪒", sortOrder = 1362, skinVariations = Dict.fromList [], keywords = [ "razor", "sharp", "shave" ] } )
        , ( "axe", { name = "AXE", native = "🪓", sortOrder = 1312, skinVariations = Dict.fromList [], keywords = [ "axe", "chop", "hatchet", "split", "wood" ] } )
        , ( "diya_lamp", { name = "DIYA LAMP", native = "🪔", sortOrder = 1234, skinVariations = Dict.fromList [], keywords = [ "diya", "lamp", "oil" ] } )
        , ( "banjo", { name = "BANJO", native = "🪕", sortOrder = 1194, skinVariations = Dict.fromList [], keywords = [ "banjo", "music", "stringed" ] } )
        , ( "military_helmet", { name = "MILITARY HELMET", native = "🪖", sortOrder = 1164, skinVariations = Dict.fromList [], keywords = [ "army", "helmet", "military", "soldier", "warrior" ] } )
        , ( "accordion", { name = "ACCORDION", native = "🪗", sortOrder = 1189, skinVariations = Dict.fromList [], keywords = [ "accordion", "concertina", "squeeze box" ] } )
        , ( "long_drum", { name = "LONG DRUM", native = "🪘", sortOrder = 1196, skinVariations = Dict.fromList [], keywords = [ "beat", "conga", "drum", "long drum", "rhythm" ] } )
        , ( "coin", { name = "COIN", native = "🪙", sortOrder = 1253, skinVariations = Dict.fromList [], keywords = [ "coin", "gold", "metal", "money", "silver", "treasure" ] } )
        , ( "carpentry_saw", { name = "CARPENTRY SAW", native = "🪚", sortOrder = 1322, skinVariations = Dict.fromList [], keywords = [ "carpenter", "carpentry saw", "lumber", "saw", "tool" ] } )
        , ( "screwdriver", { name = "SCREWDRIVER", native = "🪛", sortOrder = 1324, skinVariations = Dict.fromList [], keywords = [ "screw", "screwdriver", "tool" ] } )
        , ( "ladder", { name = "LADDER", native = "🪜", sortOrder = 1335, skinVariations = Dict.fromList [], keywords = [ "climb", "ladder", "rung", "step" ] } )
        , ( "hook", { name = "HOOK", native = "🪝", sortOrder = 1332, skinVariations = Dict.fromList [], keywords = [ "catch", "crook", "curve", "ensnare", "hook", "selling point" ] } )
        , ( "mirror", { name = "MIRROR", native = "🪞", sortOrder = 1352, skinVariations = Dict.fromList [], keywords = [ "mirror", "reflection", "reflector", "speculum" ] } )
        , ( "window", { name = "WINDOW", native = "🪟", sortOrder = 1353, skinVariations = Dict.fromList [], keywords = [ "frame", "fresh air", "opening", "transparent", "view", "window" ] } )
        , ( "plunger", { name = "PLUNGER", native = "🪠", sortOrder = 1358, skinVariations = Dict.fromList [], keywords = [ "force cup", "plumber", "plunger", "suction", "toilet" ] } )
        , ( "sewing_needle", { name = "SEWING NEEDLE", native = "🪡", sortOrder = 1120, skinVariations = Dict.fromList [], keywords = [ "embroidery", "needle", "sewing", "stitches", "sutures", "tailoring" ] } )
        , ( "knot", { name = "KNOT", native = "🪢", sortOrder = 1122, skinVariations = Dict.fromList [], keywords = [ "knot", "rope", "tangled", "tie", "twine", "twist" ] } )
        , ( "bucket", { name = "BUCKET", native = "🪣", sortOrder = 1368, skinVariations = Dict.fromList [], keywords = [ "bucket", "cask", "pail", "vat" ] } )
        , ( "mouse_trap", { name = "MOUSE TRAP", native = "🪤", sortOrder = 1361, skinVariations = Dict.fromList [], keywords = [ "bait", "mouse trap", "mousetrap", "snare", "trap" ] } )
        , ( "toothbrush", { name = "TOOTHBRUSH", native = "🪥", sortOrder = 1371, skinVariations = Dict.fromList [], keywords = [ "bathroom", "brush", "clean", "dental", "hygiene", "teeth", "toothbrush" ] } )
        , ( "headstone", { name = "HEADSTONE", native = "🪦", sortOrder = 1377, skinVariations = Dict.fromList [], keywords = [ "cemetery", "grave", "graveyard", "headstone", "tombstone" ] } )
        , ( "placard", { name = "PLACARD", native = "🪧", sortOrder = 1382, skinVariations = Dict.fromList [], keywords = [ "demonstration", "picket", "placard", "protest", "sign" ] } )
        , ( "rock", { name = "ROCK", native = "🪨", sortOrder = 840, skinVariations = Dict.fromList [], keywords = [ "boulder", "heavy", "rock", "solid", "stone" ] } )
        , ( "mirror_ball", { name = "MIRROR BALL", native = "🪩", sortOrder = 1106, skinVariations = Dict.fromList [], keywords = [ "dance", "disco", "glitter", "mirror ball", "party" ] } )
        , ( "identification_card", { name = "IDENTIFICATION CARD", native = "🪪", sortOrder = 1383, skinVariations = Dict.fromList [], keywords = [ "credentials", "ID", "identification card", "license", "security" ] } )
        , ( "low_battery", { name = "LOW BATTERY", native = "🪫", sortOrder = 1206, skinVariations = Dict.fromList [], keywords = [ "electronic", "low battery", "low energy" ] } )
        , ( "hamsa", { name = "HAMSA", native = "🪬", sortOrder = 1380, skinVariations = Dict.fromList [], keywords = [ "amulet", "Fatima", "hamsa", "hand", "Mary", "Miriam", "protection" ] } )
        , ( "folding_hand_fan", { name = "FOLDING HAND FAN", native = "\u{1FAAD}", sortOrder = 1143, skinVariations = Dict.fromList [], keywords = [ "cooling", "dance", "fan", "flutter", "folding hand fan", "hot", "shy" ] } )
        , ( "hair_pick", { name = "HAIR PICK", native = "\u{1FAAE}", sortOrder = 1158, skinVariations = Dict.fromList [], keywords = [ "Afro", "comb", "hair", "pick" ] } )
        , ( "khanda", { name = "KHANDA", native = "\u{1FAAF}", sortOrder = 1443, skinVariations = Dict.fromList [], keywords = [ "khanda", "religion", "Sikh" ] } )
        , ( "fly", { name = "FLY", native = "🪰", sortOrder = 656, skinVariations = Dict.fromList [], keywords = [ "disease", "fly", "maggot", "pest", "rotting" ] } )
        , ( "worm", { name = "WORM", native = "🪱", sortOrder = 657, skinVariations = Dict.fromList [], keywords = [ "annelid", "earthworm", "parasite", "worm" ] } )
        , ( "beetle", { name = "BEETLE", native = "🪲", sortOrder = 648, skinVariations = Dict.fromList [], keywords = [ "beetle", "bug", "insect" ] } )
        , ( "cockroach", { name = "COCKROACH", native = "🪳", sortOrder = 651, skinVariations = Dict.fromList [], keywords = [ "cockroach", "insect", "pest", "roach" ] } )
        , ( "potted_plant", { name = "POTTED PLANT", native = "🪴", sortOrder = 672, skinVariations = Dict.fromList [], keywords = [ "boring", "grow", "house", "nurturing", "plant", "potted plant", "useless" ] } )
        , ( "wood", { name = "WOOD", native = "🪵", sortOrder = 841, skinVariations = Dict.fromList [], keywords = [ "log", "lumber", "timber", "wood" ] } )
        , ( "feather", { name = "FEATHER", native = "🪶", sortOrder = 615, skinVariations = Dict.fromList [], keywords = [ "bird", "feather", "flight", "light", "plumage" ] } )
        , ( "lotus", { name = "LOTUS", native = "🪷", sortOrder = 662, skinVariations = Dict.fromList [], keywords = [ "Buddhism", "flower", "Hinduism", "lotus", "purity" ] } )
        , ( "coral", { name = "CORAL", native = "🪸", sortOrder = 641, skinVariations = Dict.fromList [], keywords = [ "coral", "ocean", "reef" ] } )
        , ( "empty_nest", { name = "EMPTY NEST", native = "🪹", sortOrder = 684, skinVariations = Dict.fromList [], keywords = [ "empty nest", "nesting" ] } )
        , ( "nest_with_eggs", { name = "NEST WITH EGGS", native = "🪺", sortOrder = 685, skinVariations = Dict.fromList [], keywords = [ "nest with eggs", "nesting" ] } )
        , ( "hyacinth", { name = "HYACINTH", native = "\u{1FABB}", sortOrder = 670, skinVariations = Dict.fromList [], keywords = [ "bluebonnet", "flower", "hyacinth", "lavender", "lupine", "snapdragon" ] } )
        , ( "jellyfish", { name = "JELLYFISH", native = "\u{1FABC}", sortOrder = 642, skinVariations = Dict.fromList [], keywords = [ "burn", "invertebrate", "jelly", "jellyfish", "marine", "ouch", "stinger" ] } )
        , ( "wing", { name = "WING", native = "\u{1FABD}", sortOrder = 619, skinVariations = Dict.fromList [], keywords = [ "angelic", "aviation", "bird", "flying", "mythology", "wing" ] } )
        , ( "goose", { name = "GOOSE", native = "\u{1FABF}", sortOrder = 621, skinVariations = Dict.fromList [], keywords = [ "bird", "fowl", "goose", "honk", "silly" ] } )
        , ( "anatomical_heart", { name = "ANATOMICAL HEART", native = "🫀", sortOrder = 219, skinVariations = Dict.fromList [], keywords = [ "anatomical", "cardiology", "heart", "organ", "pulse" ] } )
        , ( "lungs", { name = "LUNGS", native = "🫁", sortOrder = 220, skinVariations = Dict.fromList [], keywords = [ "breath", "exhalation", "inhalation", "lungs", "organ", "respiration" ] } )
        , ( "people_hugging", { name = "PEOPLE HUGGING", native = "🫂", sortOrder = 528, skinVariations = Dict.fromList [], keywords = [ "goodbye", "hello", "hug", "people hugging", "thanks" ] } )
        , ( "pregnant_man", { name = "PREGNANT MAN", native = "🫃", sortOrder = 362, skinVariations = Dict.fromList [ ( "1F3FB", "🫃🏻" ), ( "1F3FC", "🫃🏼" ), ( "1F3FD", "🫃🏽" ), ( "1F3FE", "🫃🏾" ), ( "1F3FF", "🫃🏿" ) ], keywords = [ "belly", "bloated", "full", "pregnant", "pregnant man" ] } )
        , ( "pregnant_person", { name = "PREGNANT PERSON", native = "🫄", sortOrder = 363, skinVariations = Dict.fromList [ ( "1F3FB", "🫄🏻" ), ( "1F3FC", "🫄🏼" ), ( "1F3FD", "🫄🏽" ), ( "1F3FE", "🫄🏾" ), ( "1F3FF", "🫄🏿" ) ], keywords = [ "belly", "bloated", "full", "pregnant", "pregnant person" ] } )
        , ( "person_with_crown", { name = "PERSON WITH CROWN", native = "🫅", sortOrder = 347, skinVariations = Dict.fromList [ ( "1F3FB", "🫅🏻" ), ( "1F3FC", "🫅🏼" ), ( "1F3FD", "🫅🏽" ), ( "1F3FE", "🫅🏾" ), ( "1F3FF", "🫅🏿" ) ], keywords = [ "monarch", "noble", "person with crown", "regal", "royalty" ] } )
        , ( "moose", { name = "MOOSE", native = "\u{1FACE}", sortOrder = 555, skinVariations = Dict.fromList [], keywords = [ "animal", "antlers", "elk", "mammal", "moose" ] } )
        , ( "donkey", { name = "DONKEY", native = "\u{1FACF}", sortOrder = 556, skinVariations = Dict.fromList [], keywords = [ "animal", "ass", "burro", "donkey", "mammal", "mule", "stubborn" ] } )
        , ( "blueberries", { name = "BLUEBERRIES", native = "🫐", sortOrder = 701, skinVariations = Dict.fromList [], keywords = [ "berry", "bilberry", "blue", "blueberries", "blueberry" ] } )
        , ( "bell_pepper", { name = "BELL PEPPER", native = "🫑", sortOrder = 712, skinVariations = Dict.fromList [], keywords = [ "bell pepper", "capsicum", "pepper", "vegetable" ] } )
        , ( "olive", { name = "OLIVE", native = "🫒", sortOrder = 704, skinVariations = Dict.fromList [], keywords = [ "food", "olive" ] } )
        , ( "flatbread", { name = "FLATBREAD", native = "🫓", sortOrder = 726, skinVariations = Dict.fromList [], keywords = [ "arepa", "flatbread", "lavash", "naan", "pita" ] } )
        , ( "tamale", { name = "TAMALE", native = "🫔", sortOrder = 743, skinVariations = Dict.fromList [], keywords = [ "mexican", "tamale", "wrapped" ] } )
        , ( "fondue", { name = "FONDUE", native = "🫕", sortOrder = 750, skinVariations = Dict.fromList [], keywords = [ "cheese", "chocolate", "fondue", "melted", "pot", "Swiss" ] } )
        , ( "teapot", { name = "TEAPOT", native = "🫖", sortOrder = 796, skinVariations = Dict.fromList [], keywords = [ "drink", "pot", "tea", "teapot" ] } )
        , ( "pouring_liquid", { name = "POURING LIQUID", native = "🫗", sortOrder = 807, skinVariations = Dict.fromList [], keywords = [ "drink", "empty", "glass", "pouring liquid", "spill" ] } )
        , ( "beans", { name = "BEANS", native = "🫘", sortOrder = 719, skinVariations = Dict.fromList [], keywords = [ "beans", "food", "kidney", "legume" ] } )
        , ( "jar", { name = "JAR", native = "🫙", sortOrder = 818, skinVariations = Dict.fromList [], keywords = [ "condiment", "container", "empty", "jar", "sauce", "store" ] } )
        , ( "ginger_root", { name = "GINGER ROOT", native = "\u{1FADA}", sortOrder = 721, skinVariations = Dict.fromList [], keywords = [ "beer", "ginger root", "root", "spice" ] } )
        , ( "pea_pod", { name = "PEA POD", native = "\u{1FADB}", sortOrder = 722, skinVariations = Dict.fromList [], keywords = [ "beans", "edamame", "legume", "pea", "pod", "vegetable" ] } )
        , ( "melting_face", { name = "MELTING FACE", native = "🫠", sortOrder = 11, skinVariations = Dict.fromList [], keywords = [ "disappear", "dissolve", "liquid", "melt", "melting face" ] } )
        , ( "saluting_face", { name = "SALUTING FACE", native = "🫡", sortOrder = 36, skinVariations = Dict.fromList [], keywords = [ "OK", "salute", "saluting face", "sunny", "troops", "yes" ] } )
        , ( "face_with_open_eyes_and_hand_over_mouth", { name = "FACE WITH OPEN EYES AND HAND OVER MOUTH", native = "🫢", sortOrder = 32, skinVariations = Dict.fromList [], keywords = [ "amazement", "awe", "disbelief", "embarrass", "face with open eyes and hand over mouth", "scared", "surprise" ] } )
        , ( "face_with_peeking_eye", { name = "FACE WITH PEEKING EYE", native = "🫣", sortOrder = 33, skinVariations = Dict.fromList [], keywords = [ "captivated", "face with peeking eye", "peep", "stare" ] } )
        , ( "face_with_diagonal_mouth", { name = "FACE WITH DIAGONAL MOUTH", native = "🫤", sortOrder = 75, skinVariations = Dict.fromList [], keywords = [ "disappointed", "face with diagonal mouth", "meh", "skeptical", "unsure" ] } )
        , ( "dotted_line_face", { name = "DOTTED LINE FACE", native = "🫥", sortOrder = 42, skinVariations = Dict.fromList [], keywords = [ "depressed", "disappear", "dotted line face", "hide", "introvert", "invisible" ] } )
        , ( "biting_lip", { name = "BITING LIP", native = "🫦", sortOrder = 227, skinVariations = Dict.fromList [], keywords = [ "anxious", "biting lip", "fear", "flirting", "nervous", "uncomfortable", "worried" ] } )
        , ( "bubbles", { name = "BUBBLES", native = "🫧", sortOrder = 1370, skinVariations = Dict.fromList [], keywords = [ "bubbles", "burp", "clean", "soap", "underwater" ] } )
        , ( "shaking_face", { name = "SHAKING FACE", native = "\u{1FAE8}", sortOrder = 50, skinVariations = Dict.fromList [], keywords = [ "earthquake", "face", "shaking", "shock", "vibrate" ] } )
        , ( "hand_with_index_finger_and_thumb_crossed", { name = "HAND WITH INDEX FINGER AND THUMB CROSSED", native = "🫰", sortOrder = 183, skinVariations = Dict.fromList [ ( "1F3FB", "🫰🏻" ), ( "1F3FC", "🫰🏼" ), ( "1F3FD", "🫰🏽" ), ( "1F3FE", "🫰🏾" ), ( "1F3FF", "🫰🏿" ) ], keywords = [ "expensive", "hand with index finger and thumb crossed", "heart", "love", "money", "snap" ] } )
        , ( "rightwards_hand", { name = "RIGHTWARDS HAND", native = "🫱", sortOrder = 172, skinVariations = Dict.fromList [ ( "1F3FB", "🫱🏻" ), ( "1F3FC", "🫱🏼" ), ( "1F3FD", "🫱🏽" ), ( "1F3FE", "🫱🏾" ), ( "1F3FF", "🫱🏿" ) ], keywords = [ "hand", "right", "rightward", "rightwards hand" ] } )
        , ( "leftwards_hand", { name = "LEFTWARDS HAND", native = "🫲", sortOrder = 173, skinVariations = Dict.fromList [ ( "1F3FB", "🫲🏻" ), ( "1F3FC", "🫲🏼" ), ( "1F3FD", "🫲🏽" ), ( "1F3FE", "🫲🏾" ), ( "1F3FF", "🫲🏿" ) ], keywords = [ "hand", "left", "leftward", "leftwards hand" ] } )
        , ( "palm_down_hand", { name = "PALM DOWN HAND", native = "🫳", sortOrder = 174, skinVariations = Dict.fromList [ ( "1F3FB", "🫳🏻" ), ( "1F3FC", "🫳🏼" ), ( "1F3FD", "🫳🏽" ), ( "1F3FE", "🫳🏾" ), ( "1F3FF", "🫳🏿" ) ], keywords = [ "dismiss", "drop", "palm down hand", "shoo" ] } )
        , ( "palm_up_hand", { name = "PALM UP HAND", native = "🫴", sortOrder = 175, skinVariations = Dict.fromList [ ( "1F3FB", "🫴🏻" ), ( "1F3FC", "🫴🏼" ), ( "1F3FD", "🫴🏽" ), ( "1F3FE", "🫴🏾" ), ( "1F3FF", "🫴🏿" ) ], keywords = [ "beckon", "catch", "come", "offer", "palm up hand" ] } )
        , ( "index_pointing_at_the_viewer", { name = "INDEX POINTING AT THE VIEWER", native = "🫵", sortOrder = 193, skinVariations = Dict.fromList [ ( "1F3FB", "🫵🏻" ), ( "1F3FC", "🫵🏼" ), ( "1F3FD", "🫵🏽" ), ( "1F3FE", "🫵🏾" ), ( "1F3FF", "🫵🏿" ) ], keywords = [ "index pointing at the viewer", "point", "you" ] } )
        , ( "heart_hands", { name = "HEART HANDS", native = "🫶", sortOrder = 202, skinVariations = Dict.fromList [ ( "1F3FB", "🫶🏻" ), ( "1F3FC", "🫶🏼" ), ( "1F3FD", "🫶🏽" ), ( "1F3FE", "🫶🏾" ), ( "1F3FF", "🫶🏿" ) ], keywords = [ "heart hands", "love" ] } )
        , ( "leftwards_pushing_hand", { name = "LEFTWARDS PUSHING HAND", native = "\u{1FAF7}", sortOrder = 176, skinVariations = Dict.fromList [ ( "1F3FB", "\u{1FAF7}🏻" ), ( "1F3FC", "\u{1FAF7}🏼" ), ( "1F3FD", "\u{1FAF7}🏽" ), ( "1F3FE", "\u{1FAF7}🏾" ), ( "1F3FF", "\u{1FAF7}🏿" ) ], keywords = [ "high five", "leftward", "leftwards pushing hand", "push", "refuse", "stop", "wait" ] } )
        , ( "rightwards_pushing_hand", { name = "RIGHTWARDS PUSHING HAND", native = "\u{1FAF8}", sortOrder = 177, skinVariations = Dict.fromList [ ( "1F3FB", "\u{1FAF8}🏻" ), ( "1F3FC", "\u{1FAF8}🏼" ), ( "1F3FD", "\u{1FAF8}🏽" ), ( "1F3FE", "\u{1FAF8}🏾" ), ( "1F3FF", "\u{1FAF8}🏿" ) ], keywords = [ "high five", "push", "refuse", "rightward", "rightwards pushing hand", "stop", "wait" ] } )
        , ( "bangbang", { name = "DOUBLE EXCLAMATION MARK", native = "‼️", sortOrder = 1491, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "interrobang", { name = "EXCLAMATION QUESTION MARK", native = "⁉️", sortOrder = 1492, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "tm", { name = "TRADE MARK SIGN", native = "™️", sortOrder = 1520, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "information_source", { name = "INFORMATION SOURCE", native = "ℹ️", sortOrder = 1545, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "left_right_arrow", { name = "LEFT RIGHT ARROW", native = "↔️", sortOrder = 1419, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_up_down", { name = "UP DOWN ARROW", native = "↕️", sortOrder = 1418, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_upper_left", { name = "NORTH WEST ARROW", native = "↖️", sortOrder = 1417, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_upper_right", { name = "NORTH EAST ARROW", native = "↗️", sortOrder = 1411, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_lower_right", { name = "SOUTH EAST ARROW", native = "↘️", sortOrder = 1413, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_lower_left", { name = "SOUTH WEST ARROW", native = "↙️", sortOrder = 1415, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "leftwards_arrow_with_hook", { name = "LEFTWARDS ARROW WITH HOOK", native = "↩️", sortOrder = 1420, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_right_hook", { name = "RIGHTWARDS ARROW WITH HOOK", native = "↪️", sortOrder = 1421, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "watch", { name = "WATCH", native = "⌚", sortOrder = 962, skinVariations = Dict.fromList [], keywords = [ "clock", "watch" ] } )
        , ( "hourglass", { name = "HOURGLASS", native = "⌛", sortOrder = 960, skinVariations = Dict.fromList [], keywords = [ "hourglass done", "sand", "timer" ] } )
        , ( "keyboard", { name = "KEYBOARD", native = "⌨️", sortOrder = 1211, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "eject", { name = "EJECT BUTTON", native = "⏏️", sortOrder = 1474, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "fast_forward", { name = "BLACK RIGHT-POINTING DOUBLE TRIANGLE", native = "⏩", sortOrder = 1461, skinVariations = Dict.fromList [], keywords = [ "arrow", "double", "fast", "fast-forward button", "forward" ] } )
        , ( "rewind", { name = "BLACK LEFT-POINTING DOUBLE TRIANGLE", native = "⏪", sortOrder = 1465, skinVariations = Dict.fromList [], keywords = [ "arrow", "double", "fast reverse button", "rewind" ] } )
        , ( "arrow_double_up", { name = "BLACK UP-POINTING DOUBLE TRIANGLE", native = "⏫", sortOrder = 1468, skinVariations = Dict.fromList [], keywords = [ "arrow", "double", "fast up button" ] } )
        , ( "arrow_double_down", { name = "BLACK DOWN-POINTING DOUBLE TRIANGLE", native = "⏬", sortOrder = 1470, skinVariations = Dict.fromList [], keywords = [ "arrow", "double", "down", "fast down button" ] } )
        , ( "black_right_pointing_double_triangle_with_vertical_bar", { name = "NEXT TRACK BUTTON", native = "⏭️", sortOrder = 1462, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_left_pointing_double_triangle_with_vertical_bar", { name = "LAST TRACK BUTTON", native = "⏮️", sortOrder = 1466, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_right_pointing_triangle_with_double_vertical_bar", { name = "PLAY OR PAUSE BUTTON", native = "⏯️", sortOrder = 1463, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "alarm_clock", { name = "ALARM CLOCK", native = "⏰", sortOrder = 963, skinVariations = Dict.fromList [], keywords = [ "alarm", "clock" ] } )
        , ( "stopwatch", { name = "STOPWATCH", native = "⏱️", sortOrder = 964, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "timer_clock", { name = "TIMER CLOCK", native = "⏲️", sortOrder = 965, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "hourglass_flowing_sand", { name = "HOURGLASS WITH FLOWING SAND", native = "⏳", sortOrder = 961, skinVariations = Dict.fromList [], keywords = [ "hourglass", "hourglass not done", "sand", "timer" ] } )
        , ( "double_vertical_bar", { name = "PAUSE BUTTON", native = "⏸️", sortOrder = 1471, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_square_for_stop", { name = "STOP BUTTON", native = "⏹️", sortOrder = 1472, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_circle_for_record", { name = "RECORD BUTTON", native = "⏺️", sortOrder = 1473, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "m", { name = "CIRCLED LATIN CAPITAL LETTER M", native = "Ⓜ️", sortOrder = 1547, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_small_square", { name = "BLACK SMALL SQUARE", native = "▪️", sortOrder = 1595, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "white_small_square", { name = "WHITE SMALL SQUARE", native = "▫️", sortOrder = 1596, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_forward", { name = "BLACK RIGHT-POINTING TRIANGLE", native = "▶️", sortOrder = 1460, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_backward", { name = "BLACK LEFT-POINTING TRIANGLE", native = "◀️", sortOrder = 1464, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "white_medium_square", { name = "WHITE MEDIUM SQUARE", native = "◻️", sortOrder = 1592, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_medium_square", { name = "BLACK MEDIUM SQUARE", native = "◼️", sortOrder = 1591, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "white_medium_small_square", { name = "WHITE MEDIUM SMALL SQUARE", native = "◽", sortOrder = 1594, skinVariations = Dict.fromList [], keywords = [ "geometric", "square", "white medium-small square" ] } )
        , ( "black_medium_small_square", { name = "BLACK MEDIUM SMALL SQUARE", native = "◾", sortOrder = 1593, skinVariations = Dict.fromList [], keywords = [ "black medium-small square", "geometric", "square" ] } )
        , ( "sunny", { name = "BLACK SUN WITH RAYS", native = "☀️", sortOrder = 1004, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "cloud", { name = "CLOUD", native = "☁️", sortOrder = 1012, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "umbrella", { name = "UMBRELLA", native = "☂️", sortOrder = 1027, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "snowman", { name = "SNOWMAN", native = "☃️", sortOrder = 1032, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "comet", { name = "COMET", native = "☄️", sortOrder = 1034, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "phone", { name = "BLACK TELEPHONE", native = "☎️", sortOrder = 1201, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ballot_box_with_check", { name = "BALLOT BOX WITH CHECK", native = "☑️", sortOrder = 1508, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "umbrella_with_rain_drops", { name = "UMBRELLA WITH RAIN DROPS", native = "☔", sortOrder = 1028, skinVariations = Dict.fromList [], keywords = [ "clothing", "drop", "rain", "umbrella", "umbrella with rain drops" ] } )
        , ( "coffee", { name = "HOT BEVERAGE", native = "☕", sortOrder = 795, skinVariations = Dict.fromList [], keywords = [ "beverage", "coffee", "drink", "hot", "steaming", "tea" ] } )
        , ( "shamrock", { name = "SHAMROCK", native = "☘️", sortOrder = 679, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "point_up", { name = "WHITE UP POINTING INDEX", native = "☝️", sortOrder = 192, skinVariations = Dict.fromList [ ( "1F3FB", "☝🏻" ), ( "1F3FC", "☝🏼" ), ( "1F3FD", "☝🏽" ), ( "1F3FE", "☝🏾" ), ( "1F3FF", "☝🏿" ) ], keywords = [] } )
        , ( "skull_and_crossbones", { name = "SKULL AND CROSSBONES", native = "☠️", sortOrder = 107, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "radioactive_sign", { name = "RADIOACTIVE", native = "☢️", sortOrder = 1408, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "biohazard_sign", { name = "BIOHAZARD", native = "☣️", sortOrder = 1409, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "orthodox_cross", { name = "ORTHODOX CROSS", native = "☦️", sortOrder = 1438, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "star_and_crescent", { name = "STAR AND CRESCENT", native = "☪️", sortOrder = 1439, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "peace_symbol", { name = "PEACE SYMBOL", native = "☮️", sortOrder = 1440, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "yin_yang", { name = "YIN YANG", native = "☯️", sortOrder = 1436, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "wheel_of_dharma", { name = "WHEEL OF DHARMA", native = "☸️", sortOrder = 1435, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "white_frowning_face", { name = "FROWNING FACE", native = "☹️", sortOrder = 78, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "relaxed", { name = "WHITE SMILING FACE", native = "☺️", sortOrder = 20, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "female_sign", { name = "FEMALE SIGN", native = "♀️", sortOrder = 1482, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "male_sign", { name = "MALE SIGN", native = "♂️", sortOrder = 1483, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "aries", { name = "ARIES", native = "♈", sortOrder = 1444, skinVariations = Dict.fromList [], keywords = [ "Aries", "ram", "zodiac" ] } )
        , ( "taurus", { name = "TAURUS", native = "♉", sortOrder = 1445, skinVariations = Dict.fromList [], keywords = [ "bull", "ox", "Taurus", "zodiac" ] } )
        , ( "gemini", { name = "GEMINI", native = "♊", sortOrder = 1446, skinVariations = Dict.fromList [], keywords = [ "Gemini", "twins", "zodiac" ] } )
        , ( "cancer", { name = "CANCER", native = "♋", sortOrder = 1447, skinVariations = Dict.fromList [], keywords = [ "Cancer", "crab", "zodiac" ] } )
        , ( "leo", { name = "LEO", native = "♌", sortOrder = 1448, skinVariations = Dict.fromList [], keywords = [ "Leo", "lion", "zodiac" ] } )
        , ( "virgo", { name = "VIRGO", native = "♍", sortOrder = 1449, skinVariations = Dict.fromList [], keywords = [ "Virgo", "zodiac" ] } )
        , ( "libra", { name = "LIBRA", native = "♎", sortOrder = 1450, skinVariations = Dict.fromList [], keywords = [ "balance", "justice", "Libra", "scales", "zodiac" ] } )
        , ( "scorpius", { name = "SCORPIUS", native = "♏", sortOrder = 1451, skinVariations = Dict.fromList [], keywords = [ "Scorpio", "scorpion", "scorpius", "zodiac" ] } )
        , ( "sagittarius", { name = "SAGITTARIUS", native = "♐", sortOrder = 1452, skinVariations = Dict.fromList [], keywords = [ "archer", "Sagittarius", "zodiac" ] } )
        , ( "capricorn", { name = "CAPRICORN", native = "♑", sortOrder = 1453, skinVariations = Dict.fromList [], keywords = [ "Capricorn", "goat", "zodiac" ] } )
        , ( "aquarius", { name = "AQUARIUS", native = "♒", sortOrder = 1454, skinVariations = Dict.fromList [], keywords = [ "Aquarius", "bearer", "water", "zodiac" ] } )
        , ( "pisces", { name = "PISCES", native = "♓", sortOrder = 1455, skinVariations = Dict.fromList [], keywords = [ "fish", "Pisces", "zodiac" ] } )
        , ( "chess_pawn", { name = "CHESS PAWN", native = "♟️", sortOrder = 1112, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "spades", { name = "BLACK SPADE SUIT", native = "♠️", sortOrder = 1108, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "clubs", { name = "BLACK CLUB SUIT", native = "♣️", sortOrder = 1111, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "hearts", { name = "BLACK HEART SUIT", native = "♥️", sortOrder = 1109, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "diamonds", { name = "BLACK DIAMOND SUIT", native = "♦️", sortOrder = 1110, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "hotsprings", { name = "HOT SPRINGS", native = "♨️", sortOrder = 879, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "recycle", { name = "BLACK UNIVERSAL RECYCLING SYMBOL", native = "♻️", sortOrder = 1501, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "infinity", { name = "INFINITY", native = "♾️", sortOrder = 1490, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "wheelchair", { name = "WHEELCHAIR SYMBOL", native = "♿", sortOrder = 1387, skinVariations = Dict.fromList [], keywords = [ "access", "wheelchair symbol" ] } )
        , ( "hammer_and_pick", { name = "HAMMER AND PICK", native = "⚒️", sortOrder = 1314, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "anchor", { name = "ANCHOR", native = "⚓", sortOrder = 936, skinVariations = Dict.fromList [], keywords = [ "anchor", "ship", "tool" ] } )
        , ( "crossed_swords", { name = "CROSSED SWORDS", native = "⚔️", sortOrder = 1317, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "medical_symbol", { name = "MEDICAL SYMBOL", native = "⚕️", sortOrder = 1500, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "scales", { name = "BALANCE SCALE", native = "⚖️", sortOrder = 1328, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "alembic", { name = "ALEMBIC", native = "⚗️", sortOrder = 1336, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "gear", { name = "GEAR", native = "⚙️", sortOrder = 1326, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "atom_symbol", { name = "ATOM SYMBOL", native = "⚛️", sortOrder = 1432, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "fleur_de_lis", { name = "FLEUR-DE-LIS", native = "⚜️", sortOrder = 1502, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "warning", { name = "WARNING SIGN", native = "⚠️", sortOrder = 1397, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "zap", { name = "HIGH VOLTAGE SIGN", native = "⚡", sortOrder = 1030, skinVariations = Dict.fromList [], keywords = [ "danger", "electric", "high voltage", "lightning", "voltage", "zap" ] } )
        , ( "transgender_symbol", { name = "TRANSGENDER SYMBOL", native = "⚧️", sortOrder = 1484, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "white_circle", { name = "MEDIUM WHITE CIRCLE", native = "⚪", sortOrder = 1581, skinVariations = Dict.fromList [], keywords = [ "circle", "geometric", "white circle" ] } )
        , ( "black_circle", { name = "MEDIUM BLACK CIRCLE", native = "⚫", sortOrder = 1580, skinVariations = Dict.fromList [], keywords = [ "black circle", "circle", "geometric" ] } )
        , ( "coffin", { name = "COFFIN", native = "⚰️", sortOrder = 1376, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "funeral_urn", { name = "FUNERAL URN", native = "⚱️", sortOrder = 1378, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "soccer", { name = "SOCCER BALL", native = "⚽", sortOrder = 1065, skinVariations = Dict.fromList [], keywords = [ "ball", "football", "soccer" ] } )
        , ( "baseball", { name = "BASEBALL", native = "⚾", sortOrder = 1066, skinVariations = Dict.fromList [], keywords = [ "ball", "baseball" ] } )
        , ( "snowman_without_snow", { name = "SNOWMAN WITHOUT SNOW", native = "⛄", sortOrder = 1033, skinVariations = Dict.fromList [], keywords = [ "cold", "snow", "snowman", "snowman without snow" ] } )
        , ( "partly_sunny", { name = "SUN BEHIND CLOUD", native = "⛅", sortOrder = 1013, skinVariations = Dict.fromList [], keywords = [ "cloud", "sun", "sun behind cloud" ] } )
        , ( "thunder_cloud_and_rain", { name = "CLOUD WITH LIGHTNING AND RAIN", native = "⛈️", sortOrder = 1014, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ophiuchus", { name = "OPHIUCHUS", native = "⛎", sortOrder = 1456, skinVariations = Dict.fromList [], keywords = [ "bearer", "Ophiuchus", "serpent", "snake", "zodiac" ] } )
        , ( "pick", { name = "PICK", native = "⛏️", sortOrder = 1313, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "helmet_with_white_cross", { name = "RESCUE WORKER’S HELMET", native = "⛑️", sortOrder = 1165, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "chains", { name = "CHAINS", native = "⛓️", sortOrder = 1331, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "no_entry", { name = "NO ENTRY", native = "⛔", sortOrder = 1399, skinVariations = Dict.fromList [], keywords = [ "entry", "forbidden", "no", "not", "prohibited", "traffic" ] } )
        , ( "shinto_shrine", { name = "SHINTO SHRINE", native = "⛩️", sortOrder = 867, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "church", { name = "CHURCH", native = "⛪", sortOrder = 863, skinVariations = Dict.fromList [], keywords = [ "Christian", "church", "cross", "religion" ] } )
        , ( "mountain", { name = "MOUNTAIN", native = "⛰️", sortOrder = 828, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "umbrella_on_ground", { name = "UMBRELLA ON GROUND", native = "⛱️", sortOrder = 1029, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "fountain", { name = "FOUNTAIN", native = "⛲", sortOrder = 869, skinVariations = Dict.fromList [], keywords = [ "fountain" ] } )
        , ( "golf", { name = "FLAG IN HOLE", native = "⛳", sortOrder = 1084, skinVariations = Dict.fromList [], keywords = [ "flag in hole", "golf", "hole" ] } )
        , ( "ferry", { name = "FERRY", native = "⛴️", sortOrder = 942, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "boat", { name = "SAILBOAT", native = "⛵", sortOrder = 938, skinVariations = Dict.fromList [], keywords = [ "boat", "resort", "sailboat", "sea", "yacht" ] } )
        , ( "skier", { name = "SKIER", native = "⛷️", sortOrder = 441, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "ice_skate", { name = "ICE SKATE", native = "⛸️", sortOrder = 1085, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "woman-bouncing-ball", { name = "WOMAN BOUNCING BALL", native = "⛹️\u{200D}♀️", sortOrder = 457, skinVariations = Dict.fromList [ ( "1F3FB", "⛹🏻\u{200D}♀️" ), ( "1F3FC", "⛹🏼\u{200D}♀️" ), ( "1F3FD", "⛹🏽\u{200D}♀️" ), ( "1F3FE", "⛹🏾\u{200D}♀️" ), ( "1F3FF", "⛹🏿\u{200D}♀️" ) ], keywords = [] } )
        , ( "man-bouncing-ball", { name = "MAN BOUNCING BALL", native = "⛹️\u{200D}♂️", sortOrder = 456, skinVariations = Dict.fromList [ ( "1F3FB", "⛹🏻\u{200D}♂️" ), ( "1F3FC", "⛹🏼\u{200D}♂️" ), ( "1F3FD", "⛹🏽\u{200D}♂️" ), ( "1F3FE", "⛹🏾\u{200D}♂️" ), ( "1F3FF", "⛹🏿\u{200D}♂️" ) ], keywords = [] } )
        , ( "person_with_ball", { name = "PERSON BOUNCING BALL", native = "⛹️", sortOrder = 455, skinVariations = Dict.fromList [ ( "1F3FB", "⛹🏻" ), ( "1F3FC", "⛹🏼" ), ( "1F3FD", "⛹🏽" ), ( "1F3FE", "⛹🏾" ), ( "1F3FF", "⛹🏿" ) ], keywords = [] } )
        , ( "tent", { name = "TENT", native = "⛺", sortOrder = 870, skinVariations = Dict.fromList [], keywords = [ "camping", "tent" ] } )
        , ( "fuelpump", { name = "FUEL PUMP", native = "⛽", sortOrder = 929, skinVariations = Dict.fromList [], keywords = [ "diesel", "fuel", "fuelpump", "gas", "pump", "station" ] } )
        , ( "scissors", { name = "BLACK SCISSORS", native = "✂️", sortOrder = 1301, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "white_check_mark", { name = "WHITE HEAVY CHECK MARK", native = "✅", sortOrder = 1507, skinVariations = Dict.fromList [], keywords = [ "✓", "button", "check", "mark" ] } )
        , ( "airplane", { name = "AIRPLANE", native = "✈️", sortOrder = 945, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "email", { name = "ENVELOPE", native = "✉️", sortOrder = 1262, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "fist", { name = "RAISED FIST", native = "✊", sortOrder = 196, skinVariations = Dict.fromList [ ( "1F3FB", "✊🏻" ), ( "1F3FC", "✊🏼" ), ( "1F3FD", "✊🏽" ), ( "1F3FE", "✊🏾" ), ( "1F3FF", "✊🏿" ) ], keywords = [ "clenched", "fist", "hand", "punch", "raised fist" ] } )
        , ( "hand", { name = "RAISED HAND", native = "✋", sortOrder = 170, skinVariations = Dict.fromList [ ( "1F3FB", "✋🏻" ), ( "1F3FC", "✋🏼" ), ( "1F3FD", "✋🏽" ), ( "1F3FE", "✋🏾" ), ( "1F3FF", "✋🏿" ) ], keywords = [ "hand", "high 5", "high five", "raised hand" ] } )
        , ( "v", { name = "VICTORY HAND", native = "✌️", sortOrder = 181, skinVariations = Dict.fromList [ ( "1F3FB", "✌🏻" ), ( "1F3FC", "✌🏼" ), ( "1F3FD", "✌🏽" ), ( "1F3FE", "✌🏾" ), ( "1F3FF", "✌🏿" ) ], keywords = [] } )
        , ( "writing_hand", { name = "WRITING HAND", native = "✍️", sortOrder = 207, skinVariations = Dict.fromList [ ( "1F3FB", "✍🏻" ), ( "1F3FC", "✍🏼" ), ( "1F3FD", "✍🏽" ), ( "1F3FE", "✍🏾" ), ( "1F3FF", "✍🏿" ) ], keywords = [] } )
        , ( "pencil2", { name = "PENCIL", native = "✏️", sortOrder = 1275, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_nib", { name = "BLACK NIB", native = "✒️", sortOrder = 1276, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "heavy_check_mark", { name = "HEAVY CHECK MARK", native = "✔️", sortOrder = 1509, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "heavy_multiplication_x", { name = "HEAVY MULTIPLICATION X", native = "✖️", sortOrder = 1485, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "latin_cross", { name = "LATIN CROSS", native = "✝️", sortOrder = 1437, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "star_of_david", { name = "STAR OF DAVID", native = "✡️", sortOrder = 1434, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "sparkles", { name = "SPARKLES", native = "✨", sortOrder = 1043, skinVariations = Dict.fromList [], keywords = [ "*", "sparkle", "sparkles", "star" ] } )
        , ( "eight_spoked_asterisk", { name = "EIGHT SPOKED ASTERISK", native = "✳️", sortOrder = 1515, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "eight_pointed_black_star", { name = "EIGHT POINTED BLACK STAR", native = "✴️", sortOrder = 1516, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "snowflake", { name = "SNOWFLAKE", native = "❄️", sortOrder = 1031, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "sparkle", { name = "SPARKLE", native = "❇️", sortOrder = 1517, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "x", { name = "CROSS MARK", native = "❌", sortOrder = 1510, skinVariations = Dict.fromList [], keywords = [ "×", "cancel", "cross", "mark", "multiplication", "multiply", "x" ] } )
        , ( "negative_squared_cross_mark", { name = "NEGATIVE SQUARED CROSS MARK", native = "❎", sortOrder = 1511, skinVariations = Dict.fromList [], keywords = [ "×", "cross mark button", "mark", "square", "x" ] } )
        , ( "question", { name = "BLACK QUESTION MARK ORNAMENT", native = "❓", sortOrder = 1493, skinVariations = Dict.fromList [], keywords = [ "?", "mark", "punctuation", "question", "red question mark" ] } )
        , ( "grey_question", { name = "WHITE QUESTION MARK ORNAMENT", native = "❔", sortOrder = 1494, skinVariations = Dict.fromList [], keywords = [ "?", "mark", "outlined", "punctuation", "question", "white question mark" ] } )
        , ( "grey_exclamation", { name = "WHITE EXCLAMATION MARK ORNAMENT", native = "❕", sortOrder = 1495, skinVariations = Dict.fromList [], keywords = [ "!", "exclamation", "mark", "outlined", "punctuation", "white exclamation mark" ] } )
        , ( "exclamation", { name = "HEAVY EXCLAMATION MARK SYMBOL", native = "❗", sortOrder = 1496, skinVariations = Dict.fromList [], keywords = [ "!", "exclamation", "mark", "punctuation", "red exclamation mark" ] } )
        , ( "heavy_heart_exclamation_mark_ornament", { name = "HEART EXCLAMATION", native = "❣️", sortOrder = 137, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "heart_on_fire", { name = "HEART ON FIRE", native = "❤️\u{200D}🔥", sortOrder = 139, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "mending_heart", { name = "MENDING HEART", native = "❤️\u{200D}🩹", sortOrder = 140, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "heart", { name = "HEAVY BLACK HEART", native = "❤️", sortOrder = 141, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "heavy_plus_sign", { name = "HEAVY PLUS SIGN", native = "➕", sortOrder = 1486, skinVariations = Dict.fromList [], keywords = [ "+", "math", "plus", "sign" ] } )
        , ( "heavy_minus_sign", { name = "HEAVY MINUS SIGN", native = "➖", sortOrder = 1487, skinVariations = Dict.fromList [], keywords = [ "-", "−", "math", "minus", "sign" ] } )
        , ( "heavy_division_sign", { name = "HEAVY DIVISION SIGN", native = "➗", sortOrder = 1488, skinVariations = Dict.fromList [], keywords = [ "÷", "divide", "division", "math", "sign" ] } )
        , ( "arrow_right", { name = "BLACK RIGHTWARDS ARROW", native = "➡️", sortOrder = 1412, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "curly_loop", { name = "CURLY LOOP", native = "➰", sortOrder = 1512, skinVariations = Dict.fromList [], keywords = [ "curl", "curly loop", "loop" ] } )
        , ( "loop", { name = "DOUBLE CURLY LOOP", native = "➿", sortOrder = 1513, skinVariations = Dict.fromList [], keywords = [ "curl", "double", "double curly loop", "loop" ] } )
        , ( "arrow_heading_up", { name = "ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS", native = "⤴️", sortOrder = 1422, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_heading_down", { name = "ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS", native = "⤵️", sortOrder = 1423, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_left", { name = "LEFTWARDS BLACK ARROW", native = "⬅️", sortOrder = 1416, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_up", { name = "UPWARDS BLACK ARROW", native = "⬆️", sortOrder = 1410, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "arrow_down", { name = "DOWNWARDS BLACK ARROW", native = "⬇️", sortOrder = 1414, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "black_large_square", { name = "BLACK LARGE SQUARE", native = "⬛", sortOrder = 1589, skinVariations = Dict.fromList [], keywords = [ "black large square", "geometric", "square" ] } )
        , ( "white_large_square", { name = "WHITE LARGE SQUARE", native = "⬜", sortOrder = 1590, skinVariations = Dict.fromList [], keywords = [ "geometric", "square", "white large square" ] } )
        , ( "star", { name = "WHITE MEDIUM STAR", native = "⭐", sortOrder = 1008, skinVariations = Dict.fromList [], keywords = [ "star" ] } )
        , ( "o", { name = "HEAVY LARGE CIRCLE", native = "⭕", sortOrder = 1506, skinVariations = Dict.fromList [], keywords = [ "circle", "hollow red circle", "large", "o", "red" ] } )
        , ( "wavy_dash", { name = "WAVY DASH", native = "〰️", sortOrder = 1497, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "part_alternation_mark", { name = "PART ALTERNATION MARK", native = "〽️", sortOrder = 1514, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "congratulations", { name = "CIRCLED IDEOGRAPH CONGRATULATION", native = "㊗️", sortOrder = 1569, skinVariations = Dict.fromList [], keywords = [] } )
        , ( "secret", { name = "CIRCLED IDEOGRAPH SECRET", native = "㊙️", sortOrder = 1570, skinVariations = Dict.fromList [], keywords = [] } )
        ]
